/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtcore_python.h"

#include "qbitarray_wrapper.h"

// Extra includes
#include <qbitarray.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QBitArray_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QBitArray >()))
        return -1;

    QBitArray* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);

    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QBitArray(): too many arguments");
        return -1;
    }

    if (!PyArg_ParseTuple(args, "|OO:QBitArray", &(pyargs[0]), &(pyargs[1])))
        return -1;

    // Overloaded function decisor
    // 0: QBitArray()
    // 1: QBitArray(QBitArray)
    // 2: QBitArray(int,bool)
    if (numArgs == 0) {
        overloadId = 0; // QBitArray()
    } else if (SbkNumber_Check(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 2; // QBitArray(int,bool)
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 2; // QBitArray(int,bool)
        }
    } else if (numArgs == 1 && Shiboken::Converter< ::QBitArray >::isConvertible(pyargs[0])) {
        overloadId = 1; // QBitArray(QBitArray)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QBitArray_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QBitArray()
            {

                if(!PyErr_Occurred()) {
                    // QBitArray()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QBitArray();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // QBitArray(QBitArray)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QBitArray cppArg0 = Shiboken::Converter<QBitArray >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QBitArray(QBitArray)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QBitArray(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // QBitArray(int,bool)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "val");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "val";
                        else if (SbkNumber_Check(value))
                            pyargs[1] = value;
else
                            goto Sbk_QBitArray_Init_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtCore.QBitArray(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                bool cppArg1 = pyargs[1] ? Shiboken::Converter<bool >::toCpp(pyargs[1]) : false;

                if(!PyErr_Occurred()) {
                    // QBitArray(int,bool)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QBitArray(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QBitArray >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QBitArray_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QBitArray_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtCore.QBitArray", "int, bool = false", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QBitArray", overloads);
        return -1;
}

static PyObject* Sbk_QBitArrayFunc_at(PyObject* self, PyObject* arg)
{
    QBitArray* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QBitArray* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: at(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // at(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QBitArrayFunc_at_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // at(int)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->at(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QBitArrayFunc_at_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QBitArray.at", overloads);
        return 0;
}

static PyObject* Sbk_QBitArrayFunc_clear(PyObject* self)
{
    QBitArray* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QBitArray* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // clear()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->clear();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QBitArrayFunc_clearBit(PyObject* self, PyObject* arg)
{
    QBitArray* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QBitArray* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: clearBit(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // clearBit(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QBitArrayFunc_clearBit_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // clearBit(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->clearBit(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QBitArrayFunc_clearBit_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QBitArray.clearBit", overloads);
        return 0;
}

static PyObject* Sbk_QBitArrayFunc_count(PyObject* self, PyObject* args)
{
    QBitArray* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QBitArray* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "count", 0, 1, &(pyargs[0])))
        return 0;


    // Overloaded function decisor
    // 0: count()const
    // 1: count(bool)const
    if (numArgs == 0) {
        overloadId = 0; // count()const
    } else if (numArgs == 1 && SbkNumber_Check(pyargs[0])) {
        overloadId = 1; // count(bool)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QBitArrayFunc_count_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // count()const
            {

                if(!PyErr_Occurred()) {
                    // count()const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    int cppResult = cppSelf->count();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< int >::toPython(cppResult);
                }
                break;
            }
            case 1: // count(bool)const
            {
                bool cppArg0 = Shiboken::Converter<bool >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // count(bool)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    int cppResult = cppSelf->count(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< int >::toPython(cppResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QBitArrayFunc_count_TypeError:
        const char* overloads[] = {"", "bool", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QBitArray.count", overloads);
        return 0;
}

static PyObject* Sbk_QBitArrayFunc_fill(PyObject* self, PyObject* args)
{
    QBitArray* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QBitArray* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "fill", 3, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: fill(bool,int,int)
    if (numArgs == 3 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
        overloadId = 0; // fill(bool,int,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QBitArrayFunc_fill_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(pyargs[0]);
            int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
            int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

            if(!PyErr_Occurred()) {
                // fill(bool,int,int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->fill(cppArg0, cppArg1, cppArg2);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QBitArrayFunc_fill_TypeError:
        const char* overloads[] = {"bool, int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QBitArray.fill", overloads);
        return 0;
}

static PyObject* Sbk_QBitArrayFunc_isEmpty(PyObject* self)
{
    QBitArray* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QBitArray* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isEmpty()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->isEmpty();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QBitArrayFunc_isNull(PyObject* self)
{
    QBitArray* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QBitArray* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isNull()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->isNull();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QBitArrayFunc_resize(PyObject* self, PyObject* arg)
{
    QBitArray* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QBitArray* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: resize(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // resize(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QBitArrayFunc_resize_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // resize(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->resize(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QBitArrayFunc_resize_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QBitArray.resize", overloads);
        return 0;
}

static PyObject* Sbk_QBitArrayFunc_setBit(PyObject* self, PyObject* args)
{
    QBitArray* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QBitArray* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setBit", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setBit(int)
    // 1: setBit(int,bool)
    if (SbkNumber_Check(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // setBit(int)
        } else if (numArgs == 2 && SbkNumber_Check(pyargs[1])) {
            overloadId = 1; // setBit(int,bool)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QBitArrayFunc_setBit_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setBit(int)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // setBit(int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setBit(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // setBit(int,bool)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                bool cppArg1 = Shiboken::Converter<bool >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // setBit(int,bool)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setBit(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QBitArrayFunc_setBit_TypeError:
        const char* overloads[] = {"int", "int, bool", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QBitArray.setBit", overloads);
        return 0;
}

static PyObject* Sbk_QBitArrayFunc_size(PyObject* self)
{
    QBitArray* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QBitArray* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // size()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->size();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QBitArrayFunc_testBit(PyObject* self, PyObject* arg)
{
    QBitArray* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QBitArray* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: testBit(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // testBit(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QBitArrayFunc_testBit_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // testBit(int)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->testBit(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QBitArrayFunc_testBit_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QBitArray.testBit", overloads);
        return 0;
}

static PyObject* Sbk_QBitArrayFunc_toggleBit(PyObject* self, PyObject* arg)
{
    QBitArray* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QBitArray* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: toggleBit(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // toggleBit(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QBitArrayFunc_toggleBit_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // toggleBit(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->toggleBit(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QBitArrayFunc_toggleBit_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QBitArray.toggleBit", overloads);
        return 0;
}

static PyObject* Sbk_QBitArrayFunc_truncate(PyObject* self, PyObject* arg)
{
    QBitArray* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QBitArray* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: truncate(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // truncate(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QBitArrayFunc_truncate_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // truncate(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->truncate(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QBitArrayFunc_truncate_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QBitArray.truncate", overloads);
        return 0;
}

static PyObject *Sbk_QBitArray___copy__(PyObject *self)
{
        QBitArray* cppSelf = 0;
        if (!Shiboken::Object::isValid(self))
            return 0;
        cppSelf = Shiboken::Converter<QBitArray*>::toCpp(self);
        PyObject* pyResult = 0;
        QBitArray* copy = new QBitArray(*cppSelf);
        pyResult = Shiboken::Converter<QBitArray*>::toPython(copy);
        Shiboken::Object::getOwnership(pyResult);

        if (PyErr_Occurred() || !pyResult) {
            Py_XDECREF(pyResult);
            return 0;
        }
        return pyResult;
}

static PyMethodDef Sbk_QBitArray_methods[] = {
    {"at", (PyCFunction)Sbk_QBitArrayFunc_at, METH_O},
    {"clear", (PyCFunction)Sbk_QBitArrayFunc_clear, METH_NOARGS},
    {"clearBit", (PyCFunction)Sbk_QBitArrayFunc_clearBit, METH_O},
    {"count", (PyCFunction)Sbk_QBitArrayFunc_count, METH_VARARGS},
    {"fill", (PyCFunction)Sbk_QBitArrayFunc_fill, METH_VARARGS},
    {"isEmpty", (PyCFunction)Sbk_QBitArrayFunc_isEmpty, METH_NOARGS},
    {"isNull", (PyCFunction)Sbk_QBitArrayFunc_isNull, METH_NOARGS},
    {"resize", (PyCFunction)Sbk_QBitArrayFunc_resize, METH_O},
    {"setBit", (PyCFunction)Sbk_QBitArrayFunc_setBit, METH_VARARGS},
    {"size", (PyCFunction)Sbk_QBitArrayFunc_size, METH_NOARGS},
    {"testBit", (PyCFunction)Sbk_QBitArrayFunc_testBit, METH_O},
    {"toggleBit", (PyCFunction)Sbk_QBitArrayFunc_toggleBit, METH_O},
    {"truncate", (PyCFunction)Sbk_QBitArrayFunc_truncate, METH_O},

    {"__copy__", (PyCFunction)Sbk_QBitArray___copy__, METH_NOARGS},
    {0} // Sentinel
};

static PyObject* Sbk_QBitArrayFunc___and__(PyObject* self, PyObject* arg)
{
    QBitArray* cppSelf = 0;
    bool isReverse = Shiboken::Converter< ::QBitArray >::checkType(arg) && !Shiboken::Converter< ::QBitArray >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QBitArray* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && Shiboken::Object::checkType(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rand__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rand__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator&(QBitArray,QBitArray)
    if (!isReverse && Shiboken::Converter< ::QBitArray >::isConvertible(arg)) {
        overloadId = 0; // operator&(QBitArray,QBitArray)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QBitArrayFunc___and___TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QBitArray cppArg0 = Shiboken::Converter<QBitArray >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // operator&(QBitArray,QBitArray)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QBitArray cppResult = (*cppSelf) & (cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QBitArray >::toPython(cppResult);
            }
        }
    }


    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QBitArrayFunc___and___TypeError:
        const char* overloads[] = {"PySide.QtCore.QBitArray", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QBitArray.__and__", overloads);
        return 0;
}

static PyObject* Sbk_QBitArrayFunc___iand__(PyObject* self, PyObject* arg)
{
    QBitArray* cppSelf = 0;
    bool isReverse = Shiboken::Converter< ::QBitArray >::checkType(arg) && !Shiboken::Converter< ::QBitArray >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QBitArray* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: operator&=(QBitArray)
    if (!isReverse && Shiboken::Converter< ::QBitArray >::isConvertible(arg)) {
        overloadId = 0; // operator&=(QBitArray)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QBitArrayFunc___iand___TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QBitArray cppArg0 = Shiboken::Converter<QBitArray >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // operator&=(QBitArray)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (*cppSelf) &= (cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_INCREF(self);
    return self;

    Sbk_QBitArrayFunc___iand___TypeError:
        const char* overloads[] = {"PySide.QtCore.QBitArray", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QBitArray.__iand__", overloads);
        return 0;
}

static PyObject* Sbk_QBitArrayFunc___xor__(PyObject* self, PyObject* arg)
{
    QBitArray* cppSelf = 0;
    bool isReverse = Shiboken::Converter< ::QBitArray >::checkType(arg) && !Shiboken::Converter< ::QBitArray >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QBitArray* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && Shiboken::Object::checkType(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rxor__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rxor__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator^(QBitArray,QBitArray)
    if (!isReverse && Shiboken::Converter< ::QBitArray >::isConvertible(arg)) {
        overloadId = 0; // operator^(QBitArray,QBitArray)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QBitArrayFunc___xor___TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QBitArray cppArg0 = Shiboken::Converter<QBitArray >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // operator^(QBitArray,QBitArray)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QBitArray cppResult = (*cppSelf) ^ (cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QBitArray >::toPython(cppResult);
            }
        }
    }


    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QBitArrayFunc___xor___TypeError:
        const char* overloads[] = {"PySide.QtCore.QBitArray", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QBitArray.__xor__", overloads);
        return 0;
}

static PyObject* Sbk_QBitArrayFunc___ixor__(PyObject* self, PyObject* arg)
{
    QBitArray* cppSelf = 0;
    bool isReverse = Shiboken::Converter< ::QBitArray >::checkType(arg) && !Shiboken::Converter< ::QBitArray >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QBitArray* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: operator^=(QBitArray)
    if (!isReverse && Shiboken::Converter< ::QBitArray >::isConvertible(arg)) {
        overloadId = 0; // operator^=(QBitArray)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QBitArrayFunc___ixor___TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QBitArray cppArg0 = Shiboken::Converter<QBitArray >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // operator^=(QBitArray)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (*cppSelf) ^= (cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_INCREF(self);
    return self;

    Sbk_QBitArrayFunc___ixor___TypeError:
        const char* overloads[] = {"PySide.QtCore.QBitArray", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QBitArray.__ixor__", overloads);
        return 0;
}

static PyObject* Sbk_QBitArrayFunc___or__(PyObject* self, PyObject* arg)
{
    QBitArray* cppSelf = 0;
    bool isReverse = Shiboken::Converter< ::QBitArray >::checkType(arg) && !Shiboken::Converter< ::QBitArray >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QBitArray* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && Shiboken::Object::checkType(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__ror__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__ror__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator|(QBitArray,QBitArray)
    if (!isReverse && Shiboken::Converter< ::QBitArray >::isConvertible(arg)) {
        overloadId = 0; // operator|(QBitArray,QBitArray)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QBitArrayFunc___or___TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QBitArray cppArg0 = Shiboken::Converter<QBitArray >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // operator|(QBitArray,QBitArray)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QBitArray cppResult = (*cppSelf) | (cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QBitArray >::toPython(cppResult);
            }
        }
    }


    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QBitArrayFunc___or___TypeError:
        const char* overloads[] = {"PySide.QtCore.QBitArray", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QBitArray.__or__", overloads);
        return 0;
}

static PyObject* Sbk_QBitArrayFunc___ior__(PyObject* self, PyObject* arg)
{
    QBitArray* cppSelf = 0;
    bool isReverse = Shiboken::Converter< ::QBitArray >::checkType(arg) && !Shiboken::Converter< ::QBitArray >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QBitArray* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: operator|=(QBitArray)
    if (!isReverse && Shiboken::Converter< ::QBitArray >::isConvertible(arg)) {
        overloadId = 0; // operator|=(QBitArray)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QBitArrayFunc___ior___TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QBitArray cppArg0 = Shiboken::Converter<QBitArray >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // operator|=(QBitArray)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (*cppSelf) |= (cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_INCREF(self);
    return self;

    Sbk_QBitArrayFunc___ior___TypeError:
        const char* overloads[] = {"PySide.QtCore.QBitArray", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QBitArray.__ior__", overloads);
        return 0;
}

static PyObject* Sbk_QBitArrayFunc___invert__(PyObject* self)
{
    QBitArray* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QBitArray* >::toCpp(self);

    PyObject* pyResult = 0;

    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // operator~()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QBitArray cppResult = ~ (*cppSelf);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QBitArray >::toPython(cppResult);
            }
        }
    }


    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

// type has number operators
static PyNumberMethods Sbk_QBitArray_as_number = {
    /*nb_add*/                  (binaryfunc)0,
    /*nb_subtract*/             (binaryfunc)0,
    /*nb_multiply*/             (binaryfunc)0,
    /*nb_divide*/               (binaryfunc)0,
    /*nb_remainder*/            (binaryfunc)0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             (unaryfunc)0,
    /*nb_positive*/             (unaryfunc)0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              0,
    /*nb_invert*/               (unaryfunc)Sbk_QBitArrayFunc___invert__,
    /*nb_lshift*/               (binaryfunc)0,
    /*nb_rshift*/               (binaryfunc)0,
    /*nb_and*/                  (binaryfunc)Sbk_QBitArrayFunc___and__,
    /*nb_xor*/                  (binaryfunc)Sbk_QBitArrayFunc___xor__,
    /*nb_or*/                   (binaryfunc)Sbk_QBitArrayFunc___or__,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          (binaryfunc)0,
    /*nb_inplace_subtract*/     (binaryfunc)0,
    /*nb_inplace_multiply*/     (binaryfunc)0,
    /*nb_inplace_divide*/       (binaryfunc)0,
    /*nb_inplace_remainder*/    (binaryfunc)0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       (binaryfunc)0,
    /*nb_inplace_rshift*/       (binaryfunc)0,
    /*nb_inplace_and*/          (binaryfunc)Sbk_QBitArrayFunc___iand__,
    /*nb_inplace_xor*/          (binaryfunc)Sbk_QBitArrayFunc___ixor__,
    /*nb_inplace_or*/           (binaryfunc)Sbk_QBitArrayFunc___ior__,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          (binaryfunc)0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};

Py_ssize_t Sbk_QBitArrayFunc___len__(PyObject* self)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    QBitArray* cppSelf = Shiboken::Converter< QBitArray* >::toCpp(self);
    (void)cppSelf; // avoid warnings about unused variables
    // Begin code injection
    
    return cppSelf->size();
    
    // End of code injection
}

PyObject* Sbk_QBitArrayFunc___getitem__(PyObject* self, Py_ssize_t _i)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    QBitArray* cppSelf = Shiboken::Converter< QBitArray* >::toCpp(self);
    (void)cppSelf; // avoid warnings about unused variables
    // Begin code injection
    
    if (_i < 0 || _i >= cppSelf->size()) {
        PyErr_SetString(PyExc_IndexError, "index out of bounds");
        return 0;
    }
    return Shiboken::Converter<bool >::toPython(cppSelf->at(_i));
    
    // End of code injection
}

int Sbk_QBitArrayFunc___setitem__(PyObject* self, Py_ssize_t _i, PyObject* _value)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    QBitArray* cppSelf = Shiboken::Converter< QBitArray* >::toCpp(self);
    (void)cppSelf; // avoid warnings about unused variables
    // Begin code injection
    
    PyObject* args = Py_BuildValue("(iiO)", _i, 1, _value);
    PyObject* result = Sbk_QBitArrayFunc_setBit(self, args);
    Py_DECREF(args);
    Py_XDECREF(result);
    return !result ? -1 : 0;
    
    // End of code injection
}

static PySequenceMethods PyQBitArray_as_sequence = {
    /*sq_length*/ &Sbk_QBitArrayFunc___len__,
    /*sq_concat*/ 0,
    /*sq_repeat*/ 0,
    /*sq_item*/ &Sbk_QBitArrayFunc___getitem__,
    /*sq_slice*/ 0,
    /*sq_ass_item*/ &Sbk_QBitArrayFunc___setitem__,
    /*sq_ass_slice*/ 0,
    /*sq_contains*/ 0,
    /*sq_inplace_concat*/ 0,
    /*sq_inplace_repeat*/ 0
};

// Rich comparison
static PyObject* Sbk_QBitArray_richcompare(PyObject* self, PyObject* arg, int op)
{
    PyObject* pyResult = 0;
    QBitArray& cppSelf = *Shiboken::Converter< QBitArray* >::toCpp(self);

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter< ::QBitArray >::isConvertible(arg)) {
                // operator!=(const QBitArray & a) const
                QBitArray cppArg0 = Shiboken::Converter< ::QBitArray >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf != cppArg0);
            } else goto Sbk_QBitArray_RichComparison_TypeError;

            break;
        case Py_EQ:
            if (Shiboken::Converter< ::QBitArray >::isConvertible(arg)) {
                // operator==(const QBitArray & a) const
                QBitArray cppArg0 = Shiboken::Converter< ::QBitArray >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf == cppArg0);
            } else goto Sbk_QBitArray_RichComparison_TypeError;

            break;
        default:
            goto Sbk_QBitArray_RichComparison_TypeError;
    }

    if (pyResult && !PyErr_Occurred())
        return pyResult;
    Sbk_QBitArray_RichComparison_TypeError:
    PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
    return 0;

}

} // extern "C"

static long Sbk_QBitArray_HashFunc(PyObject* obj){
    return qHash(Shiboken::Converter< ::QBitArray >::toCpp(obj));
}

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QBitArray_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtCore.QBitArray",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        &Sbk_QBitArray_as_number,
    /*tp_as_sequence*/      &PyQBitArray_as_sequence,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             &Sbk_QBitArray_HashFunc,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      Sbk_QBitArray_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QBitArray_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QBitArray_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QBitArray(PyObject* module)
{
    SbkPySide_QtCoreTypes[SBK_QBITARRAY_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QBitArray_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QBitArray_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QBitArray_Type, &Shiboken::callCppDestructor<QBitArray >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QBitArray_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QBitArray_Type, "QBitArray");
    PyModule_AddObject(module, "QBitArray",
        ((PyObject*)&Sbk_QBitArray_Type));


    Shiboken::TypeResolver::createValueTypeResolver<QBitArray >("QBitArray");
    Shiboken::TypeResolver::createObjectTypeResolver<QBitArray >("QBitArray*");
    Shiboken::TypeResolver::createValueTypeResolver<QBitArray >(typeid(QBitArray).name());
    PySide::initQtMetaType<QBitArray >();
}

