/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtcore_python.h"

#include "qbytearraymatcher_wrapper.h"

// Extra includes
#include <qbytearray.h>
#include <qbytearraymatcher.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QByteArrayMatcher_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QByteArrayMatcher >()))
        return -1;

    QByteArrayMatcher* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QByteArrayMatcher", 0, 2, &(pyargs[0]), &(pyargs[1])))
        return -1;

    // Overloaded function decisor
    // 0: QByteArrayMatcher()
    // 1: QByteArrayMatcher(QByteArray)
    // 2: QByteArrayMatcher(QByteArrayMatcher)
    // 3: QByteArrayMatcher(const char*,int)
    if (numArgs == 0) {
        overloadId = 0; // QByteArrayMatcher()
    } else if (numArgs == 2 && Shiboken::Converter< const char * >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 3; // QByteArrayMatcher(const char*,int)
    } else if (numArgs == 1 && Shiboken::Converter< ::QByteArrayMatcher >::isConvertible(pyargs[0])) {
        overloadId = 2; // QByteArrayMatcher(QByteArrayMatcher)
    } else if (numArgs == 1 && Shiboken::Converter< ::QByteArray >::isConvertible(pyargs[0])) {
        overloadId = 1; // QByteArrayMatcher(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QByteArrayMatcher_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QByteArrayMatcher()
            {

                if(!PyErr_Occurred()) {
                    // QByteArrayMatcher()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QByteArrayMatcher();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // QByteArrayMatcher(QByteArray)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QByteArray cppArg0 = Shiboken::Converter<QByteArray >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QByteArrayMatcher(QByteArray)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QByteArrayMatcher(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // QByteArrayMatcher(QByteArrayMatcher)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QByteArrayMatcher cppArg0 = Shiboken::Converter<QByteArrayMatcher >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QByteArrayMatcher(QByteArrayMatcher)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QByteArrayMatcher(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 3: // QByteArrayMatcher(const char*,int)
            {
                const char * cppArg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // QByteArrayMatcher(const char*,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QByteArrayMatcher(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QByteArrayMatcher >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QByteArrayMatcher_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QByteArrayMatcher_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtCore.QByteArray", "PySide.QtCore.QByteArrayMatcher", "str, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QByteArrayMatcher", overloads);
        return -1;
}

static PyObject* Sbk_QByteArrayMatcherFunc_indexIn(PyObject* self, PyObject* args, PyObject* kwds)
{
    QByteArrayMatcher* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QByteArrayMatcher* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QByteArrayMatcher.indexIn(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QByteArrayMatcher.indexIn(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:indexIn", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: indexIn(QByteArray,int)const
    // 1: indexIn(const char*,int,int)const
    if (numArgs >= 2 && Shiboken::Converter< const char * >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 1; // indexIn(const char*,int,int)const
        } else if (SbkNumber_Check(pyargs[2])) {
            overloadId = 1; // indexIn(const char*,int,int)const
        }
    } else if (Shiboken::Converter< ::QByteArray >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // indexIn(QByteArray,int)const
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 0; // indexIn(QByteArray,int)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QByteArrayMatcherFunc_indexIn_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // indexIn(QByteArray,int)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "from");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "from";
                        else if (SbkNumber_Check(value))
                            pyargs[1] = value;
else
                            goto Sbk_QByteArrayMatcherFunc_indexIn_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtCore.QByteArrayMatcher.indexIn(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QByteArray cppArg0 = Shiboken::Converter<QByteArray >::toCpp(pyargs[0]);
                int cppArg1 = pyargs[1] ? Shiboken::Converter<int >::toCpp(pyargs[1]) : 0;

                if(!PyErr_Occurred()) {
                    // indexIn(QByteArray,int)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    int cppResult = cppSelf->indexIn(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< int >::toPython(cppResult);
                }
                break;
            }
            case 1: // indexIn(const char*,int,int)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "from");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "from";
                        else if (SbkNumber_Check(value))
                            pyargs[2] = value;
else
                            goto Sbk_QByteArrayMatcherFunc_indexIn_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtCore.QByteArrayMatcher.indexIn(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                const char * cppArg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                int cppArg2 = pyargs[2] ? Shiboken::Converter<int >::toCpp(pyargs[2]) : 0;

                if(!PyErr_Occurred()) {
                    // indexIn(const char*,int,int)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    int cppResult = cppSelf->indexIn(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< int >::toPython(cppResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QByteArrayMatcherFunc_indexIn_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray, int = 0", "str, int, int = 0", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QByteArrayMatcher.indexIn", overloads);
        return 0;
}

static PyObject* Sbk_QByteArrayMatcherFunc_pattern(PyObject* self)
{
    QByteArrayMatcher* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QByteArrayMatcher* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // pattern()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QByteArray cppResult = cppSelf->pattern();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QByteArray >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QByteArrayMatcherFunc_setPattern(PyObject* self, PyObject* arg)
{
    QByteArrayMatcher* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QByteArrayMatcher* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setPattern(QByteArray)
    if (Shiboken::Converter< ::QByteArray >::isConvertible(arg)) {
        overloadId = 0; // setPattern(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QByteArrayMatcherFunc_setPattern_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QByteArray cppArg0 = Shiboken::Converter<QByteArray >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setPattern(QByteArray)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setPattern(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QByteArrayMatcherFunc_setPattern_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QByteArrayMatcher.setPattern", overloads);
        return 0;
}

static PyObject *Sbk_QByteArrayMatcher___copy__(PyObject *self)
{
        QByteArrayMatcher* cppSelf = 0;
        if (!Shiboken::Object::isValid(self))
            return 0;
        cppSelf = Shiboken::Converter<QByteArrayMatcher*>::toCpp(self);
        PyObject* pyResult = 0;
        QByteArrayMatcher* copy = new QByteArrayMatcher(*cppSelf);
        pyResult = Shiboken::Converter<QByteArrayMatcher*>::toPython(copy);
        Shiboken::Object::getOwnership(pyResult);

        if (PyErr_Occurred() || !pyResult) {
            Py_XDECREF(pyResult);
            return 0;
        }
        return pyResult;
}

static PyMethodDef Sbk_QByteArrayMatcher_methods[] = {
    {"indexIn", (PyCFunction)Sbk_QByteArrayMatcherFunc_indexIn, METH_VARARGS|METH_KEYWORDS},
    {"pattern", (PyCFunction)Sbk_QByteArrayMatcherFunc_pattern, METH_NOARGS},
    {"setPattern", (PyCFunction)Sbk_QByteArrayMatcherFunc_setPattern, METH_O},

    {"__copy__", (PyCFunction)Sbk_QByteArrayMatcher___copy__, METH_NOARGS},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QByteArrayMatcher_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtCore.QByteArrayMatcher",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QByteArrayMatcher_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QByteArrayMatcher_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QByteArrayMatcher(PyObject* module)
{
    SbkPySide_QtCoreTypes[SBK_QBYTEARRAYMATCHER_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QByteArrayMatcher_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QByteArrayMatcher_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QByteArrayMatcher_Type, &Shiboken::callCppDestructor<QByteArrayMatcher >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QByteArrayMatcher_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QByteArrayMatcher_Type, "QByteArrayMatcher");
    PyModule_AddObject(module, "QByteArrayMatcher",
        ((PyObject*)&Sbk_QByteArrayMatcher_Type));


    Shiboken::TypeResolver::createValueTypeResolver<QByteArrayMatcher >("QByteArrayMatcher");
    Shiboken::TypeResolver::createObjectTypeResolver<QByteArrayMatcher >("QByteArrayMatcher*");
    Shiboken::TypeResolver::createValueTypeResolver<QByteArrayMatcher >(typeid(QByteArrayMatcher).name());
    PySide::initQtMetaType<QByteArrayMatcher >();
}

