/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtcore_python.h"

#include "qdate_wrapper.h"

// Extra includes
#include <datetime.h>
#include <qdatetime.h>


// Python Conversion
namespace Shiboken {
template <>
struct PythonConverter<QDate>
{
    static bool isPythonConvertible(PyObject* pyObj)
    {
        if (!PyDateTimeAPI)
            PyDateTime_IMPORT;

        return pyObj && PyDate_Check(pyObj);
    }

    static QDate* transformFromPython(PyObject* obj)
    {
        if (isPythonConvertible(obj)) {
            int day = PyDateTime_GET_DAY(obj);
            int month = PyDateTime_GET_MONTH(obj);
            int year = PyDateTime_GET_YEAR(obj);
            return new QDate(year, month, day);
        }
        return 0;
    }

    static PyObject* transformToPython(QDate* d)
    {
        if (d) {
            if (!PyDateTimeAPI) 
                PyDateTime_IMPORT;

            return PyDate_FromDate(d->year(), d->month(), d->day());
        }
        return 0;
    }
};
}


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QDate_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QDate >()))
        return -1;

    QDate* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs == 2)
        goto Sbk_QDate_Init_TypeError;

    if (!PyArg_UnpackTuple(args, "QDate", 0, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return -1;

    // Try python conversion rules
    cptr = Shiboken::PythonConverter< QDate >::transformFromPython(pyargs[0]);
    if (!cptr) {
    // Overloaded function decisor
    // 0: QDate()
    // 1: QDate(QDate)
    // 2: QDate(int,int,int)
    if (numArgs == 0) {
        overloadId = 0; // QDate()
    } else if (numArgs == 3 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
        overloadId = 2; // QDate(int,int,int)
    } else if (numArgs == 1 && Shiboken::Converter< ::QDate >::isConvertible(pyargs[0])) {
        overloadId = 1; // QDate(QDate)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDate_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QDate()
            {

                if(!PyErr_Occurred()) {
                    // QDate()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QDate();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // QDate(QDate)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QDate cppArg0 = Shiboken::Converter<QDate >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QDate(QDate)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QDate(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // QDate(int,int,int)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                    // QDate(int,int,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QDate(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    }
    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QDate >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QDate_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QDate_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtCore.QDate", "int, int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QDate", overloads);
        return -1;
}

static PyObject* Sbk_QDateFunc___reduce__(PyObject* self)
{
    QDate* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDate* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // __reduce__()
                // Begin code injection
                
                // TEMPLATE - reduce_code - START
                pyResult = Py_BuildValue("(N(iii))", PyObject_Type(self), cppSelf->year(), cppSelf->month(), cppSelf->day());
                // TEMPLATE - reduce_code - END
                
                // End of code injection


            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDateFunc_addDays(PyObject* self, PyObject* arg)
{
    QDate* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDate* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: addDays(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // addDays(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDateFunc_addDays_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // addDays(int)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDate cppResult = cppSelf->addDays(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDate >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QDateFunc_addDays_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QDate.addDays", overloads);
        return 0;
}

static PyObject* Sbk_QDateFunc_addMonths(PyObject* self, PyObject* arg)
{
    QDate* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDate* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: addMonths(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // addMonths(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDateFunc_addMonths_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // addMonths(int)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDate cppResult = cppSelf->addMonths(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDate >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QDateFunc_addMonths_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QDate.addMonths", overloads);
        return 0;
}

static PyObject* Sbk_QDateFunc_addYears(PyObject* self, PyObject* arg)
{
    QDate* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDate* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: addYears(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // addYears(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDateFunc_addYears_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // addYears(int)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDate cppResult = cppSelf->addYears(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDate >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QDateFunc_addYears_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QDate.addYears", overloads);
        return 0;
}

static PyObject* Sbk_QDateFunc_currentDate(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // currentDate()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDate cppResult = QDate::currentDate();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDate >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDateFunc_day(PyObject* self)
{
    QDate* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDate* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // day()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->day();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDateFunc_dayOfWeek(PyObject* self)
{
    QDate* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDate* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // dayOfWeek()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->dayOfWeek();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDateFunc_dayOfYear(PyObject* self)
{
    QDate* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDate* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // dayOfYear()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->dayOfYear();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDateFunc_daysInMonth(PyObject* self)
{
    QDate* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDate* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // daysInMonth()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->daysInMonth();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDateFunc_daysInYear(PyObject* self)
{
    QDate* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDate* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // daysInYear()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->daysInYear();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDateFunc_daysTo(PyObject* self, PyObject* arg)
{
    QDate* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDate* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: daysTo(QDate)const
    if (Shiboken::Converter< ::QDate >::isConvertible(arg)) {
        overloadId = 0; // daysTo(QDate)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDateFunc_daysTo_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QDate cppArg0 = Shiboken::Converter<QDate >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // daysTo(QDate)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->daysTo(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QDateFunc_daysTo_TypeError:
        const char* overloads[] = {"PySide.QtCore.QDate", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QDate.daysTo", overloads);
        return 0;
}

static PyObject* Sbk_QDateFunc_fromJulianDay(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: fromJulianDay(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // fromJulianDay(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDateFunc_fromJulianDay_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // fromJulianDay(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDate cppResult = QDate::fromJulianDay(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDate >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QDateFunc_fromJulianDay_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QDate.fromJulianDay", overloads);
        return 0;
}

static PyObject* Sbk_QDateFunc_fromString(PyObject* self, PyObject* args, PyObject* kwds)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QDate.fromString(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QDate.fromString(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:fromString", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: fromString(QString,Qt::DateFormat)
    // 1: fromString(QString,QString)
    if (Shiboken::Converter< QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // fromString(QString,Qt::DateFormat)
        } else if (numArgs == 2 && Shiboken::Converter< QString >::isConvertible(pyargs[1])) {
            overloadId = 1; // fromString(QString,QString)
        } else if (Shiboken::Converter< ::Qt::DateFormat >::isConvertible(pyargs[1])) {
            overloadId = 0; // fromString(QString,Qt::DateFormat)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDateFunc_fromString_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // fromString(QString,Qt::DateFormat)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "f");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "f";
                        else if (Shiboken::Converter< ::Qt::DateFormat >::isConvertible(value))
                            pyargs[1] = value;
else
                            goto Sbk_QDateFunc_fromString_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtCore.QDate.fromString(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                Qt::DateFormat cppArg1 = pyargs[1] ? Shiboken::Converter<Qt::DateFormat >::toCpp(pyargs[1]) : Qt::TextDate;

                if(!PyErr_Occurred()) {
                    // fromString(QString,Qt::DateFormat)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QDate cppResult = QDate::fromString(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QDate >::toPython(cppResult);
                }
                break;
            }
            case 1: // fromString(QString,QString)
            {
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                QString cppArg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // fromString(QString,QString)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QDate cppResult = QDate::fromString(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QDate >::toPython(cppResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QDateFunc_fromString_TypeError:
        const char* overloads[] = {"QString, PySide.QtCore.Qt.DateFormat = Qt.TextDate", "QString, QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QDate.fromString", overloads);
        return 0;
}

static PyObject* Sbk_QDateFunc_getDate(PyObject* self)
{
    QDate* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDate* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // getDate(int*,int*,int*)
                // Begin code injection
                
                int year, month, day;
                cppSelf->getDate(&year, &month, &day);
                pyResult = Shiboken::makeTuple(year, month, day);
                
                // End of code injection


            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDateFunc_gregorianToJulian(PyObject* self, PyObject* args)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "gregorianToJulian", 3, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: gregorianToJulian(int,int,int)
    if (numArgs == 3 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
        overloadId = 0; // gregorianToJulian(int,int,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDateFunc_gregorianToJulian_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
            int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

            if(!PyErr_Occurred()) {
                // gregorianToJulian(int,int,int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                uint cppResult = QDate::gregorianToJulian(cppArg0, cppArg1, cppArg2);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< unsigned int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QDateFunc_gregorianToJulian_TypeError:
        const char* overloads[] = {"int, int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QDate.gregorianToJulian", overloads);
        return 0;
}

static PyObject* Sbk_QDateFunc_isLeapYear(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: isLeapYear(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // isLeapYear(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDateFunc_isLeapYear_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // isLeapYear(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = QDate::isLeapYear(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QDateFunc_isLeapYear_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QDate.isLeapYear", overloads);
        return 0;
}

static PyObject* Sbk_QDateFunc_isNull(PyObject* self)
{
    QDate* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDate* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isNull()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->isNull();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDateFunc_isValid(PyObject* self, PyObject* args)
{
    QDate* cppSelf = 0;
    if (self) {
        if (!Shiboken::Object::isValid(self))
            return 0;
        cppSelf = Shiboken::Converter< QDate* >::toCpp(self);
    }

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs == 1 || numArgs == 2)
        goto Sbk_QDateFunc_isValid_TypeError;

    if (!PyArg_UnpackTuple(args, "isValid", 0, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: isValid()const
    // 1: isValid(int,int,int)
    if (numArgs == 0) {
        overloadId = 0; // isValid()const
    } else if (numArgs == 3 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
        overloadId = 1; // isValid(int,int,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDateFunc_isValid_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // isValid()const
            {

                if(!PyErr_Occurred()) {
                    // isValid()const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    bool cppResult = cppSelf->isValid();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< bool >::toPython(cppResult);
                }
                break;
            }
            case 1: // isValid(int,int,int)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                    // isValid(int,int,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    bool cppResult = QDate::isValid(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< bool >::toPython(cppResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QDateFunc_isValid_TypeError:
        const char* overloads[] = {"", "int, int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QDate.isValid", overloads);
        return 0;
}

static PyObject* Sbk_QDateFunc_longDayName(PyObject* self, PyObject* args)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "longDayName", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: longDayName(int)
    // 1: longDayName(int,QDate::MonthNameType)
    if (SbkNumber_Check(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // longDayName(int)
        } else if (numArgs == 2 && Shiboken::Converter< ::QDate::MonthNameType >::isConvertible(pyargs[1])) {
            overloadId = 1; // longDayName(int,QDate::MonthNameType)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDateFunc_longDayName_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // longDayName(int)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // longDayName(int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QString cppResult = QDate::longDayName(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< QString >::toPython(cppResult);
                }
                break;
            }
            case 1: // longDayName(int,QDate::MonthNameType)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                QDate::MonthNameType cppArg1 = Shiboken::Converter<QDate::MonthNameType >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // longDayName(int,QDate::MonthNameType)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QString cppResult = QDate::longDayName(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< QString >::toPython(cppResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QDateFunc_longDayName_TypeError:
        const char* overloads[] = {"int", "int, PySide.QtCore.QDate.MonthNameType", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QDate.longDayName", overloads);
        return 0;
}

static PyObject* Sbk_QDateFunc_longMonthName(PyObject* self, PyObject* args)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "longMonthName", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: longMonthName(int)
    // 1: longMonthName(int,QDate::MonthNameType)
    if (SbkNumber_Check(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // longMonthName(int)
        } else if (numArgs == 2 && Shiboken::Converter< ::QDate::MonthNameType >::isConvertible(pyargs[1])) {
            overloadId = 1; // longMonthName(int,QDate::MonthNameType)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDateFunc_longMonthName_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // longMonthName(int)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // longMonthName(int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QString cppResult = QDate::longMonthName(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< QString >::toPython(cppResult);
                }
                break;
            }
            case 1: // longMonthName(int,QDate::MonthNameType)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                QDate::MonthNameType cppArg1 = Shiboken::Converter<QDate::MonthNameType >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // longMonthName(int,QDate::MonthNameType)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QString cppResult = QDate::longMonthName(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< QString >::toPython(cppResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QDateFunc_longMonthName_TypeError:
        const char* overloads[] = {"int", "int, PySide.QtCore.QDate.MonthNameType", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QDate.longMonthName", overloads);
        return 0;
}

static PyObject* Sbk_QDateFunc_month(PyObject* self)
{
    QDate* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDate* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // month()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->month();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDateFunc_setDate(PyObject* self, PyObject* args)
{
    QDate* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDate* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setDate", 3, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: setDate(int,int,int)
    if (numArgs == 3 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
        overloadId = 0; // setDate(int,int,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDateFunc_setDate_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
            int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

            if(!PyErr_Occurred()) {
                // setDate(int,int,int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->setDate(cppArg0, cppArg1, cppArg2);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QDateFunc_setDate_TypeError:
        const char* overloads[] = {"int, int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QDate.setDate", overloads);
        return 0;
}

static PyObject* Sbk_QDateFunc_setYMD(PyObject* self, PyObject* args)
{
    QDate* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDate* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setYMD", 3, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: setYMD(int,int,int)
    if (numArgs == 3 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
        overloadId = 0; // setYMD(int,int,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDateFunc_setYMD_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
            int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

            if(!PyErr_Occurred()) {
                // setYMD(int,int,int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->setYMD(cppArg0, cppArg1, cppArg2);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QDateFunc_setYMD_TypeError:
        const char* overloads[] = {"int, int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QDate.setYMD", overloads);
        return 0;
}

static PyObject* Sbk_QDateFunc_shortDayName(PyObject* self, PyObject* args)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "shortDayName", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: shortDayName(int)
    // 1: shortDayName(int,QDate::MonthNameType)
    if (SbkNumber_Check(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // shortDayName(int)
        } else if (numArgs == 2 && Shiboken::Converter< ::QDate::MonthNameType >::isConvertible(pyargs[1])) {
            overloadId = 1; // shortDayName(int,QDate::MonthNameType)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDateFunc_shortDayName_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // shortDayName(int)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // shortDayName(int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QString cppResult = QDate::shortDayName(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< QString >::toPython(cppResult);
                }
                break;
            }
            case 1: // shortDayName(int,QDate::MonthNameType)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                QDate::MonthNameType cppArg1 = Shiboken::Converter<QDate::MonthNameType >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // shortDayName(int,QDate::MonthNameType)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QString cppResult = QDate::shortDayName(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< QString >::toPython(cppResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QDateFunc_shortDayName_TypeError:
        const char* overloads[] = {"int", "int, PySide.QtCore.QDate.MonthNameType", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QDate.shortDayName", overloads);
        return 0;
}

static PyObject* Sbk_QDateFunc_shortMonthName(PyObject* self, PyObject* args)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "shortMonthName", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: shortMonthName(int)
    // 1: shortMonthName(int,QDate::MonthNameType)
    if (SbkNumber_Check(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // shortMonthName(int)
        } else if (numArgs == 2 && Shiboken::Converter< ::QDate::MonthNameType >::isConvertible(pyargs[1])) {
            overloadId = 1; // shortMonthName(int,QDate::MonthNameType)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDateFunc_shortMonthName_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // shortMonthName(int)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // shortMonthName(int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QString cppResult = QDate::shortMonthName(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< QString >::toPython(cppResult);
                }
                break;
            }
            case 1: // shortMonthName(int,QDate::MonthNameType)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                QDate::MonthNameType cppArg1 = Shiboken::Converter<QDate::MonthNameType >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // shortMonthName(int,QDate::MonthNameType)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QString cppResult = QDate::shortMonthName(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< QString >::toPython(cppResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QDateFunc_shortMonthName_TypeError:
        const char* overloads[] = {"int", "int, PySide.QtCore.QDate.MonthNameType", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QDate.shortMonthName", overloads);
        return 0;
}

static PyObject* Sbk_QDateFunc_toJulianDay(PyObject* self)
{
    QDate* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDate* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // toJulianDay()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->toJulianDay();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDateFunc_toString(PyObject* self, PyObject* args, PyObject* kwds)
{
    QDate* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDate* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QDate.toString(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:toString", &(pyargs[0])))
        return 0;


    // Overloaded function decisor
    // 0: toString(Qt::DateFormat)const
    // 1: toString(QString)const
    if (numArgs == 0) {
        overloadId = 0; // toString(Qt::DateFormat)const
    } else if (numArgs == 1 && Shiboken::Converter< QString >::isConvertible(pyargs[0])) {
        overloadId = 1; // toString(QString)const
    } else if (Shiboken::Converter< ::Qt::DateFormat >::isConvertible(pyargs[0])) {
        overloadId = 0; // toString(Qt::DateFormat)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDateFunc_toString_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // toString(Qt::DateFormat)const
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "f");
                    if (value) {
                        if (pyargs[0])
                            errorArgName = "f";
                        else if (Shiboken::Converter< ::Qt::DateFormat >::isConvertible(value))
                            pyargs[0] = value;
else
                            goto Sbk_QDateFunc_toString_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtCore.QDate.toString(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                Qt::DateFormat cppArg0 = pyargs[0] ? Shiboken::Converter<Qt::DateFormat >::toCpp(pyargs[0]) : Qt::TextDate;

                if(!PyErr_Occurred()) {
                    // toString(Qt::DateFormat)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QString cppResult = cppSelf->toString(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< QString >::toPython(cppResult);
                }
                break;
            }
            case 1: // toString(QString)const
            {
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // toString(QString)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QString cppResult = cppSelf->toString(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< QString >::toPython(cppResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QDateFunc_toString_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.DateFormat = Qt.TextDate", "QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QDate.toString", overloads);
        return 0;
}

static PyObject* Sbk_QDateFunc_weekNumber(PyObject* self)
{
    QDate* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDate* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // weekNumber(int*)const
                // Begin code injection
                
                int yearNumber;
                int week = cppSelf->weekNumber(&yearNumber);
                pyResult = Shiboken::makeTuple(week, yearNumber);
                
                // End of code injection


            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDateFunc_year(PyObject* self)
{
    QDate* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDate* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // year()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->year();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDate_ToPythonFunc(PyObject* self)
{
    QDate* cppSelf = Shiboken::Converter<QDate* >::toCpp(self);
    PyObject* pyResult = Shiboken::PythonConverter<QDate >::transformToPython(cppSelf);
    if (PyErr_Occurred() || !pyResult) {
                Py_XDECREF(pyResult);
                return 0;
    }
    return pyResult;
}
static PyObject *Sbk_QDate___copy__(PyObject *self)
{
        QDate* cppSelf = 0;
        if (!Shiboken::Object::isValid(self))
            return 0;
        cppSelf = Shiboken::Converter<QDate*>::toCpp(self);
        PyObject* pyResult = 0;
        QDate* copy = new QDate(*cppSelf);
        pyResult = Shiboken::Converter<QDate*>::toPython(copy);
        Shiboken::Object::getOwnership(pyResult);

        if (PyErr_Occurred() || !pyResult) {
            Py_XDECREF(pyResult);
            return 0;
        }
        return pyResult;
}

static PyMethodDef Sbk_QDateMethod_isValid = {
    "isValid", (PyCFunction)Sbk_QDateFunc_isValid, METH_VARARGS|METH_STATIC
};

static PyMethodDef Sbk_QDate_methods[] = {
    {"__reduce__", (PyCFunction)Sbk_QDateFunc___reduce__, METH_NOARGS},
    {"addDays", (PyCFunction)Sbk_QDateFunc_addDays, METH_O},
    {"addMonths", (PyCFunction)Sbk_QDateFunc_addMonths, METH_O},
    {"addYears", (PyCFunction)Sbk_QDateFunc_addYears, METH_O},
    {"currentDate", (PyCFunction)Sbk_QDateFunc_currentDate, METH_NOARGS|METH_STATIC},
    {"day", (PyCFunction)Sbk_QDateFunc_day, METH_NOARGS},
    {"dayOfWeek", (PyCFunction)Sbk_QDateFunc_dayOfWeek, METH_NOARGS},
    {"dayOfYear", (PyCFunction)Sbk_QDateFunc_dayOfYear, METH_NOARGS},
    {"daysInMonth", (PyCFunction)Sbk_QDateFunc_daysInMonth, METH_NOARGS},
    {"daysInYear", (PyCFunction)Sbk_QDateFunc_daysInYear, METH_NOARGS},
    {"daysTo", (PyCFunction)Sbk_QDateFunc_daysTo, METH_O},
    {"fromJulianDay", (PyCFunction)Sbk_QDateFunc_fromJulianDay, METH_O|METH_STATIC},
    {"fromString", (PyCFunction)Sbk_QDateFunc_fromString, METH_VARARGS|METH_KEYWORDS|METH_STATIC},
    {"getDate", (PyCFunction)Sbk_QDateFunc_getDate, METH_NOARGS},
    {"gregorianToJulian", (PyCFunction)Sbk_QDateFunc_gregorianToJulian, METH_VARARGS|METH_STATIC},
    {"isLeapYear", (PyCFunction)Sbk_QDateFunc_isLeapYear, METH_O|METH_STATIC},
    {"isNull", (PyCFunction)Sbk_QDateFunc_isNull, METH_NOARGS},
    Sbk_QDateMethod_isValid,
    {"longDayName", (PyCFunction)Sbk_QDateFunc_longDayName, METH_VARARGS|METH_STATIC},
    {"longMonthName", (PyCFunction)Sbk_QDateFunc_longMonthName, METH_VARARGS|METH_STATIC},
    {"month", (PyCFunction)Sbk_QDateFunc_month, METH_NOARGS},
    {"setDate", (PyCFunction)Sbk_QDateFunc_setDate, METH_VARARGS},
    {"setYMD", (PyCFunction)Sbk_QDateFunc_setYMD, METH_VARARGS},
    {"shortDayName", (PyCFunction)Sbk_QDateFunc_shortDayName, METH_VARARGS|METH_STATIC},
    {"shortMonthName", (PyCFunction)Sbk_QDateFunc_shortMonthName, METH_VARARGS|METH_STATIC},
    {"toJulianDay", (PyCFunction)Sbk_QDateFunc_toJulianDay, METH_NOARGS},
    {"toString", (PyCFunction)Sbk_QDateFunc_toString, METH_VARARGS|METH_KEYWORDS},
    {"weekNumber", (PyCFunction)Sbk_QDateFunc_weekNumber, METH_NOARGS},
    {"year", (PyCFunction)Sbk_QDateFunc_year, METH_NOARGS},
    {"toPython", (PyCFunction)Sbk_QDate_ToPythonFunc, METH_NOARGS},

    {"__copy__", (PyCFunction)Sbk_QDate___copy__, METH_NOARGS},
    {0} // Sentinel
};

static PyObject* Sbk_QDate_getattro(PyObject* self, PyObject* name)
{
    if (self) {
        if (reinterpret_cast<SbkObject*>(self)->ob_dict) {
            PyObject* meth = PyDict_GetItem(reinterpret_cast<SbkObject*>(self)->ob_dict, name);
            if (meth) {
                Py_INCREF(meth);
                return meth;
            }
        }
        const char* cname = PyString_AS_STRING(name);
        if (strcmp(cname, "isValid") == 0)
            return PyCFunction_NewEx(&Sbk_QDateMethod_isValid, self, 0);
    }
    return PyObject_GenericGetAttr(self, name);
}

// Rich comparison
static PyObject* Sbk_QDate_richcompare(PyObject* self, PyObject* arg, int op)
{
    PyObject* pyResult = 0;
    QDate& cppSelf = *Shiboken::Converter< QDate* >::toCpp(self);

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter< ::QDate >::isConvertible(arg)) {
                // operator!=(const QDate & other) const
                QDate cppArg0 = Shiboken::Converter< ::QDate >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf != cppArg0);
            } else goto Sbk_QDate_RichComparison_TypeError;

            break;
        case Py_LT:
            if (Shiboken::Converter< ::QDate >::isConvertible(arg)) {
                // operator<(const QDate & other) const
                QDate cppArg0 = Shiboken::Converter< ::QDate >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf < cppArg0);
            } else goto Sbk_QDate_RichComparison_TypeError;

            break;
        case Py_LE:
            if (Shiboken::Converter< ::QDate >::isConvertible(arg)) {
                // operator<=(const QDate & other) const
                QDate cppArg0 = Shiboken::Converter< ::QDate >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf <= cppArg0);
            } else goto Sbk_QDate_RichComparison_TypeError;

            break;
        case Py_EQ:
            if (Shiboken::Converter< ::QDate >::isConvertible(arg)) {
                // operator==(const QDate & other) const
                QDate cppArg0 = Shiboken::Converter< ::QDate >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf == cppArg0);
            } else goto Sbk_QDate_RichComparison_TypeError;

            break;
        case Py_GT:
            if (Shiboken::Converter< ::QDate >::isConvertible(arg)) {
                // operator>(const QDate & other) const
                QDate cppArg0 = Shiboken::Converter< ::QDate >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf > cppArg0);
            } else goto Sbk_QDate_RichComparison_TypeError;

            break;
        case Py_GE:
            if (Shiboken::Converter< ::QDate >::isConvertible(arg)) {
                // operator>=(const QDate & other) const
                QDate cppArg0 = Shiboken::Converter< ::QDate >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf >= cppArg0);
            } else goto Sbk_QDate_RichComparison_TypeError;

            break;
        default:
            goto Sbk_QDate_RichComparison_TypeError;
    }

    if (pyResult && !PyErr_Occurred())
        return pyResult;
    Sbk_QDate_RichComparison_TypeError:
    PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
    return 0;

}

} // extern "C"

static long Sbk_QDate_HashFunc(PyObject* obj){
    return PySide::hash(Shiboken::Converter< ::QDate >::toCpp(obj));
}

extern "C"
{
static PyObject* Sbk_QDate__repr__(PyObject* pyObj)
{
    QBuffer buffer;
    buffer.open(QBuffer::ReadWrite);
    QDebug dbg(&buffer);
    dbg << Shiboken::Converter< ::QDate >::toCpp(pyObj);
    buffer.close();
    return PyString_FromFormat("<PySide.QtCore.%s at %p>", buffer.data().constData(), pyObj);
}
} // extern C

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QDate_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtCore.QDate",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Sbk_QDate__repr__,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             &Sbk_QDate_HashFunc,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         Sbk_QDate_getattro,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      Sbk_QDate_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QDate_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QDate_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QDate(PyObject* module)
{
    SbkPySide_QtCoreTypes[SBK_QDATE_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QDate_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QDate_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QDate_Type, &Shiboken::callCppDestructor<QDate >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QDate_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QDate_Type, "QDate");
    PyModule_AddObject(module, "QDate",
        ((PyObject*)&Sbk_QDate_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: MonthNameType
    PyTypeObject* SbkPySide_QtCore_QDate_MonthNameType = Shiboken::Enum::newType("MonthNameType");
    SbkPySide_QtCoreTypes[SBK_QDATE_MONTHNAMETYPE_IDX] = SbkPySide_QtCore_QDate_MonthNameType;
    if (PyType_Ready(SbkPySide_QtCore_QDate_MonthNameType) < 0)
        return;
    PyDict_SetItemString(Sbk_QDate_Type.super.ht_type.tp_dict,
            "MonthNameType",((PyObject*)SbkPySide_QtCore_QDate_MonthNameType));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QDate_MonthNameType,(long) QDate::DateFormat, "DateFormat");
    PyDict_SetItemString(Sbk_QDate_Type.super.ht_type.tp_dict,"DateFormat", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QDate_MonthNameType->tp_dict,"DateFormat", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QDate_MonthNameType,(long) QDate::StandaloneFormat, "StandaloneFormat");
    PyDict_SetItemString(Sbk_QDate_Type.super.ht_type.tp_dict,"StandaloneFormat", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QDate_MonthNameType->tp_dict,"StandaloneFormat", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QDate::MonthNameType");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::MonthNameType");
    // end of enum MonthNameType


    Shiboken::TypeResolver::createValueTypeResolver<QDate >("QDate");
    Shiboken::TypeResolver::createObjectTypeResolver<QDate >("QDate*");
    Shiboken::TypeResolver::createValueTypeResolver<QDate >(typeid(QDate).name());
    PySide::initQtMetaType<QDate >();
}

