/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtcore_python.h"

#include "qdiriterator_wrapper.h"

// Extra includes
#include <QStringList>
#include <qdir.h>
#include <qdiriterator.h>
#include <qfileinfo.h>


// Native ---------------------------------------------------------

QDirIteratorWrapper::QDirIteratorWrapper(const QDir & dir, QFlags<QDirIterator::IteratorFlag> flags) : QDirIterator(dir, flags) {
    // ... middle
}

QDirIteratorWrapper::QDirIteratorWrapper(const QString & path, QFlags<QDir::Filter> filter, QFlags<QDirIterator::IteratorFlag> flags) : QDirIterator(path, filter, flags) {
    // ... middle
}

QDirIteratorWrapper::QDirIteratorWrapper(const QString & path, QFlags<QDirIterator::IteratorFlag> flags) : QDirIterator(path, flags) {
    // ... middle
}

QDirIteratorWrapper::QDirIteratorWrapper(const QString & path, const QStringList & nameFilters, QFlags<QDir::Filter> filters, QFlags<QDirIterator::IteratorFlag> flags) : QDirIterator(path, nameFilters, filters, flags) {
    // ... middle
}

QDirIteratorWrapper::~QDirIteratorWrapper()
{
    SbkObject* wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QDirIterator_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QDirIterator >()))
        return -1;

    QDirIteratorWrapper* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);

    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 4) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QDirIterator(): too many arguments");
        return -1;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QDirIterator(): not enough arguments");
        return -1;
    }

    if (!PyArg_ParseTuple(args, "|OOOO:QDirIterator", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return -1;

    // Overloaded function decisor
    // 0: QDirIterator(QDir,QFlags<QDirIterator::IteratorFlag>)
    // 1: QDirIterator(QString,QFlags<QDir::Filter>,QFlags<QDirIterator::IteratorFlag>)
    // 2: QDirIterator(QString,QFlags<QDirIterator::IteratorFlag>)
    // 3: QDirIterator(QString,QStringList,QFlags<QDir::Filter>,QFlags<QDirIterator::IteratorFlag>)
    if (Shiboken::Converter< QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 2; // QDirIterator(QString,QFlags<QDirIterator::IteratorFlag>)
        } else if (Shiboken::Converter< ::QStringList >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 3; // QDirIterator(QString,QStringList,QFlags<QDir::Filter>,QFlags<QDirIterator::IteratorFlag>)
            } else if (Shiboken::Converter< ::QFlags<QDir::Filter> >::isConvertible(pyargs[2])) {
                if (numArgs == 3) {
                    overloadId = 3; // QDirIterator(QString,QStringList,QFlags<QDir::Filter>,QFlags<QDirIterator::IteratorFlag>)
                } else if (Shiboken::Converter< ::QFlags<QDirIterator::IteratorFlag> >::isConvertible(pyargs[3])) {
                    overloadId = 3; // QDirIterator(QString,QStringList,QFlags<QDir::Filter>,QFlags<QDirIterator::IteratorFlag>)
                }
            }
        } else if (Shiboken::Converter< ::QFlags<QDirIterator::IteratorFlag> >::isConvertible(pyargs[1])) {
            overloadId = 2; // QDirIterator(QString,QFlags<QDirIterator::IteratorFlag>)
        } else if (Shiboken::Converter< ::QFlags<QDir::Filter> >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 1; // QDirIterator(QString,QFlags<QDir::Filter>,QFlags<QDirIterator::IteratorFlag>)
            } else if (Shiboken::Converter< ::QFlags<QDirIterator::IteratorFlag> >::isConvertible(pyargs[2])) {
                overloadId = 1; // QDirIterator(QString,QFlags<QDir::Filter>,QFlags<QDirIterator::IteratorFlag>)
            }
        }
    } else if (Shiboken::Converter< ::QDir >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // QDirIterator(QDir,QFlags<QDirIterator::IteratorFlag>)
        } else if (Shiboken::Converter< ::QFlags<QDirIterator::IteratorFlag> >::isConvertible(pyargs[1])) {
            overloadId = 0; // QDirIterator(QDir,QFlags<QDirIterator::IteratorFlag>)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDirIterator_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QDirIterator(QDir,QFlags<QDirIterator::IteratorFlag>)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "flags");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "flags";
                        else if (Shiboken::Converter< ::QFlags<QDirIterator::IteratorFlag> >::isConvertible(value))
                            pyargs[1] = value;
else
                            goto Sbk_QDirIterator_Init_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtCore.QDirIterator(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QDir cppArg0 = Shiboken::Converter<QDir >::toCpp(pyargs[0]);
                QFlags<QDirIterator::IteratorFlag> cppArg1 = pyargs[1] ? Shiboken::Converter<QFlags<QDirIterator::IteratorFlag> >::toCpp(pyargs[1]) : QDirIterator::NoIteratorFlags;

                if(!PyErr_Occurred()) {
                    // QDirIterator(QDir,QFlags<QDirIterator::IteratorFlag>)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QDirIteratorWrapper(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // QDirIterator(QString,QFlags<QDir::Filter>,QFlags<QDirIterator::IteratorFlag>)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "flags");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "flags";
                        else if (Shiboken::Converter< ::QFlags<QDirIterator::IteratorFlag> >::isConvertible(value))
                            pyargs[2] = value;
else
                            goto Sbk_QDirIterator_Init_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtCore.QDirIterator(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                QFlags<QDir::Filter> cppArg1 = Shiboken::Converter<QFlags<QDir::Filter> >::toCpp(pyargs[1]);
                QFlags<QDirIterator::IteratorFlag> cppArg2 = pyargs[2] ? Shiboken::Converter<QFlags<QDirIterator::IteratorFlag> >::toCpp(pyargs[2]) : QDirIterator::NoIteratorFlags;

                if(!PyErr_Occurred()) {
                    // QDirIterator(QString,QFlags<QDir::Filter>,QFlags<QDirIterator::IteratorFlag>)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QDirIteratorWrapper(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // QDirIterator(QString,QFlags<QDirIterator::IteratorFlag>)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "flags");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "flags";
                        else if (Shiboken::Converter< ::QFlags<QDirIterator::IteratorFlag> >::isConvertible(value))
                            pyargs[1] = value;
else
                            goto Sbk_QDirIterator_Init_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtCore.QDirIterator(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                QFlags<QDirIterator::IteratorFlag> cppArg1 = pyargs[1] ? Shiboken::Converter<QFlags<QDirIterator::IteratorFlag> >::toCpp(pyargs[1]) : QDirIterator::NoIteratorFlags;

                if(!PyErr_Occurred()) {
                    // QDirIterator(QString,QFlags<QDirIterator::IteratorFlag>)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QDirIteratorWrapper(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 3: // QDirIterator(QString,QStringList,QFlags<QDir::Filter>,QFlags<QDirIterator::IteratorFlag>)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "filters");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "filters";
                        else if (Shiboken::Converter< ::QFlags<QDir::Filter> >::isConvertible(value))
                            pyargs[2] = value;
else
                            goto Sbk_QDirIterator_Init_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "flags");
                    if (value) {
                        if (pyargs[3])
                            errorArgName = "flags";
                        else if (Shiboken::Converter< ::QFlags<QDirIterator::IteratorFlag> >::isConvertible(value))
                            pyargs[3] = value;
else
                            goto Sbk_QDirIterator_Init_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtCore.QDirIterator(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                QStringList cppArg1 = Shiboken::Converter<QStringList >::toCpp(pyargs[1]);
                QFlags<QDir::Filter> cppArg2 = pyargs[2] ? Shiboken::Converter<QFlags<QDir::Filter> >::toCpp(pyargs[2]) : QDir::NoFilter;
                QFlags<QDirIterator::IteratorFlag> cppArg3 = pyargs[3] ? Shiboken::Converter<QFlags<QDirIterator::IteratorFlag> >::toCpp(pyargs[3]) : QDirIterator::NoIteratorFlags;

                if(!PyErr_Occurred()) {
                    // QDirIterator(QString,QStringList,QFlags<QDir::Filter>,QFlags<QDirIterator::IteratorFlag>)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QDirIteratorWrapper(cppArg0, cppArg1, cppArg2, cppArg3);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QDirIterator >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QDirIterator_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QDirIterator_Init_TypeError:
        const char* overloads[] = {"PySide.QtCore.QDir, PySide.QtCore.QDirIterator.IteratorFlags = QDirIterator.NoIteratorFlags", "QString, PySide.QtCore.QDir.Filters, PySide.QtCore.QDirIterator.IteratorFlags = QDirIterator.NoIteratorFlags", "QString, PySide.QtCore.QDirIterator.IteratorFlags = QDirIterator.NoIteratorFlags", "QString, list, PySide.QtCore.QDir.Filters = QDir.NoFilter, PySide.QtCore.QDirIterator.IteratorFlags = QDirIterator.NoIteratorFlags", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QDirIterator", overloads);
        return -1;
}

static PyObject* Sbk_QDirIteratorFunc_fileInfo(PyObject* self)
{
    QDirIterator* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDirIterator* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // fileInfo()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QFileInfo cppResult = cppSelf->fileInfo();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QFileInfo >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDirIteratorFunc_fileName(PyObject* self)
{
    QDirIterator* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDirIterator* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // fileName()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = cppSelf->fileName();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDirIteratorFunc_filePath(PyObject* self)
{
    QDirIterator* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDirIterator* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // filePath()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = cppSelf->filePath();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDirIteratorFunc_hasNext(PyObject* self)
{
    QDirIterator* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDirIterator* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // hasNext()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->hasNext();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDirIteratorFunc_next(PyObject* self)
{
    QDirIterator* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDirIterator* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // next()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = cppSelf->next();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDirIteratorFunc_path(PyObject* self)
{
    QDirIterator* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDirIterator* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // path()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = cppSelf->path();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef Sbk_QDirIterator_methods[] = {
    {"fileInfo", (PyCFunction)Sbk_QDirIteratorFunc_fileInfo, METH_NOARGS},
    {"fileName", (PyCFunction)Sbk_QDirIteratorFunc_fileName, METH_NOARGS},
    {"filePath", (PyCFunction)Sbk_QDirIteratorFunc_filePath, METH_NOARGS},
    {"hasNext", (PyCFunction)Sbk_QDirIteratorFunc_hasNext, METH_NOARGS},
    {"next", (PyCFunction)Sbk_QDirIteratorFunc_next, METH_NOARGS},
    {"path", (PyCFunction)Sbk_QDirIteratorFunc_path, METH_NOARGS},

    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QDirIterator_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtCore.QDirIterator",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QDirIterator_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QDirIterator_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern

PyObject* SbkPySide_QtCore_QDirIterator_IteratorFlag___and__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QDirIterator::IteratorFlags >::toPython(
        Shiboken::Converter<QDirIterator::IteratorFlags>::toCpp(self)
        & Shiboken::Converter< QDirIterator::IteratorFlags >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtCore_QDirIterator_IteratorFlag___or__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QDirIterator::IteratorFlags >::toPython(
        Shiboken::Converter<QDirIterator::IteratorFlags>::toCpp(self)
        | Shiboken::Converter< QDirIterator::IteratorFlags >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtCore_QDirIterator_IteratorFlag___xor__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QDirIterator::IteratorFlags >::toPython(
        Shiboken::Converter<QDirIterator::IteratorFlags>::toCpp(self)
        ^ Shiboken::Converter< QDirIterator::IteratorFlags >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtCore_QDirIterator_IteratorFlag___invert__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QDirIterator::IteratorFlags >::toPython(
        ~Shiboken::Converter<QDirIterator::IteratorFlags >::toCpp(self)
    );
}


static PyNumberMethods SbkPySide_QtCore_QDirIterator_IteratorFlag_as_number = {
    /*nb_add*/                  0,
    /*nb_subtract*/             0,
    /*nb_multiply*/             0,
    /*nb_divide*/               0,
    /*nb_remainder*/            0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             0,
    /*nb_positive*/             0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              0,
    /*nb_invert*/               (unaryfunc)SbkPySide_QtCore_QDirIterator_IteratorFlag___invert__,
    /*nb_lshift*/               0,
    /*nb_rshift*/               0,
    /*nb_and*/                  (binaryfunc)SbkPySide_QtCore_QDirIterator_IteratorFlag___and__,
    /*nb_xor*/                  (binaryfunc)SbkPySide_QtCore_QDirIterator_IteratorFlag___xor__,
    /*nb_or*/                   (binaryfunc)SbkPySide_QtCore_QDirIterator_IteratorFlag___or__,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          0,
    /*nb_inplace_subtract*/     0,
    /*nb_inplace_multiply*/     0,
    /*nb_inplace_divide*/       0,
    /*nb_inplace_remainder*/    0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       0,
    /*nb_inplace_rshift*/       0,
    /*nb_inplace_and*/          0,
    /*nb_inplace_xor*/          0,
    /*nb_inplace_or*/           0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};


// forward declaration of new function
static PyTypeObject SbkPySide_QtCore_QDirIterator_IteratorFlags_Type = {
    PyObject_HEAD_INIT(&PyType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "IteratorFlags",
    /*tp_basicsize*/        0,
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        &SbkPySide_QtCore_QDirIterator_IteratorFlag_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT | Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              PyInt_Type.tp_new,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};



void init_QDirIterator(PyObject* module)
{
    SbkPySide_QtCoreTypes[SBK_QDIRITERATOR_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QDirIterator_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QDirIterator_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QDirIterator_Type, &Shiboken::callCppDestructor<QDirIterator >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QDirIterator_Type) < 0)
        return;

    // Fill type discovery information

    Shiboken::ObjectType::setOriginalName(&Sbk_QDirIterator_Type, "QDirIterator*");
    PyModule_AddObject(module, "QDirIterator",
        ((PyObject*)&Sbk_QDirIterator_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: IteratorFlag
    PyTypeObject* SbkPySide_QtCore_QDirIterator_IteratorFlag = Shiboken::Enum::newType("IteratorFlag");
    SbkPySide_QtCore_QDirIterator_IteratorFlag->tp_as_number = &SbkPySide_QtCore_QDirIterator_IteratorFlag_as_number;
    SbkPySide_QtCoreTypes[SBK_QDIRITERATOR_ITERATORFLAG_IDX] = SbkPySide_QtCore_QDirIterator_IteratorFlag;
    if (PyType_Ready(SbkPySide_QtCore_QDirIterator_IteratorFlag) < 0)
        return;
    PyDict_SetItemString(Sbk_QDirIterator_Type.super.ht_type.tp_dict,
            "IteratorFlag",((PyObject*)SbkPySide_QtCore_QDirIterator_IteratorFlag));

    // init flags class: QFlags<QDirIterator::IteratorFlag>
    SbkPySide_QtCoreTypes[SBK_QFLAGS_QDIRITERATOR_ITERATORFLAG__IDX] = &SbkPySide_QtCore_QDirIterator_IteratorFlags_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtCore_QDirIterator_IteratorFlags_Type) < 0)
        return;
    PyDict_SetItemString(Sbk_QDirIterator_Type.super.ht_type.tp_dict,
            "IteratorFlags",((PyObject*)&SbkPySide_QtCore_QDirIterator_IteratorFlags_Type));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QDirIterator_IteratorFlag,(long) QDirIterator::NoIteratorFlags, "NoIteratorFlags");
    PyDict_SetItemString(Sbk_QDirIterator_Type.super.ht_type.tp_dict,"NoIteratorFlags", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QDirIterator_IteratorFlag->tp_dict,"NoIteratorFlags", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QDirIterator_IteratorFlag,(long) QDirIterator::FollowSymlinks, "FollowSymlinks");
    PyDict_SetItemString(Sbk_QDirIterator_Type.super.ht_type.tp_dict,"FollowSymlinks", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QDirIterator_IteratorFlag->tp_dict,"FollowSymlinks", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QDirIterator_IteratorFlag,(long) QDirIterator::Subdirectories, "Subdirectories");
    PyDict_SetItemString(Sbk_QDirIterator_Type.super.ht_type.tp_dict,"Subdirectories", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QDirIterator_IteratorFlag->tp_dict,"Subdirectories", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QDirIterator::IteratorFlag");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::IteratorFlag");
    // end of enum IteratorFlag


    Shiboken::TypeResolver::createObjectTypeResolver<QDirIterator >("QDirIterator*");
    Shiboken::TypeResolver::createObjectTypeResolver<QDirIterator >(typeid(QDirIterator).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QDirIterator >(typeid(QDirIteratorWrapper).name());
    PySide::initQtMetaType<QDirIterator* >();
}

