/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtcore_python.h"

#include "qeasingcurve_wrapper.h"

// Extra includes
#include <qeasingcurve.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QEasingCurve_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QEasingCurve >()))
        return -1;

    QEasingCurve* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);

    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QEasingCurve(): too many arguments");
        return -1;
    }

    if (!PyArg_ParseTuple(args, "|O:QEasingCurve", &(pyargs[0])))
        return -1;

    // Overloaded function decisor
    // 0: QEasingCurve(QEasingCurve::Type)
    // 1: QEasingCurve(QEasingCurve)
    if (numArgs == 0) {
        overloadId = 0; // QEasingCurve(QEasingCurve::Type)
    } else if (Shiboken::Converter< ::QEasingCurve::Type >::isConvertible(pyargs[0])) {
        overloadId = 0; // QEasingCurve(QEasingCurve::Type)
    } else if (numArgs == 1 && Shiboken::Converter< ::QEasingCurve >::isConvertible(pyargs[0])) {
        overloadId = 1; // QEasingCurve(QEasingCurve)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QEasingCurve_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QEasingCurve(QEasingCurve::Type)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "type");
                    if (value) {
                        if (pyargs[0])
                            errorArgName = "type";
                        else if (Shiboken::Converter< ::QEasingCurve::Type >::isConvertible(value))
                            pyargs[0] = value;
else
                            goto Sbk_QEasingCurve_Init_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtCore.QEasingCurve(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                QEasingCurve::Type cppArg0 = pyargs[0] ? Shiboken::Converter<QEasingCurve::Type >::toCpp(pyargs[0]) : QEasingCurve::Linear;

                if(!PyErr_Occurred()) {
                    // QEasingCurve(QEasingCurve::Type)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QEasingCurve(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // QEasingCurve(QEasingCurve)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QEasingCurve cppArg0 = Shiboken::Converter<QEasingCurve >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QEasingCurve(QEasingCurve)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QEasingCurve(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QEasingCurve >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QEasingCurve_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QEasingCurve_Init_TypeError:
        const char* overloads[] = {"PySide.QtCore.QEasingCurve.Type = Linear", "PySide.QtCore.QEasingCurve", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QEasingCurve", overloads);
        return -1;
}

static PyObject* Sbk_QEasingCurveFunc_amplitude(PyObject* self)
{
    QEasingCurve* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QEasingCurve* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // amplitude()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qreal cppResult = cppSelf->amplitude();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< double >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QEasingCurveFunc_overshoot(PyObject* self)
{
    QEasingCurve* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QEasingCurve* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // overshoot()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qreal cppResult = cppSelf->overshoot();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< double >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QEasingCurveFunc_period(PyObject* self)
{
    QEasingCurve* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QEasingCurve* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // period()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qreal cppResult = cppSelf->period();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< double >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QEasingCurveFunc_setAmplitude(PyObject* self, PyObject* arg)
{
    QEasingCurve* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QEasingCurve* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setAmplitude(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setAmplitude(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QEasingCurveFunc_setAmplitude_TypeError;

    // Call function/method
    {
        {
            qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setAmplitude(qreal)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setAmplitude(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QEasingCurveFunc_setAmplitude_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QEasingCurve.setAmplitude", overloads);
        return 0;
}

static PyObject* Sbk_QEasingCurveFunc_setOvershoot(PyObject* self, PyObject* arg)
{
    QEasingCurve* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QEasingCurve* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setOvershoot(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setOvershoot(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QEasingCurveFunc_setOvershoot_TypeError;

    // Call function/method
    {
        {
            qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setOvershoot(qreal)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setOvershoot(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QEasingCurveFunc_setOvershoot_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QEasingCurve.setOvershoot", overloads);
        return 0;
}

static PyObject* Sbk_QEasingCurveFunc_setPeriod(PyObject* self, PyObject* arg)
{
    QEasingCurve* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QEasingCurve* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setPeriod(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setPeriod(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QEasingCurveFunc_setPeriod_TypeError;

    // Call function/method
    {
        {
            qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setPeriod(qreal)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setPeriod(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QEasingCurveFunc_setPeriod_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QEasingCurve.setPeriod", overloads);
        return 0;
}

static PyObject* Sbk_QEasingCurveFunc_setType(PyObject* self, PyObject* arg)
{
    QEasingCurve* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QEasingCurve* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setType(QEasingCurve::Type)
    if (Shiboken::Converter< ::QEasingCurve::Type >::isConvertible(arg)) {
        overloadId = 0; // setType(QEasingCurve::Type)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QEasingCurveFunc_setType_TypeError;

    // Call function/method
    {
        {
            QEasingCurve::Type cppArg0 = Shiboken::Converter<QEasingCurve::Type >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setType(QEasingCurve::Type)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setType(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QEasingCurveFunc_setType_TypeError:
        const char* overloads[] = {"PySide.QtCore.QEasingCurve.Type", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QEasingCurve.setType", overloads);
        return 0;
}

static PyObject* Sbk_QEasingCurveFunc_type(PyObject* self)
{
    QEasingCurve* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QEasingCurve* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // type()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QEasingCurve::Type cppResult = cppSelf->type();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QEasingCurve::Type >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QEasingCurveFunc_valueForProgress(PyObject* self, PyObject* arg)
{
    QEasingCurve* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QEasingCurve* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: valueForProgress(qreal)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // valueForProgress(qreal)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QEasingCurveFunc_valueForProgress_TypeError;

    // Call function/method
    {
        {
            qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // valueForProgress(qreal)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qreal cppResult = cppSelf->valueForProgress(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< double >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QEasingCurveFunc_valueForProgress_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QEasingCurve.valueForProgress", overloads);
        return 0;
}

static PyObject *Sbk_QEasingCurve___copy__(PyObject *self)
{
        QEasingCurve* cppSelf = 0;
        if (!Shiboken::Object::isValid(self))
            return 0;
        cppSelf = Shiboken::Converter<QEasingCurve*>::toCpp(self);
        PyObject* pyResult = 0;
        QEasingCurve* copy = new QEasingCurve(*cppSelf);
        pyResult = Shiboken::Converter<QEasingCurve*>::toPython(copy);
        Shiboken::Object::getOwnership(pyResult);

        if (PyErr_Occurred() || !pyResult) {
            Py_XDECREF(pyResult);
            return 0;
        }
        return pyResult;
}

static PyMethodDef Sbk_QEasingCurve_methods[] = {
    {"amplitude", (PyCFunction)Sbk_QEasingCurveFunc_amplitude, METH_NOARGS},
    {"overshoot", (PyCFunction)Sbk_QEasingCurveFunc_overshoot, METH_NOARGS},
    {"period", (PyCFunction)Sbk_QEasingCurveFunc_period, METH_NOARGS},
    {"setAmplitude", (PyCFunction)Sbk_QEasingCurveFunc_setAmplitude, METH_O},
    {"setOvershoot", (PyCFunction)Sbk_QEasingCurveFunc_setOvershoot, METH_O},
    {"setPeriod", (PyCFunction)Sbk_QEasingCurveFunc_setPeriod, METH_O},
    {"setType", (PyCFunction)Sbk_QEasingCurveFunc_setType, METH_O},
    {"type", (PyCFunction)Sbk_QEasingCurveFunc_type, METH_NOARGS},
    {"valueForProgress", (PyCFunction)Sbk_QEasingCurveFunc_valueForProgress, METH_O},

    {"__copy__", (PyCFunction)Sbk_QEasingCurve___copy__, METH_NOARGS},
    {0} // Sentinel
};

// Rich comparison
static PyObject* Sbk_QEasingCurve_richcompare(PyObject* self, PyObject* arg, int op)
{
    PyObject* pyResult = 0;
    QEasingCurve& cppSelf = *Shiboken::Converter< QEasingCurve* >::toCpp(self);

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter< ::QEasingCurve >::isConvertible(arg)) {
                // operator!=(const QEasingCurve & other) const
                QEasingCurve cppArg0 = Shiboken::Converter< ::QEasingCurve >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf != cppArg0);
            } else goto Sbk_QEasingCurve_RichComparison_TypeError;

            break;
        case Py_EQ:
            if (Shiboken::Converter< ::QEasingCurve >::isConvertible(arg)) {
                // operator==(const QEasingCurve & other) const
                QEasingCurve cppArg0 = Shiboken::Converter< ::QEasingCurve >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf == cppArg0);
            } else goto Sbk_QEasingCurve_RichComparison_TypeError;

            break;
        default:
            goto Sbk_QEasingCurve_RichComparison_TypeError;
    }

    if (pyResult && !PyErr_Occurred())
        return pyResult;
    Sbk_QEasingCurve_RichComparison_TypeError:
    PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
    return 0;

}

} // extern "C"

extern "C"
{
static PyObject* Sbk_QEasingCurve__repr__(PyObject* pyObj)
{
    QBuffer buffer;
    buffer.open(QBuffer::ReadWrite);
    QDebug dbg(&buffer);
    dbg << Shiboken::Converter< ::QEasingCurve >::toCpp(pyObj);
    buffer.close();
    return PyString_FromFormat("<PySide.QtCore.%s at %p>", buffer.data().constData(), pyObj);
}
} // extern C

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QEasingCurve_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtCore.QEasingCurve",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Sbk_QEasingCurve__repr__,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      Sbk_QEasingCurve_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QEasingCurve_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QEasingCurve_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QEasingCurve(PyObject* module)
{
    SbkPySide_QtCoreTypes[SBK_QEASINGCURVE_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QEasingCurve_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QEasingCurve_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QEasingCurve_Type, &Shiboken::callCppDestructor<QEasingCurve >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QEasingCurve_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QEasingCurve_Type, "QEasingCurve");
    PyModule_AddObject(module, "QEasingCurve",
        ((PyObject*)&Sbk_QEasingCurve_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: Type
    PyTypeObject* SbkPySide_QtCore_QEasingCurve_Type = Shiboken::Enum::newType("Type");
    SbkPySide_QtCoreTypes[SBK_QEASINGCURVE_TYPE_IDX] = SbkPySide_QtCore_QEasingCurve_Type;
    if (PyType_Ready(SbkPySide_QtCore_QEasingCurve_Type) < 0)
        return;
    PyDict_SetItemString(Sbk_QEasingCurve_Type.super.ht_type.tp_dict,
            "Type",((PyObject*)SbkPySide_QtCore_QEasingCurve_Type));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEasingCurve_Type,(long) QEasingCurve::Linear, "Linear");
    PyDict_SetItemString(Sbk_QEasingCurve_Type.super.ht_type.tp_dict,"Linear", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEasingCurve_Type->tp_dict,"Linear", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEasingCurve_Type,(long) QEasingCurve::InQuad, "InQuad");
    PyDict_SetItemString(Sbk_QEasingCurve_Type.super.ht_type.tp_dict,"InQuad", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEasingCurve_Type->tp_dict,"InQuad", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEasingCurve_Type,(long) QEasingCurve::OutQuad, "OutQuad");
    PyDict_SetItemString(Sbk_QEasingCurve_Type.super.ht_type.tp_dict,"OutQuad", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEasingCurve_Type->tp_dict,"OutQuad", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEasingCurve_Type,(long) QEasingCurve::InOutQuad, "InOutQuad");
    PyDict_SetItemString(Sbk_QEasingCurve_Type.super.ht_type.tp_dict,"InOutQuad", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEasingCurve_Type->tp_dict,"InOutQuad", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEasingCurve_Type,(long) QEasingCurve::OutInQuad, "OutInQuad");
    PyDict_SetItemString(Sbk_QEasingCurve_Type.super.ht_type.tp_dict,"OutInQuad", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEasingCurve_Type->tp_dict,"OutInQuad", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEasingCurve_Type,(long) QEasingCurve::InCubic, "InCubic");
    PyDict_SetItemString(Sbk_QEasingCurve_Type.super.ht_type.tp_dict,"InCubic", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEasingCurve_Type->tp_dict,"InCubic", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEasingCurve_Type,(long) QEasingCurve::OutCubic, "OutCubic");
    PyDict_SetItemString(Sbk_QEasingCurve_Type.super.ht_type.tp_dict,"OutCubic", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEasingCurve_Type->tp_dict,"OutCubic", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEasingCurve_Type,(long) QEasingCurve::InOutCubic, "InOutCubic");
    PyDict_SetItemString(Sbk_QEasingCurve_Type.super.ht_type.tp_dict,"InOutCubic", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEasingCurve_Type->tp_dict,"InOutCubic", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEasingCurve_Type,(long) QEasingCurve::OutInCubic, "OutInCubic");
    PyDict_SetItemString(Sbk_QEasingCurve_Type.super.ht_type.tp_dict,"OutInCubic", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEasingCurve_Type->tp_dict,"OutInCubic", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEasingCurve_Type,(long) QEasingCurve::InQuart, "InQuart");
    PyDict_SetItemString(Sbk_QEasingCurve_Type.super.ht_type.tp_dict,"InQuart", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEasingCurve_Type->tp_dict,"InQuart", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEasingCurve_Type,(long) QEasingCurve::OutQuart, "OutQuart");
    PyDict_SetItemString(Sbk_QEasingCurve_Type.super.ht_type.tp_dict,"OutQuart", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEasingCurve_Type->tp_dict,"OutQuart", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEasingCurve_Type,(long) QEasingCurve::InOutQuart, "InOutQuart");
    PyDict_SetItemString(Sbk_QEasingCurve_Type.super.ht_type.tp_dict,"InOutQuart", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEasingCurve_Type->tp_dict,"InOutQuart", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEasingCurve_Type,(long) QEasingCurve::OutInQuart, "OutInQuart");
    PyDict_SetItemString(Sbk_QEasingCurve_Type.super.ht_type.tp_dict,"OutInQuart", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEasingCurve_Type->tp_dict,"OutInQuart", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEasingCurve_Type,(long) QEasingCurve::InQuint, "InQuint");
    PyDict_SetItemString(Sbk_QEasingCurve_Type.super.ht_type.tp_dict,"InQuint", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEasingCurve_Type->tp_dict,"InQuint", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEasingCurve_Type,(long) QEasingCurve::OutQuint, "OutQuint");
    PyDict_SetItemString(Sbk_QEasingCurve_Type.super.ht_type.tp_dict,"OutQuint", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEasingCurve_Type->tp_dict,"OutQuint", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEasingCurve_Type,(long) QEasingCurve::InOutQuint, "InOutQuint");
    PyDict_SetItemString(Sbk_QEasingCurve_Type.super.ht_type.tp_dict,"InOutQuint", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEasingCurve_Type->tp_dict,"InOutQuint", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEasingCurve_Type,(long) QEasingCurve::OutInQuint, "OutInQuint");
    PyDict_SetItemString(Sbk_QEasingCurve_Type.super.ht_type.tp_dict,"OutInQuint", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEasingCurve_Type->tp_dict,"OutInQuint", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEasingCurve_Type,(long) QEasingCurve::InSine, "InSine");
    PyDict_SetItemString(Sbk_QEasingCurve_Type.super.ht_type.tp_dict,"InSine", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEasingCurve_Type->tp_dict,"InSine", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEasingCurve_Type,(long) QEasingCurve::OutSine, "OutSine");
    PyDict_SetItemString(Sbk_QEasingCurve_Type.super.ht_type.tp_dict,"OutSine", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEasingCurve_Type->tp_dict,"OutSine", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEasingCurve_Type,(long) QEasingCurve::InOutSine, "InOutSine");
    PyDict_SetItemString(Sbk_QEasingCurve_Type.super.ht_type.tp_dict,"InOutSine", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEasingCurve_Type->tp_dict,"InOutSine", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEasingCurve_Type,(long) QEasingCurve::OutInSine, "OutInSine");
    PyDict_SetItemString(Sbk_QEasingCurve_Type.super.ht_type.tp_dict,"OutInSine", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEasingCurve_Type->tp_dict,"OutInSine", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEasingCurve_Type,(long) QEasingCurve::InExpo, "InExpo");
    PyDict_SetItemString(Sbk_QEasingCurve_Type.super.ht_type.tp_dict,"InExpo", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEasingCurve_Type->tp_dict,"InExpo", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEasingCurve_Type,(long) QEasingCurve::OutExpo, "OutExpo");
    PyDict_SetItemString(Sbk_QEasingCurve_Type.super.ht_type.tp_dict,"OutExpo", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEasingCurve_Type->tp_dict,"OutExpo", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEasingCurve_Type,(long) QEasingCurve::InOutExpo, "InOutExpo");
    PyDict_SetItemString(Sbk_QEasingCurve_Type.super.ht_type.tp_dict,"InOutExpo", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEasingCurve_Type->tp_dict,"InOutExpo", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEasingCurve_Type,(long) QEasingCurve::OutInExpo, "OutInExpo");
    PyDict_SetItemString(Sbk_QEasingCurve_Type.super.ht_type.tp_dict,"OutInExpo", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEasingCurve_Type->tp_dict,"OutInExpo", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEasingCurve_Type,(long) QEasingCurve::InCirc, "InCirc");
    PyDict_SetItemString(Sbk_QEasingCurve_Type.super.ht_type.tp_dict,"InCirc", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEasingCurve_Type->tp_dict,"InCirc", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEasingCurve_Type,(long) QEasingCurve::OutCirc, "OutCirc");
    PyDict_SetItemString(Sbk_QEasingCurve_Type.super.ht_type.tp_dict,"OutCirc", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEasingCurve_Type->tp_dict,"OutCirc", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEasingCurve_Type,(long) QEasingCurve::InOutCirc, "InOutCirc");
    PyDict_SetItemString(Sbk_QEasingCurve_Type.super.ht_type.tp_dict,"InOutCirc", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEasingCurve_Type->tp_dict,"InOutCirc", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEasingCurve_Type,(long) QEasingCurve::OutInCirc, "OutInCirc");
    PyDict_SetItemString(Sbk_QEasingCurve_Type.super.ht_type.tp_dict,"OutInCirc", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEasingCurve_Type->tp_dict,"OutInCirc", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEasingCurve_Type,(long) QEasingCurve::InElastic, "InElastic");
    PyDict_SetItemString(Sbk_QEasingCurve_Type.super.ht_type.tp_dict,"InElastic", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEasingCurve_Type->tp_dict,"InElastic", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEasingCurve_Type,(long) QEasingCurve::OutElastic, "OutElastic");
    PyDict_SetItemString(Sbk_QEasingCurve_Type.super.ht_type.tp_dict,"OutElastic", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEasingCurve_Type->tp_dict,"OutElastic", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEasingCurve_Type,(long) QEasingCurve::InOutElastic, "InOutElastic");
    PyDict_SetItemString(Sbk_QEasingCurve_Type.super.ht_type.tp_dict,"InOutElastic", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEasingCurve_Type->tp_dict,"InOutElastic", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEasingCurve_Type,(long) QEasingCurve::OutInElastic, "OutInElastic");
    PyDict_SetItemString(Sbk_QEasingCurve_Type.super.ht_type.tp_dict,"OutInElastic", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEasingCurve_Type->tp_dict,"OutInElastic", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEasingCurve_Type,(long) QEasingCurve::InBack, "InBack");
    PyDict_SetItemString(Sbk_QEasingCurve_Type.super.ht_type.tp_dict,"InBack", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEasingCurve_Type->tp_dict,"InBack", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEasingCurve_Type,(long) QEasingCurve::OutBack, "OutBack");
    PyDict_SetItemString(Sbk_QEasingCurve_Type.super.ht_type.tp_dict,"OutBack", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEasingCurve_Type->tp_dict,"OutBack", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEasingCurve_Type,(long) QEasingCurve::InOutBack, "InOutBack");
    PyDict_SetItemString(Sbk_QEasingCurve_Type.super.ht_type.tp_dict,"InOutBack", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEasingCurve_Type->tp_dict,"InOutBack", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEasingCurve_Type,(long) QEasingCurve::OutInBack, "OutInBack");
    PyDict_SetItemString(Sbk_QEasingCurve_Type.super.ht_type.tp_dict,"OutInBack", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEasingCurve_Type->tp_dict,"OutInBack", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEasingCurve_Type,(long) QEasingCurve::InBounce, "InBounce");
    PyDict_SetItemString(Sbk_QEasingCurve_Type.super.ht_type.tp_dict,"InBounce", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEasingCurve_Type->tp_dict,"InBounce", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEasingCurve_Type,(long) QEasingCurve::OutBounce, "OutBounce");
    PyDict_SetItemString(Sbk_QEasingCurve_Type.super.ht_type.tp_dict,"OutBounce", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEasingCurve_Type->tp_dict,"OutBounce", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEasingCurve_Type,(long) QEasingCurve::InOutBounce, "InOutBounce");
    PyDict_SetItemString(Sbk_QEasingCurve_Type.super.ht_type.tp_dict,"InOutBounce", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEasingCurve_Type->tp_dict,"InOutBounce", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEasingCurve_Type,(long) QEasingCurve::OutInBounce, "OutInBounce");
    PyDict_SetItemString(Sbk_QEasingCurve_Type.super.ht_type.tp_dict,"OutInBounce", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEasingCurve_Type->tp_dict,"OutInBounce", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEasingCurve_Type,(long) QEasingCurve::InCurve, "InCurve");
    PyDict_SetItemString(Sbk_QEasingCurve_Type.super.ht_type.tp_dict,"InCurve", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEasingCurve_Type->tp_dict,"InCurve", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEasingCurve_Type,(long) QEasingCurve::OutCurve, "OutCurve");
    PyDict_SetItemString(Sbk_QEasingCurve_Type.super.ht_type.tp_dict,"OutCurve", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEasingCurve_Type->tp_dict,"OutCurve", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEasingCurve_Type,(long) QEasingCurve::SineCurve, "SineCurve");
    PyDict_SetItemString(Sbk_QEasingCurve_Type.super.ht_type.tp_dict,"SineCurve", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEasingCurve_Type->tp_dict,"SineCurve", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEasingCurve_Type,(long) QEasingCurve::CosineCurve, "CosineCurve");
    PyDict_SetItemString(Sbk_QEasingCurve_Type.super.ht_type.tp_dict,"CosineCurve", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEasingCurve_Type->tp_dict,"CosineCurve", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEasingCurve_Type,(long) QEasingCurve::Custom, "Custom");
    PyDict_SetItemString(Sbk_QEasingCurve_Type.super.ht_type.tp_dict,"Custom", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEasingCurve_Type->tp_dict,"Custom", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QEasingCurve_Type,(long) QEasingCurve::NCurveTypes, "NCurveTypes");
    PyDict_SetItemString(Sbk_QEasingCurve_Type.super.ht_type.tp_dict,"NCurveTypes", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QEasingCurve_Type->tp_dict,"NCurveTypes", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QEasingCurve::Type");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::Type");
    // end of enum Type


    Shiboken::TypeResolver::createValueTypeResolver<QEasingCurve >("QEasingCurve");
    Shiboken::TypeResolver::createObjectTypeResolver<QEasingCurve >("QEasingCurve*");
    Shiboken::TypeResolver::createValueTypeResolver<QEasingCurve >(typeid(QEasingCurve).name());
    PySide::initQtMetaType<QEasingCurve >();
}

