/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtcore_python.h"

#include "qmetaobject_wrapper.h"

// Extra includes
#include <qbytearray.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QMetaObject_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QMetaObject >()))
        return -1;

    QMetaObject* cptr = 0;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // QMetaObject()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new QMetaObject();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QMetaObject >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject* Sbk_QMetaObjectFunc_cast(PyObject* self, PyObject* arg)
{
    QMetaObject* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMetaObject* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: cast(QObject*)const
    if (Shiboken::Converter< ::QObject * >::isConvertible(arg)) {
        overloadId = 0; // cast(QObject*)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QMetaObjectFunc_cast_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QObject * cppArg0 = Shiboken::Converter<QObject * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // cast(QObject*)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QObject * cppResult = cppSelf->cast(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QObject * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QMetaObjectFunc_cast_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QMetaObject.cast", overloads);
        return 0;
}

static PyObject* Sbk_QMetaObjectFunc_checkConnectArgs(PyObject* self, PyObject* args)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "checkConnectArgs", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: checkConnectArgs(const char*,const char*)
    if (numArgs == 2 && Shiboken::Converter< const char * >::isConvertible(pyargs[0]) && Shiboken::Converter< const char * >::isConvertible(pyargs[1])) {
        overloadId = 0; // checkConnectArgs(const char*,const char*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QMetaObjectFunc_checkConnectArgs_TypeError;

    // Call function/method
    {
        {
            const char * cppArg0 = Shiboken::Converter<const char * >::toCpp(pyargs[0]);
            const char * cppArg1 = Shiboken::Converter<const char * >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // checkConnectArgs(const char*,const char*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = QMetaObject::checkConnectArgs(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QMetaObjectFunc_checkConnectArgs_TypeError:
        const char* overloads[] = {"str, str", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QMetaObject.checkConnectArgs", overloads);
        return 0;
}

static PyObject* Sbk_QMetaObjectFunc_classInfo(PyObject* self, PyObject* arg)
{
    QMetaObject* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMetaObject* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: classInfo(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // classInfo(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QMetaObjectFunc_classInfo_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // classInfo(int)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QMetaClassInfo cppResult = cppSelf->classInfo(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QMetaClassInfo >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QMetaObjectFunc_classInfo_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QMetaObject.classInfo", overloads);
        return 0;
}

static PyObject* Sbk_QMetaObjectFunc_classInfoCount(PyObject* self)
{
    QMetaObject* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMetaObject* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // classInfoCount()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->classInfoCount();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QMetaObjectFunc_classInfoOffset(PyObject* self)
{
    QMetaObject* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMetaObject* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // classInfoOffset()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->classInfoOffset();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QMetaObjectFunc_className(PyObject* self)
{
    QMetaObject* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMetaObject* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // className()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                const char * cppResult = cppSelf->className();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< const char * >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QMetaObjectFunc_connectSlotsByName(PyObject* self, PyObject* arg)
{
    int overloadId = -1;

    // Overloaded function decisor
    // 0: connectSlotsByName(QObject*)
    if (Shiboken::Converter< ::QObject * >::isConvertible(arg)) {
        overloadId = 0; // connectSlotsByName(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QMetaObjectFunc_connectSlotsByName_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QObject * cppArg0 = Shiboken::Converter<QObject * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // connectSlotsByName(QObject*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QMetaObject::connectSlotsByName(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QMetaObjectFunc_connectSlotsByName_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QMetaObject.connectSlotsByName", overloads);
        return 0;
}

static PyObject* Sbk_QMetaObjectFunc_constructor(PyObject* self, PyObject* arg)
{
    QMetaObject* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMetaObject* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: constructor(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // constructor(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QMetaObjectFunc_constructor_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // constructor(int)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QMetaMethod cppResult = cppSelf->constructor(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QMetaMethod >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QMetaObjectFunc_constructor_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QMetaObject.constructor", overloads);
        return 0;
}

static PyObject* Sbk_QMetaObjectFunc_constructorCount(PyObject* self)
{
    QMetaObject* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMetaObject* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // constructorCount()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->constructorCount();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QMetaObjectFunc_disconnect(PyObject* self, PyObject* args)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "disconnect", 4, 4, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: disconnect(const QObject*,int,const QObject*,int)
    if (numArgs == 4 && Shiboken::Converter< ::QObject * >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1]) && Shiboken::Converter< ::QObject * >::isConvertible(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
        overloadId = 0; // disconnect(const QObject*,int,const QObject*,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QMetaObjectFunc_disconnect_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QObject * cppArg0 = Shiboken::Converter<QObject * >::toCpp(pyargs[0]);
            int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
            if (!Shiboken::Object::isValid(pyargs[2]))
                return 0;
            QObject * cppArg2 = Shiboken::Converter<QObject * >::toCpp(pyargs[2]);
            int cppArg3 = Shiboken::Converter<int >::toCpp(pyargs[3]);

            if(!PyErr_Occurred()) {
                // disconnect(const QObject*,int,const QObject*,int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = QMetaObject::disconnect(cppArg0, cppArg1, cppArg2, cppArg3);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QMetaObjectFunc_disconnect_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject, int, PySide.QtCore.QObject, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QMetaObject.disconnect", overloads);
        return 0;
}

static PyObject* Sbk_QMetaObjectFunc_enumerator(PyObject* self, PyObject* arg)
{
    QMetaObject* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMetaObject* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: enumerator(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // enumerator(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QMetaObjectFunc_enumerator_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // enumerator(int)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QMetaEnum cppResult = cppSelf->enumerator(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QMetaEnum >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QMetaObjectFunc_enumerator_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QMetaObject.enumerator", overloads);
        return 0;
}

static PyObject* Sbk_QMetaObjectFunc_enumeratorCount(PyObject* self)
{
    QMetaObject* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMetaObject* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // enumeratorCount()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->enumeratorCount();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QMetaObjectFunc_enumeratorOffset(PyObject* self)
{
    QMetaObject* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMetaObject* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // enumeratorOffset()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->enumeratorOffset();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QMetaObjectFunc_indexOfClassInfo(PyObject* self, PyObject* arg)
{
    QMetaObject* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMetaObject* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: indexOfClassInfo(const char*)const
    if (Shiboken::Converter< const char * >::isConvertible(arg)) {
        overloadId = 0; // indexOfClassInfo(const char*)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QMetaObjectFunc_indexOfClassInfo_TypeError;

    // Call function/method
    {
        {
            const char * cppArg0 = Shiboken::Converter<const char * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // indexOfClassInfo(const char*)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->indexOfClassInfo(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QMetaObjectFunc_indexOfClassInfo_TypeError:
        const char* overloads[] = {"str", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QMetaObject.indexOfClassInfo", overloads);
        return 0;
}

static PyObject* Sbk_QMetaObjectFunc_indexOfConstructor(PyObject* self, PyObject* arg)
{
    QMetaObject* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMetaObject* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: indexOfConstructor(const char*)const
    if (Shiboken::Converter< const char * >::isConvertible(arg)) {
        overloadId = 0; // indexOfConstructor(const char*)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QMetaObjectFunc_indexOfConstructor_TypeError;

    // Call function/method
    {
        {
            const char * cppArg0 = Shiboken::Converter<const char * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // indexOfConstructor(const char*)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->indexOfConstructor(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QMetaObjectFunc_indexOfConstructor_TypeError:
        const char* overloads[] = {"str", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QMetaObject.indexOfConstructor", overloads);
        return 0;
}

static PyObject* Sbk_QMetaObjectFunc_indexOfEnumerator(PyObject* self, PyObject* arg)
{
    QMetaObject* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMetaObject* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: indexOfEnumerator(const char*)const
    if (Shiboken::Converter< const char * >::isConvertible(arg)) {
        overloadId = 0; // indexOfEnumerator(const char*)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QMetaObjectFunc_indexOfEnumerator_TypeError;

    // Call function/method
    {
        {
            const char * cppArg0 = Shiboken::Converter<const char * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // indexOfEnumerator(const char*)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->indexOfEnumerator(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QMetaObjectFunc_indexOfEnumerator_TypeError:
        const char* overloads[] = {"str", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QMetaObject.indexOfEnumerator", overloads);
        return 0;
}

static PyObject* Sbk_QMetaObjectFunc_indexOfMethod(PyObject* self, PyObject* arg)
{
    QMetaObject* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMetaObject* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: indexOfMethod(const char*)const
    if (Shiboken::Converter< const char * >::isConvertible(arg)) {
        overloadId = 0; // indexOfMethod(const char*)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QMetaObjectFunc_indexOfMethod_TypeError;

    // Call function/method
    {
        {
            const char * cppArg0 = Shiboken::Converter<const char * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // indexOfMethod(const char*)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->indexOfMethod(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QMetaObjectFunc_indexOfMethod_TypeError:
        const char* overloads[] = {"str", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QMetaObject.indexOfMethod", overloads);
        return 0;
}

static PyObject* Sbk_QMetaObjectFunc_indexOfProperty(PyObject* self, PyObject* arg)
{
    QMetaObject* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMetaObject* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: indexOfProperty(const char*)const
    if (Shiboken::Converter< const char * >::isConvertible(arg)) {
        overloadId = 0; // indexOfProperty(const char*)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QMetaObjectFunc_indexOfProperty_TypeError;

    // Call function/method
    {
        {
            const char * cppArg0 = Shiboken::Converter<const char * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // indexOfProperty(const char*)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->indexOfProperty(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QMetaObjectFunc_indexOfProperty_TypeError:
        const char* overloads[] = {"str", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QMetaObject.indexOfProperty", overloads);
        return 0;
}

static PyObject* Sbk_QMetaObjectFunc_indexOfSignal(PyObject* self, PyObject* arg)
{
    QMetaObject* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMetaObject* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: indexOfSignal(const char*)const
    if (Shiboken::Converter< const char * >::isConvertible(arg)) {
        overloadId = 0; // indexOfSignal(const char*)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QMetaObjectFunc_indexOfSignal_TypeError;

    // Call function/method
    {
        {
            const char * cppArg0 = Shiboken::Converter<const char * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // indexOfSignal(const char*)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->indexOfSignal(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QMetaObjectFunc_indexOfSignal_TypeError:
        const char* overloads[] = {"str", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QMetaObject.indexOfSignal", overloads);
        return 0;
}

static PyObject* Sbk_QMetaObjectFunc_indexOfSlot(PyObject* self, PyObject* arg)
{
    QMetaObject* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMetaObject* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: indexOfSlot(const char*)const
    if (Shiboken::Converter< const char * >::isConvertible(arg)) {
        overloadId = 0; // indexOfSlot(const char*)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QMetaObjectFunc_indexOfSlot_TypeError;

    // Call function/method
    {
        {
            const char * cppArg0 = Shiboken::Converter<const char * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // indexOfSlot(const char*)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->indexOfSlot(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QMetaObjectFunc_indexOfSlot_TypeError:
        const char* overloads[] = {"str", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QMetaObject.indexOfSlot", overloads);
        return 0;
}

static PyObject* Sbk_QMetaObjectFunc_invokeMethod(PyObject* self, PyObject* args, PyObject* kwds)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 14) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QMetaObject.invokeMethod(): too many arguments");
        return 0;
    } else if (numArgs < 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QMetaObject.invokeMethod(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOOOOOOOOOOOO:invokeMethod", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4]), &(pyargs[5]), &(pyargs[6]), &(pyargs[7]), &(pyargs[8]), &(pyargs[9]), &(pyargs[10]), &(pyargs[11]), &(pyargs[12]), &(pyargs[13])))
        return 0;


    // Overloaded function decisor
    // 0: invokeMethod(QObject*,const char*,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
    // 1: invokeMethod(QObject*,const char*,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
    // 2: invokeMethod(QObject*,const char*,Qt::ConnectionType,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
    // 3: invokeMethod(QObject*,const char*,Qt::ConnectionType,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
    if (numArgs >= 2 && Shiboken::Converter< ::QObject * >::isConvertible(pyargs[0]) && Shiboken::Converter< const char * >::isConvertible(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 0; // invokeMethod(QObject*,const char*,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
        } else if (Shiboken::Converter< ::Qt::ConnectionType >::isConvertible(pyargs[2])) {
            if (numArgs == 3) {
                overloadId = 3; // invokeMethod(QObject*,const char*,Qt::ConnectionType,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
            } else if (Shiboken::Converter< ::QGenericArgument >::isConvertible(pyargs[3])) {
                if (numArgs == 4) {
                    overloadId = 3; // invokeMethod(QObject*,const char*,Qt::ConnectionType,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                } else if (Shiboken::Converter< ::QGenericArgument >::isConvertible(pyargs[4])) {
                    if (numArgs == 5) {
                        overloadId = 3; // invokeMethod(QObject*,const char*,Qt::ConnectionType,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                    } else if (Shiboken::Converter< ::QGenericArgument >::isConvertible(pyargs[5])) {
                        if (numArgs == 6) {
                            overloadId = 3; // invokeMethod(QObject*,const char*,Qt::ConnectionType,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                        } else if (Shiboken::Converter< ::QGenericArgument >::isConvertible(pyargs[6])) {
                            if (numArgs == 7) {
                                overloadId = 3; // invokeMethod(QObject*,const char*,Qt::ConnectionType,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                            } else if (Shiboken::Converter< ::QGenericArgument >::isConvertible(pyargs[7])) {
                                if (numArgs == 8) {
                                    overloadId = 3; // invokeMethod(QObject*,const char*,Qt::ConnectionType,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                                } else if (Shiboken::Converter< ::QGenericArgument >::isConvertible(pyargs[8])) {
                                    if (numArgs == 9) {
                                        overloadId = 3; // invokeMethod(QObject*,const char*,Qt::ConnectionType,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                                    } else if (Shiboken::Converter< ::QGenericArgument >::isConvertible(pyargs[9])) {
                                        if (numArgs == 10) {
                                            overloadId = 3; // invokeMethod(QObject*,const char*,Qt::ConnectionType,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                                        } else if (Shiboken::Converter< ::QGenericArgument >::isConvertible(pyargs[10])) {
                                            if (numArgs == 11) {
                                                overloadId = 3; // invokeMethod(QObject*,const char*,Qt::ConnectionType,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                                            } else if (Shiboken::Converter< ::QGenericArgument >::isConvertible(pyargs[11])) {
                                                if (numArgs == 12) {
                                                    overloadId = 3; // invokeMethod(QObject*,const char*,Qt::ConnectionType,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                                                } else if (Shiboken::Converter< ::QGenericArgument >::isConvertible(pyargs[12])) {
                                                    overloadId = 3; // invokeMethod(QObject*,const char*,Qt::ConnectionType,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                                                }
                                            }
                                        }
                                    }
                                }
                            }
                        }
                    }
                }
            } else if (Shiboken::Converter< ::QGenericReturnArgument >::isConvertible(pyargs[3])) {
                if (numArgs == 4) {
                    overloadId = 2; // invokeMethod(QObject*,const char*,Qt::ConnectionType,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                } else if (Shiboken::Converter< ::QGenericArgument >::isConvertible(pyargs[4])) {
                    if (numArgs == 5) {
                        overloadId = 2; // invokeMethod(QObject*,const char*,Qt::ConnectionType,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                    } else if (Shiboken::Converter< ::QGenericArgument >::isConvertible(pyargs[5])) {
                        if (numArgs == 6) {
                            overloadId = 2; // invokeMethod(QObject*,const char*,Qt::ConnectionType,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                        } else if (Shiboken::Converter< ::QGenericArgument >::isConvertible(pyargs[6])) {
                            if (numArgs == 7) {
                                overloadId = 2; // invokeMethod(QObject*,const char*,Qt::ConnectionType,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                            } else if (Shiboken::Converter< ::QGenericArgument >::isConvertible(pyargs[7])) {
                                if (numArgs == 8) {
                                    overloadId = 2; // invokeMethod(QObject*,const char*,Qt::ConnectionType,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                                } else if (Shiboken::Converter< ::QGenericArgument >::isConvertible(pyargs[8])) {
                                    if (numArgs == 9) {
                                        overloadId = 2; // invokeMethod(QObject*,const char*,Qt::ConnectionType,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                                    } else if (Shiboken::Converter< ::QGenericArgument >::isConvertible(pyargs[9])) {
                                        if (numArgs == 10) {
                                            overloadId = 2; // invokeMethod(QObject*,const char*,Qt::ConnectionType,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                                        } else if (Shiboken::Converter< ::QGenericArgument >::isConvertible(pyargs[10])) {
                                            if (numArgs == 11) {
                                                overloadId = 2; // invokeMethod(QObject*,const char*,Qt::ConnectionType,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                                            } else if (Shiboken::Converter< ::QGenericArgument >::isConvertible(pyargs[11])) {
                                                if (numArgs == 12) {
                                                    overloadId = 2; // invokeMethod(QObject*,const char*,Qt::ConnectionType,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                                                } else if (Shiboken::Converter< ::QGenericArgument >::isConvertible(pyargs[12])) {
                                                    if (numArgs == 13) {
                                                        overloadId = 2; // invokeMethod(QObject*,const char*,Qt::ConnectionType,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                                                    } else if (Shiboken::Converter< ::QGenericArgument >::isConvertible(pyargs[13])) {
                                                        overloadId = 2; // invokeMethod(QObject*,const char*,Qt::ConnectionType,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                                                    }
                                                }
                                            }
                                        }
                                    }
                                }
                            }
                        }
                    }
                }
            }
        } else if (Shiboken::Converter< ::QGenericReturnArgument >::isConvertible(pyargs[2])) {
            if (numArgs == 3) {
                overloadId = 1; // invokeMethod(QObject*,const char*,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
            } else if (Shiboken::Converter< ::QGenericArgument >::isConvertible(pyargs[3])) {
                if (numArgs == 4) {
                    overloadId = 1; // invokeMethod(QObject*,const char*,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                } else if (Shiboken::Converter< ::QGenericArgument >::isConvertible(pyargs[4])) {
                    if (numArgs == 5) {
                        overloadId = 1; // invokeMethod(QObject*,const char*,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                    } else if (Shiboken::Converter< ::QGenericArgument >::isConvertible(pyargs[5])) {
                        if (numArgs == 6) {
                            overloadId = 1; // invokeMethod(QObject*,const char*,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                        } else if (Shiboken::Converter< ::QGenericArgument >::isConvertible(pyargs[6])) {
                            if (numArgs == 7) {
                                overloadId = 1; // invokeMethod(QObject*,const char*,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                            } else if (Shiboken::Converter< ::QGenericArgument >::isConvertible(pyargs[7])) {
                                if (numArgs == 8) {
                                    overloadId = 1; // invokeMethod(QObject*,const char*,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                                } else if (Shiboken::Converter< ::QGenericArgument >::isConvertible(pyargs[8])) {
                                    if (numArgs == 9) {
                                        overloadId = 1; // invokeMethod(QObject*,const char*,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                                    } else if (Shiboken::Converter< ::QGenericArgument >::isConvertible(pyargs[9])) {
                                        if (numArgs == 10) {
                                            overloadId = 1; // invokeMethod(QObject*,const char*,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                                        } else if (Shiboken::Converter< ::QGenericArgument >::isConvertible(pyargs[10])) {
                                            if (numArgs == 11) {
                                                overloadId = 1; // invokeMethod(QObject*,const char*,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                                            } else if (Shiboken::Converter< ::QGenericArgument >::isConvertible(pyargs[11])) {
                                                if (numArgs == 12) {
                                                    overloadId = 1; // invokeMethod(QObject*,const char*,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                                                } else if (Shiboken::Converter< ::QGenericArgument >::isConvertible(pyargs[12])) {
                                                    overloadId = 1; // invokeMethod(QObject*,const char*,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                                                }
                                            }
                                        }
                                    }
                                }
                            }
                        }
                    }
                }
            }
        } else if (Shiboken::Converter< ::QGenericArgument >::isConvertible(pyargs[2])) {
            if (numArgs == 3) {
                overloadId = 0; // invokeMethod(QObject*,const char*,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
            } else if (Shiboken::Converter< ::QGenericArgument >::isConvertible(pyargs[3])) {
                if (numArgs == 4) {
                    overloadId = 0; // invokeMethod(QObject*,const char*,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                } else if (Shiboken::Converter< ::QGenericArgument >::isConvertible(pyargs[4])) {
                    if (numArgs == 5) {
                        overloadId = 0; // invokeMethod(QObject*,const char*,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                    } else if (Shiboken::Converter< ::QGenericArgument >::isConvertible(pyargs[5])) {
                        if (numArgs == 6) {
                            overloadId = 0; // invokeMethod(QObject*,const char*,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                        } else if (Shiboken::Converter< ::QGenericArgument >::isConvertible(pyargs[6])) {
                            if (numArgs == 7) {
                                overloadId = 0; // invokeMethod(QObject*,const char*,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                            } else if (Shiboken::Converter< ::QGenericArgument >::isConvertible(pyargs[7])) {
                                if (numArgs == 8) {
                                    overloadId = 0; // invokeMethod(QObject*,const char*,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                                } else if (Shiboken::Converter< ::QGenericArgument >::isConvertible(pyargs[8])) {
                                    if (numArgs == 9) {
                                        overloadId = 0; // invokeMethod(QObject*,const char*,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                                    } else if (Shiboken::Converter< ::QGenericArgument >::isConvertible(pyargs[9])) {
                                        if (numArgs == 10) {
                                            overloadId = 0; // invokeMethod(QObject*,const char*,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                                        } else if (Shiboken::Converter< ::QGenericArgument >::isConvertible(pyargs[10])) {
                                            if (numArgs == 11) {
                                                overloadId = 0; // invokeMethod(QObject*,const char*,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                                            } else if (Shiboken::Converter< ::QGenericArgument >::isConvertible(pyargs[11])) {
                                                overloadId = 0; // invokeMethod(QObject*,const char*,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                                            }
                                        }
                                    }
                                }
                            }
                        }
                    }
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QMetaObjectFunc_invokeMethod_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // invokeMethod(QObject*,const char*,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "val0");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "val0";
                        else if (Shiboken::Converter< ::QGenericArgument >::isConvertible(value))
                            pyargs[2] = value;
else
                            goto Sbk_QMetaObjectFunc_invokeMethod_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "val1");
                    if (value) {
                        if (pyargs[3])
                            errorArgName = "val1";
                        else if (Shiboken::Converter< ::QGenericArgument >::isConvertible(value))
                            pyargs[3] = value;
else
                            goto Sbk_QMetaObjectFunc_invokeMethod_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "val2");
                    if (value) {
                        if (pyargs[4])
                            errorArgName = "val2";
                        else if (Shiboken::Converter< ::QGenericArgument >::isConvertible(value))
                            pyargs[4] = value;
else
                            goto Sbk_QMetaObjectFunc_invokeMethod_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "val3");
                    if (value) {
                        if (pyargs[5])
                            errorArgName = "val3";
                        else if (Shiboken::Converter< ::QGenericArgument >::isConvertible(value))
                            pyargs[5] = value;
else
                            goto Sbk_QMetaObjectFunc_invokeMethod_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "val4");
                    if (value) {
                        if (pyargs[6])
                            errorArgName = "val4";
                        else if (Shiboken::Converter< ::QGenericArgument >::isConvertible(value))
                            pyargs[6] = value;
else
                            goto Sbk_QMetaObjectFunc_invokeMethod_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "val5");
                    if (value) {
                        if (pyargs[7])
                            errorArgName = "val5";
                        else if (Shiboken::Converter< ::QGenericArgument >::isConvertible(value))
                            pyargs[7] = value;
else
                            goto Sbk_QMetaObjectFunc_invokeMethod_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "val6");
                    if (value) {
                        if (pyargs[8])
                            errorArgName = "val6";
                        else if (Shiboken::Converter< ::QGenericArgument >::isConvertible(value))
                            pyargs[8] = value;
else
                            goto Sbk_QMetaObjectFunc_invokeMethod_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "val7");
                    if (value) {
                        if (pyargs[9])
                            errorArgName = "val7";
                        else if (Shiboken::Converter< ::QGenericArgument >::isConvertible(value))
                            pyargs[9] = value;
else
                            goto Sbk_QMetaObjectFunc_invokeMethod_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "val8");
                    if (value) {
                        if (pyargs[10])
                            errorArgName = "val8";
                        else if (Shiboken::Converter< ::QGenericArgument >::isConvertible(value))
                            pyargs[10] = value;
else
                            goto Sbk_QMetaObjectFunc_invokeMethod_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "val9");
                    if (value) {
                        if (pyargs[11])
                            errorArgName = "val9";
                        else if (Shiboken::Converter< ::QGenericArgument >::isConvertible(value))
                            pyargs[11] = value;
else
                            goto Sbk_QMetaObjectFunc_invokeMethod_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtCore.QMetaObject.invokeMethod(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QObject * cppArg0 = Shiboken::Converter<QObject * >::toCpp(pyargs[0]);
                const char * cppArg1 = Shiboken::Converter<const char * >::toCpp(pyargs[1]);
                if (!Shiboken::Object::isValid(pyargs[2]))
                    return 0;
                QGenericArgument cppArg2_tmp = QGenericArgument(0);
                QGenericArgument cppArg2 = pyargs[2] ? Shiboken::Converter<QGenericArgument >::toCpp(pyargs[2]) : cppArg2_tmp;
                if (!Shiboken::Object::isValid(pyargs[3]))
                    return 0;
                QGenericArgument cppArg3_tmp = QGenericArgument();
                QGenericArgument cppArg3 = pyargs[3] ? Shiboken::Converter<QGenericArgument >::toCpp(pyargs[3]) : cppArg3_tmp;
                if (!Shiboken::Object::isValid(pyargs[4]))
                    return 0;
                QGenericArgument cppArg4_tmp = QGenericArgument();
                QGenericArgument cppArg4 = pyargs[4] ? Shiboken::Converter<QGenericArgument >::toCpp(pyargs[4]) : cppArg4_tmp;
                if (!Shiboken::Object::isValid(pyargs[5]))
                    return 0;
                QGenericArgument cppArg5_tmp = QGenericArgument();
                QGenericArgument cppArg5 = pyargs[5] ? Shiboken::Converter<QGenericArgument >::toCpp(pyargs[5]) : cppArg5_tmp;
                if (!Shiboken::Object::isValid(pyargs[6]))
                    return 0;
                QGenericArgument cppArg6_tmp = QGenericArgument();
                QGenericArgument cppArg6 = pyargs[6] ? Shiboken::Converter<QGenericArgument >::toCpp(pyargs[6]) : cppArg6_tmp;
                if (!Shiboken::Object::isValid(pyargs[7]))
                    return 0;
                QGenericArgument cppArg7_tmp = QGenericArgument();
                QGenericArgument cppArg7 = pyargs[7] ? Shiboken::Converter<QGenericArgument >::toCpp(pyargs[7]) : cppArg7_tmp;
                if (!Shiboken::Object::isValid(pyargs[8]))
                    return 0;
                QGenericArgument cppArg8_tmp = QGenericArgument();
                QGenericArgument cppArg8 = pyargs[8] ? Shiboken::Converter<QGenericArgument >::toCpp(pyargs[8]) : cppArg8_tmp;
                if (!Shiboken::Object::isValid(pyargs[9]))
                    return 0;
                QGenericArgument cppArg9_tmp = QGenericArgument();
                QGenericArgument cppArg9 = pyargs[9] ? Shiboken::Converter<QGenericArgument >::toCpp(pyargs[9]) : cppArg9_tmp;
                if (!Shiboken::Object::isValid(pyargs[10]))
                    return 0;
                QGenericArgument cppArg10_tmp = QGenericArgument();
                QGenericArgument cppArg10 = pyargs[10] ? Shiboken::Converter<QGenericArgument >::toCpp(pyargs[10]) : cppArg10_tmp;
                if (!Shiboken::Object::isValid(pyargs[11]))
                    return 0;
                QGenericArgument cppArg11_tmp = QGenericArgument();
                QGenericArgument cppArg11 = pyargs[11] ? Shiboken::Converter<QGenericArgument >::toCpp(pyargs[11]) : cppArg11_tmp;

                if(!PyErr_Occurred()) {
                    // invokeMethod(QObject*,const char*,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    bool cppResult = QMetaObject::invokeMethod(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5, cppArg6, cppArg7, cppArg8, cppArg9, cppArg10, cppArg11);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< bool >::toPython(cppResult);
                }
                break;
            }
            case 1: // invokeMethod(QObject*,const char*,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "val0");
                    if (value) {
                        if (pyargs[3])
                            errorArgName = "val0";
                        else if (Shiboken::Converter< ::QGenericArgument >::isConvertible(value))
                            pyargs[3] = value;
else
                            goto Sbk_QMetaObjectFunc_invokeMethod_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "val1");
                    if (value) {
                        if (pyargs[4])
                            errorArgName = "val1";
                        else if (Shiboken::Converter< ::QGenericArgument >::isConvertible(value))
                            pyargs[4] = value;
else
                            goto Sbk_QMetaObjectFunc_invokeMethod_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "val2");
                    if (value) {
                        if (pyargs[5])
                            errorArgName = "val2";
                        else if (Shiboken::Converter< ::QGenericArgument >::isConvertible(value))
                            pyargs[5] = value;
else
                            goto Sbk_QMetaObjectFunc_invokeMethod_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "val3");
                    if (value) {
                        if (pyargs[6])
                            errorArgName = "val3";
                        else if (Shiboken::Converter< ::QGenericArgument >::isConvertible(value))
                            pyargs[6] = value;
else
                            goto Sbk_QMetaObjectFunc_invokeMethod_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "val4");
                    if (value) {
                        if (pyargs[7])
                            errorArgName = "val4";
                        else if (Shiboken::Converter< ::QGenericArgument >::isConvertible(value))
                            pyargs[7] = value;
else
                            goto Sbk_QMetaObjectFunc_invokeMethod_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "val5");
                    if (value) {
                        if (pyargs[8])
                            errorArgName = "val5";
                        else if (Shiboken::Converter< ::QGenericArgument >::isConvertible(value))
                            pyargs[8] = value;
else
                            goto Sbk_QMetaObjectFunc_invokeMethod_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "val6");
                    if (value) {
                        if (pyargs[9])
                            errorArgName = "val6";
                        else if (Shiboken::Converter< ::QGenericArgument >::isConvertible(value))
                            pyargs[9] = value;
else
                            goto Sbk_QMetaObjectFunc_invokeMethod_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "val7");
                    if (value) {
                        if (pyargs[10])
                            errorArgName = "val7";
                        else if (Shiboken::Converter< ::QGenericArgument >::isConvertible(value))
                            pyargs[10] = value;
else
                            goto Sbk_QMetaObjectFunc_invokeMethod_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "val8");
                    if (value) {
                        if (pyargs[11])
                            errorArgName = "val8";
                        else if (Shiboken::Converter< ::QGenericArgument >::isConvertible(value))
                            pyargs[11] = value;
else
                            goto Sbk_QMetaObjectFunc_invokeMethod_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "val9");
                    if (value) {
                        if (pyargs[12])
                            errorArgName = "val9";
                        else if (Shiboken::Converter< ::QGenericArgument >::isConvertible(value))
                            pyargs[12] = value;
else
                            goto Sbk_QMetaObjectFunc_invokeMethod_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtCore.QMetaObject.invokeMethod(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QObject * cppArg0 = Shiboken::Converter<QObject * >::toCpp(pyargs[0]);
                const char * cppArg1 = Shiboken::Converter<const char * >::toCpp(pyargs[1]);
                if (!Shiboken::Object::isValid(pyargs[2]))
                    return 0;
                QGenericReturnArgument cppArg2 = Shiboken::Converter<QGenericReturnArgument >::toCpp(pyargs[2]);
                if (!Shiboken::Object::isValid(pyargs[3]))
                    return 0;
                QGenericArgument cppArg3_tmp = QGenericArgument(0);
                QGenericArgument cppArg3 = pyargs[3] ? Shiboken::Converter<QGenericArgument >::toCpp(pyargs[3]) : cppArg3_tmp;
                if (!Shiboken::Object::isValid(pyargs[4]))
                    return 0;
                QGenericArgument cppArg4_tmp = QGenericArgument();
                QGenericArgument cppArg4 = pyargs[4] ? Shiboken::Converter<QGenericArgument >::toCpp(pyargs[4]) : cppArg4_tmp;
                if (!Shiboken::Object::isValid(pyargs[5]))
                    return 0;
                QGenericArgument cppArg5_tmp = QGenericArgument();
                QGenericArgument cppArg5 = pyargs[5] ? Shiboken::Converter<QGenericArgument >::toCpp(pyargs[5]) : cppArg5_tmp;
                if (!Shiboken::Object::isValid(pyargs[6]))
                    return 0;
                QGenericArgument cppArg6_tmp = QGenericArgument();
                QGenericArgument cppArg6 = pyargs[6] ? Shiboken::Converter<QGenericArgument >::toCpp(pyargs[6]) : cppArg6_tmp;
                if (!Shiboken::Object::isValid(pyargs[7]))
                    return 0;
                QGenericArgument cppArg7_tmp = QGenericArgument();
                QGenericArgument cppArg7 = pyargs[7] ? Shiboken::Converter<QGenericArgument >::toCpp(pyargs[7]) : cppArg7_tmp;
                if (!Shiboken::Object::isValid(pyargs[8]))
                    return 0;
                QGenericArgument cppArg8_tmp = QGenericArgument();
                QGenericArgument cppArg8 = pyargs[8] ? Shiboken::Converter<QGenericArgument >::toCpp(pyargs[8]) : cppArg8_tmp;
                if (!Shiboken::Object::isValid(pyargs[9]))
                    return 0;
                QGenericArgument cppArg9_tmp = QGenericArgument();
                QGenericArgument cppArg9 = pyargs[9] ? Shiboken::Converter<QGenericArgument >::toCpp(pyargs[9]) : cppArg9_tmp;
                if (!Shiboken::Object::isValid(pyargs[10]))
                    return 0;
                QGenericArgument cppArg10_tmp = QGenericArgument();
                QGenericArgument cppArg10 = pyargs[10] ? Shiboken::Converter<QGenericArgument >::toCpp(pyargs[10]) : cppArg10_tmp;
                if (!Shiboken::Object::isValid(pyargs[11]))
                    return 0;
                QGenericArgument cppArg11_tmp = QGenericArgument();
                QGenericArgument cppArg11 = pyargs[11] ? Shiboken::Converter<QGenericArgument >::toCpp(pyargs[11]) : cppArg11_tmp;
                if (!Shiboken::Object::isValid(pyargs[12]))
                    return 0;
                QGenericArgument cppArg12_tmp = QGenericArgument();
                QGenericArgument cppArg12 = pyargs[12] ? Shiboken::Converter<QGenericArgument >::toCpp(pyargs[12]) : cppArg12_tmp;

                if(!PyErr_Occurred()) {
                    // invokeMethod(QObject*,const char*,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    bool cppResult = QMetaObject::invokeMethod(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5, cppArg6, cppArg7, cppArg8, cppArg9, cppArg10, cppArg11, cppArg12);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< bool >::toPython(cppResult);
                }
                break;
            }
            case 2: // invokeMethod(QObject*,const char*,Qt::ConnectionType,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "val0");
                    if (value) {
                        if (pyargs[4])
                            errorArgName = "val0";
                        else if (Shiboken::Converter< ::QGenericArgument >::isConvertible(value))
                            pyargs[4] = value;
else
                            goto Sbk_QMetaObjectFunc_invokeMethod_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "val1");
                    if (value) {
                        if (pyargs[5])
                            errorArgName = "val1";
                        else if (Shiboken::Converter< ::QGenericArgument >::isConvertible(value))
                            pyargs[5] = value;
else
                            goto Sbk_QMetaObjectFunc_invokeMethod_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "val2");
                    if (value) {
                        if (pyargs[6])
                            errorArgName = "val2";
                        else if (Shiboken::Converter< ::QGenericArgument >::isConvertible(value))
                            pyargs[6] = value;
else
                            goto Sbk_QMetaObjectFunc_invokeMethod_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "val3");
                    if (value) {
                        if (pyargs[7])
                            errorArgName = "val3";
                        else if (Shiboken::Converter< ::QGenericArgument >::isConvertible(value))
                            pyargs[7] = value;
else
                            goto Sbk_QMetaObjectFunc_invokeMethod_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "val4");
                    if (value) {
                        if (pyargs[8])
                            errorArgName = "val4";
                        else if (Shiboken::Converter< ::QGenericArgument >::isConvertible(value))
                            pyargs[8] = value;
else
                            goto Sbk_QMetaObjectFunc_invokeMethod_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "val5");
                    if (value) {
                        if (pyargs[9])
                            errorArgName = "val5";
                        else if (Shiboken::Converter< ::QGenericArgument >::isConvertible(value))
                            pyargs[9] = value;
else
                            goto Sbk_QMetaObjectFunc_invokeMethod_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "val6");
                    if (value) {
                        if (pyargs[10])
                            errorArgName = "val6";
                        else if (Shiboken::Converter< ::QGenericArgument >::isConvertible(value))
                            pyargs[10] = value;
else
                            goto Sbk_QMetaObjectFunc_invokeMethod_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "val7");
                    if (value) {
                        if (pyargs[11])
                            errorArgName = "val7";
                        else if (Shiboken::Converter< ::QGenericArgument >::isConvertible(value))
                            pyargs[11] = value;
else
                            goto Sbk_QMetaObjectFunc_invokeMethod_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "val8");
                    if (value) {
                        if (pyargs[12])
                            errorArgName = "val8";
                        else if (Shiboken::Converter< ::QGenericArgument >::isConvertible(value))
                            pyargs[12] = value;
else
                            goto Sbk_QMetaObjectFunc_invokeMethod_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "val9");
                    if (value) {
                        if (pyargs[13])
                            errorArgName = "val9";
                        else if (Shiboken::Converter< ::QGenericArgument >::isConvertible(value))
                            pyargs[13] = value;
else
                            goto Sbk_QMetaObjectFunc_invokeMethod_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtCore.QMetaObject.invokeMethod(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QObject * cppArg0 = Shiboken::Converter<QObject * >::toCpp(pyargs[0]);
                const char * cppArg1 = Shiboken::Converter<const char * >::toCpp(pyargs[1]);
                Qt::ConnectionType cppArg2 = Shiboken::Converter<Qt::ConnectionType >::toCpp(pyargs[2]);
                if (!Shiboken::Object::isValid(pyargs[3]))
                    return 0;
                QGenericReturnArgument cppArg3 = Shiboken::Converter<QGenericReturnArgument >::toCpp(pyargs[3]);
                if (!Shiboken::Object::isValid(pyargs[4]))
                    return 0;
                QGenericArgument cppArg4_tmp = QGenericArgument(0);
                QGenericArgument cppArg4 = pyargs[4] ? Shiboken::Converter<QGenericArgument >::toCpp(pyargs[4]) : cppArg4_tmp;
                if (!Shiboken::Object::isValid(pyargs[5]))
                    return 0;
                QGenericArgument cppArg5_tmp = QGenericArgument();
                QGenericArgument cppArg5 = pyargs[5] ? Shiboken::Converter<QGenericArgument >::toCpp(pyargs[5]) : cppArg5_tmp;
                if (!Shiboken::Object::isValid(pyargs[6]))
                    return 0;
                QGenericArgument cppArg6_tmp = QGenericArgument();
                QGenericArgument cppArg6 = pyargs[6] ? Shiboken::Converter<QGenericArgument >::toCpp(pyargs[6]) : cppArg6_tmp;
                if (!Shiboken::Object::isValid(pyargs[7]))
                    return 0;
                QGenericArgument cppArg7_tmp = QGenericArgument();
                QGenericArgument cppArg7 = pyargs[7] ? Shiboken::Converter<QGenericArgument >::toCpp(pyargs[7]) : cppArg7_tmp;
                if (!Shiboken::Object::isValid(pyargs[8]))
                    return 0;
                QGenericArgument cppArg8_tmp = QGenericArgument();
                QGenericArgument cppArg8 = pyargs[8] ? Shiboken::Converter<QGenericArgument >::toCpp(pyargs[8]) : cppArg8_tmp;
                if (!Shiboken::Object::isValid(pyargs[9]))
                    return 0;
                QGenericArgument cppArg9_tmp = QGenericArgument();
                QGenericArgument cppArg9 = pyargs[9] ? Shiboken::Converter<QGenericArgument >::toCpp(pyargs[9]) : cppArg9_tmp;
                if (!Shiboken::Object::isValid(pyargs[10]))
                    return 0;
                QGenericArgument cppArg10_tmp = QGenericArgument();
                QGenericArgument cppArg10 = pyargs[10] ? Shiboken::Converter<QGenericArgument >::toCpp(pyargs[10]) : cppArg10_tmp;
                if (!Shiboken::Object::isValid(pyargs[11]))
                    return 0;
                QGenericArgument cppArg11_tmp = QGenericArgument();
                QGenericArgument cppArg11 = pyargs[11] ? Shiboken::Converter<QGenericArgument >::toCpp(pyargs[11]) : cppArg11_tmp;
                if (!Shiboken::Object::isValid(pyargs[12]))
                    return 0;
                QGenericArgument cppArg12_tmp = QGenericArgument();
                QGenericArgument cppArg12 = pyargs[12] ? Shiboken::Converter<QGenericArgument >::toCpp(pyargs[12]) : cppArg12_tmp;
                if (!Shiboken::Object::isValid(pyargs[13]))
                    return 0;
                QGenericArgument cppArg13_tmp = QGenericArgument();
                QGenericArgument cppArg13 = pyargs[13] ? Shiboken::Converter<QGenericArgument >::toCpp(pyargs[13]) : cppArg13_tmp;

                if(!PyErr_Occurred()) {
                    // invokeMethod(QObject*,const char*,Qt::ConnectionType,QGenericReturnArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    bool cppResult = QMetaObject::invokeMethod(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5, cppArg6, cppArg7, cppArg8, cppArg9, cppArg10, cppArg11, cppArg12, cppArg13);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< bool >::toPython(cppResult);
                }
                break;
            }
            case 3: // invokeMethod(QObject*,const char*,Qt::ConnectionType,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "val0");
                    if (value) {
                        if (pyargs[3])
                            errorArgName = "val0";
                        else if (Shiboken::Converter< ::QGenericArgument >::isConvertible(value))
                            pyargs[3] = value;
else
                            goto Sbk_QMetaObjectFunc_invokeMethod_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "val1");
                    if (value) {
                        if (pyargs[4])
                            errorArgName = "val1";
                        else if (Shiboken::Converter< ::QGenericArgument >::isConvertible(value))
                            pyargs[4] = value;
else
                            goto Sbk_QMetaObjectFunc_invokeMethod_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "val2");
                    if (value) {
                        if (pyargs[5])
                            errorArgName = "val2";
                        else if (Shiboken::Converter< ::QGenericArgument >::isConvertible(value))
                            pyargs[5] = value;
else
                            goto Sbk_QMetaObjectFunc_invokeMethod_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "val3");
                    if (value) {
                        if (pyargs[6])
                            errorArgName = "val3";
                        else if (Shiboken::Converter< ::QGenericArgument >::isConvertible(value))
                            pyargs[6] = value;
else
                            goto Sbk_QMetaObjectFunc_invokeMethod_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "val4");
                    if (value) {
                        if (pyargs[7])
                            errorArgName = "val4";
                        else if (Shiboken::Converter< ::QGenericArgument >::isConvertible(value))
                            pyargs[7] = value;
else
                            goto Sbk_QMetaObjectFunc_invokeMethod_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "val5");
                    if (value) {
                        if (pyargs[8])
                            errorArgName = "val5";
                        else if (Shiboken::Converter< ::QGenericArgument >::isConvertible(value))
                            pyargs[8] = value;
else
                            goto Sbk_QMetaObjectFunc_invokeMethod_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "val6");
                    if (value) {
                        if (pyargs[9])
                            errorArgName = "val6";
                        else if (Shiboken::Converter< ::QGenericArgument >::isConvertible(value))
                            pyargs[9] = value;
else
                            goto Sbk_QMetaObjectFunc_invokeMethod_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "val7");
                    if (value) {
                        if (pyargs[10])
                            errorArgName = "val7";
                        else if (Shiboken::Converter< ::QGenericArgument >::isConvertible(value))
                            pyargs[10] = value;
else
                            goto Sbk_QMetaObjectFunc_invokeMethod_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "val8");
                    if (value) {
                        if (pyargs[11])
                            errorArgName = "val8";
                        else if (Shiboken::Converter< ::QGenericArgument >::isConvertible(value))
                            pyargs[11] = value;
else
                            goto Sbk_QMetaObjectFunc_invokeMethod_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "val9");
                    if (value) {
                        if (pyargs[12])
                            errorArgName = "val9";
                        else if (Shiboken::Converter< ::QGenericArgument >::isConvertible(value))
                            pyargs[12] = value;
else
                            goto Sbk_QMetaObjectFunc_invokeMethod_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtCore.QMetaObject.invokeMethod(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QObject * cppArg0 = Shiboken::Converter<QObject * >::toCpp(pyargs[0]);
                const char * cppArg1 = Shiboken::Converter<const char * >::toCpp(pyargs[1]);
                Qt::ConnectionType cppArg2 = Shiboken::Converter<Qt::ConnectionType >::toCpp(pyargs[2]);
                if (!Shiboken::Object::isValid(pyargs[3]))
                    return 0;
                QGenericArgument cppArg3_tmp = QGenericArgument(0);
                QGenericArgument cppArg3 = pyargs[3] ? Shiboken::Converter<QGenericArgument >::toCpp(pyargs[3]) : cppArg3_tmp;
                if (!Shiboken::Object::isValid(pyargs[4]))
                    return 0;
                QGenericArgument cppArg4_tmp = QGenericArgument();
                QGenericArgument cppArg4 = pyargs[4] ? Shiboken::Converter<QGenericArgument >::toCpp(pyargs[4]) : cppArg4_tmp;
                if (!Shiboken::Object::isValid(pyargs[5]))
                    return 0;
                QGenericArgument cppArg5_tmp = QGenericArgument();
                QGenericArgument cppArg5 = pyargs[5] ? Shiboken::Converter<QGenericArgument >::toCpp(pyargs[5]) : cppArg5_tmp;
                if (!Shiboken::Object::isValid(pyargs[6]))
                    return 0;
                QGenericArgument cppArg6_tmp = QGenericArgument();
                QGenericArgument cppArg6 = pyargs[6] ? Shiboken::Converter<QGenericArgument >::toCpp(pyargs[6]) : cppArg6_tmp;
                if (!Shiboken::Object::isValid(pyargs[7]))
                    return 0;
                QGenericArgument cppArg7_tmp = QGenericArgument();
                QGenericArgument cppArg7 = pyargs[7] ? Shiboken::Converter<QGenericArgument >::toCpp(pyargs[7]) : cppArg7_tmp;
                if (!Shiboken::Object::isValid(pyargs[8]))
                    return 0;
                QGenericArgument cppArg8_tmp = QGenericArgument();
                QGenericArgument cppArg8 = pyargs[8] ? Shiboken::Converter<QGenericArgument >::toCpp(pyargs[8]) : cppArg8_tmp;
                if (!Shiboken::Object::isValid(pyargs[9]))
                    return 0;
                QGenericArgument cppArg9_tmp = QGenericArgument();
                QGenericArgument cppArg9 = pyargs[9] ? Shiboken::Converter<QGenericArgument >::toCpp(pyargs[9]) : cppArg9_tmp;
                if (!Shiboken::Object::isValid(pyargs[10]))
                    return 0;
                QGenericArgument cppArg10_tmp = QGenericArgument();
                QGenericArgument cppArg10 = pyargs[10] ? Shiboken::Converter<QGenericArgument >::toCpp(pyargs[10]) : cppArg10_tmp;
                if (!Shiboken::Object::isValid(pyargs[11]))
                    return 0;
                QGenericArgument cppArg11_tmp = QGenericArgument();
                QGenericArgument cppArg11 = pyargs[11] ? Shiboken::Converter<QGenericArgument >::toCpp(pyargs[11]) : cppArg11_tmp;
                if (!Shiboken::Object::isValid(pyargs[12]))
                    return 0;
                QGenericArgument cppArg12_tmp = QGenericArgument();
                QGenericArgument cppArg12 = pyargs[12] ? Shiboken::Converter<QGenericArgument >::toCpp(pyargs[12]) : cppArg12_tmp;

                if(!PyErr_Occurred()) {
                    // invokeMethod(QObject*,const char*,Qt::ConnectionType,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    bool cppResult = QMetaObject::invokeMethod(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5, cppArg6, cppArg7, cppArg8, cppArg9, cppArg10, cppArg11, cppArg12);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< bool >::toPython(cppResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QMetaObjectFunc_invokeMethod_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject, str, PySide.QtCore.QGenericArgument = QGenericArgument(0), PySide.QtCore.QGenericArgument = QGenericArgument(), PySide.QtCore.QGenericArgument = QGenericArgument(), PySide.QtCore.QGenericArgument = QGenericArgument(), PySide.QtCore.QGenericArgument = QGenericArgument(), PySide.QtCore.QGenericArgument = QGenericArgument(), PySide.QtCore.QGenericArgument = QGenericArgument(), PySide.QtCore.QGenericArgument = QGenericArgument(), PySide.QtCore.QGenericArgument = QGenericArgument(), PySide.QtCore.QGenericArgument = QGenericArgument()", "PySide.QtCore.QObject, str, PySide.QtCore.QGenericReturnArgument, PySide.QtCore.QGenericArgument = QGenericArgument(0), PySide.QtCore.QGenericArgument = QGenericArgument(), PySide.QtCore.QGenericArgument = QGenericArgument(), PySide.QtCore.QGenericArgument = QGenericArgument(), PySide.QtCore.QGenericArgument = QGenericArgument(), PySide.QtCore.QGenericArgument = QGenericArgument(), PySide.QtCore.QGenericArgument = QGenericArgument(), PySide.QtCore.QGenericArgument = QGenericArgument(), PySide.QtCore.QGenericArgument = QGenericArgument(), PySide.QtCore.QGenericArgument = QGenericArgument()", "PySide.QtCore.QObject, str, PySide.QtCore.Qt.ConnectionType, PySide.QtCore.QGenericReturnArgument, PySide.QtCore.QGenericArgument = QGenericArgument(0), PySide.QtCore.QGenericArgument = QGenericArgument(), PySide.QtCore.QGenericArgument = QGenericArgument(), PySide.QtCore.QGenericArgument = QGenericArgument(), PySide.QtCore.QGenericArgument = QGenericArgument(), PySide.QtCore.QGenericArgument = QGenericArgument(), PySide.QtCore.QGenericArgument = QGenericArgument(), PySide.QtCore.QGenericArgument = QGenericArgument(), PySide.QtCore.QGenericArgument = QGenericArgument(), PySide.QtCore.QGenericArgument = QGenericArgument()", "PySide.QtCore.QObject, str, PySide.QtCore.Qt.ConnectionType, PySide.QtCore.QGenericArgument = QGenericArgument(0), PySide.QtCore.QGenericArgument = QGenericArgument(), PySide.QtCore.QGenericArgument = QGenericArgument(), PySide.QtCore.QGenericArgument = QGenericArgument(), PySide.QtCore.QGenericArgument = QGenericArgument(), PySide.QtCore.QGenericArgument = QGenericArgument(), PySide.QtCore.QGenericArgument = QGenericArgument(), PySide.QtCore.QGenericArgument = QGenericArgument(), PySide.QtCore.QGenericArgument = QGenericArgument(), PySide.QtCore.QGenericArgument = QGenericArgument()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QMetaObject.invokeMethod", overloads);
        return 0;
}

static PyObject* Sbk_QMetaObjectFunc_method(PyObject* self, PyObject* arg)
{
    QMetaObject* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMetaObject* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: method(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // method(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QMetaObjectFunc_method_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // method(int)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QMetaMethod cppResult = cppSelf->method(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QMetaMethod >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QMetaObjectFunc_method_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QMetaObject.method", overloads);
        return 0;
}

static PyObject* Sbk_QMetaObjectFunc_methodCount(PyObject* self)
{
    QMetaObject* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMetaObject* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // methodCount()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->methodCount();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QMetaObjectFunc_methodOffset(PyObject* self)
{
    QMetaObject* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMetaObject* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // methodOffset()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->methodOffset();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QMetaObjectFunc_newInstance(PyObject* self, PyObject* args, PyObject* kwds)
{
    QMetaObject* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMetaObject* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 10) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QMetaObject.newInstance(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOOOOOOOO:newInstance", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4]), &(pyargs[5]), &(pyargs[6]), &(pyargs[7]), &(pyargs[8]), &(pyargs[9])))
        return 0;


    // Overloaded function decisor
    // 0: newInstance(QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
    if (numArgs == 0) {
        overloadId = 0; // newInstance(QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
    } else if (Shiboken::Converter< ::QGenericArgument >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // newInstance(QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
        } else if (Shiboken::Converter< ::QGenericArgument >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 0; // newInstance(QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
            } else if (Shiboken::Converter< ::QGenericArgument >::isConvertible(pyargs[2])) {
                if (numArgs == 3) {
                    overloadId = 0; // newInstance(QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                } else if (Shiboken::Converter< ::QGenericArgument >::isConvertible(pyargs[3])) {
                    if (numArgs == 4) {
                        overloadId = 0; // newInstance(QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                    } else if (Shiboken::Converter< ::QGenericArgument >::isConvertible(pyargs[4])) {
                        if (numArgs == 5) {
                            overloadId = 0; // newInstance(QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                        } else if (Shiboken::Converter< ::QGenericArgument >::isConvertible(pyargs[5])) {
                            if (numArgs == 6) {
                                overloadId = 0; // newInstance(QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                            } else if (Shiboken::Converter< ::QGenericArgument >::isConvertible(pyargs[6])) {
                                if (numArgs == 7) {
                                    overloadId = 0; // newInstance(QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                                } else if (Shiboken::Converter< ::QGenericArgument >::isConvertible(pyargs[7])) {
                                    if (numArgs == 8) {
                                        overloadId = 0; // newInstance(QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                                    } else if (Shiboken::Converter< ::QGenericArgument >::isConvertible(pyargs[8])) {
                                        if (numArgs == 9) {
                                            overloadId = 0; // newInstance(QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                                        } else if (Shiboken::Converter< ::QGenericArgument >::isConvertible(pyargs[9])) {
                                            overloadId = 0; // newInstance(QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                                        }
                                    }
                                }
                            }
                        }
                    }
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QMetaObjectFunc_newInstance_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "val0");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "val0";
                    else if (Shiboken::Converter< ::QGenericArgument >::isConvertible(value))
                        pyargs[0] = value;
else
                        goto Sbk_QMetaObjectFunc_newInstance_TypeError;
                }
                value = PyDict_GetItemString(kwds, "val1");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "val1";
                    else if (Shiboken::Converter< ::QGenericArgument >::isConvertible(value))
                        pyargs[1] = value;
else
                        goto Sbk_QMetaObjectFunc_newInstance_TypeError;
                }
                value = PyDict_GetItemString(kwds, "val2");
                if (value) {
                    if (pyargs[2])
                        errorArgName = "val2";
                    else if (Shiboken::Converter< ::QGenericArgument >::isConvertible(value))
                        pyargs[2] = value;
else
                        goto Sbk_QMetaObjectFunc_newInstance_TypeError;
                }
                value = PyDict_GetItemString(kwds, "val3");
                if (value) {
                    if (pyargs[3])
                        errorArgName = "val3";
                    else if (Shiboken::Converter< ::QGenericArgument >::isConvertible(value))
                        pyargs[3] = value;
else
                        goto Sbk_QMetaObjectFunc_newInstance_TypeError;
                }
                value = PyDict_GetItemString(kwds, "val4");
                if (value) {
                    if (pyargs[4])
                        errorArgName = "val4";
                    else if (Shiboken::Converter< ::QGenericArgument >::isConvertible(value))
                        pyargs[4] = value;
else
                        goto Sbk_QMetaObjectFunc_newInstance_TypeError;
                }
                value = PyDict_GetItemString(kwds, "val5");
                if (value) {
                    if (pyargs[5])
                        errorArgName = "val5";
                    else if (Shiboken::Converter< ::QGenericArgument >::isConvertible(value))
                        pyargs[5] = value;
else
                        goto Sbk_QMetaObjectFunc_newInstance_TypeError;
                }
                value = PyDict_GetItemString(kwds, "val6");
                if (value) {
                    if (pyargs[6])
                        errorArgName = "val6";
                    else if (Shiboken::Converter< ::QGenericArgument >::isConvertible(value))
                        pyargs[6] = value;
else
                        goto Sbk_QMetaObjectFunc_newInstance_TypeError;
                }
                value = PyDict_GetItemString(kwds, "val7");
                if (value) {
                    if (pyargs[7])
                        errorArgName = "val7";
                    else if (Shiboken::Converter< ::QGenericArgument >::isConvertible(value))
                        pyargs[7] = value;
else
                        goto Sbk_QMetaObjectFunc_newInstance_TypeError;
                }
                value = PyDict_GetItemString(kwds, "val8");
                if (value) {
                    if (pyargs[8])
                        errorArgName = "val8";
                    else if (Shiboken::Converter< ::QGenericArgument >::isConvertible(value))
                        pyargs[8] = value;
else
                        goto Sbk_QMetaObjectFunc_newInstance_TypeError;
                }
                value = PyDict_GetItemString(kwds, "val9");
                if (value) {
                    if (pyargs[9])
                        errorArgName = "val9";
                    else if (Shiboken::Converter< ::QGenericArgument >::isConvertible(value))
                        pyargs[9] = value;
else
                        goto Sbk_QMetaObjectFunc_newInstance_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QMetaObject.newInstance(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QGenericArgument cppArg0_tmp = QGenericArgument(0);
            QGenericArgument cppArg0 = pyargs[0] ? Shiboken::Converter<QGenericArgument >::toCpp(pyargs[0]) : cppArg0_tmp;
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QGenericArgument cppArg1_tmp = QGenericArgument();
            QGenericArgument cppArg1 = pyargs[1] ? Shiboken::Converter<QGenericArgument >::toCpp(pyargs[1]) : cppArg1_tmp;
            if (!Shiboken::Object::isValid(pyargs[2]))
                return 0;
            QGenericArgument cppArg2_tmp = QGenericArgument();
            QGenericArgument cppArg2 = pyargs[2] ? Shiboken::Converter<QGenericArgument >::toCpp(pyargs[2]) : cppArg2_tmp;
            if (!Shiboken::Object::isValid(pyargs[3]))
                return 0;
            QGenericArgument cppArg3_tmp = QGenericArgument();
            QGenericArgument cppArg3 = pyargs[3] ? Shiboken::Converter<QGenericArgument >::toCpp(pyargs[3]) : cppArg3_tmp;
            if (!Shiboken::Object::isValid(pyargs[4]))
                return 0;
            QGenericArgument cppArg4_tmp = QGenericArgument();
            QGenericArgument cppArg4 = pyargs[4] ? Shiboken::Converter<QGenericArgument >::toCpp(pyargs[4]) : cppArg4_tmp;
            if (!Shiboken::Object::isValid(pyargs[5]))
                return 0;
            QGenericArgument cppArg5_tmp = QGenericArgument();
            QGenericArgument cppArg5 = pyargs[5] ? Shiboken::Converter<QGenericArgument >::toCpp(pyargs[5]) : cppArg5_tmp;
            if (!Shiboken::Object::isValid(pyargs[6]))
                return 0;
            QGenericArgument cppArg6_tmp = QGenericArgument();
            QGenericArgument cppArg6 = pyargs[6] ? Shiboken::Converter<QGenericArgument >::toCpp(pyargs[6]) : cppArg6_tmp;
            if (!Shiboken::Object::isValid(pyargs[7]))
                return 0;
            QGenericArgument cppArg7_tmp = QGenericArgument();
            QGenericArgument cppArg7 = pyargs[7] ? Shiboken::Converter<QGenericArgument >::toCpp(pyargs[7]) : cppArg7_tmp;
            if (!Shiboken::Object::isValid(pyargs[8]))
                return 0;
            QGenericArgument cppArg8_tmp = QGenericArgument();
            QGenericArgument cppArg8 = pyargs[8] ? Shiboken::Converter<QGenericArgument >::toCpp(pyargs[8]) : cppArg8_tmp;
            if (!Shiboken::Object::isValid(pyargs[9]))
                return 0;
            QGenericArgument cppArg9_tmp = QGenericArgument();
            QGenericArgument cppArg9 = pyargs[9] ? Shiboken::Converter<QGenericArgument >::toCpp(pyargs[9]) : cppArg9_tmp;

            if(!PyErr_Occurred()) {
                // newInstance(QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument,QGenericArgument)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QObject * cppResult = cppSelf->newInstance(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5, cppArg6, cppArg7, cppArg8, cppArg9);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QObject * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QMetaObjectFunc_newInstance_TypeError:
        const char* overloads[] = {"PySide.QtCore.QGenericArgument = QGenericArgument(0), PySide.QtCore.QGenericArgument = QGenericArgument(), PySide.QtCore.QGenericArgument = QGenericArgument(), PySide.QtCore.QGenericArgument = QGenericArgument(), PySide.QtCore.QGenericArgument = QGenericArgument(), PySide.QtCore.QGenericArgument = QGenericArgument(), PySide.QtCore.QGenericArgument = QGenericArgument(), PySide.QtCore.QGenericArgument = QGenericArgument(), PySide.QtCore.QGenericArgument = QGenericArgument(), PySide.QtCore.QGenericArgument = QGenericArgument()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QMetaObject.newInstance", overloads);
        return 0;
}

static PyObject* Sbk_QMetaObjectFunc_normalizedSignature(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: normalizedSignature(const char*)
    if (Shiboken::Converter< const char * >::isConvertible(arg)) {
        overloadId = 0; // normalizedSignature(const char*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QMetaObjectFunc_normalizedSignature_TypeError;

    // Call function/method
    {
        {
            const char * cppArg0 = Shiboken::Converter<const char * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // normalizedSignature(const char*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QByteArray cppResult = QMetaObject::normalizedSignature(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QByteArray >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QMetaObjectFunc_normalizedSignature_TypeError:
        const char* overloads[] = {"str", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QMetaObject.normalizedSignature", overloads);
        return 0;
}

static PyObject* Sbk_QMetaObjectFunc_normalizedType(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: normalizedType(const char*)
    if (Shiboken::Converter< const char * >::isConvertible(arg)) {
        overloadId = 0; // normalizedType(const char*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QMetaObjectFunc_normalizedType_TypeError;

    // Call function/method
    {
        {
            const char * cppArg0 = Shiboken::Converter<const char * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // normalizedType(const char*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QByteArray cppResult = QMetaObject::normalizedType(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QByteArray >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QMetaObjectFunc_normalizedType_TypeError:
        const char* overloads[] = {"str", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QMetaObject.normalizedType", overloads);
        return 0;
}

static PyObject* Sbk_QMetaObjectFunc_property(PyObject* self, PyObject* arg)
{
    QMetaObject* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMetaObject* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: property(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // property(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QMetaObjectFunc_property_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // property(int)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QMetaProperty cppResult = cppSelf->property(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QMetaProperty >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QMetaObjectFunc_property_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QMetaObject.property", overloads);
        return 0;
}

static PyObject* Sbk_QMetaObjectFunc_propertyCount(PyObject* self)
{
    QMetaObject* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMetaObject* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // propertyCount()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->propertyCount();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QMetaObjectFunc_propertyOffset(PyObject* self)
{
    QMetaObject* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMetaObject* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // propertyOffset()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->propertyOffset();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QMetaObjectFunc_superClass(PyObject* self)
{
    QMetaObject* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMetaObject* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // superClass()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                const QMetaObject * cppResult = cppSelf->superClass();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QMetaObject * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QMetaObjectFunc_userProperty(PyObject* self)
{
    QMetaObject* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMetaObject* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // userProperty()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QMetaProperty cppResult = cppSelf->userProperty();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QMetaProperty >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef Sbk_QMetaObject_methods[] = {
    {"cast", (PyCFunction)Sbk_QMetaObjectFunc_cast, METH_O},
    {"checkConnectArgs", (PyCFunction)Sbk_QMetaObjectFunc_checkConnectArgs, METH_VARARGS|METH_STATIC},
    {"classInfo", (PyCFunction)Sbk_QMetaObjectFunc_classInfo, METH_O},
    {"classInfoCount", (PyCFunction)Sbk_QMetaObjectFunc_classInfoCount, METH_NOARGS},
    {"classInfoOffset", (PyCFunction)Sbk_QMetaObjectFunc_classInfoOffset, METH_NOARGS},
    {"className", (PyCFunction)Sbk_QMetaObjectFunc_className, METH_NOARGS},
    {"connectSlotsByName", (PyCFunction)Sbk_QMetaObjectFunc_connectSlotsByName, METH_O|METH_STATIC},
    {"constructor", (PyCFunction)Sbk_QMetaObjectFunc_constructor, METH_O},
    {"constructorCount", (PyCFunction)Sbk_QMetaObjectFunc_constructorCount, METH_NOARGS},
    {"disconnect", (PyCFunction)Sbk_QMetaObjectFunc_disconnect, METH_VARARGS|METH_STATIC},
    {"enumerator", (PyCFunction)Sbk_QMetaObjectFunc_enumerator, METH_O},
    {"enumeratorCount", (PyCFunction)Sbk_QMetaObjectFunc_enumeratorCount, METH_NOARGS},
    {"enumeratorOffset", (PyCFunction)Sbk_QMetaObjectFunc_enumeratorOffset, METH_NOARGS},
    {"indexOfClassInfo", (PyCFunction)Sbk_QMetaObjectFunc_indexOfClassInfo, METH_O},
    {"indexOfConstructor", (PyCFunction)Sbk_QMetaObjectFunc_indexOfConstructor, METH_O},
    {"indexOfEnumerator", (PyCFunction)Sbk_QMetaObjectFunc_indexOfEnumerator, METH_O},
    {"indexOfMethod", (PyCFunction)Sbk_QMetaObjectFunc_indexOfMethod, METH_O},
    {"indexOfProperty", (PyCFunction)Sbk_QMetaObjectFunc_indexOfProperty, METH_O},
    {"indexOfSignal", (PyCFunction)Sbk_QMetaObjectFunc_indexOfSignal, METH_O},
    {"indexOfSlot", (PyCFunction)Sbk_QMetaObjectFunc_indexOfSlot, METH_O},
    {"invokeMethod", (PyCFunction)Sbk_QMetaObjectFunc_invokeMethod, METH_VARARGS|METH_KEYWORDS|METH_STATIC},
    {"method", (PyCFunction)Sbk_QMetaObjectFunc_method, METH_O},
    {"methodCount", (PyCFunction)Sbk_QMetaObjectFunc_methodCount, METH_NOARGS},
    {"methodOffset", (PyCFunction)Sbk_QMetaObjectFunc_methodOffset, METH_NOARGS},
    {"newInstance", (PyCFunction)Sbk_QMetaObjectFunc_newInstance, METH_VARARGS|METH_KEYWORDS},
    {"normalizedSignature", (PyCFunction)Sbk_QMetaObjectFunc_normalizedSignature, METH_O|METH_STATIC},
    {"normalizedType", (PyCFunction)Sbk_QMetaObjectFunc_normalizedType, METH_O|METH_STATIC},
    {"property", (PyCFunction)Sbk_QMetaObjectFunc_property, METH_O},
    {"propertyCount", (PyCFunction)Sbk_QMetaObjectFunc_propertyCount, METH_NOARGS},
    {"propertyOffset", (PyCFunction)Sbk_QMetaObjectFunc_propertyOffset, METH_NOARGS},
    {"superClass", (PyCFunction)Sbk_QMetaObjectFunc_superClass, METH_NOARGS},
    {"userProperty", (PyCFunction)Sbk_QMetaObjectFunc_userProperty, METH_NOARGS},

    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QMetaObject_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtCore.QMetaObject",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QMetaObject_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QMetaObject_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QMetaObject(PyObject* module)
{
    SbkPySide_QtCoreTypes[SBK_QMETAOBJECT_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QMetaObject_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QMetaObject_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QMetaObject_Type, &Shiboken::callCppDestructor<QMetaObject >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QMetaObject_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QMetaObject_Type, "QMetaObject*");
    PyModule_AddObject(module, "QMetaObject",
        ((PyObject*)&Sbk_QMetaObject_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: Call
    PyTypeObject* SbkPySide_QtCore_QMetaObject_Call = Shiboken::Enum::newType("Call");
    SbkPySide_QtCoreTypes[SBK_QMETAOBJECT_CALL_IDX] = SbkPySide_QtCore_QMetaObject_Call;
    if (PyType_Ready(SbkPySide_QtCore_QMetaObject_Call) < 0)
        return;
    PyDict_SetItemString(Sbk_QMetaObject_Type.super.ht_type.tp_dict,
            "Call",((PyObject*)SbkPySide_QtCore_QMetaObject_Call));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QMetaObject_Call,(long) QMetaObject::InvokeMetaMethod, "InvokeMetaMethod");
    PyDict_SetItemString(Sbk_QMetaObject_Type.super.ht_type.tp_dict,"InvokeMetaMethod", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QMetaObject_Call->tp_dict,"InvokeMetaMethod", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QMetaObject_Call,(long) QMetaObject::ReadProperty, "ReadProperty");
    PyDict_SetItemString(Sbk_QMetaObject_Type.super.ht_type.tp_dict,"ReadProperty", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QMetaObject_Call->tp_dict,"ReadProperty", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QMetaObject_Call,(long) QMetaObject::WriteProperty, "WriteProperty");
    PyDict_SetItemString(Sbk_QMetaObject_Type.super.ht_type.tp_dict,"WriteProperty", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QMetaObject_Call->tp_dict,"WriteProperty", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QMetaObject_Call,(long) QMetaObject::ResetProperty, "ResetProperty");
    PyDict_SetItemString(Sbk_QMetaObject_Type.super.ht_type.tp_dict,"ResetProperty", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QMetaObject_Call->tp_dict,"ResetProperty", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QMetaObject_Call,(long) QMetaObject::QueryPropertyDesignable, "QueryPropertyDesignable");
    PyDict_SetItemString(Sbk_QMetaObject_Type.super.ht_type.tp_dict,"QueryPropertyDesignable", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QMetaObject_Call->tp_dict,"QueryPropertyDesignable", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QMetaObject_Call,(long) QMetaObject::QueryPropertyScriptable, "QueryPropertyScriptable");
    PyDict_SetItemString(Sbk_QMetaObject_Type.super.ht_type.tp_dict,"QueryPropertyScriptable", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QMetaObject_Call->tp_dict,"QueryPropertyScriptable", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QMetaObject_Call,(long) QMetaObject::QueryPropertyStored, "QueryPropertyStored");
    PyDict_SetItemString(Sbk_QMetaObject_Type.super.ht_type.tp_dict,"QueryPropertyStored", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QMetaObject_Call->tp_dict,"QueryPropertyStored", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QMetaObject_Call,(long) QMetaObject::QueryPropertyEditable, "QueryPropertyEditable");
    PyDict_SetItemString(Sbk_QMetaObject_Type.super.ht_type.tp_dict,"QueryPropertyEditable", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QMetaObject_Call->tp_dict,"QueryPropertyEditable", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QMetaObject_Call,(long) QMetaObject::QueryPropertyUser, "QueryPropertyUser");
    PyDict_SetItemString(Sbk_QMetaObject_Type.super.ht_type.tp_dict,"QueryPropertyUser", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QMetaObject_Call->tp_dict,"QueryPropertyUser", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QMetaObject_Call,(long) QMetaObject::CreateInstance, "CreateInstance");
    PyDict_SetItemString(Sbk_QMetaObject_Type.super.ht_type.tp_dict,"CreateInstance", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QMetaObject_Call->tp_dict,"CreateInstance", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QMetaObject::Call");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::Call");
    // end of enum Call


    Shiboken::TypeResolver::createObjectTypeResolver<QMetaObject >("QMetaObject*");
    Shiboken::TypeResolver::createObjectTypeResolver<QMetaObject >(typeid(QMetaObject).name());
    PySide::initQtMetaType<QMetaObject* >();
}

