/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtcore_python.h"

#include "qmutex_wrapper.h"

// Extra includes
#include <qmutex.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QMutex_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QMutex >()))
        return -1;

    QMutex* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);

    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QMutex(): too many arguments");
        return -1;
    }

    if (!PyArg_ParseTuple(args, "|O:QMutex", &(pyargs[0])))
        return -1;

    // Overloaded function decisor
    // 0: QMutex(QMutex::RecursionMode)
    if (numArgs == 0) {
        overloadId = 0; // QMutex(QMutex::RecursionMode)
    } else if (Shiboken::Converter< ::QMutex::RecursionMode >::isConvertible(pyargs[0])) {
        overloadId = 0; // QMutex(QMutex::RecursionMode)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QMutex_Init_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "mode");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "mode";
                    else if (Shiboken::Converter< ::QMutex::RecursionMode >::isConvertible(value))
                        pyargs[0] = value;
else
                        goto Sbk_QMutex_Init_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QMutex(): got multiple values for keyword argument '%s'", errorArgName);
                    return -1;
                }
            }
            QMutex::RecursionMode cppArg0 = pyargs[0] ? Shiboken::Converter<QMutex::RecursionMode >::toCpp(pyargs[0]) : QMutex::NonRecursive;

            if(!PyErr_Occurred()) {
                // QMutex(QMutex::RecursionMode)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new QMutex(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QMutex >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QMutex_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QMutex_Init_TypeError:
        const char* overloads[] = {"PySide.QtCore.QMutex.RecursionMode = NonRecursive", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QMutex", overloads);
        return -1;
}

static PyObject* Sbk_QMutexFunc_lock(PyObject* self)
{
    QMutex* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMutex* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // lock()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->lock();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QMutexFunc_tryLock(PyObject* self, PyObject* args)
{
    QMutex* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMutex* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "tryLock", 0, 1, &(pyargs[0])))
        return 0;


    // Overloaded function decisor
    // 0: tryLock()
    // 1: tryLock(int)
    if (numArgs == 0) {
        overloadId = 0; // tryLock()
    } else if (numArgs == 1 && SbkNumber_Check(pyargs[0])) {
        overloadId = 1; // tryLock(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QMutexFunc_tryLock_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // tryLock()
            {

                if(!PyErr_Occurred()) {
                    // tryLock()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    bool cppResult = cppSelf->tryLock();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< bool >::toPython(cppResult);
                }
                break;
            }
            case 1: // tryLock(int)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // tryLock(int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    bool cppResult = cppSelf->tryLock(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< bool >::toPython(cppResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QMutexFunc_tryLock_TypeError:
        const char* overloads[] = {"", "int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QMutex.tryLock", overloads);
        return 0;
}

static PyObject* Sbk_QMutexFunc_unlock(PyObject* self)
{
    QMutex* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMutex* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // unlock()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->unlock();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyMethodDef Sbk_QMutex_methods[] = {
    {"lock", (PyCFunction)Sbk_QMutexFunc_lock, METH_NOARGS},
    {"tryLock", (PyCFunction)Sbk_QMutexFunc_tryLock, METH_VARARGS},
    {"unlock", (PyCFunction)Sbk_QMutexFunc_unlock, METH_NOARGS},

    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QMutex_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtCore.QMutex",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QMutex_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QMutex_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QMutex(PyObject* module)
{
    SbkPySide_QtCoreTypes[SBK_QMUTEX_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QMutex_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QMutex_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QMutex_Type, &Shiboken::callCppDestructor<QMutex >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QMutex_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QMutex_Type, "QMutex*");
    PyModule_AddObject(module, "QMutex",
        ((PyObject*)&Sbk_QMutex_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: RecursionMode
    PyTypeObject* SbkPySide_QtCore_QMutex_RecursionMode = Shiboken::Enum::newType("RecursionMode");
    SbkPySide_QtCoreTypes[SBK_QMUTEX_RECURSIONMODE_IDX] = SbkPySide_QtCore_QMutex_RecursionMode;
    if (PyType_Ready(SbkPySide_QtCore_QMutex_RecursionMode) < 0)
        return;
    PyDict_SetItemString(Sbk_QMutex_Type.super.ht_type.tp_dict,
            "RecursionMode",((PyObject*)SbkPySide_QtCore_QMutex_RecursionMode));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QMutex_RecursionMode,(long) QMutex::NonRecursive, "NonRecursive");
    PyDict_SetItemString(Sbk_QMutex_Type.super.ht_type.tp_dict,"NonRecursive", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QMutex_RecursionMode->tp_dict,"NonRecursive", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QMutex_RecursionMode,(long) QMutex::Recursive, "Recursive");
    PyDict_SetItemString(Sbk_QMutex_Type.super.ht_type.tp_dict,"Recursive", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QMutex_RecursionMode->tp_dict,"Recursive", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QMutex::RecursionMode");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::RecursionMode");
    // end of enum RecursionMode


    Shiboken::TypeResolver::createObjectTypeResolver<QMutex >("QMutex*");
    Shiboken::TypeResolver::createObjectTypeResolver<QMutex >(typeid(QMutex).name());
    PySide::initQtMetaType<QMutex* >();
}

