/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtcore_python.h"

#include "qregexp_wrapper.h"

// Extra includes
#include <QStringList>
#include <qregexp.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QRegExp_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QRegExp >()))
        return -1;

    QRegExp* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);

    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QRegExp(): too many arguments");
        return -1;
    }

    if (!PyArg_ParseTuple(args, "|OOO:QRegExp", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return -1;

    // Overloaded function decisor
    // 0: QRegExp()
    // 1: QRegExp(QRegExp)
    // 2: QRegExp(QString,Qt::CaseSensitivity,QRegExp::PatternSyntax)
    if (numArgs == 0) {
        overloadId = 0; // QRegExp()
    } else if (Shiboken::Converter< QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 2; // QRegExp(QString,Qt::CaseSensitivity,QRegExp::PatternSyntax)
        } else if (Shiboken::Converter< ::Qt::CaseSensitivity >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 2; // QRegExp(QString,Qt::CaseSensitivity,QRegExp::PatternSyntax)
            } else if (Shiboken::Converter< ::QRegExp::PatternSyntax >::isConvertible(pyargs[2])) {
                overloadId = 2; // QRegExp(QString,Qt::CaseSensitivity,QRegExp::PatternSyntax)
            }
        }
    } else if (numArgs == 1 && Shiboken::Converter< ::QRegExp >::isConvertible(pyargs[0])) {
        overloadId = 1; // QRegExp(QRegExp)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRegExp_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QRegExp()
            {

                if(!PyErr_Occurred()) {
                    // QRegExp()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QRegExp();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // QRegExp(QRegExp)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QRegExp cppArg0 = Shiboken::Converter<QRegExp >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QRegExp(QRegExp)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QRegExp(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // QRegExp(QString,Qt::CaseSensitivity,QRegExp::PatternSyntax)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "cs");
                    if (value) {
                        if (pyargs[1])
                            errorArgName = "cs";
                        else if (Shiboken::Converter< ::Qt::CaseSensitivity >::isConvertible(value))
                            pyargs[1] = value;
else
                            goto Sbk_QRegExp_Init_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "syntax");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "syntax";
                        else if (Shiboken::Converter< ::QRegExp::PatternSyntax >::isConvertible(value))
                            pyargs[2] = value;
else
                            goto Sbk_QRegExp_Init_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtCore.QRegExp(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                Qt::CaseSensitivity cppArg1 = pyargs[1] ? Shiboken::Converter<Qt::CaseSensitivity >::toCpp(pyargs[1]) : Qt::CaseSensitive;
                QRegExp::PatternSyntax cppArg2 = pyargs[2] ? Shiboken::Converter<QRegExp::PatternSyntax >::toCpp(pyargs[2]) : QRegExp::RegExp;

                if(!PyErr_Occurred()) {
                    // QRegExp(QString,Qt::CaseSensitivity,QRegExp::PatternSyntax)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QRegExp(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QRegExp >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QRegExp_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QRegExp_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtCore.QRegExp", "QString, PySide.QtCore.Qt.CaseSensitivity = Qt.CaseSensitive, PySide.QtCore.QRegExp.PatternSyntax = RegExp", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QRegExp", overloads);
        return -1;
}

static PyObject* Sbk_QRegExpFunc___reduce__(PyObject* self)
{
    QRegExp* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QRegExp* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // __reduce__()
                // Begin code injection
                
                // TEMPLATE - reduce_code - START
                pyResult = Py_BuildValue("(N(sii))", PyObject_Type(self), qPrintable(cppSelf->pattern()), (int)cppSelf->caseSensitivity(), (int)cppSelf->patternSyntax());
                // TEMPLATE - reduce_code - END
                
                // End of code injection


            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QRegExpFunc_cap(PyObject* self, PyObject* args, PyObject* kwds)
{
    QRegExp* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QRegExp* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QRegExp.cap(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:cap", &(pyargs[0])))
        return 0;


    // Overloaded function decisor
    // 0: cap(int)
    if (numArgs == 0) {
        overloadId = 0; // cap(int)
    } else if (SbkNumber_Check(pyargs[0])) {
        overloadId = 0; // cap(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRegExpFunc_cap_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "nth");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "nth";
                    else if (SbkNumber_Check(value))
                        pyargs[0] = value;
else
                        goto Sbk_QRegExpFunc_cap_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QRegExp.cap(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cppArg0 = pyargs[0] ? Shiboken::Converter<int >::toCpp(pyargs[0]) : 0;

            if(!PyErr_Occurred()) {
                // cap(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = cppSelf->cap(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QRegExpFunc_cap_TypeError:
        const char* overloads[] = {"int = 0", "int = 0", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QRegExp.cap", overloads);
        return 0;
}

static PyObject* Sbk_QRegExpFunc_captureCount(PyObject* self)
{
    QRegExp* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QRegExp* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // captureCount()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->captureCount();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QRegExpFunc_capturedTexts(PyObject* self)
{
    QRegExp* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QRegExp* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // capturedTexts()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QStringList cppResult = cppSelf->capturedTexts();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QStringList >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QRegExpFunc_caseSensitivity(PyObject* self)
{
    QRegExp* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QRegExp* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // caseSensitivity()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                Qt::CaseSensitivity cppResult = cppSelf->caseSensitivity();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::Qt::CaseSensitivity >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QRegExpFunc_errorString(PyObject* self)
{
    QRegExp* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QRegExp* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // errorString()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = cppSelf->errorString();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QRegExpFunc_escape(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: escape(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // escape(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRegExpFunc_escape_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // escape(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = QRegExp::escape(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QRegExpFunc_escape_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QRegExp.escape", overloads);
        return 0;
}

static PyObject* Sbk_QRegExpFunc_exactMatch(PyObject* self, PyObject* arg)
{
    QRegExp* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QRegExp* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: exactMatch(QString)const
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // exactMatch(QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRegExpFunc_exactMatch_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // exactMatch(QString)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->exactMatch(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QRegExpFunc_exactMatch_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QRegExp.exactMatch", overloads);
        return 0;
}

static PyObject* Sbk_QRegExpFunc_indexIn(PyObject* self, PyObject* args, PyObject* kwds)
{
    QRegExp* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QRegExp* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QRegExp.indexIn(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QRegExp.indexIn(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:indexIn", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: indexIn(QString,int,QRegExp::CaretMode)const
    if (Shiboken::Converter< QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // indexIn(QString,int,QRegExp::CaretMode)const
        } else if (SbkNumber_Check(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 0; // indexIn(QString,int,QRegExp::CaretMode)const
            } else if (Shiboken::Converter< ::QRegExp::CaretMode >::isConvertible(pyargs[2])) {
                overloadId = 0; // indexIn(QString,int,QRegExp::CaretMode)const
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRegExpFunc_indexIn_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "offset");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "offset";
                    else if (SbkNumber_Check(value))
                        pyargs[1] = value;
else
                        goto Sbk_QRegExpFunc_indexIn_TypeError;
                }
                value = PyDict_GetItemString(kwds, "caretMode");
                if (value) {
                    if (pyargs[2])
                        errorArgName = "caretMode";
                    else if (Shiboken::Converter< ::QRegExp::CaretMode >::isConvertible(value))
                        pyargs[2] = value;
else
                        goto Sbk_QRegExpFunc_indexIn_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QRegExp.indexIn(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            int cppArg1 = pyargs[1] ? Shiboken::Converter<int >::toCpp(pyargs[1]) : 0;
            QRegExp::CaretMode cppArg2 = pyargs[2] ? Shiboken::Converter<QRegExp::CaretMode >::toCpp(pyargs[2]) : QRegExp::CaretAtZero;

            if(!PyErr_Occurred()) {
                // indexIn(QString,int,QRegExp::CaretMode)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->indexIn(cppArg0, cppArg1, cppArg2);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QRegExpFunc_indexIn_TypeError:
        const char* overloads[] = {"QString, int = 0, PySide.QtCore.QRegExp.CaretMode = CaretAtZero", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QRegExp.indexIn", overloads);
        return 0;
}

static PyObject* Sbk_QRegExpFunc_isEmpty(PyObject* self)
{
    QRegExp* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QRegExp* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isEmpty()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->isEmpty();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QRegExpFunc_isMinimal(PyObject* self)
{
    QRegExp* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QRegExp* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isMinimal()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->isMinimal();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QRegExpFunc_isValid(PyObject* self)
{
    QRegExp* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QRegExp* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isValid()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->isValid();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QRegExpFunc_lastIndexIn(PyObject* self, PyObject* args, PyObject* kwds)
{
    QRegExp* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QRegExp* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QRegExp.lastIndexIn(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QRegExp.lastIndexIn(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:lastIndexIn", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: lastIndexIn(QString,int,QRegExp::CaretMode)const
    if (Shiboken::Converter< QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // lastIndexIn(QString,int,QRegExp::CaretMode)const
        } else if (SbkNumber_Check(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 0; // lastIndexIn(QString,int,QRegExp::CaretMode)const
            } else if (Shiboken::Converter< ::QRegExp::CaretMode >::isConvertible(pyargs[2])) {
                overloadId = 0; // lastIndexIn(QString,int,QRegExp::CaretMode)const
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRegExpFunc_lastIndexIn_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "offset");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "offset";
                    else if (SbkNumber_Check(value))
                        pyargs[1] = value;
else
                        goto Sbk_QRegExpFunc_lastIndexIn_TypeError;
                }
                value = PyDict_GetItemString(kwds, "caretMode");
                if (value) {
                    if (pyargs[2])
                        errorArgName = "caretMode";
                    else if (Shiboken::Converter< ::QRegExp::CaretMode >::isConvertible(value))
                        pyargs[2] = value;
else
                        goto Sbk_QRegExpFunc_lastIndexIn_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QRegExp.lastIndexIn(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            int cppArg1 = pyargs[1] ? Shiboken::Converter<int >::toCpp(pyargs[1]) : -1;
            QRegExp::CaretMode cppArg2 = pyargs[2] ? Shiboken::Converter<QRegExp::CaretMode >::toCpp(pyargs[2]) : QRegExp::CaretAtZero;

            if(!PyErr_Occurred()) {
                // lastIndexIn(QString,int,QRegExp::CaretMode)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->lastIndexIn(cppArg0, cppArg1, cppArg2);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QRegExpFunc_lastIndexIn_TypeError:
        const char* overloads[] = {"QString, int = -1, PySide.QtCore.QRegExp.CaretMode = CaretAtZero", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QRegExp.lastIndexIn", overloads);
        return 0;
}

static PyObject* Sbk_QRegExpFunc_matchedLength(PyObject* self)
{
    QRegExp* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QRegExp* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // matchedLength()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->matchedLength();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QRegExpFunc_numCaptures(PyObject* self)
{
    QRegExp* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QRegExp* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // numCaptures()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->numCaptures();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QRegExpFunc_pattern(PyObject* self)
{
    QRegExp* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QRegExp* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // pattern()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = cppSelf->pattern();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QRegExpFunc_patternSyntax(PyObject* self)
{
    QRegExp* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QRegExp* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // patternSyntax()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QRegExp::PatternSyntax cppResult = cppSelf->patternSyntax();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QRegExp::PatternSyntax >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QRegExpFunc_pos(PyObject* self, PyObject* args, PyObject* kwds)
{
    QRegExp* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QRegExp* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QRegExp.pos(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:pos", &(pyargs[0])))
        return 0;


    // Overloaded function decisor
    // 0: pos(int)
    if (numArgs == 0) {
        overloadId = 0; // pos(int)
    } else if (SbkNumber_Check(pyargs[0])) {
        overloadId = 0; // pos(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRegExpFunc_pos_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "nth");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "nth";
                    else if (SbkNumber_Check(value))
                        pyargs[0] = value;
else
                        goto Sbk_QRegExpFunc_pos_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QRegExp.pos(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cppArg0 = pyargs[0] ? Shiboken::Converter<int >::toCpp(pyargs[0]) : 0;

            if(!PyErr_Occurred()) {
                // pos(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->pos(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QRegExpFunc_pos_TypeError:
        const char* overloads[] = {"int = 0", "int = 0", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QRegExp.pos", overloads);
        return 0;
}

static PyObject* Sbk_QRegExpFunc_replace(PyObject* self, PyObject* args)
{
    QRegExp* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QRegExp* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "replace", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: replace(QString,QString)
    if (numArgs == 2 && Shiboken::Converter< QString >::isConvertible(pyargs[0]) && Shiboken::Converter< QString >::isConvertible(pyargs[1])) {
        overloadId = 0; // replace(QString,QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRegExpFunc_replace_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QString cppArg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // replace(QString,QString)
                // Begin code injection
                
                cppArg0.replace(*cppSelf, cppArg1);
                pyResult = Shiboken::Converter<QString >::toPython(cppArg0);
                
                // End of code injection


            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QRegExpFunc_replace_TypeError:
        const char* overloads[] = {"QString, QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QRegExp.replace", overloads);
        return 0;
}

static PyObject* Sbk_QRegExpFunc_setCaseSensitivity(PyObject* self, PyObject* arg)
{
    QRegExp* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QRegExp* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setCaseSensitivity(Qt::CaseSensitivity)
    if (Shiboken::Converter< ::Qt::CaseSensitivity >::isConvertible(arg)) {
        overloadId = 0; // setCaseSensitivity(Qt::CaseSensitivity)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRegExpFunc_setCaseSensitivity_TypeError;

    // Call function/method
    {
        {
            Qt::CaseSensitivity cppArg0 = Shiboken::Converter<Qt::CaseSensitivity >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setCaseSensitivity(Qt::CaseSensitivity)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setCaseSensitivity(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QRegExpFunc_setCaseSensitivity_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.CaseSensitivity", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QRegExp.setCaseSensitivity", overloads);
        return 0;
}

static PyObject* Sbk_QRegExpFunc_setMinimal(PyObject* self, PyObject* arg)
{
    QRegExp* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QRegExp* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setMinimal(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setMinimal(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRegExpFunc_setMinimal_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setMinimal(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setMinimal(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QRegExpFunc_setMinimal_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QRegExp.setMinimal", overloads);
        return 0;
}

static PyObject* Sbk_QRegExpFunc_setPattern(PyObject* self, PyObject* arg)
{
    QRegExp* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QRegExp* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setPattern(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // setPattern(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRegExpFunc_setPattern_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setPattern(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setPattern(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QRegExpFunc_setPattern_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QRegExp.setPattern", overloads);
        return 0;
}

static PyObject* Sbk_QRegExpFunc_setPatternSyntax(PyObject* self, PyObject* arg)
{
    QRegExp* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QRegExp* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setPatternSyntax(QRegExp::PatternSyntax)
    if (Shiboken::Converter< ::QRegExp::PatternSyntax >::isConvertible(arg)) {
        overloadId = 0; // setPatternSyntax(QRegExp::PatternSyntax)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QRegExpFunc_setPatternSyntax_TypeError;

    // Call function/method
    {
        {
            QRegExp::PatternSyntax cppArg0 = Shiboken::Converter<QRegExp::PatternSyntax >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setPatternSyntax(QRegExp::PatternSyntax)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setPatternSyntax(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QRegExpFunc_setPatternSyntax_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRegExp.PatternSyntax", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QRegExp.setPatternSyntax", overloads);
        return 0;
}

static PyObject *Sbk_QRegExp___copy__(PyObject *self)
{
        QRegExp* cppSelf = 0;
        if (!Shiboken::Object::isValid(self))
            return 0;
        cppSelf = Shiboken::Converter<QRegExp*>::toCpp(self);
        PyObject* pyResult = 0;
        QRegExp* copy = new QRegExp(*cppSelf);
        pyResult = Shiboken::Converter<QRegExp*>::toPython(copy);
        Shiboken::Object::getOwnership(pyResult);

        if (PyErr_Occurred() || !pyResult) {
            Py_XDECREF(pyResult);
            return 0;
        }
        return pyResult;
}

static PyMethodDef Sbk_QRegExp_methods[] = {
    {"__reduce__", (PyCFunction)Sbk_QRegExpFunc___reduce__, METH_NOARGS},
    {"cap", (PyCFunction)Sbk_QRegExpFunc_cap, METH_VARARGS|METH_KEYWORDS},
    {"captureCount", (PyCFunction)Sbk_QRegExpFunc_captureCount, METH_NOARGS},
    {"capturedTexts", (PyCFunction)Sbk_QRegExpFunc_capturedTexts, METH_NOARGS},
    {"caseSensitivity", (PyCFunction)Sbk_QRegExpFunc_caseSensitivity, METH_NOARGS},
    {"errorString", (PyCFunction)Sbk_QRegExpFunc_errorString, METH_NOARGS},
    {"escape", (PyCFunction)Sbk_QRegExpFunc_escape, METH_O|METH_STATIC},
    {"exactMatch", (PyCFunction)Sbk_QRegExpFunc_exactMatch, METH_O},
    {"indexIn", (PyCFunction)Sbk_QRegExpFunc_indexIn, METH_VARARGS|METH_KEYWORDS},
    {"isEmpty", (PyCFunction)Sbk_QRegExpFunc_isEmpty, METH_NOARGS},
    {"isMinimal", (PyCFunction)Sbk_QRegExpFunc_isMinimal, METH_NOARGS},
    {"isValid", (PyCFunction)Sbk_QRegExpFunc_isValid, METH_NOARGS},
    {"lastIndexIn", (PyCFunction)Sbk_QRegExpFunc_lastIndexIn, METH_VARARGS|METH_KEYWORDS},
    {"matchedLength", (PyCFunction)Sbk_QRegExpFunc_matchedLength, METH_NOARGS},
    {"numCaptures", (PyCFunction)Sbk_QRegExpFunc_numCaptures, METH_NOARGS},
    {"pattern", (PyCFunction)Sbk_QRegExpFunc_pattern, METH_NOARGS},
    {"patternSyntax", (PyCFunction)Sbk_QRegExpFunc_patternSyntax, METH_NOARGS},
    {"pos", (PyCFunction)Sbk_QRegExpFunc_pos, METH_VARARGS|METH_KEYWORDS},
    {"replace", (PyCFunction)Sbk_QRegExpFunc_replace, METH_VARARGS},
    {"setCaseSensitivity", (PyCFunction)Sbk_QRegExpFunc_setCaseSensitivity, METH_O},
    {"setMinimal", (PyCFunction)Sbk_QRegExpFunc_setMinimal, METH_O},
    {"setPattern", (PyCFunction)Sbk_QRegExpFunc_setPattern, METH_O},
    {"setPatternSyntax", (PyCFunction)Sbk_QRegExpFunc_setPatternSyntax, METH_O},

    {"__copy__", (PyCFunction)Sbk_QRegExp___copy__, METH_NOARGS},
    {0} // Sentinel
};

// Rich comparison
static PyObject* Sbk_QRegExp_richcompare(PyObject* self, PyObject* arg, int op)
{
    PyObject* pyResult = 0;
    QRegExp& cppSelf = *Shiboken::Converter< QRegExp* >::toCpp(self);

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter< ::QRegExp >::isConvertible(arg)) {
                // operator!=(const QRegExp & rx) const
                QRegExp cppArg0 = Shiboken::Converter< ::QRegExp >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf != cppArg0);
            } else goto Sbk_QRegExp_RichComparison_TypeError;

            break;
        case Py_EQ:
            if (Shiboken::Converter< ::QRegExp >::isConvertible(arg)) {
                // operator==(const QRegExp & rx) const
                QRegExp cppArg0 = Shiboken::Converter< ::QRegExp >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf == cppArg0);
            } else goto Sbk_QRegExp_RichComparison_TypeError;

            break;
        default:
            goto Sbk_QRegExp_RichComparison_TypeError;
    }

    if (pyResult && !PyErr_Occurred())
        return pyResult;
    Sbk_QRegExp_RichComparison_TypeError:
    PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
    return 0;

}

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QRegExp_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtCore.QRegExp",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      Sbk_QRegExp_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QRegExp_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QRegExp_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QRegExp(PyObject* module)
{
    SbkPySide_QtCoreTypes[SBK_QREGEXP_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QRegExp_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QRegExp_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QRegExp_Type, &Shiboken::callCppDestructor<QRegExp >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QRegExp_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QRegExp_Type, "QRegExp");
    PyModule_AddObject(module, "QRegExp",
        ((PyObject*)&Sbk_QRegExp_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: PatternSyntax
    PyTypeObject* SbkPySide_QtCore_QRegExp_PatternSyntax = Shiboken::Enum::newType("PatternSyntax");
    SbkPySide_QtCoreTypes[SBK_QREGEXP_PATTERNSYNTAX_IDX] = SbkPySide_QtCore_QRegExp_PatternSyntax;
    if (PyType_Ready(SbkPySide_QtCore_QRegExp_PatternSyntax) < 0)
        return;
    PyDict_SetItemString(Sbk_QRegExp_Type.super.ht_type.tp_dict,
            "PatternSyntax",((PyObject*)SbkPySide_QtCore_QRegExp_PatternSyntax));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QRegExp_PatternSyntax,(long) QRegExp::RegExp, "RegExp");
    PyDict_SetItemString(Sbk_QRegExp_Type.super.ht_type.tp_dict,"RegExp", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QRegExp_PatternSyntax->tp_dict,"RegExp", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QRegExp_PatternSyntax,(long) QRegExp::Wildcard, "Wildcard");
    PyDict_SetItemString(Sbk_QRegExp_Type.super.ht_type.tp_dict,"Wildcard", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QRegExp_PatternSyntax->tp_dict,"Wildcard", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QRegExp_PatternSyntax,(long) QRegExp::FixedString, "FixedString");
    PyDict_SetItemString(Sbk_QRegExp_Type.super.ht_type.tp_dict,"FixedString", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QRegExp_PatternSyntax->tp_dict,"FixedString", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QRegExp_PatternSyntax,(long) QRegExp::RegExp2, "RegExp2");
    PyDict_SetItemString(Sbk_QRegExp_Type.super.ht_type.tp_dict,"RegExp2", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QRegExp_PatternSyntax->tp_dict,"RegExp2", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QRegExp_PatternSyntax,(long) QRegExp::WildcardUnix, "WildcardUnix");
    PyDict_SetItemString(Sbk_QRegExp_Type.super.ht_type.tp_dict,"WildcardUnix", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QRegExp_PatternSyntax->tp_dict,"WildcardUnix", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QRegExp_PatternSyntax,(long) QRegExp::W3CXmlSchema11, "W3CXmlSchema11");
    PyDict_SetItemString(Sbk_QRegExp_Type.super.ht_type.tp_dict,"W3CXmlSchema11", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QRegExp_PatternSyntax->tp_dict,"W3CXmlSchema11", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QRegExp::PatternSyntax");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::PatternSyntax");
    // end of enum PatternSyntax

    // init enum: CaretMode
    PyTypeObject* SbkPySide_QtCore_QRegExp_CaretMode = Shiboken::Enum::newType("CaretMode");
    SbkPySide_QtCoreTypes[SBK_QREGEXP_CARETMODE_IDX] = SbkPySide_QtCore_QRegExp_CaretMode;
    if (PyType_Ready(SbkPySide_QtCore_QRegExp_CaretMode) < 0)
        return;
    PyDict_SetItemString(Sbk_QRegExp_Type.super.ht_type.tp_dict,
            "CaretMode",((PyObject*)SbkPySide_QtCore_QRegExp_CaretMode));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QRegExp_CaretMode,(long) QRegExp::CaretAtZero, "CaretAtZero");
    PyDict_SetItemString(Sbk_QRegExp_Type.super.ht_type.tp_dict,"CaretAtZero", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QRegExp_CaretMode->tp_dict,"CaretAtZero", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QRegExp_CaretMode,(long) QRegExp::CaretAtOffset, "CaretAtOffset");
    PyDict_SetItemString(Sbk_QRegExp_Type.super.ht_type.tp_dict,"CaretAtOffset", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QRegExp_CaretMode->tp_dict,"CaretAtOffset", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QRegExp_CaretMode,(long) QRegExp::CaretWontMatch, "CaretWontMatch");
    PyDict_SetItemString(Sbk_QRegExp_Type.super.ht_type.tp_dict,"CaretWontMatch", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QRegExp_CaretMode->tp_dict,"CaretWontMatch", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QRegExp::CaretMode");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::CaretMode");
    // end of enum CaretMode


    Shiboken::TypeResolver::createValueTypeResolver<QRegExp >("QRegExp");
    Shiboken::TypeResolver::createObjectTypeResolver<QRegExp >("QRegExp*");
    Shiboken::TypeResolver::createValueTypeResolver<QRegExp >(typeid(QRegExp).name());
    PySide::initQtMetaType<QRegExp >();
}

