/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtcore_python.h"

#include "qsemaphore_wrapper.h"

// Extra includes
#include <qsemaphore.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QSemaphore_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QSemaphore >()))
        return -1;

    QSemaphore* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);

    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QSemaphore(): too many arguments");
        return -1;
    }

    if (!PyArg_ParseTuple(args, "|O:QSemaphore", &(pyargs[0])))
        return -1;

    // Overloaded function decisor
    // 0: QSemaphore(int)
    if (numArgs == 0) {
        overloadId = 0; // QSemaphore(int)
    } else if (SbkNumber_Check(pyargs[0])) {
        overloadId = 0; // QSemaphore(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSemaphore_Init_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "n");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "n";
                    else if (SbkNumber_Check(value))
                        pyargs[0] = value;
else
                        goto Sbk_QSemaphore_Init_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QSemaphore(): got multiple values for keyword argument '%s'", errorArgName);
                    return -1;
                }
            }
            int cppArg0 = pyargs[0] ? Shiboken::Converter<int >::toCpp(pyargs[0]) : 0;

            if(!PyErr_Occurred()) {
                // QSemaphore(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new QSemaphore(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QSemaphore >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QSemaphore_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QSemaphore_Init_TypeError:
        const char* overloads[] = {"int = 0", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QSemaphore", overloads);
        return -1;
}

static PyObject* Sbk_QSemaphoreFunc_acquire(PyObject* self, PyObject* args, PyObject* kwds)
{
    QSemaphore* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSemaphore* >::toCpp(self);

    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QSemaphore.acquire(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:acquire", &(pyargs[0])))
        return 0;


    // Overloaded function decisor
    // 0: acquire(int)
    if (numArgs == 0) {
        overloadId = 0; // acquire(int)
    } else if (SbkNumber_Check(pyargs[0])) {
        overloadId = 0; // acquire(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSemaphoreFunc_acquire_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "n");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "n";
                    else if (SbkNumber_Check(value))
                        pyargs[0] = value;
else
                        goto Sbk_QSemaphoreFunc_acquire_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QSemaphore.acquire(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cppArg0 = pyargs[0] ? Shiboken::Converter<int >::toCpp(pyargs[0]) : 1;

            if(!PyErr_Occurred()) {
                // acquire(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->acquire(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QSemaphoreFunc_acquire_TypeError:
        const char* overloads[] = {"int = 1", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QSemaphore.acquire", overloads);
        return 0;
}

static PyObject* Sbk_QSemaphoreFunc_available(PyObject* self)
{
    QSemaphore* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSemaphore* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // available()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->available();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QSemaphoreFunc_release(PyObject* self, PyObject* args, PyObject* kwds)
{
    QSemaphore* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSemaphore* >::toCpp(self);

    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QSemaphore.release(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:release", &(pyargs[0])))
        return 0;


    // Overloaded function decisor
    // 0: release(int)
    if (numArgs == 0) {
        overloadId = 0; // release(int)
    } else if (SbkNumber_Check(pyargs[0])) {
        overloadId = 0; // release(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSemaphoreFunc_release_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "n");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "n";
                    else if (SbkNumber_Check(value))
                        pyargs[0] = value;
else
                        goto Sbk_QSemaphoreFunc_release_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QSemaphore.release(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cppArg0 = pyargs[0] ? Shiboken::Converter<int >::toCpp(pyargs[0]) : 1;

            if(!PyErr_Occurred()) {
                // release(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->release(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QSemaphoreFunc_release_TypeError:
        const char* overloads[] = {"int = 1", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QSemaphore.release", overloads);
        return 0;
}

static PyObject* Sbk_QSemaphoreFunc_tryAcquire(PyObject* self, PyObject* args, PyObject* kwds)
{
    QSemaphore* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSemaphore* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QSemaphore.tryAcquire(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:tryAcquire", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: tryAcquire(int)
    // 1: tryAcquire(int,int)
    if (numArgs == 0) {
        overloadId = 0; // tryAcquire(int)
    } else if (SbkNumber_Check(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // tryAcquire(int)
        } else if (numArgs == 2 && SbkNumber_Check(pyargs[1])) {
            overloadId = 1; // tryAcquire(int,int)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSemaphoreFunc_tryAcquire_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // tryAcquire(int)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "n");
                    if (value) {
                        if (pyargs[0])
                            errorArgName = "n";
                        else if (SbkNumber_Check(value))
                            pyargs[0] = value;
else
                            goto Sbk_QSemaphoreFunc_tryAcquire_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtCore.QSemaphore.tryAcquire(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                int cppArg0 = pyargs[0] ? Shiboken::Converter<int >::toCpp(pyargs[0]) : 1;

                if(!PyErr_Occurred()) {
                    // tryAcquire(int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    bool cppResult = cppSelf->tryAcquire(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< bool >::toPython(cppResult);
                }
                break;
            }
            case 1: // tryAcquire(int,int)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // tryAcquire(int,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    bool cppResult = cppSelf->tryAcquire(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< bool >::toPython(cppResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QSemaphoreFunc_tryAcquire_TypeError:
        const char* overloads[] = {"int = 1", "int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QSemaphore.tryAcquire", overloads);
        return 0;
}

static PyMethodDef Sbk_QSemaphore_methods[] = {
    {"acquire", (PyCFunction)Sbk_QSemaphoreFunc_acquire, METH_VARARGS|METH_KEYWORDS},
    {"available", (PyCFunction)Sbk_QSemaphoreFunc_available, METH_NOARGS},
    {"release", (PyCFunction)Sbk_QSemaphoreFunc_release, METH_VARARGS|METH_KEYWORDS},
    {"tryAcquire", (PyCFunction)Sbk_QSemaphoreFunc_tryAcquire, METH_VARARGS|METH_KEYWORDS},

    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QSemaphore_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtCore.QSemaphore",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QSemaphore_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QSemaphore_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QSemaphore(PyObject* module)
{
    SbkPySide_QtCoreTypes[SBK_QSEMAPHORE_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QSemaphore_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QSemaphore_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QSemaphore_Type, &Shiboken::callCppDestructor<QSemaphore >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QSemaphore_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QSemaphore_Type, "QSemaphore*");
    PyModule_AddObject(module, "QSemaphore",
        ((PyObject*)&Sbk_QSemaphore_Type));


    Shiboken::TypeResolver::createObjectTypeResolver<QSemaphore >("QSemaphore*");
    Shiboken::TypeResolver::createObjectTypeResolver<QSemaphore >(typeid(QSemaphore).name());
    PySide::initQtMetaType<QSemaphore* >();
}

