/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtcore_python.h"

#include "qstatemachine_wrappedevent_wrapper.h"

// Extra includes
#include <qcoreevent.h>
#include <qobject.h>


// Native ---------------------------------------------------------

WrappedEventWrapper::WrappedEventWrapper(QObject * object, QEvent * event) : QStateMachine::WrappedEvent(object, event) {
    // ... middle
}

WrappedEventWrapper::~WrappedEventWrapper()
{
    SbkObject* wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QStateMachine_WrappedEvent_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QStateMachine::WrappedEvent >()))
        return -1;

    WrappedEventWrapper* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "WrappedEvent", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return -1;

    // Overloaded function decisor
    // 0: WrappedEvent(QObject*,QEvent*)
    // 1: WrappedEvent(QStateMachine::WrappedEvent)
    if (numArgs == 1 && Shiboken::Converter< ::QStateMachine::WrappedEvent >::isConvertible(pyargs[0])) {
        overloadId = 1; // WrappedEvent(QStateMachine::WrappedEvent)
    } else if (numArgs == 2 && Shiboken::Converter< ::QObject * >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QEvent * >::isConvertible(pyargs[1])) {
        overloadId = 0; // WrappedEvent(QObject*,QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStateMachine_WrappedEvent_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // WrappedEvent(QObject*,QEvent*)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QObject * cppArg0 = Shiboken::Converter<QObject * >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return -1;
                QEvent * cppArg1 = Shiboken::Converter<QEvent * >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // WrappedEvent(QObject*,QEvent*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new WrappedEventWrapper(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // WrappedEvent(QStateMachine::WrappedEvent)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QStateMachine::WrappedEvent cppArg0 = Shiboken::Converter<QStateMachine::WrappedEvent >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // WrappedEvent(QStateMachine::WrappedEvent)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new WrappedEventWrapper(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QStateMachine::WrappedEvent >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QStateMachine_WrappedEvent_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QStateMachine_WrappedEvent_Init_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject, PySide.QtCore.QEvent", "PySide.QtCore.QStateMachine::WrappedEvent", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.WrappedEvent", overloads);
        return -1;
}

static PyObject* Sbk_QStateMachine_WrappedEventFunc_event(PyObject* self)
{
    QStateMachine::WrappedEvent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStateMachine::WrappedEvent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // event()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QEvent * cppResult = cppSelf->event();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QEvent * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QStateMachine_WrappedEventFunc_object(PyObject* self)
{
    QStateMachine::WrappedEvent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QStateMachine::WrappedEvent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // object()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QObject * cppResult = cppSelf->object();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QObject * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject *Sbk_QStateMachine_WrappedEvent___copy__(PyObject *self)
{
        QStateMachine::WrappedEvent* cppSelf = 0;
        if (!Shiboken::Object::isValid(self))
            return 0;
        cppSelf = Shiboken::Converter<QStateMachine::WrappedEvent*>::toCpp(self);
        PyObject* pyResult = 0;
        QStateMachine::WrappedEvent* copy = new QStateMachine::WrappedEvent(*cppSelf);
        pyResult = Shiboken::Converter<QStateMachine::WrappedEvent*>::toPython(copy);
        Shiboken::Object::getOwnership(pyResult);

        if (PyErr_Occurred() || !pyResult) {
            Py_XDECREF(pyResult);
            return 0;
        }
        return pyResult;
}

static PyMethodDef Sbk_QStateMachine_WrappedEvent_methods[] = {
    {"event", (PyCFunction)Sbk_QStateMachine_WrappedEventFunc_event, METH_NOARGS},
    {"object", (PyCFunction)Sbk_QStateMachine_WrappedEventFunc_object, METH_NOARGS},

    {"__copy__", (PyCFunction)Sbk_QStateMachine_WrappedEvent___copy__, METH_NOARGS},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QStateMachine_WrappedEvent_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtCore.WrappedEvent",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QStateMachine_WrappedEvent_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QStateMachine_WrappedEvent_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern

static SbkObjectType* Sbk_QStateMachine_WrappedEvent_typeDiscovery(void* cptr, SbkObjectType* instanceType)
{
    if (instanceType == reinterpret_cast<SbkObjectType*>(Shiboken::SbkType<QEvent >()) && dynamic_cast<QStateMachine::WrappedEvent*>(reinterpret_cast<QEvent*>(cptr)))
        return &Sbk_QStateMachine_WrappedEvent_Type;
    return 0;
}


void init_QStateMachine_WrappedEvent(PyObject* module)
{
    SbkPySide_QtCoreTypes[SBK_QSTATEMACHINE_WRAPPEDEVENT_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QStateMachine_WrappedEvent_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QStateMachine_WrappedEvent_Type);
    Sbk_QStateMachine_WrappedEvent_Type.super.ht_type.tp_base = SbkPySide_QtCoreTypes[SBK_QEVENT_IDX];
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QStateMachine_WrappedEvent_Type, &Shiboken::callCppDestructor<WrappedEventWrapper >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QStateMachine_WrappedEvent_Type) < 0)
        return;

    // Fill type discovery information
    Shiboken::ObjectType::setTypeDiscoveryFunction(&Sbk_QStateMachine_WrappedEvent_Type, &Sbk_QStateMachine_WrappedEvent_typeDiscovery);
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkObjectType*>(SbkPySide_QtCoreTypes[SBK_QEVENT_IDX]), &Sbk_QStateMachine_WrappedEvent_Type);

    Shiboken::ObjectType::setOriginalName(&Sbk_QStateMachine_WrappedEvent_Type, "QStateMachine::WrappedEvent");
    PyDict_SetItemString(module,"WrappedEvent", (PyObject*)&Sbk_QStateMachine_WrappedEvent_Type);

    Shiboken::TypeResolver::createValueTypeResolver<QStateMachine::WrappedEvent >("QStateMachine::WrappedEvent");
    Shiboken::TypeResolver::createObjectTypeResolver<QStateMachine::WrappedEvent >("QStateMachine::WrappedEvent*");
    Shiboken::TypeResolver::createValueTypeResolver<QStateMachine::WrappedEvent >(typeid(QStateMachine::WrappedEvent).name());
    Shiboken::TypeResolver::createValueTypeResolver<QStateMachine::WrappedEvent >(typeid(WrappedEventWrapper).name());
    PySide::initQtMetaType<QStateMachine::WrappedEvent >();
}

