/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtcore_python.h"

#include "qsysinfo_wrapper.h"

// Extra includes



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QSysInfo_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QSysInfo >()))
        return -1;

    QSysInfo* cptr = 0;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // QSysInfo()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new QSysInfo();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QSysInfo >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyMethodDef Sbk_QSysInfo_methods[] = {

    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QSysInfo_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtCore.QSysInfo",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QSysInfo_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QSysInfo_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QSysInfo(PyObject* module)
{
    SbkPySide_QtCoreTypes[SBK_QSYSINFO_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QSysInfo_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QSysInfo_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QSysInfo_Type, &Shiboken::callCppDestructor<QSysInfo >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QSysInfo_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QSysInfo_Type, "QSysInfo*");
    PyModule_AddObject(module, "QSysInfo",
        ((PyObject*)&Sbk_QSysInfo_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: Sizes
    PyTypeObject* SbkPySide_QtCore_QSysInfo_Sizes = Shiboken::Enum::newType("Sizes");
    SbkPySide_QtCoreTypes[SBK_QSYSINFO_SIZES_IDX] = SbkPySide_QtCore_QSysInfo_Sizes;
    if (PyType_Ready(SbkPySide_QtCore_QSysInfo_Sizes) < 0)
        return;
    PyDict_SetItemString(Sbk_QSysInfo_Type.super.ht_type.tp_dict,
            "Sizes",((PyObject*)SbkPySide_QtCore_QSysInfo_Sizes));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QSysInfo_Sizes,(long) QSysInfo::WordSize, "WordSize");
    PyDict_SetItemString(Sbk_QSysInfo_Type.super.ht_type.tp_dict,"WordSize", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QSysInfo_Sizes->tp_dict,"WordSize", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QSysInfo::Sizes");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::Sizes");
    // end of enum Sizes


    Shiboken::TypeResolver::createObjectTypeResolver<QSysInfo >("QSysInfo*");
    Shiboken::TypeResolver::createObjectTypeResolver<QSysInfo >(typeid(QSysInfo).name());
    PySide::initQtMetaType<QSysInfo* >();
}

