/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtcore_python.h"

#include "qsystemlocale_wrapper.h"

// Extra includes
#include <qlocale.h>


// Native ---------------------------------------------------------

QSystemLocaleWrapper::QSystemLocaleWrapper() : QSystemLocale() {
    // ... middle
}

QLocale QSystemLocaleWrapper::fallbackLocale() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "fallbackLocale"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QSystemLocale::fallbackLocale();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QLocale();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QLocale >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QSystemLocale.fallbackLocale", Shiboken::SbkType<QLocale >()->tp_name, pyResult->ob_type->tp_name);
        return QLocale();
    }
    QLocale cppResult(Shiboken::Converter< ::QLocale >::toCpp(pyResult));
    return cppResult;
}

QVariant QSystemLocaleWrapper::query(QSystemLocale::QueryType type, QVariant in) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "query"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QSystemLocale::query(type, in);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QSystemLocale::QueryType >::toPython(type),
        Shiboken::Converter< QVariant >::toPython(in)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QVariant(0);
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< QVariant >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QSystemLocale.query", "QVariant", pyResult->ob_type->tp_name);
        return QVariant(0);
    }
    QVariant cppResult(Shiboken::Converter< QVariant >::toCpp(pyResult));
    return cppResult;
}

QSystemLocaleWrapper::~QSystemLocaleWrapper()
{
    SbkObject* wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QSystemLocale_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QSystemLocale >()))
        return -1;

    QSystemLocaleWrapper* cptr = 0;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // QSystemLocale()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new QSystemLocaleWrapper();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QSystemLocale >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject* Sbk_QSystemLocaleFunc_fallbackLocale(PyObject* self)
{
    QSystemLocale* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSystemLocale* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // fallbackLocale()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QLocale cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QSystemLocale::fallbackLocale():cppSelf->fallbackLocale());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QLocale >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QSystemLocaleFunc_query(PyObject* self, PyObject* args)
{
    QSystemLocale* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSystemLocale* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "query", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: query(QSystemLocale::QueryType,QVariant)const
    if (numArgs == 2 && Shiboken::Converter< ::QSystemLocale::QueryType >::isConvertible(pyargs[0]) && Shiboken::Converter< QVariant >::isConvertible(pyargs[1])) {
        overloadId = 0; // query(QSystemLocale::QueryType,QVariant)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSystemLocaleFunc_query_TypeError;

    // Call function/method
    {
        {
            QSystemLocale::QueryType cppArg0 = Shiboken::Converter<QSystemLocale::QueryType >::toCpp(pyargs[0]);
            QVariant cppArg1 = Shiboken::Converter<QVariant >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // query(QSystemLocale::QueryType,QVariant)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QVariant cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QSystemLocale::query(cppArg0, cppArg1):cppSelf->query(cppArg0, cppArg1));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QVariant >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QSystemLocaleFunc_query_TypeError:
        const char* overloads[] = {"PySide.QtCore.QSystemLocale.QueryType, QVariant", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QSystemLocale.query", overloads);
        return 0;
}

static PyMethodDef Sbk_QSystemLocale_methods[] = {
    {"fallbackLocale", (PyCFunction)Sbk_QSystemLocaleFunc_fallbackLocale, METH_NOARGS},
    {"query", (PyCFunction)Sbk_QSystemLocaleFunc_query, METH_VARARGS},

    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QSystemLocale_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtCore.QSystemLocale",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QSystemLocale_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QSystemLocale_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QSystemLocale(PyObject* module)
{
    SbkPySide_QtCoreTypes[SBK_QSYSTEMLOCALE_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QSystemLocale_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QSystemLocale_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QSystemLocale_Type, &Shiboken::callCppDestructor<QSystemLocale >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QSystemLocale_Type) < 0)
        return;

    // Fill type discovery information

    Shiboken::ObjectType::setOriginalName(&Sbk_QSystemLocale_Type, "QSystemLocale*");
    PyModule_AddObject(module, "QSystemLocale",
        ((PyObject*)&Sbk_QSystemLocale_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: QueryType
    PyTypeObject* SbkPySide_QtCore_QSystemLocale_QueryType = Shiboken::Enum::newType("QueryType");
    SbkPySide_QtCoreTypes[SBK_QSYSTEMLOCALE_QUERYTYPE_IDX] = SbkPySide_QtCore_QSystemLocale_QueryType;
    if (PyType_Ready(SbkPySide_QtCore_QSystemLocale_QueryType) < 0)
        return;
    PyDict_SetItemString(Sbk_QSystemLocale_Type.super.ht_type.tp_dict,
            "QueryType",((PyObject*)SbkPySide_QtCore_QSystemLocale_QueryType));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QSystemLocale_QueryType,(long) QSystemLocale::LanguageId, "LanguageId");
    PyDict_SetItemString(Sbk_QSystemLocale_Type.super.ht_type.tp_dict,"LanguageId", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QSystemLocale_QueryType->tp_dict,"LanguageId", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QSystemLocale_QueryType,(long) QSystemLocale::CountryId, "CountryId");
    PyDict_SetItemString(Sbk_QSystemLocale_Type.super.ht_type.tp_dict,"CountryId", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QSystemLocale_QueryType->tp_dict,"CountryId", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QSystemLocale_QueryType,(long) QSystemLocale::DecimalPoint, "DecimalPoint");
    PyDict_SetItemString(Sbk_QSystemLocale_Type.super.ht_type.tp_dict,"DecimalPoint", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QSystemLocale_QueryType->tp_dict,"DecimalPoint", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QSystemLocale_QueryType,(long) QSystemLocale::GroupSeparator, "GroupSeparator");
    PyDict_SetItemString(Sbk_QSystemLocale_Type.super.ht_type.tp_dict,"GroupSeparator", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QSystemLocale_QueryType->tp_dict,"GroupSeparator", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QSystemLocale_QueryType,(long) QSystemLocale::ZeroDigit, "ZeroDigit");
    PyDict_SetItemString(Sbk_QSystemLocale_Type.super.ht_type.tp_dict,"ZeroDigit", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QSystemLocale_QueryType->tp_dict,"ZeroDigit", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QSystemLocale_QueryType,(long) QSystemLocale::NegativeSign, "NegativeSign");
    PyDict_SetItemString(Sbk_QSystemLocale_Type.super.ht_type.tp_dict,"NegativeSign", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QSystemLocale_QueryType->tp_dict,"NegativeSign", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QSystemLocale_QueryType,(long) QSystemLocale::DateFormatLong, "DateFormatLong");
    PyDict_SetItemString(Sbk_QSystemLocale_Type.super.ht_type.tp_dict,"DateFormatLong", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QSystemLocale_QueryType->tp_dict,"DateFormatLong", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QSystemLocale_QueryType,(long) QSystemLocale::DateFormatShort, "DateFormatShort");
    PyDict_SetItemString(Sbk_QSystemLocale_Type.super.ht_type.tp_dict,"DateFormatShort", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QSystemLocale_QueryType->tp_dict,"DateFormatShort", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QSystemLocale_QueryType,(long) QSystemLocale::TimeFormatLong, "TimeFormatLong");
    PyDict_SetItemString(Sbk_QSystemLocale_Type.super.ht_type.tp_dict,"TimeFormatLong", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QSystemLocale_QueryType->tp_dict,"TimeFormatLong", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QSystemLocale_QueryType,(long) QSystemLocale::TimeFormatShort, "TimeFormatShort");
    PyDict_SetItemString(Sbk_QSystemLocale_Type.super.ht_type.tp_dict,"TimeFormatShort", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QSystemLocale_QueryType->tp_dict,"TimeFormatShort", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QSystemLocale_QueryType,(long) QSystemLocale::DayNameLong, "DayNameLong");
    PyDict_SetItemString(Sbk_QSystemLocale_Type.super.ht_type.tp_dict,"DayNameLong", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QSystemLocale_QueryType->tp_dict,"DayNameLong", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QSystemLocale_QueryType,(long) QSystemLocale::DayNameShort, "DayNameShort");
    PyDict_SetItemString(Sbk_QSystemLocale_Type.super.ht_type.tp_dict,"DayNameShort", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QSystemLocale_QueryType->tp_dict,"DayNameShort", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QSystemLocale_QueryType,(long) QSystemLocale::MonthNameLong, "MonthNameLong");
    PyDict_SetItemString(Sbk_QSystemLocale_Type.super.ht_type.tp_dict,"MonthNameLong", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QSystemLocale_QueryType->tp_dict,"MonthNameLong", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QSystemLocale_QueryType,(long) QSystemLocale::MonthNameShort, "MonthNameShort");
    PyDict_SetItemString(Sbk_QSystemLocale_Type.super.ht_type.tp_dict,"MonthNameShort", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QSystemLocale_QueryType->tp_dict,"MonthNameShort", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QSystemLocale_QueryType,(long) QSystemLocale::DateToStringLong, "DateToStringLong");
    PyDict_SetItemString(Sbk_QSystemLocale_Type.super.ht_type.tp_dict,"DateToStringLong", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QSystemLocale_QueryType->tp_dict,"DateToStringLong", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QSystemLocale_QueryType,(long) QSystemLocale::DateToStringShort, "DateToStringShort");
    PyDict_SetItemString(Sbk_QSystemLocale_Type.super.ht_type.tp_dict,"DateToStringShort", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QSystemLocale_QueryType->tp_dict,"DateToStringShort", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QSystemLocale_QueryType,(long) QSystemLocale::TimeToStringLong, "TimeToStringLong");
    PyDict_SetItemString(Sbk_QSystemLocale_Type.super.ht_type.tp_dict,"TimeToStringLong", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QSystemLocale_QueryType->tp_dict,"TimeToStringLong", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QSystemLocale_QueryType,(long) QSystemLocale::TimeToStringShort, "TimeToStringShort");
    PyDict_SetItemString(Sbk_QSystemLocale_Type.super.ht_type.tp_dict,"TimeToStringShort", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QSystemLocale_QueryType->tp_dict,"TimeToStringShort", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QSystemLocale_QueryType,(long) QSystemLocale::DateTimeFormatLong, "DateTimeFormatLong");
    PyDict_SetItemString(Sbk_QSystemLocale_Type.super.ht_type.tp_dict,"DateTimeFormatLong", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QSystemLocale_QueryType->tp_dict,"DateTimeFormatLong", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QSystemLocale_QueryType,(long) QSystemLocale::DateTimeFormatShort, "DateTimeFormatShort");
    PyDict_SetItemString(Sbk_QSystemLocale_Type.super.ht_type.tp_dict,"DateTimeFormatShort", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QSystemLocale_QueryType->tp_dict,"DateTimeFormatShort", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QSystemLocale_QueryType,(long) QSystemLocale::DateTimeToStringLong, "DateTimeToStringLong");
    PyDict_SetItemString(Sbk_QSystemLocale_Type.super.ht_type.tp_dict,"DateTimeToStringLong", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QSystemLocale_QueryType->tp_dict,"DateTimeToStringLong", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QSystemLocale_QueryType,(long) QSystemLocale::DateTimeToStringShort, "DateTimeToStringShort");
    PyDict_SetItemString(Sbk_QSystemLocale_Type.super.ht_type.tp_dict,"DateTimeToStringShort", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QSystemLocale_QueryType->tp_dict,"DateTimeToStringShort", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QSystemLocale_QueryType,(long) QSystemLocale::MeasurementSystem, "MeasurementSystem");
    PyDict_SetItemString(Sbk_QSystemLocale_Type.super.ht_type.tp_dict,"MeasurementSystem", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QSystemLocale_QueryType->tp_dict,"MeasurementSystem", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QSystemLocale_QueryType,(long) QSystemLocale::PositiveSign, "PositiveSign");
    PyDict_SetItemString(Sbk_QSystemLocale_Type.super.ht_type.tp_dict,"PositiveSign", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QSystemLocale_QueryType->tp_dict,"PositiveSign", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QSystemLocale_QueryType,(long) QSystemLocale::AMText, "AMText");
    PyDict_SetItemString(Sbk_QSystemLocale_Type.super.ht_type.tp_dict,"AMText", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QSystemLocale_QueryType->tp_dict,"AMText", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QSystemLocale_QueryType,(long) QSystemLocale::PMText, "PMText");
    PyDict_SetItemString(Sbk_QSystemLocale_Type.super.ht_type.tp_dict,"PMText", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QSystemLocale_QueryType->tp_dict,"PMText", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QSystemLocale::QueryType");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::QueryType");
    // end of enum QueryType


    Shiboken::TypeResolver::createObjectTypeResolver<QSystemLocale >("QSystemLocale*");
    Shiboken::TypeResolver::createObjectTypeResolver<QSystemLocale >(typeid(QSystemLocale).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QSystemLocale >(typeid(QSystemLocaleWrapper).name());
    PySide::initQtMetaType<QSystemLocale* >();
}

