/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtcore_python.h"

#include "qtextstreammanipulator_wrapper.h"

// Extra includes
#include <qtextstream.h>



// Target ---------------------------------------------------------

extern "C" {
static PyObject* Sbk_QTextStreamManipulatorFunc_exec_(PyObject* self, PyObject* arg)
{
    QTextStreamManipulator* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextStreamManipulator* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: exec(QTextStream&)
    if (Shiboken::Converter< ::QTextStream & >::isConvertible(arg)) {
        overloadId = 0; // exec(QTextStream&)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextStreamManipulatorFunc_exec__TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QTextStream & cppArg0 = Shiboken::Converter<QTextStream & >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // exec(QTextStream&)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->exec(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextStreamManipulatorFunc_exec__TypeError:
        const char* overloads[] = {"PySide.QtCore.QTextStream", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QTextStreamManipulator.exec_", overloads);
        return 0;
}

static PyObject *Sbk_QTextStreamManipulator___copy__(PyObject *self)
{
        QTextStreamManipulator* cppSelf = 0;
        if (!Shiboken::Object::isValid(self))
            return 0;
        cppSelf = Shiboken::Converter<QTextStreamManipulator*>::toCpp(self);
        PyObject* pyResult = 0;
        QTextStreamManipulator* copy = new QTextStreamManipulator(*cppSelf);
        pyResult = Shiboken::Converter<QTextStreamManipulator*>::toPython(copy);
        Shiboken::Object::getOwnership(pyResult);

        if (PyErr_Occurred() || !pyResult) {
            Py_XDECREF(pyResult);
            return 0;
        }
        return pyResult;
}

static PyMethodDef Sbk_QTextStreamManipulator_methods[] = {
    {"exec_", (PyCFunction)Sbk_QTextStreamManipulatorFunc_exec_, METH_O},

    {"__copy__", (PyCFunction)Sbk_QTextStreamManipulator___copy__, METH_NOARGS},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QTextStreamManipulator_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtCore.QTextStreamManipulator",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QTextStreamManipulator_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              0,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QTextStreamManipulator(PyObject* module)
{
    SbkPySide_QtCoreTypes[SBK_QTEXTSTREAMMANIPULATOR_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QTextStreamManipulator_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QTextStreamManipulator_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QTextStreamManipulator_Type, &Shiboken::callCppDestructor<QTextStreamManipulator >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QTextStreamManipulator_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QTextStreamManipulator_Type, "QTextStreamManipulator");
    PyModule_AddObject(module, "QTextStreamManipulator",
        ((PyObject*)&Sbk_QTextStreamManipulator_Type));


    Shiboken::TypeResolver::createValueTypeResolver<QTextStreamManipulator >("QTextStreamManipulator");
    Shiboken::TypeResolver::createObjectTypeResolver<QTextStreamManipulator >("QTextStreamManipulator*");
    Shiboken::TypeResolver::createValueTypeResolver<QTextStreamManipulator >(typeid(QTextStreamManipulator).name());
    PySide::initQtMetaType<QTextStreamManipulator >();
}

