/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include "pyside_qtcore_python.h"

#include "qthread_wrapper.h"

// Extra includes
#include <QList>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qthread.h>


// Native ---------------------------------------------------------

QThreadWrapper::QThreadWrapper(QObject * parent) : QThread(parent) {
    // ... middle
}

void QThreadWrapper::childEvent(QChildEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "childEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::childEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QChildEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QThreadWrapper::connectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "connectNotify"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QThreadWrapper::customEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "customEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::customEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QThreadWrapper::disconnectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

bool QThreadWrapper::event(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "event"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::event(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QThread.event", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
    return cppResult;
}

bool QThreadWrapper::eventFilter(QObject * arg__1, QEvent * arg__2)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "eventFilter"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::eventFilter(arg__1, arg__2);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QObject * >::toPython(arg__1),
        Shiboken::Converter< ::QEvent * >::toPython(arg__2)
    ));
    bool invalidadeArg2 = PyTuple_GET_ITEM(pyargs, 1)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QThread.eventFilter", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    if (invalidadeArg2)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 1));
    return cppResult;
}

void QThreadWrapper::run()
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "run"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QThread::run();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QThreadWrapper::timerEvent(QTimerEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "timerEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::timerEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QTimerEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

const QMetaObject* QThreadWrapper::metaObject() const
{
    SbkObject* pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    return reinterpret_cast<QMetaObject*>(Shiboken::Object::getTypeUserData(pySelf));
}

int QThreadWrapper::qt_metacall(QMetaObject::Call call, int id, void** args)
{
    int result = QThread::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

QThreadWrapper::~QThreadWrapper()
{
    SbkObject* wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QThread_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QThread >()))
        return -1;

    QThreadWrapper* cptr = 0;
    int overloadId = -1;
    const char* argNames[] = {"parent"};
    const QMetaObject* metaObject;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_ParseTuple(args, "|O:QThread", &(pyargs[0])))
        return -1;

    // Overloaded function decisor
    // 0: QThread(QObject*)
    if (numArgs == 0) {
        overloadId = 0; // QThread(QObject*)
    } else if (Shiboken::Converter< ::QObject * >::isConvertible(pyargs[0])) {
        overloadId = 0; // QThread(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QThread_Init_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "parent");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "parent";
                    else if (Shiboken::Converter< ::QObject * >::isConvertible(value))
                        pyargs[0] = value;
else
                        goto Sbk_QThread_Init_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QThread(): got multiple values for keyword argument '%s'", errorArgName);
                    return -1;
                }
            }
            if (!Shiboken::Object::isValid(pyargs[0]))
                return -1;
            QObject * cppArg0 = pyargs[0] ? Shiboken::Converter<QObject * >::toCpp(pyargs[0]) : 0;

            if(!PyErr_Occurred()) {
                // QThread(QObject*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new QThreadWrapper(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                Shiboken::Object::setParent(pyargs[0], self);
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QThread >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QThread_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    metaObject = cptr->metaObject(); // <- init python qt properties
    if (kwds && !PySide::fillQtProperties(self, metaObject, kwds, argNames, 1))
        return -1;


    return 1;

    Sbk_QThread_Init_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QThread", overloads);
        return -1;
}

static PyObject* Sbk_QThreadFunc_currentThread(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // currentThread()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QThread * cppResult = QThread::currentThread();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QThread * >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QThreadFunc_currentThreadId(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // currentThreadId()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                Qt::HANDLE cppResult = QThread::currentThreadId();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< Qt::HANDLE >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QThreadFunc_exec_(PyObject* self)
{
    QThread* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QThread* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // exec()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->exec();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QThreadFunc_exit(PyObject* self, PyObject* args, PyObject* kwds)
{
    QThread* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QThread* >::toCpp(self);

    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QThread.exit(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:exit", &(pyargs[0])))
        return 0;


    // Overloaded function decisor
    // 0: exit(int)
    if (numArgs == 0) {
        overloadId = 0; // exit(int)
    } else if (SbkNumber_Check(pyargs[0])) {
        overloadId = 0; // exit(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QThreadFunc_exit_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "retcode");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "retcode";
                    else if (SbkNumber_Check(value))
                        pyargs[0] = value;
else
                        goto Sbk_QThreadFunc_exit_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QThread.exit(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cppArg0 = pyargs[0] ? Shiboken::Converter<int >::toCpp(pyargs[0]) : 0;

            if(!PyErr_Occurred()) {
                // exit(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->exit(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QThreadFunc_exit_TypeError:
        const char* overloads[] = {"int = 0", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QThread.exit", overloads);
        return 0;
}

static PyObject* Sbk_QThreadFunc_idealThreadCount(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // idealThreadCount()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = QThread::idealThreadCount();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QThreadFunc_isFinished(PyObject* self)
{
    QThread* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QThread* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isFinished()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->isFinished();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QThreadFunc_isRunning(PyObject* self)
{
    QThread* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QThread* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isRunning()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->isRunning();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QThreadFunc_msleep(PyObject* self, PyObject* arg)
{
    int overloadId = -1;

    // Overloaded function decisor
    // 0: msleep(ulong)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // msleep(ulong)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QThreadFunc_msleep_TypeError;

    // Call function/method
    {
        {
            unsigned long cppArg0 = Shiboken::Converter<unsigned long >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // msleep(ulong)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QThread::msleep(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QThreadFunc_msleep_TypeError:
        const char* overloads[] = {"unsigned long", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QThread.msleep", overloads);
        return 0;
}

static PyObject* Sbk_QThreadFunc_priority(PyObject* self)
{
    QThread* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QThread* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // priority()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QThread::Priority cppResult = cppSelf->priority();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QThread::Priority >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QThreadFunc_quit(PyObject* self)
{
    QThread* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QThread* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // quit()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->quit();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QThreadFunc_run(PyObject* self)
{
    QThread* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QThread* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // run()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QThread::run():cppSelf->run());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QThreadFunc_setPriority(PyObject* self, PyObject* arg)
{
    QThread* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QThread* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setPriority(QThread::Priority)
    if (Shiboken::Converter< ::QThread::Priority >::isConvertible(arg)) {
        overloadId = 0; // setPriority(QThread::Priority)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QThreadFunc_setPriority_TypeError;

    // Call function/method
    {
        {
            QThread::Priority cppArg0 = Shiboken::Converter<QThread::Priority >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setPriority(QThread::Priority)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setPriority(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QThreadFunc_setPriority_TypeError:
        const char* overloads[] = {"PySide.QtCore.QThread.Priority", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QThread.setPriority", overloads);
        return 0;
}

static PyObject* Sbk_QThreadFunc_setStackSize(PyObject* self, PyObject* arg)
{
    QThread* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QThread* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setStackSize(uint)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setStackSize(uint)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QThreadFunc_setStackSize_TypeError;

    // Call function/method
    {
        {
            uint cppArg0 = Shiboken::Converter<uint >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setStackSize(uint)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setStackSize(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QThreadFunc_setStackSize_TypeError:
        const char* overloads[] = {"unsigned int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QThread.setStackSize", overloads);
        return 0;
}

static PyObject* Sbk_QThreadFunc_setTerminationEnabled(PyObject* self, PyObject* args, PyObject* kwds)
{
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QThread.setTerminationEnabled(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:setTerminationEnabled", &(pyargs[0])))
        return 0;


    // Overloaded function decisor
    // 0: setTerminationEnabled(bool)
    if (numArgs == 0) {
        overloadId = 0; // setTerminationEnabled(bool)
    } else if (SbkNumber_Check(pyargs[0])) {
        overloadId = 0; // setTerminationEnabled(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QThreadFunc_setTerminationEnabled_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "enabled");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "enabled";
                    else if (SbkNumber_Check(value))
                        pyargs[0] = value;
else
                        goto Sbk_QThreadFunc_setTerminationEnabled_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QThread.setTerminationEnabled(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            bool cppArg0 = pyargs[0] ? Shiboken::Converter<bool >::toCpp(pyargs[0]) : true;

            if(!PyErr_Occurred()) {
                // setTerminationEnabled(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QThread::setTerminationEnabled(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QThreadFunc_setTerminationEnabled_TypeError:
        const char* overloads[] = {"bool = true", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QThread.setTerminationEnabled", overloads);
        return 0;
}

static PyObject* Sbk_QThreadFunc_sleep(PyObject* self, PyObject* arg)
{
    int overloadId = -1;

    // Overloaded function decisor
    // 0: sleep(ulong)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // sleep(ulong)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QThreadFunc_sleep_TypeError;

    // Call function/method
    {
        {
            unsigned long cppArg0 = Shiboken::Converter<unsigned long >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // sleep(ulong)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QThread::sleep(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QThreadFunc_sleep_TypeError:
        const char* overloads[] = {"unsigned long", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QThread.sleep", overloads);
        return 0;
}

static PyObject* Sbk_QThreadFunc_stackSize(PyObject* self)
{
    QThread* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QThread* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // stackSize()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                uint cppResult = cppSelf->stackSize();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< unsigned int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QThreadFunc_start(PyObject* self, PyObject* args, PyObject* kwds)
{
    QThread* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QThread* >::toCpp(self);

    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QThread.start(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:start", &(pyargs[0])))
        return 0;


    // Overloaded function decisor
    // 0: start(QThread::Priority)
    if (numArgs == 0) {
        overloadId = 0; // start(QThread::Priority)
    } else if (Shiboken::Converter< ::QThread::Priority >::isConvertible(pyargs[0])) {
        overloadId = 0; // start(QThread::Priority)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QThreadFunc_start_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "priority");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "priority";
                    else if (Shiboken::Converter< ::QThread::Priority >::isConvertible(value))
                        pyargs[0] = value;
else
                        goto Sbk_QThreadFunc_start_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QThread.start(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QThread::Priority cppArg0 = pyargs[0] ? Shiboken::Converter<QThread::Priority >::toCpp(pyargs[0]) : QThread::InheritPriority;

            if(!PyErr_Occurred()) {
                // start(QThread::Priority)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->start(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QThreadFunc_start_TypeError:
        const char* overloads[] = {"PySide.QtCore.QThread.Priority = InheritPriority", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QThread.start", overloads);
        return 0;
}

static PyObject* Sbk_QThreadFunc_terminate(PyObject* self)
{
    QThread* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QThread* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // terminate()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->terminate();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QThreadFunc_usleep(PyObject* self, PyObject* arg)
{
    int overloadId = -1;

    // Overloaded function decisor
    // 0: usleep(ulong)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // usleep(ulong)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QThreadFunc_usleep_TypeError;

    // Call function/method
    {
        {
            unsigned long cppArg0 = Shiboken::Converter<unsigned long >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // usleep(ulong)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QThread::usleep(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QThreadFunc_usleep_TypeError:
        const char* overloads[] = {"unsigned long", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QThread.usleep", overloads);
        return 0;
}

static PyObject* Sbk_QThreadFunc_wait(PyObject* self, PyObject* args, PyObject* kwds)
{
    QThread* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QThread* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QThread.wait(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:wait", &(pyargs[0])))
        return 0;


    // Overloaded function decisor
    // 0: wait(ulong)
    if (numArgs == 0) {
        overloadId = 0; // wait(ulong)
    } else if (SbkNumber_Check(pyargs[0])) {
        overloadId = 0; // wait(ulong)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QThreadFunc_wait_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "time");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "time";
                    else if (SbkNumber_Check(value))
                        pyargs[0] = value;
else
                        goto Sbk_QThreadFunc_wait_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QThread.wait(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            unsigned long cppArg0 = pyargs[0] ? Shiboken::Converter<unsigned long >::toCpp(pyargs[0]) : 4294967295UL;

            if(!PyErr_Occurred()) {
                // wait(ulong)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->wait(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QThreadFunc_wait_TypeError:
        const char* overloads[] = {"unsigned long = 4294967295UL", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QThread.wait", overloads);
        return 0;
}

static PyObject* Sbk_QThreadFunc_yieldCurrentThread(PyObject* self)
{

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // yieldCurrentThread()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QThread::yieldCurrentThread();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyMethodDef Sbk_QThread_methods[] = {
    {"currentThread", (PyCFunction)Sbk_QThreadFunc_currentThread, METH_NOARGS|METH_STATIC},
    {"currentThreadId", (PyCFunction)Sbk_QThreadFunc_currentThreadId, METH_NOARGS|METH_STATIC},
    {"exec_", (PyCFunction)Sbk_QThreadFunc_exec_, METH_NOARGS},
    {"exit", (PyCFunction)Sbk_QThreadFunc_exit, METH_VARARGS|METH_KEYWORDS},
    {"idealThreadCount", (PyCFunction)Sbk_QThreadFunc_idealThreadCount, METH_NOARGS|METH_STATIC},
    {"isFinished", (PyCFunction)Sbk_QThreadFunc_isFinished, METH_NOARGS},
    {"isRunning", (PyCFunction)Sbk_QThreadFunc_isRunning, METH_NOARGS},
    {"msleep", (PyCFunction)Sbk_QThreadFunc_msleep, METH_O|METH_STATIC},
    {"priority", (PyCFunction)Sbk_QThreadFunc_priority, METH_NOARGS},
    {"quit", (PyCFunction)Sbk_QThreadFunc_quit, METH_NOARGS},
    {"run", (PyCFunction)Sbk_QThreadFunc_run, METH_NOARGS},
    {"setPriority", (PyCFunction)Sbk_QThreadFunc_setPriority, METH_O},
    {"setStackSize", (PyCFunction)Sbk_QThreadFunc_setStackSize, METH_O},
    {"setTerminationEnabled", (PyCFunction)Sbk_QThreadFunc_setTerminationEnabled, METH_VARARGS|METH_KEYWORDS|METH_STATIC},
    {"sleep", (PyCFunction)Sbk_QThreadFunc_sleep, METH_O|METH_STATIC},
    {"stackSize", (PyCFunction)Sbk_QThreadFunc_stackSize, METH_NOARGS},
    {"start", (PyCFunction)Sbk_QThreadFunc_start, METH_VARARGS|METH_KEYWORDS},
    {"terminate", (PyCFunction)Sbk_QThreadFunc_terminate, METH_NOARGS},
    {"usleep", (PyCFunction)Sbk_QThreadFunc_usleep, METH_O|METH_STATIC},
    {"wait", (PyCFunction)Sbk_QThreadFunc_wait, METH_VARARGS|METH_KEYWORDS},
    {"yieldCurrentThread", (PyCFunction)Sbk_QThreadFunc_yieldCurrentThread, METH_NOARGS|METH_STATIC},

    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QThread_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtCore.QThread",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QThread_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QThread_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern

static SbkObjectType* Sbk_QThread_typeDiscovery(void* cptr, SbkObjectType* instanceType)
{
    if (instanceType == reinterpret_cast<SbkObjectType*>(Shiboken::SbkType<QObject >()) && dynamic_cast<QThread*>(reinterpret_cast<QObject*>(cptr)))
        return &Sbk_QThread_Type;
    return 0;
}


void init_QThread(PyObject* module)
{
    SbkPySide_QtCoreTypes[SBK_QTHREAD_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QThread_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QThread_Type);
    Shiboken::ObjectType::setSubTypeInitHook(&Sbk_QThread_Type, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(&Sbk_QThread_Type, &QThread::staticMetaObject);    Sbk_QThread_Type.super.ht_type.tp_base = SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX];
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QThread_Type, &Shiboken::callCppDestructor<QThread >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QThread_Type) < 0)
        return;

    // Fill type discovery information
    Shiboken::ObjectType::setTypeDiscoveryFunction(&Sbk_QThread_Type, &Sbk_QThread_typeDiscovery);
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkObjectType*>(SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX]), &Sbk_QThread_Type);

    Shiboken::ObjectType::setOriginalName(&Sbk_QThread_Type, "QThread*");
    PyModule_AddObject(module, "QThread",
        ((PyObject*)&Sbk_QThread_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: Priority
    PyTypeObject* SbkPySide_QtCore_QThread_Priority = Shiboken::Enum::newType("Priority");
    SbkPySide_QtCoreTypes[SBK_QTHREAD_PRIORITY_IDX] = SbkPySide_QtCore_QThread_Priority;
    if (PyType_Ready(SbkPySide_QtCore_QThread_Priority) < 0)
        return;
    PyDict_SetItemString(Sbk_QThread_Type.super.ht_type.tp_dict,
            "Priority",((PyObject*)SbkPySide_QtCore_QThread_Priority));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QThread_Priority,(long) QThread::IdlePriority, "IdlePriority");
    PyDict_SetItemString(Sbk_QThread_Type.super.ht_type.tp_dict,"IdlePriority", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QThread_Priority->tp_dict,"IdlePriority", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QThread_Priority,(long) QThread::LowestPriority, "LowestPriority");
    PyDict_SetItemString(Sbk_QThread_Type.super.ht_type.tp_dict,"LowestPriority", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QThread_Priority->tp_dict,"LowestPriority", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QThread_Priority,(long) QThread::LowPriority, "LowPriority");
    PyDict_SetItemString(Sbk_QThread_Type.super.ht_type.tp_dict,"LowPriority", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QThread_Priority->tp_dict,"LowPriority", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QThread_Priority,(long) QThread::NormalPriority, "NormalPriority");
    PyDict_SetItemString(Sbk_QThread_Type.super.ht_type.tp_dict,"NormalPriority", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QThread_Priority->tp_dict,"NormalPriority", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QThread_Priority,(long) QThread::HighPriority, "HighPriority");
    PyDict_SetItemString(Sbk_QThread_Type.super.ht_type.tp_dict,"HighPriority", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QThread_Priority->tp_dict,"HighPriority", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QThread_Priority,(long) QThread::HighestPriority, "HighestPriority");
    PyDict_SetItemString(Sbk_QThread_Type.super.ht_type.tp_dict,"HighestPriority", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QThread_Priority->tp_dict,"HighestPriority", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QThread_Priority,(long) QThread::TimeCriticalPriority, "TimeCriticalPriority");
    PyDict_SetItemString(Sbk_QThread_Type.super.ht_type.tp_dict,"TimeCriticalPriority", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QThread_Priority->tp_dict,"TimeCriticalPriority", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QThread_Priority,(long) QThread::InheritPriority, "InheritPriority");
    PyDict_SetItemString(Sbk_QThread_Type.super.ht_type.tp_dict,"InheritPriority", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QThread_Priority->tp_dict,"InheritPriority", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QThread::Priority");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::Priority");
    // end of enum Priority

    // Initialize signals
    PySideSignal* signal_item;

    signal_item = PySide::Signal::newObject("terminated", "void", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QThread_Type, "terminated", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("started", "void", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QThread_Type, "started", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("finished", "void", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QThread_Type, "finished", signal_item);
    Py_DECREF((PyObject*) signal_item);


    Shiboken::TypeResolver::createObjectTypeResolver<QThread >("QThread*");
    Shiboken::TypeResolver::createObjectTypeResolver<QThread >(typeid(QThread).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QThread >(typeid(QThreadWrapper).name());
    PySide::initQtMetaType<QThread* >();
}

