/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtcore_python.h"

#include "qurl_wrapper.h"

// Extra includes
#include <QList>
#include <QPair>
#include <QStringList>
#include <qbytearray.h>
#include <qurl.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QUrl_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QUrl >()))
        return -1;

    QUrl* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QUrl", 0, 2, &(pyargs[0]), &(pyargs[1])))
        return -1;

    // Overloaded function decisor
    // 0: QUrl()
    // 1: QUrl(QString)
    // 2: QUrl(QString,QUrl::ParsingMode)
    // 3: QUrl(QUrl)
    if (numArgs == 0) {
        overloadId = 0; // QUrl()
    } else if (Shiboken::Converter< QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 1; // QUrl(QString)
        } else if (numArgs == 2 && Shiboken::Converter< ::QUrl::ParsingMode >::isConvertible(pyargs[1])) {
            overloadId = 2; // QUrl(QString,QUrl::ParsingMode)
        }
    } else if (numArgs == 1 && Shiboken::Converter< ::QUrl >::isConvertible(pyargs[0])) {
        overloadId = 3; // QUrl(QUrl)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QUrl_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QUrl()
            {

                if(!PyErr_Occurred()) {
                    // QUrl()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QUrl();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // QUrl(QString)
            {
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QUrl(QString)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QUrl(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // QUrl(QString,QUrl::ParsingMode)
            {
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                QUrl::ParsingMode cppArg1 = Shiboken::Converter<QUrl::ParsingMode >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // QUrl(QString,QUrl::ParsingMode)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QUrl(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 3: // QUrl(QUrl)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QUrl cppArg0 = Shiboken::Converter<QUrl >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QUrl(QUrl)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QUrl(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QUrl >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QUrl_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QUrl_Init_TypeError:
        const char* overloads[] = {"", "QString", "QString, PySide.QtCore.QUrl.ParsingMode", "PySide.QtCore.QUrl", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QUrl", overloads);
        return -1;
}

static PyObject* Sbk_QUrlFunc___reduce__(PyObject* self)
{
    QUrl* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUrl* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // __reduce__()
                // Begin code injection
                
                // TEMPLATE - reduce_code - START
                pyResult = Py_BuildValue("(N(s))", PyObject_Type(self), qPrintable(cppSelf->toString()));
                // TEMPLATE - reduce_code - END
                
                // End of code injection


            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QUrlFunc_addEncodedQueryItem(PyObject* self, PyObject* args)
{
    QUrl* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUrl* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "addEncodedQueryItem", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: addEncodedQueryItem(QByteArray,QByteArray)
    if (numArgs == 2 && Shiboken::Converter< ::QByteArray >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QByteArray >::isConvertible(pyargs[1])) {
        overloadId = 0; // addEncodedQueryItem(QByteArray,QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QUrlFunc_addEncodedQueryItem_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QByteArray cppArg0 = Shiboken::Converter<QByteArray >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QByteArray cppArg1 = Shiboken::Converter<QByteArray >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // addEncodedQueryItem(QByteArray,QByteArray)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->addEncodedQueryItem(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QUrlFunc_addEncodedQueryItem_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray, PySide.QtCore.QByteArray", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QUrl.addEncodedQueryItem", overloads);
        return 0;
}

static PyObject* Sbk_QUrlFunc_addQueryItem(PyObject* self, PyObject* args)
{
    QUrl* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUrl* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "addQueryItem", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: addQueryItem(QString,QString)
    if (numArgs == 2 && Shiboken::Converter< QString >::isConvertible(pyargs[0]) && Shiboken::Converter< QString >::isConvertible(pyargs[1])) {
        overloadId = 0; // addQueryItem(QString,QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QUrlFunc_addQueryItem_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QString cppArg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // addQueryItem(QString,QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->addQueryItem(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QUrlFunc_addQueryItem_TypeError:
        const char* overloads[] = {"QString, QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QUrl.addQueryItem", overloads);
        return 0;
}

static PyObject* Sbk_QUrlFunc_allEncodedQueryItemValues(PyObject* self, PyObject* arg)
{
    QUrl* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUrl* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: allEncodedQueryItemValues(QByteArray)const
    if (Shiboken::Converter< ::QByteArray >::isConvertible(arg)) {
        overloadId = 0; // allEncodedQueryItemValues(QByteArray)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QUrlFunc_allEncodedQueryItemValues_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QByteArray cppArg0 = Shiboken::Converter<QByteArray >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // allEncodedQueryItemValues(QByteArray)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QList<QByteArray > cppResult = cppSelf->allEncodedQueryItemValues(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QList<QByteArray > >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QUrlFunc_allEncodedQueryItemValues_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QUrl.allEncodedQueryItemValues", overloads);
        return 0;
}

static PyObject* Sbk_QUrlFunc_allQueryItemValues(PyObject* self, PyObject* arg)
{
    QUrl* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUrl* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: allQueryItemValues(QString)const
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // allQueryItemValues(QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QUrlFunc_allQueryItemValues_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // allQueryItemValues(QString)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QStringList cppResult = cppSelf->allQueryItemValues(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QStringList >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QUrlFunc_allQueryItemValues_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QUrl.allQueryItemValues", overloads);
        return 0;
}

static PyObject* Sbk_QUrlFunc_authority(PyObject* self)
{
    QUrl* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUrl* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // authority()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = cppSelf->authority();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QUrlFunc_clear(PyObject* self)
{
    QUrl* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUrl* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // clear()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->clear();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QUrlFunc_encodedFragment(PyObject* self)
{
    QUrl* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUrl* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // encodedFragment()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QByteArray cppResult = cppSelf->encodedFragment();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QByteArray >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QUrlFunc_encodedHost(PyObject* self)
{
    QUrl* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUrl* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // encodedHost()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QByteArray cppResult = cppSelf->encodedHost();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QByteArray >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QUrlFunc_encodedPassword(PyObject* self)
{
    QUrl* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUrl* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // encodedPassword()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QByteArray cppResult = cppSelf->encodedPassword();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QByteArray >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QUrlFunc_encodedPath(PyObject* self)
{
    QUrl* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUrl* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // encodedPath()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QByteArray cppResult = cppSelf->encodedPath();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QByteArray >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QUrlFunc_encodedQuery(PyObject* self)
{
    QUrl* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUrl* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // encodedQuery()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QByteArray cppResult = cppSelf->encodedQuery();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QByteArray >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QUrlFunc_encodedQueryItemValue(PyObject* self, PyObject* arg)
{
    QUrl* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUrl* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: encodedQueryItemValue(QByteArray)const
    if (Shiboken::Converter< ::QByteArray >::isConvertible(arg)) {
        overloadId = 0; // encodedQueryItemValue(QByteArray)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QUrlFunc_encodedQueryItemValue_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QByteArray cppArg0 = Shiboken::Converter<QByteArray >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // encodedQueryItemValue(QByteArray)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QByteArray cppResult = cppSelf->encodedQueryItemValue(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QByteArray >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QUrlFunc_encodedQueryItemValue_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QUrl.encodedQueryItemValue", overloads);
        return 0;
}

static PyObject* Sbk_QUrlFunc_encodedQueryItems(PyObject* self)
{
    QUrl* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUrl* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // encodedQueryItems()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QList<QPair<QByteArray, QByteArray > > cppResult = cppSelf->encodedQueryItems();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QList<QPair<QByteArray, QByteArray > > >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QUrlFunc_encodedUserName(PyObject* self)
{
    QUrl* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUrl* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // encodedUserName()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QByteArray cppResult = cppSelf->encodedUserName();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QByteArray >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QUrlFunc_errorString(PyObject* self)
{
    QUrl* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUrl* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // errorString()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = cppSelf->errorString();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QUrlFunc_fragment(PyObject* self)
{
    QUrl* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUrl* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // fragment()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = cppSelf->fragment();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QUrlFunc_fromAce(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: fromAce(QByteArray)
    if (Shiboken::Converter< ::QByteArray >::isConvertible(arg)) {
        overloadId = 0; // fromAce(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QUrlFunc_fromAce_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QByteArray cppArg0 = Shiboken::Converter<QByteArray >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // fromAce(QByteArray)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = QUrl::fromAce(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QUrlFunc_fromAce_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QUrl.fromAce", overloads);
        return 0;
}

static PyObject* Sbk_QUrlFunc_fromEncoded(PyObject* self, PyObject* args)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "fromEncoded", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: fromEncoded(QByteArray)
    // 1: fromEncoded(QByteArray,QUrl::ParsingMode)
    if (Shiboken::Converter< ::QByteArray >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // fromEncoded(QByteArray)
        } else if (numArgs == 2 && Shiboken::Converter< ::QUrl::ParsingMode >::isConvertible(pyargs[1])) {
            overloadId = 1; // fromEncoded(QByteArray,QUrl::ParsingMode)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QUrlFunc_fromEncoded_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // fromEncoded(QByteArray)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QByteArray cppArg0 = Shiboken::Converter<QByteArray >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // fromEncoded(QByteArray)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QUrl cppResult = QUrl::fromEncoded(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QUrl >::toPython(cppResult);
                }
                break;
            }
            case 1: // fromEncoded(QByteArray,QUrl::ParsingMode)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QByteArray cppArg0 = Shiboken::Converter<QByteArray >::toCpp(pyargs[0]);
                QUrl::ParsingMode cppArg1 = Shiboken::Converter<QUrl::ParsingMode >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // fromEncoded(QByteArray,QUrl::ParsingMode)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QUrl cppResult = QUrl::fromEncoded(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QUrl >::toPython(cppResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QUrlFunc_fromEncoded_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray", "PySide.QtCore.QByteArray, PySide.QtCore.QUrl.ParsingMode", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QUrl.fromEncoded", overloads);
        return 0;
}

static PyObject* Sbk_QUrlFunc_fromLocalFile(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: fromLocalFile(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // fromLocalFile(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QUrlFunc_fromLocalFile_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // fromLocalFile(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QUrl cppResult = QUrl::fromLocalFile(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QUrl >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QUrlFunc_fromLocalFile_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QUrl.fromLocalFile", overloads);
        return 0;
}

static PyObject* Sbk_QUrlFunc_fromPercentEncoding(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: fromPercentEncoding(QByteArray)
    if (Shiboken::Converter< ::QByteArray >::isConvertible(arg)) {
        overloadId = 0; // fromPercentEncoding(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QUrlFunc_fromPercentEncoding_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QByteArray cppArg0 = Shiboken::Converter<QByteArray >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // fromPercentEncoding(QByteArray)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = QUrl::fromPercentEncoding(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QUrlFunc_fromPercentEncoding_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QUrl.fromPercentEncoding", overloads);
        return 0;
}

static PyObject* Sbk_QUrlFunc_fromPunycode(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: fromPunycode(QByteArray)
    if (Shiboken::Converter< ::QByteArray >::isConvertible(arg)) {
        overloadId = 0; // fromPunycode(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QUrlFunc_fromPunycode_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QByteArray cppArg0 = Shiboken::Converter<QByteArray >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // fromPunycode(QByteArray)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = QUrl::fromPunycode(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QUrlFunc_fromPunycode_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QUrl.fromPunycode", overloads);
        return 0;
}

static PyObject* Sbk_QUrlFunc_fromUserInput(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: fromUserInput(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // fromUserInput(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QUrlFunc_fromUserInput_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // fromUserInput(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QUrl cppResult = QUrl::fromUserInput(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QUrl >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QUrlFunc_fromUserInput_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QUrl.fromUserInput", overloads);
        return 0;
}

static PyObject* Sbk_QUrlFunc_hasEncodedQueryItem(PyObject* self, PyObject* arg)
{
    QUrl* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUrl* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: hasEncodedQueryItem(QByteArray)const
    if (Shiboken::Converter< ::QByteArray >::isConvertible(arg)) {
        overloadId = 0; // hasEncodedQueryItem(QByteArray)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QUrlFunc_hasEncodedQueryItem_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QByteArray cppArg0 = Shiboken::Converter<QByteArray >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // hasEncodedQueryItem(QByteArray)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->hasEncodedQueryItem(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QUrlFunc_hasEncodedQueryItem_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QUrl.hasEncodedQueryItem", overloads);
        return 0;
}

static PyObject* Sbk_QUrlFunc_hasFragment(PyObject* self)
{
    QUrl* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUrl* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // hasFragment()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->hasFragment();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QUrlFunc_hasQuery(PyObject* self)
{
    QUrl* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUrl* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // hasQuery()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->hasQuery();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QUrlFunc_hasQueryItem(PyObject* self, PyObject* arg)
{
    QUrl* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUrl* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: hasQueryItem(QString)const
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // hasQueryItem(QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QUrlFunc_hasQueryItem_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // hasQueryItem(QString)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->hasQueryItem(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QUrlFunc_hasQueryItem_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QUrl.hasQueryItem", overloads);
        return 0;
}

static PyObject* Sbk_QUrlFunc_host(PyObject* self)
{
    QUrl* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUrl* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // host()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = cppSelf->host();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QUrlFunc_idnWhitelist(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // idnWhitelist()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QStringList cppResult = QUrl::idnWhitelist();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QStringList >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QUrlFunc_isEmpty(PyObject* self)
{
    QUrl* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUrl* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isEmpty()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->isEmpty();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QUrlFunc_isParentOf(PyObject* self, PyObject* arg)
{
    QUrl* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUrl* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: isParentOf(QUrl)const
    if (Shiboken::Converter< ::QUrl >::isConvertible(arg)) {
        overloadId = 0; // isParentOf(QUrl)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QUrlFunc_isParentOf_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QUrl cppArg0 = Shiboken::Converter<QUrl >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // isParentOf(QUrl)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->isParentOf(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QUrlFunc_isParentOf_TypeError:
        const char* overloads[] = {"PySide.QtCore.QUrl", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QUrl.isParentOf", overloads);
        return 0;
}

static PyObject* Sbk_QUrlFunc_isRelative(PyObject* self)
{
    QUrl* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUrl* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isRelative()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->isRelative();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QUrlFunc_isValid(PyObject* self)
{
    QUrl* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUrl* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isValid()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->isValid();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QUrlFunc_password(PyObject* self)
{
    QUrl* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUrl* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // password()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = cppSelf->password();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QUrlFunc_path(PyObject* self)
{
    QUrl* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUrl* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // path()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = cppSelf->path();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QUrlFunc_port(PyObject* self, PyObject* args)
{
    QUrl* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUrl* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "port", 0, 1, &(pyargs[0])))
        return 0;


    // Overloaded function decisor
    // 0: port()const
    // 1: port(int)const
    if (numArgs == 0) {
        overloadId = 0; // port()const
    } else if (numArgs == 1 && SbkNumber_Check(pyargs[0])) {
        overloadId = 1; // port(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QUrlFunc_port_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // port()const
            {

                if(!PyErr_Occurred()) {
                    // port()const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    int cppResult = cppSelf->port();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< int >::toPython(cppResult);
                }
                break;
            }
            case 1: // port(int)const
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // port(int)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    int cppResult = cppSelf->port(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< int >::toPython(cppResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QUrlFunc_port_TypeError:
        const char* overloads[] = {"", "int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QUrl.port", overloads);
        return 0;
}

static PyObject* Sbk_QUrlFunc_queryItemValue(PyObject* self, PyObject* arg)
{
    QUrl* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUrl* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: queryItemValue(QString)const
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // queryItemValue(QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QUrlFunc_queryItemValue_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // queryItemValue(QString)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = cppSelf->queryItemValue(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QUrlFunc_queryItemValue_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QUrl.queryItemValue", overloads);
        return 0;
}

static PyObject* Sbk_QUrlFunc_queryItems(PyObject* self)
{
    QUrl* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUrl* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // queryItems()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QList<QPair<QString, QString > > cppResult = cppSelf->queryItems();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QList<QPair<QString, QString > > >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QUrlFunc_queryPairDelimiter(PyObject* self)
{
    QUrl* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUrl* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // queryPairDelimiter()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                char cppResult = cppSelf->queryPairDelimiter();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< char >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QUrlFunc_queryValueDelimiter(PyObject* self)
{
    QUrl* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUrl* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // queryValueDelimiter()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                char cppResult = cppSelf->queryValueDelimiter();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< char >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QUrlFunc_removeAllEncodedQueryItems(PyObject* self, PyObject* arg)
{
    QUrl* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUrl* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: removeAllEncodedQueryItems(QByteArray)
    if (Shiboken::Converter< ::QByteArray >::isConvertible(arg)) {
        overloadId = 0; // removeAllEncodedQueryItems(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QUrlFunc_removeAllEncodedQueryItems_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QByteArray cppArg0 = Shiboken::Converter<QByteArray >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // removeAllEncodedQueryItems(QByteArray)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->removeAllEncodedQueryItems(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QUrlFunc_removeAllEncodedQueryItems_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QUrl.removeAllEncodedQueryItems", overloads);
        return 0;
}

static PyObject* Sbk_QUrlFunc_removeAllQueryItems(PyObject* self, PyObject* arg)
{
    QUrl* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUrl* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: removeAllQueryItems(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // removeAllQueryItems(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QUrlFunc_removeAllQueryItems_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // removeAllQueryItems(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->removeAllQueryItems(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QUrlFunc_removeAllQueryItems_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QUrl.removeAllQueryItems", overloads);
        return 0;
}

static PyObject* Sbk_QUrlFunc_removeEncodedQueryItem(PyObject* self, PyObject* arg)
{
    QUrl* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUrl* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: removeEncodedQueryItem(QByteArray)
    if (Shiboken::Converter< ::QByteArray >::isConvertible(arg)) {
        overloadId = 0; // removeEncodedQueryItem(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QUrlFunc_removeEncodedQueryItem_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QByteArray cppArg0 = Shiboken::Converter<QByteArray >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // removeEncodedQueryItem(QByteArray)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->removeEncodedQueryItem(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QUrlFunc_removeEncodedQueryItem_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QUrl.removeEncodedQueryItem", overloads);
        return 0;
}

static PyObject* Sbk_QUrlFunc_removeQueryItem(PyObject* self, PyObject* arg)
{
    QUrl* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUrl* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: removeQueryItem(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // removeQueryItem(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QUrlFunc_removeQueryItem_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // removeQueryItem(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->removeQueryItem(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QUrlFunc_removeQueryItem_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QUrl.removeQueryItem", overloads);
        return 0;
}

static PyObject* Sbk_QUrlFunc_resolved(PyObject* self, PyObject* arg)
{
    QUrl* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUrl* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: resolved(QUrl)const
    if (Shiboken::Converter< ::QUrl >::isConvertible(arg)) {
        overloadId = 0; // resolved(QUrl)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QUrlFunc_resolved_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QUrl cppArg0 = Shiboken::Converter<QUrl >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // resolved(QUrl)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QUrl cppResult = cppSelf->resolved(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QUrl >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QUrlFunc_resolved_TypeError:
        const char* overloads[] = {"PySide.QtCore.QUrl", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QUrl.resolved", overloads);
        return 0;
}

static PyObject* Sbk_QUrlFunc_scheme(PyObject* self)
{
    QUrl* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUrl* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // scheme()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = cppSelf->scheme();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QUrlFunc_setAuthority(PyObject* self, PyObject* arg)
{
    QUrl* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUrl* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setAuthority(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // setAuthority(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QUrlFunc_setAuthority_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setAuthority(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setAuthority(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QUrlFunc_setAuthority_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QUrl.setAuthority", overloads);
        return 0;
}

static PyObject* Sbk_QUrlFunc_setEncodedFragment(PyObject* self, PyObject* arg)
{
    QUrl* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUrl* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setEncodedFragment(QByteArray)
    if (Shiboken::Converter< ::QByteArray >::isConvertible(arg)) {
        overloadId = 0; // setEncodedFragment(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QUrlFunc_setEncodedFragment_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QByteArray cppArg0 = Shiboken::Converter<QByteArray >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setEncodedFragment(QByteArray)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setEncodedFragment(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QUrlFunc_setEncodedFragment_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QUrl.setEncodedFragment", overloads);
        return 0;
}

static PyObject* Sbk_QUrlFunc_setEncodedHost(PyObject* self, PyObject* arg)
{
    QUrl* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUrl* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setEncodedHost(QByteArray)
    if (Shiboken::Converter< ::QByteArray >::isConvertible(arg)) {
        overloadId = 0; // setEncodedHost(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QUrlFunc_setEncodedHost_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QByteArray cppArg0 = Shiboken::Converter<QByteArray >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setEncodedHost(QByteArray)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setEncodedHost(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QUrlFunc_setEncodedHost_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QUrl.setEncodedHost", overloads);
        return 0;
}

static PyObject* Sbk_QUrlFunc_setEncodedPassword(PyObject* self, PyObject* arg)
{
    QUrl* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUrl* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setEncodedPassword(QByteArray)
    if (Shiboken::Converter< ::QByteArray >::isConvertible(arg)) {
        overloadId = 0; // setEncodedPassword(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QUrlFunc_setEncodedPassword_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QByteArray cppArg0 = Shiboken::Converter<QByteArray >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setEncodedPassword(QByteArray)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setEncodedPassword(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QUrlFunc_setEncodedPassword_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QUrl.setEncodedPassword", overloads);
        return 0;
}

static PyObject* Sbk_QUrlFunc_setEncodedPath(PyObject* self, PyObject* arg)
{
    QUrl* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUrl* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setEncodedPath(QByteArray)
    if (Shiboken::Converter< ::QByteArray >::isConvertible(arg)) {
        overloadId = 0; // setEncodedPath(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QUrlFunc_setEncodedPath_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QByteArray cppArg0 = Shiboken::Converter<QByteArray >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setEncodedPath(QByteArray)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setEncodedPath(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QUrlFunc_setEncodedPath_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QUrl.setEncodedPath", overloads);
        return 0;
}

static PyObject* Sbk_QUrlFunc_setEncodedQuery(PyObject* self, PyObject* arg)
{
    QUrl* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUrl* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setEncodedQuery(QByteArray)
    if (Shiboken::Converter< ::QByteArray >::isConvertible(arg)) {
        overloadId = 0; // setEncodedQuery(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QUrlFunc_setEncodedQuery_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QByteArray cppArg0 = Shiboken::Converter<QByteArray >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setEncodedQuery(QByteArray)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setEncodedQuery(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QUrlFunc_setEncodedQuery_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QUrl.setEncodedQuery", overloads);
        return 0;
}

static PyObject* Sbk_QUrlFunc_setEncodedQueryItems(PyObject* self, PyObject* arg)
{
    QUrl* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUrl* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setEncodedQueryItems(QList<QPair<QByteArray,QByteArray> >)
    if (Shiboken::Converter< ::QList<QPair<QByteArray, QByteArray > > >::isConvertible(arg)) {
        overloadId = 0; // setEncodedQueryItems(QList<QPair<QByteArray,QByteArray> >)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QUrlFunc_setEncodedQueryItems_TypeError;

    // Call function/method
    {
        {
            QList<QPair<QByteArray, QByteArray > > cppArg0 = Shiboken::Converter<QList<QPair<QByteArray, QByteArray > > >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setEncodedQueryItems(QList<QPair<QByteArray,QByteArray> >)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setEncodedQueryItems(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QUrlFunc_setEncodedQueryItems_TypeError:
        const char* overloads[] = {"list", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QUrl.setEncodedQueryItems", overloads);
        return 0;
}

static PyObject* Sbk_QUrlFunc_setEncodedUrl(PyObject* self, PyObject* args)
{
    QUrl* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUrl* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setEncodedUrl", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setEncodedUrl(QByteArray)
    // 1: setEncodedUrl(QByteArray,QUrl::ParsingMode)
    if (Shiboken::Converter< ::QByteArray >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // setEncodedUrl(QByteArray)
        } else if (numArgs == 2 && Shiboken::Converter< ::QUrl::ParsingMode >::isConvertible(pyargs[1])) {
            overloadId = 1; // setEncodedUrl(QByteArray,QUrl::ParsingMode)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QUrlFunc_setEncodedUrl_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setEncodedUrl(QByteArray)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QByteArray cppArg0 = Shiboken::Converter<QByteArray >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // setEncodedUrl(QByteArray)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setEncodedUrl(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // setEncodedUrl(QByteArray,QUrl::ParsingMode)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QByteArray cppArg0 = Shiboken::Converter<QByteArray >::toCpp(pyargs[0]);
                QUrl::ParsingMode cppArg1 = Shiboken::Converter<QUrl::ParsingMode >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // setEncodedUrl(QByteArray,QUrl::ParsingMode)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setEncodedUrl(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QUrlFunc_setEncodedUrl_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray", "PySide.QtCore.QByteArray, PySide.QtCore.QUrl.ParsingMode", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QUrl.setEncodedUrl", overloads);
        return 0;
}

static PyObject* Sbk_QUrlFunc_setEncodedUserName(PyObject* self, PyObject* arg)
{
    QUrl* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUrl* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setEncodedUserName(QByteArray)
    if (Shiboken::Converter< ::QByteArray >::isConvertible(arg)) {
        overloadId = 0; // setEncodedUserName(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QUrlFunc_setEncodedUserName_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QByteArray cppArg0 = Shiboken::Converter<QByteArray >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setEncodedUserName(QByteArray)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setEncodedUserName(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QUrlFunc_setEncodedUserName_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QUrl.setEncodedUserName", overloads);
        return 0;
}

static PyObject* Sbk_QUrlFunc_setFragment(PyObject* self, PyObject* arg)
{
    QUrl* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUrl* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setFragment(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // setFragment(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QUrlFunc_setFragment_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setFragment(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setFragment(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QUrlFunc_setFragment_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QUrl.setFragment", overloads);
        return 0;
}

static PyObject* Sbk_QUrlFunc_setHost(PyObject* self, PyObject* arg)
{
    QUrl* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUrl* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setHost(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // setHost(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QUrlFunc_setHost_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setHost(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setHost(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QUrlFunc_setHost_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QUrl.setHost", overloads);
        return 0;
}

static PyObject* Sbk_QUrlFunc_setIdnWhitelist(PyObject* self, PyObject* arg)
{
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setIdnWhitelist(QStringList)
    if (Shiboken::Converter< ::QStringList >::isConvertible(arg)) {
        overloadId = 0; // setIdnWhitelist(QStringList)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QUrlFunc_setIdnWhitelist_TypeError;

    // Call function/method
    {
        {
            QStringList cppArg0 = Shiboken::Converter<QStringList >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setIdnWhitelist(QStringList)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QUrl::setIdnWhitelist(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QUrlFunc_setIdnWhitelist_TypeError:
        const char* overloads[] = {"list", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QUrl.setIdnWhitelist", overloads);
        return 0;
}

static PyObject* Sbk_QUrlFunc_setPassword(PyObject* self, PyObject* arg)
{
    QUrl* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUrl* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setPassword(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // setPassword(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QUrlFunc_setPassword_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setPassword(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setPassword(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QUrlFunc_setPassword_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QUrl.setPassword", overloads);
        return 0;
}

static PyObject* Sbk_QUrlFunc_setPath(PyObject* self, PyObject* arg)
{
    QUrl* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUrl* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setPath(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // setPath(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QUrlFunc_setPath_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setPath(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setPath(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QUrlFunc_setPath_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QUrl.setPath", overloads);
        return 0;
}

static PyObject* Sbk_QUrlFunc_setPort(PyObject* self, PyObject* arg)
{
    QUrl* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUrl* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setPort(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setPort(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QUrlFunc_setPort_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setPort(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setPort(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QUrlFunc_setPort_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QUrl.setPort", overloads);
        return 0;
}

static PyObject* Sbk_QUrlFunc_setQueryDelimiters(PyObject* self, PyObject* args)
{
    QUrl* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUrl* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setQueryDelimiters", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setQueryDelimiters(char,char)
    if (numArgs == 2 && Shiboken::Converter< char >::isConvertible(pyargs[0]) && Shiboken::Converter< char >::isConvertible(pyargs[1])) {
        overloadId = 0; // setQueryDelimiters(char,char)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QUrlFunc_setQueryDelimiters_TypeError;

    // Call function/method
    {
        {
            char cppArg0 = Shiboken::Converter<char >::toCpp(pyargs[0]);
            char cppArg1 = Shiboken::Converter<char >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // setQueryDelimiters(char,char)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setQueryDelimiters(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QUrlFunc_setQueryDelimiters_TypeError:
        const char* overloads[] = {"char, char", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QUrl.setQueryDelimiters", overloads);
        return 0;
}

static PyObject* Sbk_QUrlFunc_setQueryItems(PyObject* self, PyObject* arg)
{
    QUrl* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUrl* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setQueryItems(QList<QPair<QString,QString> >)
    if (Shiboken::Converter< ::QList<QPair<QString, QString > > >::isConvertible(arg)) {
        overloadId = 0; // setQueryItems(QList<QPair<QString,QString> >)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QUrlFunc_setQueryItems_TypeError;

    // Call function/method
    {
        {
            QList<QPair<QString, QString > > cppArg0 = Shiboken::Converter<QList<QPair<QString, QString > > >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setQueryItems(QList<QPair<QString,QString> >)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setQueryItems(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QUrlFunc_setQueryItems_TypeError:
        const char* overloads[] = {"list", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QUrl.setQueryItems", overloads);
        return 0;
}

static PyObject* Sbk_QUrlFunc_setScheme(PyObject* self, PyObject* arg)
{
    QUrl* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUrl* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setScheme(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // setScheme(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QUrlFunc_setScheme_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setScheme(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setScheme(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QUrlFunc_setScheme_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QUrl.setScheme", overloads);
        return 0;
}

static PyObject* Sbk_QUrlFunc_setUrl(PyObject* self, PyObject* args)
{
    QUrl* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUrl* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setUrl", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setUrl(QString)
    // 1: setUrl(QString,QUrl::ParsingMode)
    if (Shiboken::Converter< QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // setUrl(QString)
        } else if (numArgs == 2 && Shiboken::Converter< ::QUrl::ParsingMode >::isConvertible(pyargs[1])) {
            overloadId = 1; // setUrl(QString,QUrl::ParsingMode)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QUrlFunc_setUrl_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setUrl(QString)
            {
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // setUrl(QString)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setUrl(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // setUrl(QString,QUrl::ParsingMode)
            {
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                QUrl::ParsingMode cppArg1 = Shiboken::Converter<QUrl::ParsingMode >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // setUrl(QString,QUrl::ParsingMode)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setUrl(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QUrlFunc_setUrl_TypeError:
        const char* overloads[] = {"QString", "QString, PySide.QtCore.QUrl.ParsingMode", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QUrl.setUrl", overloads);
        return 0;
}

static PyObject* Sbk_QUrlFunc_setUserInfo(PyObject* self, PyObject* arg)
{
    QUrl* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUrl* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setUserInfo(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // setUserInfo(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QUrlFunc_setUserInfo_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setUserInfo(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setUserInfo(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QUrlFunc_setUserInfo_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QUrl.setUserInfo", overloads);
        return 0;
}

static PyObject* Sbk_QUrlFunc_setUserName(PyObject* self, PyObject* arg)
{
    QUrl* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUrl* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setUserName(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // setUserName(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QUrlFunc_setUserName_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setUserName(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setUserName(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QUrlFunc_setUserName_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QUrl.setUserName", overloads);
        return 0;
}

static PyObject* Sbk_QUrlFunc_toAce(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: toAce(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // toAce(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QUrlFunc_toAce_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // toAce(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QByteArray cppResult = QUrl::toAce(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QByteArray >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QUrlFunc_toAce_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QUrl.toAce", overloads);
        return 0;
}

static PyObject* Sbk_QUrlFunc_toEncoded(PyObject* self, PyObject* args, PyObject* kwds)
{
    QUrl* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUrl* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QUrl.toEncoded(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:toEncoded", &(pyargs[0])))
        return 0;


    // Overloaded function decisor
    // 0: toEncoded(QFlags<QUrl::FormattingOption>)const
    if (numArgs == 0) {
        overloadId = 0; // toEncoded(QFlags<QUrl::FormattingOption>)const
    } else if (Shiboken::Converter< ::QFlags<QUrl::FormattingOption> >::isConvertible(pyargs[0])) {
        overloadId = 0; // toEncoded(QFlags<QUrl::FormattingOption>)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QUrlFunc_toEncoded_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "options");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "options";
                    else if (Shiboken::Converter< ::QFlags<QUrl::FormattingOption> >::isConvertible(value))
                        pyargs[0] = value;
else
                        goto Sbk_QUrlFunc_toEncoded_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QUrl.toEncoded(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QFlags<QUrl::FormattingOption> cppArg0 = pyargs[0] ? Shiboken::Converter<QFlags<QUrl::FormattingOption> >::toCpp(pyargs[0]) : QUrl::None;

            if(!PyErr_Occurred()) {
                // toEncoded(QFlags<QUrl::FormattingOption>)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QByteArray cppResult = cppSelf->toEncoded(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QByteArray >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QUrlFunc_toEncoded_TypeError:
        const char* overloads[] = {"PySide.QtCore.QUrl.FormattingOptions = QUrl.None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QUrl.toEncoded", overloads);
        return 0;
}

static PyObject* Sbk_QUrlFunc_toLocalFile(PyObject* self)
{
    QUrl* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUrl* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // toLocalFile()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = cppSelf->toLocalFile();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QUrlFunc_toPercentEncoding(PyObject* self, PyObject* args, PyObject* kwds)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QUrl.toPercentEncoding(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QUrl.toPercentEncoding(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:toPercentEncoding", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: toPercentEncoding(QString,QByteArray,QByteArray)
    if (Shiboken::Converter< QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // toPercentEncoding(QString,QByteArray,QByteArray)
        } else if (Shiboken::Converter< ::QByteArray >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 0; // toPercentEncoding(QString,QByteArray,QByteArray)
            } else if (Shiboken::Converter< ::QByteArray >::isConvertible(pyargs[2])) {
                overloadId = 0; // toPercentEncoding(QString,QByteArray,QByteArray)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QUrlFunc_toPercentEncoding_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "exclude");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "exclude";
                    else if (Shiboken::Converter< ::QByteArray >::isConvertible(value))
                        pyargs[1] = value;
else
                        goto Sbk_QUrlFunc_toPercentEncoding_TypeError;
                }
                value = PyDict_GetItemString(kwds, "include");
                if (value) {
                    if (pyargs[2])
                        errorArgName = "include";
                    else if (Shiboken::Converter< ::QByteArray >::isConvertible(value))
                        pyargs[2] = value;
else
                        goto Sbk_QUrlFunc_toPercentEncoding_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QUrl.toPercentEncoding(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QByteArray cppArg1_tmp = QByteArray();
            QByteArray cppArg1 = pyargs[1] ? Shiboken::Converter<QByteArray >::toCpp(pyargs[1]) : cppArg1_tmp;
            if (!Shiboken::Object::isValid(pyargs[2]))
                return 0;
            QByteArray cppArg2_tmp = QByteArray();
            QByteArray cppArg2 = pyargs[2] ? Shiboken::Converter<QByteArray >::toCpp(pyargs[2]) : cppArg2_tmp;

            if(!PyErr_Occurred()) {
                // toPercentEncoding(QString,QByteArray,QByteArray)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QByteArray cppResult = QUrl::toPercentEncoding(cppArg0, cppArg1, cppArg2);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QByteArray >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QUrlFunc_toPercentEncoding_TypeError:
        const char* overloads[] = {"QString, PySide.QtCore.QByteArray = QByteArray(), PySide.QtCore.QByteArray = QByteArray()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QUrl.toPercentEncoding", overloads);
        return 0;
}

static PyObject* Sbk_QUrlFunc_toPunycode(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: toPunycode(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // toPunycode(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QUrlFunc_toPunycode_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // toPunycode(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QByteArray cppResult = QUrl::toPunycode(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QByteArray >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QUrlFunc_toPunycode_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QUrl.toPunycode", overloads);
        return 0;
}

static PyObject* Sbk_QUrlFunc_toString(PyObject* self, PyObject* args, PyObject* kwds)
{
    QUrl* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUrl* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtCore.QUrl.toString(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:toString", &(pyargs[0])))
        return 0;


    // Overloaded function decisor
    // 0: toString(QFlags<QUrl::FormattingOption>)const
    if (numArgs == 0) {
        overloadId = 0; // toString(QFlags<QUrl::FormattingOption>)const
    } else if (Shiboken::Converter< ::QFlags<QUrl::FormattingOption> >::isConvertible(pyargs[0])) {
        overloadId = 0; // toString(QFlags<QUrl::FormattingOption>)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QUrlFunc_toString_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "options");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "options";
                    else if (Shiboken::Converter< ::QFlags<QUrl::FormattingOption> >::isConvertible(value))
                        pyargs[0] = value;
else
                        goto Sbk_QUrlFunc_toString_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtCore.QUrl.toString(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QFlags<QUrl::FormattingOption> cppArg0 = pyargs[0] ? Shiboken::Converter<QFlags<QUrl::FormattingOption> >::toCpp(pyargs[0]) : QUrl::None;

            if(!PyErr_Occurred()) {
                // toString(QFlags<QUrl::FormattingOption>)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = cppSelf->toString(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QUrlFunc_toString_TypeError:
        const char* overloads[] = {"PySide.QtCore.QUrl.FormattingOptions = QUrl.None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QUrl.toString", overloads);
        return 0;
}

static PyObject* Sbk_QUrlFunc_userInfo(PyObject* self)
{
    QUrl* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUrl* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // userInfo()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = cppSelf->userInfo();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QUrlFunc_userName(PyObject* self)
{
    QUrl* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUrl* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // userName()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = cppSelf->userName();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject *Sbk_QUrl___copy__(PyObject *self)
{
        QUrl* cppSelf = 0;
        if (!Shiboken::Object::isValid(self))
            return 0;
        cppSelf = Shiboken::Converter<QUrl*>::toCpp(self);
        PyObject* pyResult = 0;
        QUrl* copy = new QUrl(*cppSelf);
        pyResult = Shiboken::Converter<QUrl*>::toPython(copy);
        Shiboken::Object::getOwnership(pyResult);

        if (PyErr_Occurred() || !pyResult) {
            Py_XDECREF(pyResult);
            return 0;
        }
        return pyResult;
}

static PyMethodDef Sbk_QUrl_methods[] = {
    {"__reduce__", (PyCFunction)Sbk_QUrlFunc___reduce__, METH_NOARGS},
    {"addEncodedQueryItem", (PyCFunction)Sbk_QUrlFunc_addEncodedQueryItem, METH_VARARGS},
    {"addQueryItem", (PyCFunction)Sbk_QUrlFunc_addQueryItem, METH_VARARGS},
    {"allEncodedQueryItemValues", (PyCFunction)Sbk_QUrlFunc_allEncodedQueryItemValues, METH_O},
    {"allQueryItemValues", (PyCFunction)Sbk_QUrlFunc_allQueryItemValues, METH_O},
    {"authority", (PyCFunction)Sbk_QUrlFunc_authority, METH_NOARGS},
    {"clear", (PyCFunction)Sbk_QUrlFunc_clear, METH_NOARGS},
    {"encodedFragment", (PyCFunction)Sbk_QUrlFunc_encodedFragment, METH_NOARGS},
    {"encodedHost", (PyCFunction)Sbk_QUrlFunc_encodedHost, METH_NOARGS},
    {"encodedPassword", (PyCFunction)Sbk_QUrlFunc_encodedPassword, METH_NOARGS},
    {"encodedPath", (PyCFunction)Sbk_QUrlFunc_encodedPath, METH_NOARGS},
    {"encodedQuery", (PyCFunction)Sbk_QUrlFunc_encodedQuery, METH_NOARGS},
    {"encodedQueryItemValue", (PyCFunction)Sbk_QUrlFunc_encodedQueryItemValue, METH_O},
    {"encodedQueryItems", (PyCFunction)Sbk_QUrlFunc_encodedQueryItems, METH_NOARGS},
    {"encodedUserName", (PyCFunction)Sbk_QUrlFunc_encodedUserName, METH_NOARGS},
    {"errorString", (PyCFunction)Sbk_QUrlFunc_errorString, METH_NOARGS},
    {"fragment", (PyCFunction)Sbk_QUrlFunc_fragment, METH_NOARGS},
    {"fromAce", (PyCFunction)Sbk_QUrlFunc_fromAce, METH_O|METH_STATIC},
    {"fromEncoded", (PyCFunction)Sbk_QUrlFunc_fromEncoded, METH_VARARGS|METH_STATIC},
    {"fromLocalFile", (PyCFunction)Sbk_QUrlFunc_fromLocalFile, METH_O|METH_STATIC},
    {"fromPercentEncoding", (PyCFunction)Sbk_QUrlFunc_fromPercentEncoding, METH_O|METH_STATIC},
    {"fromPunycode", (PyCFunction)Sbk_QUrlFunc_fromPunycode, METH_O|METH_STATIC},
    {"fromUserInput", (PyCFunction)Sbk_QUrlFunc_fromUserInput, METH_O|METH_STATIC},
    {"hasEncodedQueryItem", (PyCFunction)Sbk_QUrlFunc_hasEncodedQueryItem, METH_O},
    {"hasFragment", (PyCFunction)Sbk_QUrlFunc_hasFragment, METH_NOARGS},
    {"hasQuery", (PyCFunction)Sbk_QUrlFunc_hasQuery, METH_NOARGS},
    {"hasQueryItem", (PyCFunction)Sbk_QUrlFunc_hasQueryItem, METH_O},
    {"host", (PyCFunction)Sbk_QUrlFunc_host, METH_NOARGS},
    {"idnWhitelist", (PyCFunction)Sbk_QUrlFunc_idnWhitelist, METH_NOARGS|METH_STATIC},
    {"isEmpty", (PyCFunction)Sbk_QUrlFunc_isEmpty, METH_NOARGS},
    {"isParentOf", (PyCFunction)Sbk_QUrlFunc_isParentOf, METH_O},
    {"isRelative", (PyCFunction)Sbk_QUrlFunc_isRelative, METH_NOARGS},
    {"isValid", (PyCFunction)Sbk_QUrlFunc_isValid, METH_NOARGS},
    {"password", (PyCFunction)Sbk_QUrlFunc_password, METH_NOARGS},
    {"path", (PyCFunction)Sbk_QUrlFunc_path, METH_NOARGS},
    {"port", (PyCFunction)Sbk_QUrlFunc_port, METH_VARARGS},
    {"queryItemValue", (PyCFunction)Sbk_QUrlFunc_queryItemValue, METH_O},
    {"queryItems", (PyCFunction)Sbk_QUrlFunc_queryItems, METH_NOARGS},
    {"queryPairDelimiter", (PyCFunction)Sbk_QUrlFunc_queryPairDelimiter, METH_NOARGS},
    {"queryValueDelimiter", (PyCFunction)Sbk_QUrlFunc_queryValueDelimiter, METH_NOARGS},
    {"removeAllEncodedQueryItems", (PyCFunction)Sbk_QUrlFunc_removeAllEncodedQueryItems, METH_O},
    {"removeAllQueryItems", (PyCFunction)Sbk_QUrlFunc_removeAllQueryItems, METH_O},
    {"removeEncodedQueryItem", (PyCFunction)Sbk_QUrlFunc_removeEncodedQueryItem, METH_O},
    {"removeQueryItem", (PyCFunction)Sbk_QUrlFunc_removeQueryItem, METH_O},
    {"resolved", (PyCFunction)Sbk_QUrlFunc_resolved, METH_O},
    {"scheme", (PyCFunction)Sbk_QUrlFunc_scheme, METH_NOARGS},
    {"setAuthority", (PyCFunction)Sbk_QUrlFunc_setAuthority, METH_O},
    {"setEncodedFragment", (PyCFunction)Sbk_QUrlFunc_setEncodedFragment, METH_O},
    {"setEncodedHost", (PyCFunction)Sbk_QUrlFunc_setEncodedHost, METH_O},
    {"setEncodedPassword", (PyCFunction)Sbk_QUrlFunc_setEncodedPassword, METH_O},
    {"setEncodedPath", (PyCFunction)Sbk_QUrlFunc_setEncodedPath, METH_O},
    {"setEncodedQuery", (PyCFunction)Sbk_QUrlFunc_setEncodedQuery, METH_O},
    {"setEncodedQueryItems", (PyCFunction)Sbk_QUrlFunc_setEncodedQueryItems, METH_O},
    {"setEncodedUrl", (PyCFunction)Sbk_QUrlFunc_setEncodedUrl, METH_VARARGS},
    {"setEncodedUserName", (PyCFunction)Sbk_QUrlFunc_setEncodedUserName, METH_O},
    {"setFragment", (PyCFunction)Sbk_QUrlFunc_setFragment, METH_O},
    {"setHost", (PyCFunction)Sbk_QUrlFunc_setHost, METH_O},
    {"setIdnWhitelist", (PyCFunction)Sbk_QUrlFunc_setIdnWhitelist, METH_O|METH_STATIC},
    {"setPassword", (PyCFunction)Sbk_QUrlFunc_setPassword, METH_O},
    {"setPath", (PyCFunction)Sbk_QUrlFunc_setPath, METH_O},
    {"setPort", (PyCFunction)Sbk_QUrlFunc_setPort, METH_O},
    {"setQueryDelimiters", (PyCFunction)Sbk_QUrlFunc_setQueryDelimiters, METH_VARARGS},
    {"setQueryItems", (PyCFunction)Sbk_QUrlFunc_setQueryItems, METH_O},
    {"setScheme", (PyCFunction)Sbk_QUrlFunc_setScheme, METH_O},
    {"setUrl", (PyCFunction)Sbk_QUrlFunc_setUrl, METH_VARARGS},
    {"setUserInfo", (PyCFunction)Sbk_QUrlFunc_setUserInfo, METH_O},
    {"setUserName", (PyCFunction)Sbk_QUrlFunc_setUserName, METH_O},
    {"toAce", (PyCFunction)Sbk_QUrlFunc_toAce, METH_O|METH_STATIC},
    {"toEncoded", (PyCFunction)Sbk_QUrlFunc_toEncoded, METH_VARARGS|METH_KEYWORDS},
    {"toLocalFile", (PyCFunction)Sbk_QUrlFunc_toLocalFile, METH_NOARGS},
    {"toPercentEncoding", (PyCFunction)Sbk_QUrlFunc_toPercentEncoding, METH_VARARGS|METH_KEYWORDS|METH_STATIC},
    {"toPunycode", (PyCFunction)Sbk_QUrlFunc_toPunycode, METH_O|METH_STATIC},
    {"toString", (PyCFunction)Sbk_QUrlFunc_toString, METH_VARARGS|METH_KEYWORDS},
    {"userInfo", (PyCFunction)Sbk_QUrlFunc_userInfo, METH_NOARGS},
    {"userName", (PyCFunction)Sbk_QUrlFunc_userName, METH_NOARGS},

    {"__copy__", (PyCFunction)Sbk_QUrl___copy__, METH_NOARGS},
    {0} // Sentinel
};

// Rich comparison
static PyObject* Sbk_QUrl_richcompare(PyObject* self, PyObject* arg, int op)
{
    PyObject* pyResult = 0;
    QUrl& cppSelf = *Shiboken::Converter< QUrl* >::toCpp(self);

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter< ::QUrl >::isConvertible(arg)) {
                // operator!=(const QUrl & url) const
                QUrl cppArg0 = Shiboken::Converter< ::QUrl >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf != cppArg0);
            } else goto Sbk_QUrl_RichComparison_TypeError;

            break;
        case Py_LT:
            if (Shiboken::Converter< ::QUrl >::isConvertible(arg)) {
                // operator<(const QUrl & url) const
                QUrl cppArg0 = Shiboken::Converter< ::QUrl >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf < cppArg0);
            } else goto Sbk_QUrl_RichComparison_TypeError;

            break;
        case Py_EQ:
            if (Shiboken::Converter< ::QUrl >::isConvertible(arg)) {
                // operator==(const QUrl & url) const
                QUrl cppArg0 = Shiboken::Converter< ::QUrl >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf == cppArg0);
            } else goto Sbk_QUrl_RichComparison_TypeError;

            break;
        default:
            goto Sbk_QUrl_RichComparison_TypeError;
    }

    if (pyResult && !PyErr_Occurred())
        return pyResult;
    Sbk_QUrl_RichComparison_TypeError:
    PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
    return 0;

}

} // extern "C"

static long Sbk_QUrl_HashFunc(PyObject* obj){
    return PySide::hash(Shiboken::Converter< ::QUrl >::toCpp(obj));
}

extern "C"
{
static PyObject* Sbk_QUrl__repr__(PyObject* pyObj)
{
    QBuffer buffer;
    buffer.open(QBuffer::ReadWrite);
    QDebug dbg(&buffer);
    dbg << Shiboken::Converter< ::QUrl >::toCpp(pyObj);
    buffer.close();
    return PyString_FromFormat("<PySide.QtCore.%s at %p>", buffer.data().constData(), pyObj);
}
} // extern C

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QUrl_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtCore.QUrl",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Sbk_QUrl__repr__,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             &Sbk_QUrl_HashFunc,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      Sbk_QUrl_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QUrl_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QUrl_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern

PyObject* SbkPySide_QtCore_QUrl_FormattingOption___and__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QUrl::FormattingOptions >::toPython(
        Shiboken::Converter<QUrl::FormattingOptions>::toCpp(self)
        & Shiboken::Converter< QUrl::FormattingOptions >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtCore_QUrl_FormattingOption___or__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QUrl::FormattingOptions >::toPython(
        Shiboken::Converter<QUrl::FormattingOptions>::toCpp(self)
        | Shiboken::Converter< QUrl::FormattingOptions >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtCore_QUrl_FormattingOption___xor__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QUrl::FormattingOptions >::toPython(
        Shiboken::Converter<QUrl::FormattingOptions>::toCpp(self)
        ^ Shiboken::Converter< QUrl::FormattingOptions >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtCore_QUrl_FormattingOption___invert__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QUrl::FormattingOptions >::toPython(
        ~Shiboken::Converter<QUrl::FormattingOptions >::toCpp(self)
    );
}


static PyNumberMethods SbkPySide_QtCore_QUrl_FormattingOption_as_number = {
    /*nb_add*/                  0,
    /*nb_subtract*/             0,
    /*nb_multiply*/             0,
    /*nb_divide*/               0,
    /*nb_remainder*/            0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             0,
    /*nb_positive*/             0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              0,
    /*nb_invert*/               (unaryfunc)SbkPySide_QtCore_QUrl_FormattingOption___invert__,
    /*nb_lshift*/               0,
    /*nb_rshift*/               0,
    /*nb_and*/                  (binaryfunc)SbkPySide_QtCore_QUrl_FormattingOption___and__,
    /*nb_xor*/                  (binaryfunc)SbkPySide_QtCore_QUrl_FormattingOption___xor__,
    /*nb_or*/                   (binaryfunc)SbkPySide_QtCore_QUrl_FormattingOption___or__,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          0,
    /*nb_inplace_subtract*/     0,
    /*nb_inplace_multiply*/     0,
    /*nb_inplace_divide*/       0,
    /*nb_inplace_remainder*/    0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       0,
    /*nb_inplace_rshift*/       0,
    /*nb_inplace_and*/          0,
    /*nb_inplace_xor*/          0,
    /*nb_inplace_or*/           0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};


// forward declaration of new function
static PyTypeObject SbkPySide_QtCore_QUrl_FormattingOptions_Type = {
    PyObject_HEAD_INIT(&PyType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "FormattingOptions",
    /*tp_basicsize*/        0,
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        &SbkPySide_QtCore_QUrl_FormattingOption_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT | Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              PyInt_Type.tp_new,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};



void init_QUrl(PyObject* module)
{
    SbkPySide_QtCoreTypes[SBK_QURL_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QUrl_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QUrl_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QUrl_Type, &Shiboken::callCppDestructor<QUrl >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QUrl_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QUrl_Type, "QUrl");
    PyModule_AddObject(module, "QUrl",
        ((PyObject*)&Sbk_QUrl_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: ParsingMode
    PyTypeObject* SbkPySide_QtCore_QUrl_ParsingMode = Shiboken::Enum::newType("ParsingMode");
    SbkPySide_QtCoreTypes[SBK_QURL_PARSINGMODE_IDX] = SbkPySide_QtCore_QUrl_ParsingMode;
    if (PyType_Ready(SbkPySide_QtCore_QUrl_ParsingMode) < 0)
        return;
    PyDict_SetItemString(Sbk_QUrl_Type.super.ht_type.tp_dict,
            "ParsingMode",((PyObject*)SbkPySide_QtCore_QUrl_ParsingMode));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QUrl_ParsingMode,(long) QUrl::TolerantMode, "TolerantMode");
    PyDict_SetItemString(Sbk_QUrl_Type.super.ht_type.tp_dict,"TolerantMode", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QUrl_ParsingMode->tp_dict,"TolerantMode", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QUrl_ParsingMode,(long) QUrl::StrictMode, "StrictMode");
    PyDict_SetItemString(Sbk_QUrl_Type.super.ht_type.tp_dict,"StrictMode", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QUrl_ParsingMode->tp_dict,"StrictMode", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QUrl::ParsingMode");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::ParsingMode");
    // end of enum ParsingMode

    // init enum: FormattingOption
    PyTypeObject* SbkPySide_QtCore_QUrl_FormattingOption = Shiboken::Enum::newType("FormattingOption");
    SbkPySide_QtCore_QUrl_FormattingOption->tp_as_number = &SbkPySide_QtCore_QUrl_FormattingOption_as_number;
    SbkPySide_QtCoreTypes[SBK_QURL_FORMATTINGOPTION_IDX] = SbkPySide_QtCore_QUrl_FormattingOption;
    if (PyType_Ready(SbkPySide_QtCore_QUrl_FormattingOption) < 0)
        return;
    PyDict_SetItemString(Sbk_QUrl_Type.super.ht_type.tp_dict,
            "FormattingOption",((PyObject*)SbkPySide_QtCore_QUrl_FormattingOption));

    // init flags class: QFlags<QUrl::FormattingOption>
    SbkPySide_QtCoreTypes[SBK_QFLAGS_QURL_FORMATTINGOPTION__IDX] = &SbkPySide_QtCore_QUrl_FormattingOptions_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtCore_QUrl_FormattingOptions_Type) < 0)
        return;
    PyDict_SetItemString(Sbk_QUrl_Type.super.ht_type.tp_dict,
            "FormattingOptions",((PyObject*)&SbkPySide_QtCore_QUrl_FormattingOptions_Type));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QUrl_FormattingOption,(long) QUrl::None, "None");
    PyDict_SetItemString(Sbk_QUrl_Type.super.ht_type.tp_dict,"None", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QUrl_FormattingOption->tp_dict,"None", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QUrl_FormattingOption,(long) QUrl::RemoveScheme, "RemoveScheme");
    PyDict_SetItemString(Sbk_QUrl_Type.super.ht_type.tp_dict,"RemoveScheme", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QUrl_FormattingOption->tp_dict,"RemoveScheme", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QUrl_FormattingOption,(long) QUrl::RemovePassword, "RemovePassword");
    PyDict_SetItemString(Sbk_QUrl_Type.super.ht_type.tp_dict,"RemovePassword", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QUrl_FormattingOption->tp_dict,"RemovePassword", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QUrl_FormattingOption,(long) QUrl::RemoveUserInfo, "RemoveUserInfo");
    PyDict_SetItemString(Sbk_QUrl_Type.super.ht_type.tp_dict,"RemoveUserInfo", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QUrl_FormattingOption->tp_dict,"RemoveUserInfo", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QUrl_FormattingOption,(long) QUrl::RemovePort, "RemovePort");
    PyDict_SetItemString(Sbk_QUrl_Type.super.ht_type.tp_dict,"RemovePort", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QUrl_FormattingOption->tp_dict,"RemovePort", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QUrl_FormattingOption,(long) QUrl::RemoveAuthority, "RemoveAuthority");
    PyDict_SetItemString(Sbk_QUrl_Type.super.ht_type.tp_dict,"RemoveAuthority", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QUrl_FormattingOption->tp_dict,"RemoveAuthority", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QUrl_FormattingOption,(long) QUrl::RemovePath, "RemovePath");
    PyDict_SetItemString(Sbk_QUrl_Type.super.ht_type.tp_dict,"RemovePath", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QUrl_FormattingOption->tp_dict,"RemovePath", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QUrl_FormattingOption,(long) QUrl::RemoveQuery, "RemoveQuery");
    PyDict_SetItemString(Sbk_QUrl_Type.super.ht_type.tp_dict,"RemoveQuery", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QUrl_FormattingOption->tp_dict,"RemoveQuery", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QUrl_FormattingOption,(long) QUrl::RemoveFragment, "RemoveFragment");
    PyDict_SetItemString(Sbk_QUrl_Type.super.ht_type.tp_dict,"RemoveFragment", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QUrl_FormattingOption->tp_dict,"RemoveFragment", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QUrl_FormattingOption,(long) QUrl::StripTrailingSlash, "StripTrailingSlash");
    PyDict_SetItemString(Sbk_QUrl_Type.super.ht_type.tp_dict,"StripTrailingSlash", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QUrl_FormattingOption->tp_dict,"StripTrailingSlash", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QUrl::FormattingOption");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::FormattingOption");
    // end of enum FormattingOption


    Shiboken::TypeResolver::createValueTypeResolver<QUrl >("QUrl");
    Shiboken::TypeResolver::createObjectTypeResolver<QUrl >("QUrl*");
    Shiboken::TypeResolver::createValueTypeResolver<QUrl >(typeid(QUrl).name());
    PySide::initQtMetaType<QUrl >();
}

