/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtcore_python.h"

#include "quuid_wrapper.h"

// Extra includes
#include <quuid.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QUuid_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QUuid >()))
        return -1;

    QUuid* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs == 2 || numArgs == 3 || numArgs == 4 || numArgs == 5 || numArgs == 6 || numArgs == 7 || numArgs == 8 || numArgs == 9 || numArgs == 10)
        goto Sbk_QUuid_Init_TypeError;

    if (!PyArg_UnpackTuple(args, "QUuid", 0, 11, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4]), &(pyargs[5]), &(pyargs[6]), &(pyargs[7]), &(pyargs[8]), &(pyargs[9]), &(pyargs[10])))
        return -1;

    // Overloaded function decisor
    // 0: QUuid()
    // 1: QUuid(QString)
    // 2: QUuid(QUuid)
    // 3: QUuid(uint,ushort,ushort,uchar,uchar,uchar,uchar,uchar,uchar,uchar,uchar)
    if (numArgs == 0) {
        overloadId = 0; // QUuid()
    } else if (numArgs == 11 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && Shiboken::Converter< unsigned char >::isConvertible(pyargs[3]) && Shiboken::Converter< unsigned char >::isConvertible(pyargs[4]) && Shiboken::Converter< unsigned char >::isConvertible(pyargs[5]) && Shiboken::Converter< unsigned char >::isConvertible(pyargs[6]) && Shiboken::Converter< unsigned char >::isConvertible(pyargs[7]) && Shiboken::Converter< unsigned char >::isConvertible(pyargs[8]) && Shiboken::Converter< unsigned char >::isConvertible(pyargs[9]) && Shiboken::Converter< unsigned char >::isConvertible(pyargs[10])) {
        overloadId = 3; // QUuid(uint,ushort,ushort,uchar,uchar,uchar,uchar,uchar,uchar,uchar,uchar)
    } else if (numArgs == 1 && Shiboken::Converter< QString >::isConvertible(pyargs[0])) {
        overloadId = 1; // QUuid(QString)
    } else if (numArgs == 1 && Shiboken::Converter< ::QUuid >::isConvertible(pyargs[0])) {
        overloadId = 2; // QUuid(QUuid)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QUuid_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QUuid()
            {

                if(!PyErr_Occurred()) {
                    // QUuid()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QUuid();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // QUuid(QString)
            {
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QUuid(QString)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QUuid(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // QUuid(QUuid)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QUuid cppArg0 = Shiboken::Converter<QUuid >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QUuid(QUuid)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QUuid(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 3: // QUuid(uint,ushort,ushort,uchar,uchar,uchar,uchar,uchar,uchar,uchar,uchar)
            {
                uint cppArg0 = Shiboken::Converter<uint >::toCpp(pyargs[0]);
                ushort cppArg1 = Shiboken::Converter<ushort >::toCpp(pyargs[1]);
                ushort cppArg2 = Shiboken::Converter<ushort >::toCpp(pyargs[2]);
                uchar cppArg3 = Shiboken::Converter<uchar >::toCpp(pyargs[3]);
                uchar cppArg4 = Shiboken::Converter<uchar >::toCpp(pyargs[4]);
                uchar cppArg5 = Shiboken::Converter<uchar >::toCpp(pyargs[5]);
                uchar cppArg6 = Shiboken::Converter<uchar >::toCpp(pyargs[6]);
                uchar cppArg7 = Shiboken::Converter<uchar >::toCpp(pyargs[7]);
                uchar cppArg8 = Shiboken::Converter<uchar >::toCpp(pyargs[8]);
                uchar cppArg9 = Shiboken::Converter<uchar >::toCpp(pyargs[9]);
                uchar cppArg10 = Shiboken::Converter<uchar >::toCpp(pyargs[10]);

                if(!PyErr_Occurred()) {
                    // QUuid(uint,ushort,ushort,uchar,uchar,uchar,uchar,uchar,uchar,uchar,uchar)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QUuid(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5, cppArg6, cppArg7, cppArg8, cppArg9, cppArg10);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QUuid >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QUuid_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QUuid_Init_TypeError:
        const char* overloads[] = {"", "QString", "PySide.QtCore.QUuid", "unsigned int, ushort, ushort, unsigned char, unsigned char, unsigned char, unsigned char, unsigned char, unsigned char, unsigned char, unsigned char", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QUuid", overloads);
        return -1;
}

static PyObject* Sbk_QUuidFunc___reduce__(PyObject* self)
{
    QUuid* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUuid* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // __reduce__()
                // Begin code injection
                
                // TEMPLATE - reduce_code - START
                pyResult = Py_BuildValue("(N(s))", PyObject_Type(self), qPrintable(cppSelf->toString()));
                // TEMPLATE - reduce_code - END
                
                // End of code injection


            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QUuidFunc_createUuid(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // createUuid()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QUuid cppResult = QUuid::createUuid();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QUuid >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QUuidFunc_isNull(PyObject* self)
{
    QUuid* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUuid* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isNull()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->isNull();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QUuidFunc_toString(PyObject* self)
{
    QUuid* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUuid* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // toString()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = cppSelf->toString();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QUuidFunc_variant(PyObject* self)
{
    QUuid* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUuid* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // variant()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QUuid::Variant cppResult = cppSelf->variant();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QUuid::Variant >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QUuidFunc_version(PyObject* self)
{
    QUuid* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QUuid* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // version()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QUuid::Version cppResult = cppSelf->version();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QUuid::Version >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject *Sbk_QUuid___copy__(PyObject *self)
{
        QUuid* cppSelf = 0;
        if (!Shiboken::Object::isValid(self))
            return 0;
        cppSelf = Shiboken::Converter<QUuid*>::toCpp(self);
        PyObject* pyResult = 0;
        QUuid* copy = new QUuid(*cppSelf);
        pyResult = Shiboken::Converter<QUuid*>::toPython(copy);
        Shiboken::Object::getOwnership(pyResult);

        if (PyErr_Occurred() || !pyResult) {
            Py_XDECREF(pyResult);
            return 0;
        }
        return pyResult;
}

static PyMethodDef Sbk_QUuid_methods[] = {
    {"__reduce__", (PyCFunction)Sbk_QUuidFunc___reduce__, METH_NOARGS},
    {"createUuid", (PyCFunction)Sbk_QUuidFunc_createUuid, METH_NOARGS|METH_STATIC},
    {"isNull", (PyCFunction)Sbk_QUuidFunc_isNull, METH_NOARGS},
    {"toString", (PyCFunction)Sbk_QUuidFunc_toString, METH_NOARGS},
    {"variant", (PyCFunction)Sbk_QUuidFunc_variant, METH_NOARGS},
    {"version", (PyCFunction)Sbk_QUuidFunc_version, METH_NOARGS},

    {"__copy__", (PyCFunction)Sbk_QUuid___copy__, METH_NOARGS},
    {0} // Sentinel
};

// Rich comparison
static PyObject* Sbk_QUuid_richcompare(PyObject* self, PyObject* arg, int op)
{
    PyObject* pyResult = 0;
    QUuid& cppSelf = *Shiboken::Converter< QUuid* >::toCpp(self);

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter< ::QUuid >::isConvertible(arg)) {
                // operator!=(const QUuid & orig) const
                QUuid cppArg0 = Shiboken::Converter< ::QUuid >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf != cppArg0);
            } else goto Sbk_QUuid_RichComparison_TypeError;

            break;
        case Py_LT:
            if (Shiboken::Converter< ::QUuid >::isConvertible(arg)) {
                // operator<(const QUuid & other) const
                QUuid cppArg0 = Shiboken::Converter< ::QUuid >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf < cppArg0);
            } else goto Sbk_QUuid_RichComparison_TypeError;

            break;
        case Py_EQ:
            if (Shiboken::Converter< ::QUuid >::isConvertible(arg)) {
                // operator==(const QUuid & orig) const
                QUuid cppArg0 = Shiboken::Converter< ::QUuid >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf == cppArg0);
            } else goto Sbk_QUuid_RichComparison_TypeError;

            break;
        case Py_GT:
            if (Shiboken::Converter< ::QUuid >::isConvertible(arg)) {
                // operator>(const QUuid & other) const
                QUuid cppArg0 = Shiboken::Converter< ::QUuid >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf > cppArg0);
            } else goto Sbk_QUuid_RichComparison_TypeError;

            break;
        default:
            goto Sbk_QUuid_RichComparison_TypeError;
    }

    if (pyResult && !PyErr_Occurred())
        return pyResult;
    Sbk_QUuid_RichComparison_TypeError:
    PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
    return 0;

}

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QUuid_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtCore.QUuid",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      Sbk_QUuid_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QUuid_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QUuid_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QUuid(PyObject* module)
{
    SbkPySide_QtCoreTypes[SBK_QUUID_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QUuid_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QUuid_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QUuid_Type, &Shiboken::callCppDestructor<QUuid >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QUuid_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QUuid_Type, "QUuid");
    PyModule_AddObject(module, "QUuid",
        ((PyObject*)&Sbk_QUuid_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: Variant
    PyTypeObject* SbkPySide_QtCore_QUuid_Variant = Shiboken::Enum::newType("Variant");
    SbkPySide_QtCoreTypes[SBK_QUUID_VARIANT_IDX] = SbkPySide_QtCore_QUuid_Variant;
    if (PyType_Ready(SbkPySide_QtCore_QUuid_Variant) < 0)
        return;
    PyDict_SetItemString(Sbk_QUuid_Type.super.ht_type.tp_dict,
            "Variant",((PyObject*)SbkPySide_QtCore_QUuid_Variant));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QUuid_Variant,(long) QUuid::VarUnknown, "VarUnknown");
    PyDict_SetItemString(Sbk_QUuid_Type.super.ht_type.tp_dict,"VarUnknown", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QUuid_Variant->tp_dict,"VarUnknown", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QUuid_Variant,(long) QUuid::NCS, "NCS");
    PyDict_SetItemString(Sbk_QUuid_Type.super.ht_type.tp_dict,"NCS", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QUuid_Variant->tp_dict,"NCS", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QUuid_Variant,(long) QUuid::DCE, "DCE");
    PyDict_SetItemString(Sbk_QUuid_Type.super.ht_type.tp_dict,"DCE", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QUuid_Variant->tp_dict,"DCE", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QUuid_Variant,(long) QUuid::Microsoft, "Microsoft");
    PyDict_SetItemString(Sbk_QUuid_Type.super.ht_type.tp_dict,"Microsoft", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QUuid_Variant->tp_dict,"Microsoft", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QUuid_Variant,(long) QUuid::Reserved, "Reserved");
    PyDict_SetItemString(Sbk_QUuid_Type.super.ht_type.tp_dict,"Reserved", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QUuid_Variant->tp_dict,"Reserved", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QUuid::Variant");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::Variant");
    // end of enum Variant

    // init enum: Version
    PyTypeObject* SbkPySide_QtCore_QUuid_Version = Shiboken::Enum::newType("Version");
    SbkPySide_QtCoreTypes[SBK_QUUID_VERSION_IDX] = SbkPySide_QtCore_QUuid_Version;
    if (PyType_Ready(SbkPySide_QtCore_QUuid_Version) < 0)
        return;
    PyDict_SetItemString(Sbk_QUuid_Type.super.ht_type.tp_dict,
            "Version",((PyObject*)SbkPySide_QtCore_QUuid_Version));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QUuid_Version,(long) QUuid::VerUnknown, "VerUnknown");
    PyDict_SetItemString(Sbk_QUuid_Type.super.ht_type.tp_dict,"VerUnknown", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QUuid_Version->tp_dict,"VerUnknown", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QUuid_Version,(long) QUuid::Time, "Time");
    PyDict_SetItemString(Sbk_QUuid_Type.super.ht_type.tp_dict,"Time", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QUuid_Version->tp_dict,"Time", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QUuid_Version,(long) QUuid::EmbeddedPOSIX, "EmbeddedPOSIX");
    PyDict_SetItemString(Sbk_QUuid_Type.super.ht_type.tp_dict,"EmbeddedPOSIX", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QUuid_Version->tp_dict,"EmbeddedPOSIX", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QUuid_Version,(long) QUuid::Name, "Name");
    PyDict_SetItemString(Sbk_QUuid_Type.super.ht_type.tp_dict,"Name", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QUuid_Version->tp_dict,"Name", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtCore_QUuid_Version,(long) QUuid::Random, "Random");
    PyDict_SetItemString(Sbk_QUuid_Type.super.ht_type.tp_dict,"Random", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtCore_QUuid_Version->tp_dict,"Random", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QUuid::Version");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::Version");
    // end of enum Version


    Shiboken::TypeResolver::createValueTypeResolver<QUuid >("QUuid");
    Shiboken::TypeResolver::createObjectTypeResolver<QUuid >("QUuid*");
    Shiboken::TypeResolver::createValueTypeResolver<QUuid >(typeid(QUuid).name());
    PySide::initQtMetaType<QUuid >();
}

