/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtcore_python.h"

#include "qxmlstreamentityresolver_wrapper.h"

// Extra includes


// Native ---------------------------------------------------------

QXmlStreamEntityResolverWrapper::QXmlStreamEntityResolverWrapper() : QXmlStreamEntityResolver() {
    // ... middle
}

QString QXmlStreamEntityResolverWrapper::resolveEntity(const QString & publicId, const QString & systemId)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "resolveEntity"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QXmlStreamEntityResolver::resolveEntity(publicId, systemId);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< QString >::toPython(publicId),
        Shiboken::Converter< QString >::toPython(systemId)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QString();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< QString >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QXmlStreamEntityResolver.resolveEntity", "QString", pyResult->ob_type->tp_name);
        return QString();
    }
    QString cppResult(Shiboken::Converter< QString >::toCpp(pyResult));
    return cppResult;
}

QString QXmlStreamEntityResolverWrapper::resolveUndeclaredEntity(const QString & name)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "resolveUndeclaredEntity"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QXmlStreamEntityResolver::resolveUndeclaredEntity(name);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< QString >::toPython(name)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QString();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< QString >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QXmlStreamEntityResolver.resolveUndeclaredEntity", "QString", pyResult->ob_type->tp_name);
        return QString();
    }
    QString cppResult(Shiboken::Converter< QString >::toCpp(pyResult));
    return cppResult;
}

QXmlStreamEntityResolverWrapper::~QXmlStreamEntityResolverWrapper()
{
    SbkObject* wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QXmlStreamEntityResolver_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QXmlStreamEntityResolver >()))
        return -1;

    QXmlStreamEntityResolverWrapper* cptr = 0;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // QXmlStreamEntityResolver()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new QXmlStreamEntityResolverWrapper();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QXmlStreamEntityResolver >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject* Sbk_QXmlStreamEntityResolverFunc_resolveEntity(PyObject* self, PyObject* args)
{
    QXmlStreamEntityResolver* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlStreamEntityResolver* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "resolveEntity", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: resolveEntity(QString,QString)
    if (numArgs == 2 && Shiboken::Converter< QString >::isConvertible(pyargs[0]) && Shiboken::Converter< QString >::isConvertible(pyargs[1])) {
        overloadId = 0; // resolveEntity(QString,QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QXmlStreamEntityResolverFunc_resolveEntity_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QString cppArg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // resolveEntity(QString,QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QXmlStreamEntityResolver::resolveEntity(cppArg0, cppArg1):cppSelf->resolveEntity(cppArg0, cppArg1));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QXmlStreamEntityResolverFunc_resolveEntity_TypeError:
        const char* overloads[] = {"QString, QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtCore.QXmlStreamEntityResolver.resolveEntity", overloads);
        return 0;
}

static PyObject* Sbk_QXmlStreamEntityResolverFunc_resolveUndeclaredEntity(PyObject* self, PyObject* arg)
{
    QXmlStreamEntityResolver* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlStreamEntityResolver* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: resolveUndeclaredEntity(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // resolveUndeclaredEntity(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QXmlStreamEntityResolverFunc_resolveUndeclaredEntity_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // resolveUndeclaredEntity(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QXmlStreamEntityResolver::resolveUndeclaredEntity(cppArg0):cppSelf->resolveUndeclaredEntity(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QXmlStreamEntityResolverFunc_resolveUndeclaredEntity_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtCore.QXmlStreamEntityResolver.resolveUndeclaredEntity", overloads);
        return 0;
}

static PyMethodDef Sbk_QXmlStreamEntityResolver_methods[] = {
    {"resolveEntity", (PyCFunction)Sbk_QXmlStreamEntityResolverFunc_resolveEntity, METH_VARARGS},
    {"resolveUndeclaredEntity", (PyCFunction)Sbk_QXmlStreamEntityResolverFunc_resolveUndeclaredEntity, METH_O},

    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QXmlStreamEntityResolver_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtCore.QXmlStreamEntityResolver",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QXmlStreamEntityResolver_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QXmlStreamEntityResolver_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QXmlStreamEntityResolver(PyObject* module)
{
    SbkPySide_QtCoreTypes[SBK_QXMLSTREAMENTITYRESOLVER_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QXmlStreamEntityResolver_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QXmlStreamEntityResolver_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QXmlStreamEntityResolver_Type, &Shiboken::callCppDestructor<QXmlStreamEntityResolver >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QXmlStreamEntityResolver_Type) < 0)
        return;

    // Fill type discovery information

    Shiboken::ObjectType::setOriginalName(&Sbk_QXmlStreamEntityResolver_Type, "QXmlStreamEntityResolver*");
    PyModule_AddObject(module, "QXmlStreamEntityResolver",
        ((PyObject*)&Sbk_QXmlStreamEntityResolver_Type));


    Shiboken::TypeResolver::createObjectTypeResolver<QXmlStreamEntityResolver >("QXmlStreamEntityResolver*");
    Shiboken::TypeResolver::createObjectTypeResolver<QXmlStreamEntityResolver >(typeid(QXmlStreamEntityResolver).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QXmlStreamEntityResolver >(typeid(QXmlStreamEntityResolverWrapper).name());
    PySide::initQtMetaType<QXmlStreamEntityResolver* >();
}

