/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include "pyside_qtdeclarative_python.h"

#include "qdeclarativeengine_wrapper.h"

// Extra includes
#include <QList>
#include <QStringList>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qdeclarativecontext.h>
#include <qdeclarativeengine.h>
#include <qdeclarativeerror.h>
#include <qdeclarativeimageprovider.h>
#include <qdeclarativenetworkaccessmanagerfactory.h>
#include <qnetworkaccessmanager.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qthread.h>
#include <qurl.h>


// Native ---------------------------------------------------------

QDeclarativeEngineWrapper::QDeclarativeEngineWrapper(QObject * parent) : QDeclarativeEngine(parent) {
    // ... middle
}

void QDeclarativeEngineWrapper::childEvent(QChildEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "childEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::childEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QChildEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QDeclarativeEngineWrapper::connectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "connectNotify"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QDeclarativeEngineWrapper::customEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "customEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::customEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QDeclarativeEngineWrapper::disconnectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

bool QDeclarativeEngineWrapper::event(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "event"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::event(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QDeclarativeEngine.event", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
    return cppResult;
}

bool QDeclarativeEngineWrapper::eventFilter(QObject * arg__1, QEvent * arg__2)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "eventFilter"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::eventFilter(arg__1, arg__2);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QObject * >::toPython(arg__1),
        Shiboken::Converter< ::QEvent * >::toPython(arg__2)
    ));
    bool invalidadeArg2 = PyTuple_GET_ITEM(pyargs, 1)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QDeclarativeEngine.eventFilter", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    if (invalidadeArg2)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 1));
    return cppResult;
}

void QDeclarativeEngineWrapper::timerEvent(QTimerEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "timerEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::timerEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QTimerEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

const QMetaObject* QDeclarativeEngineWrapper::metaObject() const
{
    SbkObject* pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    return reinterpret_cast<QMetaObject*>(Shiboken::Object::getTypeUserData(pySelf));
}

int QDeclarativeEngineWrapper::qt_metacall(QMetaObject::Call call, int id, void** args)
{
    int result = QDeclarativeEngine::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

QDeclarativeEngineWrapper::~QDeclarativeEngineWrapper()
{
    SbkObject* wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QDeclarativeEngine_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QDeclarativeEngine >()))
        return -1;

    QDeclarativeEngineWrapper* cptr = 0;
    int overloadId = -1;
    const char* argNames[] = {"parent"};
    const QMetaObject* metaObject;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_ParseTuple(args, "|O:QDeclarativeEngine", &(pyargs[0])))
        return -1;

    // Overloaded function decisor
    // 0: QDeclarativeEngine(QObject*)
    if (numArgs == 0) {
        overloadId = 0; // QDeclarativeEngine(QObject*)
    } else if (Shiboken::Converter< ::QObject * >::isConvertible(pyargs[0])) {
        overloadId = 0; // QDeclarativeEngine(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDeclarativeEngine_Init_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "parent");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "parent";
                    else if (Shiboken::Converter< ::QObject * >::isConvertible(value))
                        pyargs[0] = value;
else
                        goto Sbk_QDeclarativeEngine_Init_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtDeclarative.QDeclarativeEngine(): got multiple values for keyword argument '%s'", errorArgName);
                    return -1;
                }
            }
            if (!Shiboken::Object::isValid(pyargs[0]))
                return -1;
            QObject * cppArg0 = pyargs[0] ? Shiboken::Converter<QObject * >::toCpp(pyargs[0]) : 0;

            if(!PyErr_Occurred()) {
                // QDeclarativeEngine(QObject*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new QDeclarativeEngineWrapper(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                Shiboken::Object::setParent(pyargs[0], self);
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QDeclarativeEngine >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QDeclarativeEngine_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    metaObject = cptr->metaObject(); // <- init python qt properties
    if (kwds && !PySide::fillQtProperties(self, metaObject, kwds, argNames, 1))
        return -1;


    return 1;

    Sbk_QDeclarativeEngine_Init_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtDeclarative.QDeclarativeEngine", overloads);
        return -1;
}

static PyObject* Sbk_QDeclarativeEngineFunc_addImageProvider(PyObject* self, PyObject* args)
{
    QDeclarativeEngine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDeclarativeEngine* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "addImageProvider", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: addImageProvider(QString,QDeclarativeImageProvider*)
    if (numArgs == 2 && Shiboken::Converter< QString >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QDeclarativeImageProvider * >::isConvertible(pyargs[1])) {
        overloadId = 0; // addImageProvider(QString,QDeclarativeImageProvider*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDeclarativeEngineFunc_addImageProvider_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QDeclarativeImageProvider * cppArg1 = Shiboken::Converter<QDeclarativeImageProvider * >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // addImageProvider(QString,QDeclarativeImageProvider*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->addImageProvider(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QDeclarativeEngineFunc_addImageProvider_TypeError:
        const char* overloads[] = {"QString, PySide.QtDeclarative.QDeclarativeImageProvider", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtDeclarative.QDeclarativeEngine.addImageProvider", overloads);
        return 0;
}

static PyObject* Sbk_QDeclarativeEngineFunc_addImportPath(PyObject* self, PyObject* arg)
{
    QDeclarativeEngine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDeclarativeEngine* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: addImportPath(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // addImportPath(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDeclarativeEngineFunc_addImportPath_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // addImportPath(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->addImportPath(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QDeclarativeEngineFunc_addImportPath_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtDeclarative.QDeclarativeEngine.addImportPath", overloads);
        return 0;
}

static PyObject* Sbk_QDeclarativeEngineFunc_addPluginPath(PyObject* self, PyObject* arg)
{
    QDeclarativeEngine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDeclarativeEngine* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: addPluginPath(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // addPluginPath(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDeclarativeEngineFunc_addPluginPath_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // addPluginPath(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->addPluginPath(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QDeclarativeEngineFunc_addPluginPath_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtDeclarative.QDeclarativeEngine.addPluginPath", overloads);
        return 0;
}

static PyObject* Sbk_QDeclarativeEngineFunc_baseUrl(PyObject* self)
{
    QDeclarativeEngine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDeclarativeEngine* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // baseUrl()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QUrl cppResult = cppSelf->baseUrl();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QUrl >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDeclarativeEngineFunc_clearComponentCache(PyObject* self)
{
    QDeclarativeEngine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDeclarativeEngine* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // clearComponentCache()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->clearComponentCache();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QDeclarativeEngineFunc_contextForObject(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: contextForObject(const QObject*)
    if (Shiboken::Converter< ::QObject * >::isConvertible(arg)) {
        overloadId = 0; // contextForObject(const QObject*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDeclarativeEngineFunc_contextForObject_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QObject * cppArg0 = Shiboken::Converter<QObject * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // contextForObject(const QObject*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDeclarativeContext * cppResult = QDeclarativeEngine::contextForObject(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDeclarativeContext * >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QDeclarativeEngineFunc_contextForObject_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtDeclarative.QDeclarativeEngine.contextForObject", overloads);
        return 0;
}

static PyObject* Sbk_QDeclarativeEngineFunc_imageProvider(PyObject* self, PyObject* arg)
{
    QDeclarativeEngine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDeclarativeEngine* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: imageProvider(QString)const
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // imageProvider(QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDeclarativeEngineFunc_imageProvider_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // imageProvider(QString)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDeclarativeImageProvider * cppResult = cppSelf->imageProvider(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDeclarativeImageProvider * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QDeclarativeEngineFunc_imageProvider_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtDeclarative.QDeclarativeEngine.imageProvider", overloads);
        return 0;
}

static PyObject* Sbk_QDeclarativeEngineFunc_importPathList(PyObject* self)
{
    QDeclarativeEngine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDeclarativeEngine* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // importPathList()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QStringList cppResult = cppSelf->importPathList();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QStringList >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDeclarativeEngineFunc_importPlugin(PyObject* self, PyObject* args)
{
    QDeclarativeEngine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDeclarativeEngine* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "importPlugin", 3, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: importPlugin(QString,QString,QString*)
    if (numArgs == 3 && Shiboken::Converter< QString >::isConvertible(pyargs[0]) && Shiboken::Converter< QString >::isConvertible(pyargs[1]) && Shiboken::Converter< ::QString * >::isConvertible(pyargs[2])) {
        overloadId = 0; // importPlugin(QString,QString,QString*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDeclarativeEngineFunc_importPlugin_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QString cppArg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);
            QString * cppArg2 = Shiboken::Converter<QString * >::toCpp(pyargs[2]);

            if(!PyErr_Occurred()) {
                // importPlugin(QString,QString,QString*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->importPlugin(cppArg0, cppArg1, cppArg2);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QDeclarativeEngineFunc_importPlugin_TypeError:
        const char* overloads[] = {"QString, QString, QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtDeclarative.QDeclarativeEngine.importPlugin", overloads);
        return 0;
}

static PyObject* Sbk_QDeclarativeEngineFunc_networkAccessManager(PyObject* self)
{
    QDeclarativeEngine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDeclarativeEngine* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // networkAccessManager()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QNetworkAccessManager * cppResult = cppSelf->networkAccessManager();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QNetworkAccessManager * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDeclarativeEngineFunc_networkAccessManagerFactory(PyObject* self)
{
    QDeclarativeEngine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDeclarativeEngine* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // networkAccessManagerFactory()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDeclarativeNetworkAccessManagerFactory * cppResult = cppSelf->networkAccessManagerFactory();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDeclarativeNetworkAccessManagerFactory * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDeclarativeEngineFunc_objectOwnership(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: objectOwnership(QObject*)
    if (Shiboken::Converter< ::QObject * >::isConvertible(arg)) {
        overloadId = 0; // objectOwnership(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDeclarativeEngineFunc_objectOwnership_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QObject * cppArg0 = Shiboken::Converter<QObject * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // objectOwnership(QObject*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDeclarativeEngine::ObjectOwnership cppResult = QDeclarativeEngine::objectOwnership(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDeclarativeEngine::ObjectOwnership >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QDeclarativeEngineFunc_objectOwnership_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtDeclarative.QDeclarativeEngine.objectOwnership", overloads);
        return 0;
}

static PyObject* Sbk_QDeclarativeEngineFunc_offlineStoragePath(PyObject* self)
{
    QDeclarativeEngine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDeclarativeEngine* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // offlineStoragePath()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = cppSelf->offlineStoragePath();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDeclarativeEngineFunc_outputWarningsToStandardError(PyObject* self)
{
    QDeclarativeEngine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDeclarativeEngine* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // outputWarningsToStandardError()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->outputWarningsToStandardError();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDeclarativeEngineFunc_pluginPathList(PyObject* self)
{
    QDeclarativeEngine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDeclarativeEngine* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // pluginPathList()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QStringList cppResult = cppSelf->pluginPathList();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QStringList >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDeclarativeEngineFunc_removeImageProvider(PyObject* self, PyObject* arg)
{
    QDeclarativeEngine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDeclarativeEngine* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: removeImageProvider(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // removeImageProvider(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDeclarativeEngineFunc_removeImageProvider_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // removeImageProvider(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->removeImageProvider(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QDeclarativeEngineFunc_removeImageProvider_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtDeclarative.QDeclarativeEngine.removeImageProvider", overloads);
        return 0;
}

static PyObject* Sbk_QDeclarativeEngineFunc_rootContext(PyObject* self)
{
    QDeclarativeEngine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDeclarativeEngine* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // rootContext()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDeclarativeContext * cppResult = cppSelf->rootContext();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDeclarativeContext * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDeclarativeEngineFunc_setBaseUrl(PyObject* self, PyObject* arg)
{
    QDeclarativeEngine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDeclarativeEngine* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setBaseUrl(QUrl)
    if (Shiboken::Converter< ::QUrl >::isConvertible(arg)) {
        overloadId = 0; // setBaseUrl(QUrl)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDeclarativeEngineFunc_setBaseUrl_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QUrl cppArg0 = Shiboken::Converter<QUrl >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setBaseUrl(QUrl)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setBaseUrl(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QDeclarativeEngineFunc_setBaseUrl_TypeError:
        const char* overloads[] = {"PySide.QtCore.QUrl", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtDeclarative.QDeclarativeEngine.setBaseUrl", overloads);
        return 0;
}

static PyObject* Sbk_QDeclarativeEngineFunc_setContextForObject(PyObject* self, PyObject* args)
{
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setContextForObject", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setContextForObject(QObject*,QDeclarativeContext*)
    if (numArgs == 2 && Shiboken::Converter< ::QObject * >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QDeclarativeContext * >::isConvertible(pyargs[1])) {
        overloadId = 0; // setContextForObject(QObject*,QDeclarativeContext*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDeclarativeEngineFunc_setContextForObject_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QObject * cppArg0 = Shiboken::Converter<QObject * >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QDeclarativeContext * cppArg1 = Shiboken::Converter<QDeclarativeContext * >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // setContextForObject(QObject*,QDeclarativeContext*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDeclarativeEngine::setContextForObject(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QDeclarativeEngineFunc_setContextForObject_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject, PySide.QtDeclarative.QDeclarativeContext", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtDeclarative.QDeclarativeEngine.setContextForObject", overloads);
        return 0;
}

static PyObject* Sbk_QDeclarativeEngineFunc_setImportPathList(PyObject* self, PyObject* arg)
{
    QDeclarativeEngine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDeclarativeEngine* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setImportPathList(QStringList)
    if (Shiboken::Converter< ::QStringList >::isConvertible(arg)) {
        overloadId = 0; // setImportPathList(QStringList)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDeclarativeEngineFunc_setImportPathList_TypeError;

    // Call function/method
    {
        {
            QStringList cppArg0 = Shiboken::Converter<QStringList >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setImportPathList(QStringList)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setImportPathList(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QDeclarativeEngineFunc_setImportPathList_TypeError:
        const char* overloads[] = {"list", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtDeclarative.QDeclarativeEngine.setImportPathList", overloads);
        return 0;
}

static PyObject* Sbk_QDeclarativeEngineFunc_setNetworkAccessManagerFactory(PyObject* self, PyObject* arg)
{
    QDeclarativeEngine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDeclarativeEngine* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setNetworkAccessManagerFactory(QDeclarativeNetworkAccessManagerFactory*)
    if (Shiboken::Converter< ::QDeclarativeNetworkAccessManagerFactory * >::isConvertible(arg)) {
        overloadId = 0; // setNetworkAccessManagerFactory(QDeclarativeNetworkAccessManagerFactory*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDeclarativeEngineFunc_setNetworkAccessManagerFactory_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QDeclarativeNetworkAccessManagerFactory * cppArg0 = Shiboken::Converter<QDeclarativeNetworkAccessManagerFactory * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setNetworkAccessManagerFactory(QDeclarativeNetworkAccessManagerFactory*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setNetworkAccessManagerFactory(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                Shiboken::Object::setParent(self, arg);
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QDeclarativeEngineFunc_setNetworkAccessManagerFactory_TypeError:
        const char* overloads[] = {"PySide.QtDeclarative.QDeclarativeNetworkAccessManagerFactory", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtDeclarative.QDeclarativeEngine.setNetworkAccessManagerFactory", overloads);
        return 0;
}

static PyObject* Sbk_QDeclarativeEngineFunc_setObjectOwnership(PyObject* self, PyObject* args)
{
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setObjectOwnership", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setObjectOwnership(QObject*,QDeclarativeEngine::ObjectOwnership)
    if (numArgs == 2 && Shiboken::Converter< ::QObject * >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QDeclarativeEngine::ObjectOwnership >::isConvertible(pyargs[1])) {
        overloadId = 0; // setObjectOwnership(QObject*,QDeclarativeEngine::ObjectOwnership)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDeclarativeEngineFunc_setObjectOwnership_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QObject * cppArg0 = Shiboken::Converter<QObject * >::toCpp(pyargs[0]);
            QDeclarativeEngine::ObjectOwnership cppArg1 = Shiboken::Converter<QDeclarativeEngine::ObjectOwnership >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // setObjectOwnership(QObject*,QDeclarativeEngine::ObjectOwnership)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDeclarativeEngine::setObjectOwnership(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QDeclarativeEngineFunc_setObjectOwnership_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject, PySide.QtDeclarative.QDeclarativeEngine.ObjectOwnership", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtDeclarative.QDeclarativeEngine.setObjectOwnership", overloads);
        return 0;
}

static PyObject* Sbk_QDeclarativeEngineFunc_setOfflineStoragePath(PyObject* self, PyObject* arg)
{
    QDeclarativeEngine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDeclarativeEngine* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setOfflineStoragePath(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // setOfflineStoragePath(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDeclarativeEngineFunc_setOfflineStoragePath_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setOfflineStoragePath(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setOfflineStoragePath(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QDeclarativeEngineFunc_setOfflineStoragePath_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtDeclarative.QDeclarativeEngine.setOfflineStoragePath", overloads);
        return 0;
}

static PyObject* Sbk_QDeclarativeEngineFunc_setOutputWarningsToStandardError(PyObject* self, PyObject* arg)
{
    QDeclarativeEngine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDeclarativeEngine* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setOutputWarningsToStandardError(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setOutputWarningsToStandardError(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDeclarativeEngineFunc_setOutputWarningsToStandardError_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setOutputWarningsToStandardError(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setOutputWarningsToStandardError(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QDeclarativeEngineFunc_setOutputWarningsToStandardError_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtDeclarative.QDeclarativeEngine.setOutputWarningsToStandardError", overloads);
        return 0;
}

static PyObject* Sbk_QDeclarativeEngineFunc_setPluginPathList(PyObject* self, PyObject* arg)
{
    QDeclarativeEngine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDeclarativeEngine* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setPluginPathList(QStringList)
    if (Shiboken::Converter< ::QStringList >::isConvertible(arg)) {
        overloadId = 0; // setPluginPathList(QStringList)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDeclarativeEngineFunc_setPluginPathList_TypeError;

    // Call function/method
    {
        {
            QStringList cppArg0 = Shiboken::Converter<QStringList >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setPluginPathList(QStringList)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setPluginPathList(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QDeclarativeEngineFunc_setPluginPathList_TypeError:
        const char* overloads[] = {"list", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtDeclarative.QDeclarativeEngine.setPluginPathList", overloads);
        return 0;
}

static PyMethodDef Sbk_QDeclarativeEngine_methods[] = {
    {"addImageProvider", (PyCFunction)Sbk_QDeclarativeEngineFunc_addImageProvider, METH_VARARGS},
    {"addImportPath", (PyCFunction)Sbk_QDeclarativeEngineFunc_addImportPath, METH_O},
    {"addPluginPath", (PyCFunction)Sbk_QDeclarativeEngineFunc_addPluginPath, METH_O},
    {"baseUrl", (PyCFunction)Sbk_QDeclarativeEngineFunc_baseUrl, METH_NOARGS},
    {"clearComponentCache", (PyCFunction)Sbk_QDeclarativeEngineFunc_clearComponentCache, METH_NOARGS},
    {"contextForObject", (PyCFunction)Sbk_QDeclarativeEngineFunc_contextForObject, METH_O|METH_STATIC},
    {"imageProvider", (PyCFunction)Sbk_QDeclarativeEngineFunc_imageProvider, METH_O},
    {"importPathList", (PyCFunction)Sbk_QDeclarativeEngineFunc_importPathList, METH_NOARGS},
    {"importPlugin", (PyCFunction)Sbk_QDeclarativeEngineFunc_importPlugin, METH_VARARGS},
    {"networkAccessManager", (PyCFunction)Sbk_QDeclarativeEngineFunc_networkAccessManager, METH_NOARGS},
    {"networkAccessManagerFactory", (PyCFunction)Sbk_QDeclarativeEngineFunc_networkAccessManagerFactory, METH_NOARGS},
    {"objectOwnership", (PyCFunction)Sbk_QDeclarativeEngineFunc_objectOwnership, METH_O|METH_STATIC},
    {"offlineStoragePath", (PyCFunction)Sbk_QDeclarativeEngineFunc_offlineStoragePath, METH_NOARGS},
    {"outputWarningsToStandardError", (PyCFunction)Sbk_QDeclarativeEngineFunc_outputWarningsToStandardError, METH_NOARGS},
    {"pluginPathList", (PyCFunction)Sbk_QDeclarativeEngineFunc_pluginPathList, METH_NOARGS},
    {"removeImageProvider", (PyCFunction)Sbk_QDeclarativeEngineFunc_removeImageProvider, METH_O},
    {"rootContext", (PyCFunction)Sbk_QDeclarativeEngineFunc_rootContext, METH_NOARGS},
    {"setBaseUrl", (PyCFunction)Sbk_QDeclarativeEngineFunc_setBaseUrl, METH_O},
    {"setContextForObject", (PyCFunction)Sbk_QDeclarativeEngineFunc_setContextForObject, METH_VARARGS|METH_STATIC},
    {"setImportPathList", (PyCFunction)Sbk_QDeclarativeEngineFunc_setImportPathList, METH_O},
    {"setNetworkAccessManagerFactory", (PyCFunction)Sbk_QDeclarativeEngineFunc_setNetworkAccessManagerFactory, METH_O},
    {"setObjectOwnership", (PyCFunction)Sbk_QDeclarativeEngineFunc_setObjectOwnership, METH_VARARGS|METH_STATIC},
    {"setOfflineStoragePath", (PyCFunction)Sbk_QDeclarativeEngineFunc_setOfflineStoragePath, METH_O},
    {"setOutputWarningsToStandardError", (PyCFunction)Sbk_QDeclarativeEngineFunc_setOutputWarningsToStandardError, METH_O},
    {"setPluginPathList", (PyCFunction)Sbk_QDeclarativeEngineFunc_setPluginPathList, METH_O},

    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QDeclarativeEngine_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtDeclarative.QDeclarativeEngine",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QDeclarativeEngine_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QDeclarativeEngine_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern

static SbkObjectType* Sbk_QDeclarativeEngine_typeDiscovery(void* cptr, SbkObjectType* instanceType)
{
    if (instanceType == reinterpret_cast<SbkObjectType*>(Shiboken::SbkType<QObject >()) && dynamic_cast<QDeclarativeEngine*>(reinterpret_cast<QObject*>(cptr)))
        return &Sbk_QDeclarativeEngine_Type;
    return 0;
}


void init_QDeclarativeEngine(PyObject* module)
{
    SbkPySide_QtDeclarativeTypes[SBK_QDECLARATIVEENGINE_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QDeclarativeEngine_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QDeclarativeEngine_Type);
    Shiboken::ObjectType::setSubTypeInitHook(&Sbk_QDeclarativeEngine_Type, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(&Sbk_QDeclarativeEngine_Type, &QDeclarativeEngine::staticMetaObject);    Sbk_QDeclarativeEngine_Type.super.ht_type.tp_base = SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX];
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QDeclarativeEngine_Type, &Shiboken::callCppDestructor<QDeclarativeEngine >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QDeclarativeEngine_Type) < 0)
        return;

    // Fill type discovery information
    Shiboken::ObjectType::setTypeDiscoveryFunction(&Sbk_QDeclarativeEngine_Type, &Sbk_QDeclarativeEngine_typeDiscovery);
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkObjectType*>(SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX]), &Sbk_QDeclarativeEngine_Type);

    Shiboken::ObjectType::setOriginalName(&Sbk_QDeclarativeEngine_Type, "QDeclarativeEngine*");
    PyModule_AddObject(module, "QDeclarativeEngine",
        ((PyObject*)&Sbk_QDeclarativeEngine_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: ObjectOwnership
    PyTypeObject* SbkPySide_QtDeclarative_QDeclarativeEngine_ObjectOwnership = Shiboken::Enum::newType("ObjectOwnership");
    SbkPySide_QtDeclarativeTypes[SBK_QDECLARATIVEENGINE_OBJECTOWNERSHIP_IDX] = SbkPySide_QtDeclarative_QDeclarativeEngine_ObjectOwnership;
    if (PyType_Ready(SbkPySide_QtDeclarative_QDeclarativeEngine_ObjectOwnership) < 0)
        return;
    PyDict_SetItemString(Sbk_QDeclarativeEngine_Type.super.ht_type.tp_dict,
            "ObjectOwnership",((PyObject*)SbkPySide_QtDeclarative_QDeclarativeEngine_ObjectOwnership));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtDeclarative_QDeclarativeEngine_ObjectOwnership,(long) QDeclarativeEngine::CppOwnership, "CppOwnership");
    PyDict_SetItemString(Sbk_QDeclarativeEngine_Type.super.ht_type.tp_dict,"CppOwnership", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtDeclarative_QDeclarativeEngine_ObjectOwnership->tp_dict,"CppOwnership", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtDeclarative_QDeclarativeEngine_ObjectOwnership,(long) QDeclarativeEngine::JavaScriptOwnership, "JavaScriptOwnership");
    PyDict_SetItemString(Sbk_QDeclarativeEngine_Type.super.ht_type.tp_dict,"JavaScriptOwnership", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtDeclarative_QDeclarativeEngine_ObjectOwnership->tp_dict,"JavaScriptOwnership", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QDeclarativeEngine::ObjectOwnership");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::ObjectOwnership");
    // end of enum ObjectOwnership

    // Initialize signals
    PySideSignal* signal_item;

    signal_item = PySide::Signal::newObject("warnings", "QList<QDeclarativeError>", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QDeclarativeEngine_Type, "warnings", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("quit", "void", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QDeclarativeEngine_Type, "quit", signal_item);
    Py_DECREF((PyObject*) signal_item);


    Shiboken::TypeResolver::createObjectTypeResolver<QDeclarativeEngine >("QDeclarativeEngine*");
    Shiboken::TypeResolver::createObjectTypeResolver<QDeclarativeEngine >(typeid(QDeclarativeEngine).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QDeclarativeEngine >(typeid(QDeclarativeEngineWrapper).name());
    PySide::initQtMetaType<QDeclarativeEngine* >();
}

