/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtdeclarative_python.h"

#include "qdeclarativepropertyvaluesource_wrapper.h"

// Extra includes
#include <qdeclarativeproperty.h>


// Native ---------------------------------------------------------

QDeclarativePropertyValueSourceWrapper::QDeclarativePropertyValueSourceWrapper() : QDeclarativePropertyValueSource() {
    // ... middle
}

void QDeclarativePropertyValueSourceWrapper::setTarget(const QDeclarativeProperty & arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "setTarget"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QDeclarativePropertyValueSource.setTarget()' not implemented.");
        return ;
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QDeclarativeProperty >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

QDeclarativePropertyValueSourceWrapper::~QDeclarativePropertyValueSourceWrapper()
{
    SbkObject* wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QDeclarativePropertyValueSource_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QDeclarativePropertyValueSource >()))
        return -1;

    QDeclarativePropertyValueSourceWrapper* cptr = 0;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);
    SbkObjectType* type = reinterpret_cast<SbkObjectType*>(self->ob_type);
    SbkObjectType* myType = reinterpret_cast<SbkObjectType*>(SbkPySide_QtDeclarativeTypes[SBK_QDECLARATIVEPROPERTYVALUESOURCE_IDX]);
    if (type == myType) {
        PyErr_SetString(PyExc_NotImplementedError,
            "'QDeclarativePropertyValueSource' represents a C++ abstract class and cannot be instantiated");
        return -1;
    }


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // QDeclarativePropertyValueSource()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new QDeclarativePropertyValueSourceWrapper();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QDeclarativePropertyValueSource >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject* Sbk_QDeclarativePropertyValueSourceFunc_setTarget(PyObject* self, PyObject* arg)
{
    QDeclarativePropertyValueSource* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDeclarativePropertyValueSource* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setTarget(QDeclarativeProperty)
    if (Shiboken::Converter< ::QDeclarativeProperty >::isConvertible(arg)) {
        overloadId = 0; // setTarget(QDeclarativeProperty)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDeclarativePropertyValueSourceFunc_setTarget_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QDeclarativeProperty cppArg0 = Shiboken::Converter<QDeclarativeProperty >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setTarget(QDeclarativeProperty)
                if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self))) {
                    PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QDeclarativePropertyValueSource.setTarget()' not implemented.");
                    return 0;
                }
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setTarget(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QDeclarativePropertyValueSourceFunc_setTarget_TypeError:
        const char* overloads[] = {"PySide.QtDeclarative.QDeclarativeProperty", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtDeclarative.QDeclarativePropertyValueSource.setTarget", overloads);
        return 0;
}

static PyMethodDef Sbk_QDeclarativePropertyValueSource_methods[] = {
    {"setTarget", (PyCFunction)Sbk_QDeclarativePropertyValueSourceFunc_setTarget, METH_O},

    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QDeclarativePropertyValueSource_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtDeclarative.QDeclarativePropertyValueSource",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QDeclarativePropertyValueSource_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QDeclarativePropertyValueSource_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QDeclarativePropertyValueSource(PyObject* module)
{
    SbkPySide_QtDeclarativeTypes[SBK_QDECLARATIVEPROPERTYVALUESOURCE_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QDeclarativePropertyValueSource_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QDeclarativePropertyValueSource_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QDeclarativePropertyValueSource_Type, &Shiboken::callCppDestructor<QDeclarativePropertyValueSource >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QDeclarativePropertyValueSource_Type) < 0)
        return;

    // Fill type discovery information

    Shiboken::ObjectType::setOriginalName(&Sbk_QDeclarativePropertyValueSource_Type, "QDeclarativePropertyValueSource*");
    PyModule_AddObject(module, "QDeclarativePropertyValueSource",
        ((PyObject*)&Sbk_QDeclarativePropertyValueSource_Type));


    Shiboken::TypeResolver::createObjectTypeResolver<QDeclarativePropertyValueSource >("QDeclarativePropertyValueSource*");
    Shiboken::TypeResolver::createObjectTypeResolver<QDeclarativePropertyValueSource >("QDeclarativePropertyValueSource$ConcreteWrapper*");
    Shiboken::TypeResolver::createObjectTypeResolver<QDeclarativePropertyValueSource >(typeid(QDeclarativePropertyValueSource).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QDeclarativePropertyValueSource >(typeid(QDeclarativePropertyValueSourceWrapper).name());
    PySide::initQtMetaType<QDeclarativePropertyValueSource* >();
}

