/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include "pyside_qtgui_python.h"

#include "qapplication_wrapper.h"

// Extra includes
#include <QBasicTimer>
#include <QFont>
#include <QFontMetrics>
#include <QIcon>
#include <QList>
#include <QLocale>
#include <QPalette>
#include <QStringList>
#include <QStyle>
#include <qapplication.h>
#include <qbytearray.h>
#include <qclipboard.h>
#include <qcoreapplication.h>
#include <qcoreevent.h>
#include <qcursor.h>
#include <qdesktopwidget.h>
#include <qfont.h>
#include <qfontmetrics.h>
#include <qicon.h>
#include <qinputcontext.h>
#include <qlocale.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpalette.h>
#include <qpoint.h>
#include <qsessionmanager.h>
#include <qsize.h>
#include <qstyle.h>
#include <qthread.h>
#include <qtranslator.h>
#include <qwidget.h>


// Begin code injection
// ========================================================================
// START of custom code block [file: glue/qapplication_init.cpp]
// Borrowed reference to QtGui module
extern PyObject* moduleQtGui;

static int QApplicationArgCount;
static char** QApplicationArgValues;
static const char QAPP_MACRO[] = "qApp";

int Sbk_QApplication_Init(PyObject* self, PyObject* args, PyObject*)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QApplication>()))
        return -1;

    if (QApplication::instance()) {
        PyErr_SetString(PyExc_RuntimeError, "A QApplication instance already exists.");
        return -1;
    }

    int numArgs = PyTuple_GET_SIZE(args);
    if (numArgs != 1) {
        PyErr_BadArgument();
        return -1;
    }

    if (!Shiboken::sequenceToArgcArgv(PyTuple_GET_ITEM(args, 0), &QApplicationArgCount, &QApplicationArgValues, "PySideApp")) {
        PyErr_BadArgument();
        return -1;
    }

    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);
    QApplicationWrapper* cptr = new QApplicationWrapper(QApplicationArgCount, QApplicationArgValues);
    Shiboken::Object::setCppPointer(sbkSelf,
                                     Shiboken::SbkType<QApplication>(),
                                     cptr);
    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::Object::releaseOwnership(sbkSelf);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);
    PySide::Signal::updateSourceObject(self);
    cptr->metaObject();

    // Verify if qApp is in main module
    PyObject* globalsDict = PyEval_GetGlobals();
    if (globalsDict) {
        PyObject* qAppObj = PyDict_GetItemString(globalsDict, QAPP_MACRO);
        if (qAppObj)
            PyDict_SetItemString(globalsDict, QAPP_MACRO, self);
    }

    PyObject_SetAttrString(moduleQtGui, QAPP_MACRO, self);
    PySide::registerCleanupFunction(&PySide::destroyQCoreApplication);
    Py_INCREF(self);
    return 1;
}

// END of custom code block [file: glue/qapplication_init.cpp]
// ========================================================================

// End of code injection

// Native ---------------------------------------------------------

QApplicationWrapper::QApplicationWrapper(int & argc, char ** argv) : QApplication(argc, argv) {
    // ... middle
}

void QApplicationWrapper::childEvent(QChildEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "childEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::childEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QChildEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QApplicationWrapper::commitData(QSessionManager & sm)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "commitData"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QApplication::commitData(sm);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QSessionManager & >::toPython(sm)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QApplicationWrapper::connectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "connectNotify"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QApplicationWrapper::customEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "customEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::customEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QApplicationWrapper::disconnectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

bool QApplicationWrapper::event(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "event"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QApplication::event(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QApplication.event", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
    return cppResult;
}

bool QApplicationWrapper::eventFilter(QObject * arg__1, QEvent * arg__2)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "eventFilter"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::eventFilter(arg__1, arg__2);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QObject * >::toPython(arg__1),
        Shiboken::Converter< ::QEvent * >::toPython(arg__2)
    ));
    bool invalidadeArg2 = PyTuple_GET_ITEM(pyargs, 1)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QApplication.eventFilter", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    if (invalidadeArg2)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 1));
    return cppResult;
}

bool QApplicationWrapper::notify(QObject * arg__1, QEvent * arg__2)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "notify"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QApplication::notify(arg__1, arg__2);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QObject * >::toPython(arg__1),
        Shiboken::Converter< ::QEvent * >::toPython(arg__2)
    ));
    bool invalidadeArg2 = PyTuple_GET_ITEM(pyargs, 1)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QApplication.notify", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    if (invalidadeArg2)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 1));
    return cppResult;
}

void QApplicationWrapper::saveState(QSessionManager & sm)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "saveState"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QApplication::saveState(sm);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QSessionManager & >::toPython(sm)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QApplicationWrapper::timerEvent(QTimerEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "timerEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::timerEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QTimerEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

const QMetaObject* QApplicationWrapper::metaObject() const
{
    SbkObject* pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    return reinterpret_cast<QMetaObject*>(Shiboken::Object::getTypeUserData(pySelf));
}

int QApplicationWrapper::qt_metacall(QMetaObject::Call call, int id, void** args)
{
    int result = QApplication::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

QApplicationWrapper::~QApplicationWrapper()
{
    SbkObject* wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static PyObject* Sbk_QApplicationFunc_aboutQt(PyObject* self)
{

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // aboutQt()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QApplication::aboutQt();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QApplicationFunc_activeModalWidget(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // activeModalWidget()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QWidget * cppResult = QApplication::activeModalWidget();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QWidget * >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QApplicationFunc_activePopupWidget(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // activePopupWidget()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QWidget * cppResult = QApplication::activePopupWidget();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QWidget * >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QApplicationFunc_activeWindow(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // activeWindow()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QWidget * cppResult = QApplication::activeWindow();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QWidget * >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QApplicationFunc_alert(PyObject* self, PyObject* args, PyObject* kwds)
{
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QApplication.alert(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QApplication.alert(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:alert", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: alert(QWidget*,int)
    if (Shiboken::Converter< ::QWidget * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // alert(QWidget*,int)
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 0; // alert(QWidget*,int)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QApplicationFunc_alert_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "duration");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "duration";
                    else if (SbkNumber_Check(value))
                        pyargs[1] = value;
else
                        goto Sbk_QApplicationFunc_alert_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QApplication.alert(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QWidget * cppArg0 = Shiboken::Converter<QWidget * >::toCpp(pyargs[0]);
            int cppArg1 = pyargs[1] ? Shiboken::Converter<int >::toCpp(pyargs[1]) : 0;

            if(!PyErr_Occurred()) {
                // alert(QWidget*,int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QApplication::alert(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QApplicationFunc_alert_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWidget, int = 0", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QApplication.alert", overloads);
        return 0;
}

static PyObject* Sbk_QApplicationFunc_allWidgets(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // allWidgets()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QList<QWidget * > cppResult = QApplication::allWidgets();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QList<QWidget * > >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QApplicationFunc_autoSipEnabled(PyObject* self)
{
    QApplication* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QApplication* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // autoSipEnabled()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->autoSipEnabled();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QApplicationFunc_beep(PyObject* self)
{

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // beep()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QApplication::beep();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QApplicationFunc_changeOverrideCursor(PyObject* self, PyObject* arg)
{
    int overloadId = -1;

    // Overloaded function decisor
    // 0: changeOverrideCursor(QCursor)
    if (Shiboken::Converter< ::QCursor >::isConvertible(arg)) {
        overloadId = 0; // changeOverrideCursor(QCursor)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QApplicationFunc_changeOverrideCursor_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QCursor cppArg0 = Shiboken::Converter<QCursor >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // changeOverrideCursor(QCursor)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QApplication::changeOverrideCursor(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QApplicationFunc_changeOverrideCursor_TypeError:
        const char* overloads[] = {"PySide.QtGui.QCursor", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QApplication.changeOverrideCursor", overloads);
        return 0;
}

static PyObject* Sbk_QApplicationFunc_clipboard(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // clipboard()

                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QClipboard * cppResult = QApplication::clipboard();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QClipboard * >::toPython(cppResult);

                // Begin code injection
                
                // TEMPLATE - set_qapp_parent_for_orphan - START
                SbkObject* _pySelf = reinterpret_cast<SbkObject*>(pyResult);
                if (!Shiboken::Object::hasParentInfo(_pySelf))
                    Shiboken::Object::setParent(Shiboken::Converter<QApplication* >::toPython(qApp), pyResult);
                // TEMPLATE - set_qapp_parent_for_orphan - END
                
                // End of code injection
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QApplicationFunc_closeAllWindows(PyObject* self)
{

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // closeAllWindows()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QApplication::closeAllWindows();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QApplicationFunc_colorSpec(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // colorSpec()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = QApplication::colorSpec();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QApplicationFunc_commitData(PyObject* self, PyObject* arg)
{
    QApplication* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QApplication* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: commitData(QSessionManager&)
    if (Shiboken::Converter< ::QSessionManager & >::isConvertible(arg)) {
        overloadId = 0; // commitData(QSessionManager&)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QApplicationFunc_commitData_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QSessionManager & cppArg0 = Shiboken::Converter<QSessionManager & >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // commitData(QSessionManager&)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QApplication::commitData(cppArg0):cppSelf->commitData(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QApplicationFunc_commitData_TypeError:
        const char* overloads[] = {"PySide.QtGui.QSessionManager", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QApplication.commitData", overloads);
        return 0;
}

static PyObject* Sbk_QApplicationFunc_cursorFlashTime(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // cursorFlashTime()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = QApplication::cursorFlashTime();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QApplicationFunc_desktop(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // desktop()

                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDesktopWidget * cppResult = QApplication::desktop();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDesktopWidget * >::toPython(cppResult);

                // Begin code injection
                
                // TEMPLATE - set_qapp_parent_for_orphan - START
                SbkObject* _pySelf = reinterpret_cast<SbkObject*>(pyResult);
                if (!Shiboken::Object::hasParentInfo(_pySelf))
                    Shiboken::Object::setParent(Shiboken::Converter<QApplication* >::toPython(qApp), pyResult);
                // TEMPLATE - set_qapp_parent_for_orphan - END
                
                // End of code injection
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QApplicationFunc_desktopSettingsAware(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // desktopSettingsAware()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = QApplication::desktopSettingsAware();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QApplicationFunc_doubleClickInterval(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // doubleClickInterval()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = QApplication::doubleClickInterval();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QApplicationFunc_event(PyObject* self, PyObject* arg)
{
    QApplication* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QApplication* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: event(QEvent*)
    if (Shiboken::Converter< ::QEvent * >::isConvertible(arg)) {
        overloadId = 0; // event(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QApplicationFunc_event_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QEvent * cppArg0 = Shiboken::Converter<QEvent * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // event(QEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QApplication::event(cppArg0):cppSelf->event(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QApplicationFunc_event_TypeError:
        const char* overloads[] = {"PySide.QtCore.QEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QApplication.event", overloads);
        return 0;
}

static PyObject* Sbk_QApplicationFunc_exec_(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // exec()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = QApplication::exec();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QApplicationFunc_focusWidget(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // focusWidget()

                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QWidget * cppResult = QApplication::focusWidget();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QWidget * >::toPython(cppResult);

                // Begin code injection
                
                // TEMPLATE - set_qapp_parent_for_orphan - START
                SbkObject* _pySelf = reinterpret_cast<SbkObject*>(pyResult);
                if (!Shiboken::Object::hasParentInfo(_pySelf))
                    Shiboken::Object::setParent(Shiboken::Converter<QApplication* >::toPython(qApp), pyResult);
                // TEMPLATE - set_qapp_parent_for_orphan - END
                
                // End of code injection
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QApplicationFunc_font(PyObject* self, PyObject* args)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "font", 0, 1, &(pyargs[0])))
        return 0;


    // Overloaded function decisor
    // 0: font()
    // 1: font(const QWidget*)
    if (numArgs == 0) {
        overloadId = 0; // font()
    } else if (numArgs == 1 && Shiboken::Converter< ::QWidget * >::isConvertible(pyargs[0])) {
        overloadId = 1; // font(const QWidget*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QApplicationFunc_font_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // font()
            {

                if(!PyErr_Occurred()) {
                    // font()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QFont cppResult = QApplication::font();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QFont >::toPython(cppResult);
                }
                break;
            }
            case 1: // font(const QWidget*)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QWidget * cppArg0 = Shiboken::Converter<QWidget * >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // font(const QWidget*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QFont cppResult = QApplication::font(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QFont >::toPython(cppResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QApplicationFunc_font_TypeError:
        const char* overloads[] = {"", "PySide.QtGui.QWidget", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QApplication.font", overloads);
        return 0;
}

static PyObject* Sbk_QApplicationFunc_fontMetrics(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // fontMetrics()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QFontMetrics cppResult = QApplication::fontMetrics();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QFontMetrics >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QApplicationFunc_globalStrut(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // globalStrut()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QSize cppResult = QApplication::globalStrut();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QSize >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QApplicationFunc_inputContext(PyObject* self)
{
    QApplication* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QApplication* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // inputContext()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QInputContext * cppResult = cppSelf->inputContext();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QInputContext * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QApplicationFunc_isEffectEnabled(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: isEffectEnabled(Qt::UIEffect)
    if (Shiboken::Converter< ::Qt::UIEffect >::isConvertible(arg)) {
        overloadId = 0; // isEffectEnabled(Qt::UIEffect)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QApplicationFunc_isEffectEnabled_TypeError;

    // Call function/method
    {
        {
            Qt::UIEffect cppArg0 = Shiboken::Converter<Qt::UIEffect >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // isEffectEnabled(Qt::UIEffect)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = QApplication::isEffectEnabled(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QApplicationFunc_isEffectEnabled_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.UIEffect", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QApplication.isEffectEnabled", overloads);
        return 0;
}

static PyObject* Sbk_QApplicationFunc_isLeftToRight(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isLeftToRight()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = QApplication::isLeftToRight();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QApplicationFunc_isRightToLeft(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isRightToLeft()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = QApplication::isRightToLeft();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QApplicationFunc_isSessionRestored(PyObject* self)
{
    QApplication* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QApplication* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isSessionRestored()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->isSessionRestored();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QApplicationFunc_keyboardInputDirection(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // keyboardInputDirection()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                Qt::LayoutDirection cppResult = QApplication::keyboardInputDirection();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::Qt::LayoutDirection >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QApplicationFunc_keyboardInputInterval(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // keyboardInputInterval()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = QApplication::keyboardInputInterval();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QApplicationFunc_keyboardInputLocale(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // keyboardInputLocale()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QLocale cppResult = QApplication::keyboardInputLocale();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QLocale >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QApplicationFunc_keyboardModifiers(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // keyboardModifiers()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QFlags<Qt::KeyboardModifier> cppResult = QApplication::keyboardModifiers();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QFlags<Qt::KeyboardModifier> >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QApplicationFunc_layoutDirection(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // layoutDirection()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                Qt::LayoutDirection cppResult = QApplication::layoutDirection();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::Qt::LayoutDirection >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QApplicationFunc_mouseButtons(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // mouseButtons()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QFlags<Qt::MouseButton> cppResult = QApplication::mouseButtons();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QFlags<Qt::MouseButton> >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QApplicationFunc_notify(PyObject* self, PyObject* args)
{
    QApplication* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QApplication* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "notify", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: notify(QObject*,QEvent*)
    if (numArgs == 2 && Shiboken::Converter< ::QObject * >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QEvent * >::isConvertible(pyargs[1])) {
        overloadId = 0; // notify(QObject*,QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QApplicationFunc_notify_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QObject * cppArg0 = Shiboken::Converter<QObject * >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QEvent * cppArg1 = Shiboken::Converter<QEvent * >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // notify(QObject*,QEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QApplication::notify(cppArg0, cppArg1):cppSelf->notify(cppArg0, cppArg1));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QApplicationFunc_notify_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject, PySide.QtCore.QEvent", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QApplication.notify", overloads);
        return 0;
}

static PyObject* Sbk_QApplicationFunc_overrideCursor(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // overrideCursor()

                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QCursor * cppResult = QApplication::overrideCursor();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QCursor * >::toPython(cppResult);

                // Begin code injection
                
                // TEMPLATE - set_qapp_parent_for_orphan - START
                SbkObject* _pySelf = reinterpret_cast<SbkObject*>(pyResult);
                if (!Shiboken::Object::hasParentInfo(_pySelf))
                    Shiboken::Object::setParent(Shiboken::Converter<QApplication* >::toPython(qApp), pyResult);
                // TEMPLATE - set_qapp_parent_for_orphan - END
                
                // End of code injection
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QApplicationFunc_palette(PyObject* self, PyObject* args)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "palette", 0, 1, &(pyargs[0])))
        return 0;


    // Overloaded function decisor
    // 0: palette()
    // 1: palette(const QWidget*)
    if (numArgs == 0) {
        overloadId = 0; // palette()
    } else if (numArgs == 1 && Shiboken::Converter< ::QWidget * >::isConvertible(pyargs[0])) {
        overloadId = 1; // palette(const QWidget*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QApplicationFunc_palette_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // palette()
            {

                if(!PyErr_Occurred()) {
                    // palette()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QPalette cppResult = QApplication::palette();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QPalette >::toPython(cppResult);
                }
                break;
            }
            case 1: // palette(const QWidget*)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QWidget * cppArg0 = Shiboken::Converter<QWidget * >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // palette(const QWidget*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QPalette cppResult = QApplication::palette(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QPalette >::toPython(cppResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QApplicationFunc_palette_TypeError:
        const char* overloads[] = {"", "PySide.QtGui.QWidget", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QApplication.palette", overloads);
        return 0;
}

static PyObject* Sbk_QApplicationFunc_quitOnLastWindowClosed(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // quitOnLastWindowClosed()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = QApplication::quitOnLastWindowClosed();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QApplicationFunc_restoreOverrideCursor(PyObject* self)
{

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // restoreOverrideCursor()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QApplication::restoreOverrideCursor();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QApplicationFunc_saveState(PyObject* self, PyObject* arg)
{
    QApplication* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QApplication* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: saveState(QSessionManager&)
    if (Shiboken::Converter< ::QSessionManager & >::isConvertible(arg)) {
        overloadId = 0; // saveState(QSessionManager&)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QApplicationFunc_saveState_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QSessionManager & cppArg0 = Shiboken::Converter<QSessionManager & >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // saveState(QSessionManager&)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QApplication::saveState(cppArg0):cppSelf->saveState(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QApplicationFunc_saveState_TypeError:
        const char* overloads[] = {"PySide.QtGui.QSessionManager", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QApplication.saveState", overloads);
        return 0;
}

static PyObject* Sbk_QApplicationFunc_sessionId(PyObject* self)
{
    QApplication* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QApplication* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // sessionId()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = cppSelf->sessionId();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QApplicationFunc_sessionKey(PyObject* self)
{
    QApplication* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QApplication* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // sessionKey()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = cppSelf->sessionKey();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QApplicationFunc_setActiveWindow(PyObject* self, PyObject* arg)
{
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setActiveWindow(QWidget*)
    if (Shiboken::Converter< ::QWidget * >::isConvertible(arg)) {
        overloadId = 0; // setActiveWindow(QWidget*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QApplicationFunc_setActiveWindow_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QWidget * cppArg0 = Shiboken::Converter<QWidget * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setActiveWindow(QWidget*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QApplication::setActiveWindow(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QApplicationFunc_setActiveWindow_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWidget", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QApplication.setActiveWindow", overloads);
        return 0;
}

static PyObject* Sbk_QApplicationFunc_setAutoSipEnabled(PyObject* self, PyObject* arg)
{
    QApplication* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QApplication* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setAutoSipEnabled(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setAutoSipEnabled(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QApplicationFunc_setAutoSipEnabled_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setAutoSipEnabled(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setAutoSipEnabled(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QApplicationFunc_setAutoSipEnabled_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QApplication.setAutoSipEnabled", overloads);
        return 0;
}

static PyObject* Sbk_QApplicationFunc_setColorSpec(PyObject* self, PyObject* arg)
{
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setColorSpec(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setColorSpec(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QApplicationFunc_setColorSpec_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setColorSpec(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QApplication::setColorSpec(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QApplicationFunc_setColorSpec_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QApplication.setColorSpec", overloads);
        return 0;
}

static PyObject* Sbk_QApplicationFunc_setCursorFlashTime(PyObject* self, PyObject* arg)
{
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setCursorFlashTime(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setCursorFlashTime(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QApplicationFunc_setCursorFlashTime_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setCursorFlashTime(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QApplication::setCursorFlashTime(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QApplicationFunc_setCursorFlashTime_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QApplication.setCursorFlashTime", overloads);
        return 0;
}

static PyObject* Sbk_QApplicationFunc_setDesktopSettingsAware(PyObject* self, PyObject* arg)
{
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDesktopSettingsAware(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setDesktopSettingsAware(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QApplicationFunc_setDesktopSettingsAware_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setDesktopSettingsAware(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QApplication::setDesktopSettingsAware(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QApplicationFunc_setDesktopSettingsAware_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QApplication.setDesktopSettingsAware", overloads);
        return 0;
}

static PyObject* Sbk_QApplicationFunc_setDoubleClickInterval(PyObject* self, PyObject* arg)
{
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDoubleClickInterval(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setDoubleClickInterval(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QApplicationFunc_setDoubleClickInterval_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setDoubleClickInterval(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QApplication::setDoubleClickInterval(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QApplicationFunc_setDoubleClickInterval_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QApplication.setDoubleClickInterval", overloads);
        return 0;
}

static PyObject* Sbk_QApplicationFunc_setEffectEnabled(PyObject* self, PyObject* args, PyObject* kwds)
{
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QApplication.setEffectEnabled(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QApplication.setEffectEnabled(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:setEffectEnabled", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setEffectEnabled(Qt::UIEffect,bool)
    if (Shiboken::Converter< ::Qt::UIEffect >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // setEffectEnabled(Qt::UIEffect,bool)
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 0; // setEffectEnabled(Qt::UIEffect,bool)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QApplicationFunc_setEffectEnabled_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "enable");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "enable";
                    else if (SbkNumber_Check(value))
                        pyargs[1] = value;
else
                        goto Sbk_QApplicationFunc_setEffectEnabled_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QApplication.setEffectEnabled(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            Qt::UIEffect cppArg0 = Shiboken::Converter<Qt::UIEffect >::toCpp(pyargs[0]);
            bool cppArg1 = pyargs[1] ? Shiboken::Converter<bool >::toCpp(pyargs[1]) : true;

            if(!PyErr_Occurred()) {
                // setEffectEnabled(Qt::UIEffect,bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QApplication::setEffectEnabled(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QApplicationFunc_setEffectEnabled_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.UIEffect, bool = true", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QApplication.setEffectEnabled", overloads);
        return 0;
}

static PyObject* Sbk_QApplicationFunc_setGlobalStrut(PyObject* self, PyObject* arg)
{
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setGlobalStrut(QSize)
    if (Shiboken::Converter< ::QSize >::isConvertible(arg)) {
        overloadId = 0; // setGlobalStrut(QSize)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QApplicationFunc_setGlobalStrut_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QSize cppArg0 = Shiboken::Converter<QSize >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setGlobalStrut(QSize)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QApplication::setGlobalStrut(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QApplicationFunc_setGlobalStrut_TypeError:
        const char* overloads[] = {"PySide.QtCore.QSize", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QApplication.setGlobalStrut", overloads);
        return 0;
}

static PyObject* Sbk_QApplicationFunc_setGraphicsSystem(PyObject* self, PyObject* arg)
{
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setGraphicsSystem(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // setGraphicsSystem(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QApplicationFunc_setGraphicsSystem_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setGraphicsSystem(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QApplication::setGraphicsSystem(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QApplicationFunc_setGraphicsSystem_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QApplication.setGraphicsSystem", overloads);
        return 0;
}

static PyObject* Sbk_QApplicationFunc_setInputContext(PyObject* self, PyObject* arg)
{
    QApplication* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QApplication* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setInputContext(QInputContext*)
    if (Shiboken::Converter< ::QInputContext * >::isConvertible(arg)) {
        overloadId = 0; // setInputContext(QInputContext*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QApplicationFunc_setInputContext_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QInputContext * cppArg0 = Shiboken::Converter<QInputContext * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setInputContext(QInputContext*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setInputContext(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QApplicationFunc_setInputContext_TypeError:
        const char* overloads[] = {"PySide.QtGui.QInputContext", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QApplication.setInputContext", overloads);
        return 0;
}

static PyObject* Sbk_QApplicationFunc_setKeyboardInputInterval(PyObject* self, PyObject* arg)
{
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setKeyboardInputInterval(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setKeyboardInputInterval(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QApplicationFunc_setKeyboardInputInterval_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setKeyboardInputInterval(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QApplication::setKeyboardInputInterval(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QApplicationFunc_setKeyboardInputInterval_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QApplication.setKeyboardInputInterval", overloads);
        return 0;
}

static PyObject* Sbk_QApplicationFunc_setLayoutDirection(PyObject* self, PyObject* arg)
{
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setLayoutDirection(Qt::LayoutDirection)
    if (Shiboken::Converter< ::Qt::LayoutDirection >::isConvertible(arg)) {
        overloadId = 0; // setLayoutDirection(Qt::LayoutDirection)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QApplicationFunc_setLayoutDirection_TypeError;

    // Call function/method
    {
        {
            Qt::LayoutDirection cppArg0 = Shiboken::Converter<Qt::LayoutDirection >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setLayoutDirection(Qt::LayoutDirection)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QApplication::setLayoutDirection(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QApplicationFunc_setLayoutDirection_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.LayoutDirection", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QApplication.setLayoutDirection", overloads);
        return 0;
}

static PyObject* Sbk_QApplicationFunc_setOverrideCursor(PyObject* self, PyObject* arg)
{
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setOverrideCursor(QCursor)
    if (Shiboken::Converter< ::QCursor >::isConvertible(arg)) {
        overloadId = 0; // setOverrideCursor(QCursor)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QApplicationFunc_setOverrideCursor_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QCursor cppArg0 = Shiboken::Converter<QCursor >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setOverrideCursor(QCursor)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QApplication::setOverrideCursor(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QApplicationFunc_setOverrideCursor_TypeError:
        const char* overloads[] = {"PySide.QtGui.QCursor", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QApplication.setOverrideCursor", overloads);
        return 0;
}

static PyObject* Sbk_QApplicationFunc_setPalette(PyObject* self, PyObject* args, PyObject* kwds)
{
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QApplication.setPalette(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QApplication.setPalette(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:setPalette", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setPalette(QPalette,const char*)
    if (Shiboken::Converter< ::QPalette >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // setPalette(QPalette,const char*)
        } else if (Shiboken::Converter< const char * >::isConvertible(pyargs[1])) {
            overloadId = 0; // setPalette(QPalette,const char*)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QApplicationFunc_setPalette_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "className");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "className";
                    else if (Shiboken::Converter< const char * >::isConvertible(value))
                        pyargs[1] = value;
else
                        goto Sbk_QApplicationFunc_setPalette_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QApplication.setPalette(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QPalette cppArg0 = Shiboken::Converter<QPalette >::toCpp(pyargs[0]);
            const char * cppArg1 = pyargs[1] ? Shiboken::Converter<const char * >::toCpp(pyargs[1]) : 0;

            if(!PyErr_Occurred()) {
                // setPalette(QPalette,const char*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QApplication::setPalette(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QApplicationFunc_setPalette_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPalette, str = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QApplication.setPalette", overloads);
        return 0;
}

static PyObject* Sbk_QApplicationFunc_setQuitOnLastWindowClosed(PyObject* self, PyObject* arg)
{
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setQuitOnLastWindowClosed(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setQuitOnLastWindowClosed(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QApplicationFunc_setQuitOnLastWindowClosed_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setQuitOnLastWindowClosed(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QApplication::setQuitOnLastWindowClosed(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QApplicationFunc_setQuitOnLastWindowClosed_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QApplication.setQuitOnLastWindowClosed", overloads);
        return 0;
}

static PyObject* Sbk_QApplicationFunc_setStartDragDistance(PyObject* self, PyObject* arg)
{
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setStartDragDistance(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setStartDragDistance(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QApplicationFunc_setStartDragDistance_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setStartDragDistance(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QApplication::setStartDragDistance(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QApplicationFunc_setStartDragDistance_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QApplication.setStartDragDistance", overloads);
        return 0;
}

static PyObject* Sbk_QApplicationFunc_setStartDragTime(PyObject* self, PyObject* arg)
{
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setStartDragTime(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setStartDragTime(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QApplicationFunc_setStartDragTime_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setStartDragTime(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QApplication::setStartDragTime(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QApplicationFunc_setStartDragTime_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QApplication.setStartDragTime", overloads);
        return 0;
}

static PyObject* Sbk_QApplicationFunc_setStyle(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setStyle(QStyle*)
    // 1: setStyle(QString)
    if (Shiboken::Converter< ::QStyle * >::isConvertible(arg)) {
        overloadId = 0; // setStyle(QStyle*)
    } else if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 1; // setStyle(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QApplicationFunc_setStyle_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setStyle(QStyle*)
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QStyle * cppArg0 = Shiboken::Converter<QStyle * >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // setStyle(QStyle*)

                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QApplication::setStyle(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS

                    // Begin code injection
                    
                    Shiboken::Object::setParent(Shiboken::Converter<QApplication* >::toPython(qApp), arg);
                    
                    // End of code injection
                    pyResult = Py_None;
                    Py_INCREF(Py_None);
                }
                break;
            }
            case 1: // setStyle(QString)
            {
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // setStyle(QString)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QStyle * cppResult = QApplication::setStyle(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QStyle * >::toPython(cppResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QApplicationFunc_setStyle_TypeError:
        const char* overloads[] = {"PySide.QtGui.QStyle", "QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QApplication.setStyle", overloads);
        return 0;
}

static PyObject* Sbk_QApplicationFunc_setStyleSheet(PyObject* self, PyObject* arg)
{
    QApplication* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QApplication* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setStyleSheet(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // setStyleSheet(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QApplicationFunc_setStyleSheet_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setStyleSheet(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setStyleSheet(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QApplicationFunc_setStyleSheet_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QApplication.setStyleSheet", overloads);
        return 0;
}

static PyObject* Sbk_QApplicationFunc_setWheelScrollLines(PyObject* self, PyObject* arg)
{
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setWheelScrollLines(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setWheelScrollLines(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QApplicationFunc_setWheelScrollLines_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setWheelScrollLines(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QApplication::setWheelScrollLines(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QApplicationFunc_setWheelScrollLines_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QApplication.setWheelScrollLines", overloads);
        return 0;
}

static PyObject* Sbk_QApplicationFunc_setWindowIcon(PyObject* self, PyObject* arg)
{
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setWindowIcon(QIcon)
    if (Shiboken::Converter< ::QIcon >::isConvertible(arg)) {
        overloadId = 0; // setWindowIcon(QIcon)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QApplicationFunc_setWindowIcon_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QIcon cppArg0 = Shiboken::Converter<QIcon >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setWindowIcon(QIcon)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QApplication::setWindowIcon(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QApplicationFunc_setWindowIcon_TypeError:
        const char* overloads[] = {"PySide.QtGui.QIcon", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QApplication.setWindowIcon", overloads);
        return 0;
}

static PyObject* Sbk_QApplicationFunc_startDragDistance(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // startDragDistance()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = QApplication::startDragDistance();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QApplicationFunc_startDragTime(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // startDragTime()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = QApplication::startDragTime();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QApplicationFunc_style(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // style()

                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QStyle * cppResult = QApplication::style();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QStyle * >::toPython(cppResult);

                // Begin code injection
                
                // TEMPLATE - set_qapp_parent_for_orphan - START
                SbkObject* _pySelf = reinterpret_cast<SbkObject*>(pyResult);
                if (!Shiboken::Object::hasParentInfo(_pySelf))
                    Shiboken::Object::setParent(Shiboken::Converter<QApplication* >::toPython(qApp), pyResult);
                // TEMPLATE - set_qapp_parent_for_orphan - END
                
                // End of code injection
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QApplicationFunc_styleSheet(PyObject* self)
{
    QApplication* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QApplication* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // styleSheet()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = cppSelf->styleSheet();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QApplicationFunc_syncX(PyObject* self)
{

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // syncX()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QApplication::syncX();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QApplicationFunc_topLevelAt(PyObject* self, PyObject* args)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "topLevelAt", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: topLevelAt(QPoint)
    // 1: topLevelAt(int,int)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 1; // topLevelAt(int,int)
    } else if (numArgs == 1 && Shiboken::Converter< ::QPoint >::isConvertible(pyargs[0])) {
        overloadId = 0; // topLevelAt(QPoint)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QApplicationFunc_topLevelAt_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // topLevelAt(QPoint)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QPoint cppArg0 = Shiboken::Converter<QPoint >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // topLevelAt(QPoint)

                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QWidget * cppResult = QApplication::topLevelAt(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QWidget * >::toPython(cppResult);

                    // Begin code injection
                    
                    // TEMPLATE - set_qapp_parent_for_orphan - START
                    SbkObject* _pySelf = reinterpret_cast<SbkObject*>(pyResult);
                    if (!Shiboken::Object::hasParentInfo(_pySelf))
                        Shiboken::Object::setParent(Shiboken::Converter<QApplication* >::toPython(qApp), pyResult);
                    // TEMPLATE - set_qapp_parent_for_orphan - END
                    
                    // End of code injection
                }
                break;
            }
            case 1: // topLevelAt(int,int)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // topLevelAt(int,int)

                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QWidget * cppResult = QApplication::topLevelAt(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QWidget * >::toPython(cppResult);

                    // Begin code injection
                    
                    // TEMPLATE - set_qapp_parent_for_orphan - START
                    SbkObject* _pySelf = reinterpret_cast<SbkObject*>(pyResult);
                    if (!Shiboken::Object::hasParentInfo(_pySelf))
                        Shiboken::Object::setParent(Shiboken::Converter<QApplication* >::toPython(qApp), pyResult);
                    // TEMPLATE - set_qapp_parent_for_orphan - END
                    
                    // End of code injection
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QApplicationFunc_topLevelAt_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint", "int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QApplication.topLevelAt", overloads);
        return 0;
}

static PyObject* Sbk_QApplicationFunc_topLevelWidgets(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // topLevelWidgets()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QList<QWidget * > cppResult = QApplication::topLevelWidgets();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QList<QWidget * > >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QApplicationFunc_type(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // type()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QApplication::Type cppResult = QApplication::type();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QApplication::Type >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QApplicationFunc_wheelScrollLines(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // wheelScrollLines()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = QApplication::wheelScrollLines();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QApplicationFunc_widgetAt(PyObject* self, PyObject* args)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "widgetAt", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: widgetAt(QPoint)
    // 1: widgetAt(int,int)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 1; // widgetAt(int,int)
    } else if (numArgs == 1 && Shiboken::Converter< ::QPoint >::isConvertible(pyargs[0])) {
        overloadId = 0; // widgetAt(QPoint)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QApplicationFunc_widgetAt_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // widgetAt(QPoint)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QPoint cppArg0 = Shiboken::Converter<QPoint >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // widgetAt(QPoint)

                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QWidget * cppResult = QApplication::widgetAt(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QWidget * >::toPython(cppResult);

                    // Begin code injection
                    
                    // TEMPLATE - set_qapp_parent_for_orphan - START
                    SbkObject* _pySelf = reinterpret_cast<SbkObject*>(pyResult);
                    if (!Shiboken::Object::hasParentInfo(_pySelf))
                        Shiboken::Object::setParent(Shiboken::Converter<QApplication* >::toPython(qApp), pyResult);
                    // TEMPLATE - set_qapp_parent_for_orphan - END
                    
                    // End of code injection
                }
                break;
            }
            case 1: // widgetAt(int,int)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // widgetAt(int,int)

                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QWidget * cppResult = QApplication::widgetAt(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QWidget * >::toPython(cppResult);

                    // Begin code injection
                    
                    // TEMPLATE - set_qapp_parent_for_orphan - START
                    SbkObject* _pySelf = reinterpret_cast<SbkObject*>(pyResult);
                    if (!Shiboken::Object::hasParentInfo(_pySelf))
                        Shiboken::Object::setParent(Shiboken::Converter<QApplication* >::toPython(qApp), pyResult);
                    // TEMPLATE - set_qapp_parent_for_orphan - END
                    
                    // End of code injection
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QApplicationFunc_widgetAt_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint", "int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QApplication.widgetAt", overloads);
        return 0;
}

static PyObject* Sbk_QApplicationFunc_windowIcon(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // windowIcon()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QIcon cppResult = QApplication::windowIcon();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QIcon >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef Sbk_QApplication_methods[] = {
    {"aboutQt", (PyCFunction)Sbk_QApplicationFunc_aboutQt, METH_NOARGS|METH_STATIC},
    {"activeModalWidget", (PyCFunction)Sbk_QApplicationFunc_activeModalWidget, METH_NOARGS|METH_STATIC},
    {"activePopupWidget", (PyCFunction)Sbk_QApplicationFunc_activePopupWidget, METH_NOARGS|METH_STATIC},
    {"activeWindow", (PyCFunction)Sbk_QApplicationFunc_activeWindow, METH_NOARGS|METH_STATIC},
    {"alert", (PyCFunction)Sbk_QApplicationFunc_alert, METH_VARARGS|METH_KEYWORDS|METH_STATIC},
    {"allWidgets", (PyCFunction)Sbk_QApplicationFunc_allWidgets, METH_NOARGS|METH_STATIC},
    {"autoSipEnabled", (PyCFunction)Sbk_QApplicationFunc_autoSipEnabled, METH_NOARGS},
    {"beep", (PyCFunction)Sbk_QApplicationFunc_beep, METH_NOARGS|METH_STATIC},
    {"changeOverrideCursor", (PyCFunction)Sbk_QApplicationFunc_changeOverrideCursor, METH_O|METH_STATIC},
    {"clipboard", (PyCFunction)Sbk_QApplicationFunc_clipboard, METH_NOARGS|METH_STATIC},
    {"closeAllWindows", (PyCFunction)Sbk_QApplicationFunc_closeAllWindows, METH_NOARGS|METH_STATIC},
    {"colorSpec", (PyCFunction)Sbk_QApplicationFunc_colorSpec, METH_NOARGS|METH_STATIC},
    {"commitData", (PyCFunction)Sbk_QApplicationFunc_commitData, METH_O},
    {"cursorFlashTime", (PyCFunction)Sbk_QApplicationFunc_cursorFlashTime, METH_NOARGS|METH_STATIC},
    {"desktop", (PyCFunction)Sbk_QApplicationFunc_desktop, METH_NOARGS|METH_STATIC},
    {"desktopSettingsAware", (PyCFunction)Sbk_QApplicationFunc_desktopSettingsAware, METH_NOARGS|METH_STATIC},
    {"doubleClickInterval", (PyCFunction)Sbk_QApplicationFunc_doubleClickInterval, METH_NOARGS|METH_STATIC},
    {"event", (PyCFunction)Sbk_QApplicationFunc_event, METH_O},
    {"exec_", (PyCFunction)Sbk_QApplicationFunc_exec_, METH_NOARGS|METH_STATIC},
    {"focusWidget", (PyCFunction)Sbk_QApplicationFunc_focusWidget, METH_NOARGS|METH_STATIC},
    {"font", (PyCFunction)Sbk_QApplicationFunc_font, METH_VARARGS|METH_STATIC},
    {"fontMetrics", (PyCFunction)Sbk_QApplicationFunc_fontMetrics, METH_NOARGS|METH_STATIC},
    {"globalStrut", (PyCFunction)Sbk_QApplicationFunc_globalStrut, METH_NOARGS|METH_STATIC},
    {"inputContext", (PyCFunction)Sbk_QApplicationFunc_inputContext, METH_NOARGS},
    {"isEffectEnabled", (PyCFunction)Sbk_QApplicationFunc_isEffectEnabled, METH_O|METH_STATIC},
    {"isLeftToRight", (PyCFunction)Sbk_QApplicationFunc_isLeftToRight, METH_NOARGS|METH_STATIC},
    {"isRightToLeft", (PyCFunction)Sbk_QApplicationFunc_isRightToLeft, METH_NOARGS|METH_STATIC},
    {"isSessionRestored", (PyCFunction)Sbk_QApplicationFunc_isSessionRestored, METH_NOARGS},
    {"keyboardInputDirection", (PyCFunction)Sbk_QApplicationFunc_keyboardInputDirection, METH_NOARGS|METH_STATIC},
    {"keyboardInputInterval", (PyCFunction)Sbk_QApplicationFunc_keyboardInputInterval, METH_NOARGS|METH_STATIC},
    {"keyboardInputLocale", (PyCFunction)Sbk_QApplicationFunc_keyboardInputLocale, METH_NOARGS|METH_STATIC},
    {"keyboardModifiers", (PyCFunction)Sbk_QApplicationFunc_keyboardModifiers, METH_NOARGS|METH_STATIC},
    {"layoutDirection", (PyCFunction)Sbk_QApplicationFunc_layoutDirection, METH_NOARGS|METH_STATIC},
    {"mouseButtons", (PyCFunction)Sbk_QApplicationFunc_mouseButtons, METH_NOARGS|METH_STATIC},
    {"notify", (PyCFunction)Sbk_QApplicationFunc_notify, METH_VARARGS},
    {"overrideCursor", (PyCFunction)Sbk_QApplicationFunc_overrideCursor, METH_NOARGS|METH_STATIC},
    {"palette", (PyCFunction)Sbk_QApplicationFunc_palette, METH_VARARGS|METH_STATIC},
    {"quitOnLastWindowClosed", (PyCFunction)Sbk_QApplicationFunc_quitOnLastWindowClosed, METH_NOARGS|METH_STATIC},
    {"restoreOverrideCursor", (PyCFunction)Sbk_QApplicationFunc_restoreOverrideCursor, METH_NOARGS|METH_STATIC},
    {"saveState", (PyCFunction)Sbk_QApplicationFunc_saveState, METH_O},
    {"sessionId", (PyCFunction)Sbk_QApplicationFunc_sessionId, METH_NOARGS},
    {"sessionKey", (PyCFunction)Sbk_QApplicationFunc_sessionKey, METH_NOARGS},
    {"setActiveWindow", (PyCFunction)Sbk_QApplicationFunc_setActiveWindow, METH_O|METH_STATIC},
    {"setAutoSipEnabled", (PyCFunction)Sbk_QApplicationFunc_setAutoSipEnabled, METH_O},
    {"setColorSpec", (PyCFunction)Sbk_QApplicationFunc_setColorSpec, METH_O|METH_STATIC},
    {"setCursorFlashTime", (PyCFunction)Sbk_QApplicationFunc_setCursorFlashTime, METH_O|METH_STATIC},
    {"setDesktopSettingsAware", (PyCFunction)Sbk_QApplicationFunc_setDesktopSettingsAware, METH_O|METH_STATIC},
    {"setDoubleClickInterval", (PyCFunction)Sbk_QApplicationFunc_setDoubleClickInterval, METH_O|METH_STATIC},
    {"setEffectEnabled", (PyCFunction)Sbk_QApplicationFunc_setEffectEnabled, METH_VARARGS|METH_KEYWORDS|METH_STATIC},
    {"setGlobalStrut", (PyCFunction)Sbk_QApplicationFunc_setGlobalStrut, METH_O|METH_STATIC},
    {"setGraphicsSystem", (PyCFunction)Sbk_QApplicationFunc_setGraphicsSystem, METH_O|METH_STATIC},
    {"setInputContext", (PyCFunction)Sbk_QApplicationFunc_setInputContext, METH_O},
    {"setKeyboardInputInterval", (PyCFunction)Sbk_QApplicationFunc_setKeyboardInputInterval, METH_O|METH_STATIC},
    {"setLayoutDirection", (PyCFunction)Sbk_QApplicationFunc_setLayoutDirection, METH_O|METH_STATIC},
    {"setOverrideCursor", (PyCFunction)Sbk_QApplicationFunc_setOverrideCursor, METH_O|METH_STATIC},
    {"setPalette", (PyCFunction)Sbk_QApplicationFunc_setPalette, METH_VARARGS|METH_KEYWORDS|METH_STATIC},
    {"setQuitOnLastWindowClosed", (PyCFunction)Sbk_QApplicationFunc_setQuitOnLastWindowClosed, METH_O|METH_STATIC},
    {"setStartDragDistance", (PyCFunction)Sbk_QApplicationFunc_setStartDragDistance, METH_O|METH_STATIC},
    {"setStartDragTime", (PyCFunction)Sbk_QApplicationFunc_setStartDragTime, METH_O|METH_STATIC},
    {"setStyle", (PyCFunction)Sbk_QApplicationFunc_setStyle, METH_O|METH_STATIC},
    {"setStyleSheet", (PyCFunction)Sbk_QApplicationFunc_setStyleSheet, METH_O},
    {"setWheelScrollLines", (PyCFunction)Sbk_QApplicationFunc_setWheelScrollLines, METH_O|METH_STATIC},
    {"setWindowIcon", (PyCFunction)Sbk_QApplicationFunc_setWindowIcon, METH_O|METH_STATIC},
    {"startDragDistance", (PyCFunction)Sbk_QApplicationFunc_startDragDistance, METH_NOARGS|METH_STATIC},
    {"startDragTime", (PyCFunction)Sbk_QApplicationFunc_startDragTime, METH_NOARGS|METH_STATIC},
    {"style", (PyCFunction)Sbk_QApplicationFunc_style, METH_NOARGS|METH_STATIC},
    {"styleSheet", (PyCFunction)Sbk_QApplicationFunc_styleSheet, METH_NOARGS},
    {"syncX", (PyCFunction)Sbk_QApplicationFunc_syncX, METH_NOARGS|METH_STATIC},
    {"topLevelAt", (PyCFunction)Sbk_QApplicationFunc_topLevelAt, METH_VARARGS|METH_STATIC},
    {"topLevelWidgets", (PyCFunction)Sbk_QApplicationFunc_topLevelWidgets, METH_NOARGS|METH_STATIC},
    {"type", (PyCFunction)Sbk_QApplicationFunc_type, METH_NOARGS|METH_STATIC},
    {"wheelScrollLines", (PyCFunction)Sbk_QApplicationFunc_wheelScrollLines, METH_NOARGS|METH_STATIC},
    {"widgetAt", (PyCFunction)Sbk_QApplicationFunc_widgetAt, METH_VARARGS|METH_STATIC},
    {"windowIcon", (PyCFunction)Sbk_QApplicationFunc_windowIcon, METH_NOARGS|METH_STATIC},

    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QApplication_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QApplication",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QApplication_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QApplication_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern

static SbkObjectType* Sbk_QApplication_typeDiscovery(void* cptr, SbkObjectType* instanceType)
{
    if (instanceType == reinterpret_cast<SbkObjectType*>(Shiboken::SbkType<QObject >()) && dynamic_cast<QApplication*>(reinterpret_cast<QObject*>(cptr)))
        return &Sbk_QApplication_Type;
    return 0;
}


void init_QApplication(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QAPPLICATION_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QApplication_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QApplication_Type);
    Shiboken::ObjectType::setSubTypeInitHook(&Sbk_QApplication_Type, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(&Sbk_QApplication_Type, &QApplication::staticMetaObject);
    Sbk_QApplication_Type.super.ht_type.tp_base = SbkPySide_QtCoreTypes[SBK_QCOREAPPLICATION_IDX];
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QApplication_Type, &Shiboken::callCppDestructor<QApplication >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QApplication_Type) < 0)
        return;

    // Fill type discovery information
    Shiboken::ObjectType::setTypeDiscoveryFunction(&Sbk_QApplication_Type, &Sbk_QApplication_typeDiscovery);
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkObjectType*>(SbkPySide_QtCoreTypes[SBK_QCOREAPPLICATION_IDX]), &Sbk_QApplication_Type);

    Shiboken::ObjectType::setOriginalName(&Sbk_QApplication_Type, "QApplication*");
    PyModule_AddObject(module, "QApplication",
        ((PyObject*)&Sbk_QApplication_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: Type
    PyTypeObject* SbkPySide_QtGui_QApplication_Type = Shiboken::Enum::newType("Type");
    SbkPySide_QtGuiTypes[SBK_QAPPLICATION_TYPE_IDX] = SbkPySide_QtGui_QApplication_Type;
    if (PyType_Ready(SbkPySide_QtGui_QApplication_Type) < 0)
        return;
    PyDict_SetItemString(Sbk_QApplication_Type.super.ht_type.tp_dict,
            "Type",((PyObject*)SbkPySide_QtGui_QApplication_Type));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QApplication_Type,(long) QApplication::Tty, "Tty");
    PyDict_SetItemString(Sbk_QApplication_Type.super.ht_type.tp_dict,"Tty", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QApplication_Type->tp_dict,"Tty", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QApplication_Type,(long) QApplication::GuiClient, "GuiClient");
    PyDict_SetItemString(Sbk_QApplication_Type.super.ht_type.tp_dict,"GuiClient", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QApplication_Type->tp_dict,"GuiClient", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QApplication_Type,(long) QApplication::GuiServer, "GuiServer");
    PyDict_SetItemString(Sbk_QApplication_Type.super.ht_type.tp_dict,"GuiServer", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QApplication_Type->tp_dict,"GuiServer", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QApplication::Type");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::Type");
    // end of enum Type

    // init enum: ColorSpec
    PyTypeObject* SbkPySide_QtGui_QApplication_ColorSpec = Shiboken::Enum::newType("ColorSpec");
    SbkPySide_QtGuiTypes[SBK_QAPPLICATION_COLORSPEC_IDX] = SbkPySide_QtGui_QApplication_ColorSpec;
    if (PyType_Ready(SbkPySide_QtGui_QApplication_ColorSpec) < 0)
        return;
    PyDict_SetItemString(Sbk_QApplication_Type.super.ht_type.tp_dict,
            "ColorSpec",((PyObject*)SbkPySide_QtGui_QApplication_ColorSpec));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QApplication_ColorSpec,(long) QApplication::NormalColor, "NormalColor");
    PyDict_SetItemString(Sbk_QApplication_Type.super.ht_type.tp_dict,"NormalColor", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QApplication_ColorSpec->tp_dict,"NormalColor", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QApplication_ColorSpec,(long) QApplication::CustomColor, "CustomColor");
    PyDict_SetItemString(Sbk_QApplication_Type.super.ht_type.tp_dict,"CustomColor", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QApplication_ColorSpec->tp_dict,"CustomColor", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QApplication_ColorSpec,(long) QApplication::ManyColor, "ManyColor");
    PyDict_SetItemString(Sbk_QApplication_Type.super.ht_type.tp_dict,"ManyColor", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QApplication_ColorSpec->tp_dict,"ManyColor", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QApplication::ColorSpec");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::ColorSpec");
    // end of enum ColorSpec

    // Initialize signals
    PySideSignal* signal_item;

    signal_item = PySide::Signal::newObject("focusChanged", "QWidget*,QWidget*", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QApplication_Type, "focusChanged", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("commitDataRequest", "QSessionManager&", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QApplication_Type, "commitDataRequest", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("lastWindowClosed", "void", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QApplication_Type, "lastWindowClosed", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("fontDatabaseChanged", "void", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QApplication_Type, "fontDatabaseChanged", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("saveStateRequest", "QSessionManager&", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QApplication_Type, "saveStateRequest", signal_item);
    Py_DECREF((PyObject*) signal_item);



    Shiboken::TypeResolver::createObjectTypeResolver<QApplication >("QApplication*");
    Shiboken::TypeResolver::createObjectTypeResolver<QApplication >(typeid(QApplication).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QApplication >(typeid(QApplicationWrapper).name());
    PySide::initQtMetaType<QApplication* >();
}


