/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include "pyside_qtgui_python.h"

#include "qcleanlooksstyle_wrapper.h"

// Extra includes
#include <QList>
#include <qapplication.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qicon.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpainter.h>
#include <qpalette.h>
#include <qpixmap.h>
#include <qpoint.h>
#include <qrect.h>
#include <qsize.h>
#include <qstyle.h>
#include <qstyleoption.h>
#include <qthread.h>
#include <qwidget.h>
#include <qwindowsstyle.h>


// Native ---------------------------------------------------------

QCleanlooksStyleWrapper::QCleanlooksStyleWrapper() : QCleanlooksStyle() {
    // ... middle
}

void QCleanlooksStyleWrapper::childEvent(QChildEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "childEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::childEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QChildEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QCleanlooksStyleWrapper::connectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "connectNotify"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QCleanlooksStyleWrapper::customEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "customEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::customEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QCleanlooksStyleWrapper::disconnectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QCleanlooksStyleWrapper::drawComplexControl(QStyle::ComplexControl control, const QStyleOptionComplex * option, QPainter * painter, const QWidget * widget) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "drawComplexControl"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QCleanlooksStyle::drawComplexControl(control, option, painter, widget);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NNNN)",
        Shiboken::Converter< ::QStyle::ComplexControl >::toPython(control),
        Shiboken::Converter< ::QStyleOptionComplex * >::toPython(option),
        Shiboken::Converter< ::QPainter * >::toPython(painter),
        Shiboken::Converter< ::QWidget * >::toPython(widget)
    ));
    bool invalidadeArg3 = PyTuple_GET_ITEM(pyargs, 2)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg3)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 2));
}

void QCleanlooksStyleWrapper::drawControl(QStyle::ControlElement ce, const QStyleOption * option, QPainter * painter, const QWidget * widget) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "drawControl"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QCleanlooksStyle::drawControl(ce, option, painter, widget);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NNNN)",
        Shiboken::Converter< ::QStyle::ControlElement >::toPython(ce),
        Shiboken::Converter< ::QStyleOption * >::toPython(option),
        Shiboken::Converter< ::QPainter * >::toPython(painter),
        Shiboken::Converter< ::QWidget * >::toPython(widget)
    ));
    bool invalidadeArg3 = PyTuple_GET_ITEM(pyargs, 2)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg3)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 2));
}

void QCleanlooksStyleWrapper::drawItemPixmap(QPainter * painter, const QRect & rect, int alignment, const QPixmap & pixmap) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "drawItemPixmap"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QCleanlooksStyle::drawItemPixmap(painter, rect, alignment, pixmap);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NNiN)",
        Shiboken::Converter< ::QPainter * >::toPython(painter),
        Shiboken::Converter< ::QRect >::toPython(rect),
        alignment,
        Shiboken::Converter< ::QPixmap >::toPython(pixmap)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QCleanlooksStyleWrapper::drawItemText(QPainter * painter, const QRect & rect, int flags, const QPalette & pal, bool enabled, const QString & text, QPalette::ColorRole textRole) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "drawItemText"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QCleanlooksStyle::drawItemText(painter, rect, flags, pal, enabled, text, textRole);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NNiNNNN)",
        Shiboken::Converter< ::QPainter * >::toPython(painter),
        Shiboken::Converter< ::QRect >::toPython(rect),
        flags,
        Shiboken::Converter< ::QPalette >::toPython(pal),
        Shiboken::Converter< bool >::toPython(enabled),
        Shiboken::Converter< QString >::toPython(text),
        Shiboken::Converter< ::QPalette::ColorRole >::toPython(textRole)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QCleanlooksStyleWrapper::drawPrimitive(QStyle::PrimitiveElement elem, const QStyleOption * option, QPainter * painter, const QWidget * widget) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "drawPrimitive"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QCleanlooksStyle::drawPrimitive(elem, option, painter, widget);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NNNN)",
        Shiboken::Converter< ::QStyle::PrimitiveElement >::toPython(elem),
        Shiboken::Converter< ::QStyleOption * >::toPython(option),
        Shiboken::Converter< ::QPainter * >::toPython(painter),
        Shiboken::Converter< ::QWidget * >::toPython(widget)
    ));
    bool invalidadeArg3 = PyTuple_GET_ITEM(pyargs, 2)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg3)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 2));
}

bool QCleanlooksStyleWrapper::event(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "event"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::event(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QCleanlooksStyle.event", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
    return cppResult;
}

bool QCleanlooksStyleWrapper::eventFilter(QObject * o, QEvent * e)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "eventFilter"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWindowsStyle::eventFilter(o, e);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QObject * >::toPython(o),
        Shiboken::Converter< ::QEvent * >::toPython(e)
    ));
    bool invalidadeArg2 = PyTuple_GET_ITEM(pyargs, 1)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QCleanlooksStyle.eventFilter", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    if (invalidadeArg2)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 1));
    return cppResult;
}

QPixmap QCleanlooksStyleWrapper::generatedIconPixmap(QIcon::Mode iconMode, const QPixmap & pixmap, const QStyleOption * opt) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "generatedIconPixmap"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QCleanlooksStyle::generatedIconPixmap(iconMode, pixmap, opt);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NNN)",
        Shiboken::Converter< ::QIcon::Mode >::toPython(iconMode),
        Shiboken::Converter< ::QPixmap >::toPython(pixmap),
        Shiboken::Converter< ::QStyleOption * >::toPython(opt)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QPixmap();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QPixmap >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QCleanlooksStyle.generatedIconPixmap", Shiboken::SbkType<QPixmap >()->tp_name, pyResult->ob_type->tp_name);
        return QPixmap();
    }
    QPixmap cppResult(Shiboken::Converter< ::QPixmap >::toCpp(pyResult));
    return cppResult;
}

QStyle::SubControl QCleanlooksStyleWrapper::hitTestComplexControl(QStyle::ComplexControl cc, const QStyleOptionComplex * opt, const QPoint & pt, const QWidget * w) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "hitTestComplexControl"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QCleanlooksStyle::hitTestComplexControl(cc, opt, pt, w);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NNNN)",
        Shiboken::Converter< ::QStyle::ComplexControl >::toPython(cc),
        Shiboken::Converter< ::QStyleOptionComplex * >::toPython(opt),
        Shiboken::Converter< ::QPoint >::toPython(pt),
        Shiboken::Converter< ::QWidget * >::toPython(w)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QStyle::SubControl();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QStyle::SubControl >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QCleanlooksStyle.hitTestComplexControl", Shiboken::SbkType<QStyle::SubControl >()->tp_name, pyResult->ob_type->tp_name);
        return QStyle::SubControl();
    }
    QStyle::SubControl cppResult(Shiboken::Converter< ::QStyle::SubControl >::toCpp(pyResult));
    return cppResult;
}

QRect QCleanlooksStyleWrapper::itemPixmapRect(const QRect & r, int flags, const QPixmap & pixmap) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "itemPixmapRect"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QCleanlooksStyle::itemPixmapRect(r, flags, pixmap);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NiN)",
        Shiboken::Converter< ::QRect >::toPython(r),
        flags,
        Shiboken::Converter< ::QPixmap >::toPython(pixmap)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QRect();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QRect >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QCleanlooksStyle.itemPixmapRect", Shiboken::SbkType<QRect >()->tp_name, pyResult->ob_type->tp_name);
        return QRect();
    }
    QRect cppResult(Shiboken::Converter< ::QRect >::toCpp(pyResult));
    return cppResult;
}

int QCleanlooksStyleWrapper::pixelMetric(QStyle::PixelMetric metric, const QStyleOption * option, const QWidget * widget) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "pixelMetric"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QCleanlooksStyle::pixelMetric(metric, option, widget);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NNN)",
        Shiboken::Converter< ::QStyle::PixelMetric >::toPython(metric),
        Shiboken::Converter< ::QStyleOption * >::toPython(option),
        Shiboken::Converter< ::QWidget * >::toPython(widget)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QCleanlooksStyle.pixelMetric", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter< int >::toCpp(pyResult));
    return cppResult;
}

void QCleanlooksStyleWrapper::polish(QApplication * app)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "polish"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QCleanlooksStyle::polish(app);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QApplication * >::toPython(app)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QCleanlooksStyleWrapper::polish(QPalette & pal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "polish"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QCleanlooksStyle::polish(pal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QPalette & >::toPython(pal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QCleanlooksStyleWrapper::polish(QWidget * widget)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "polish"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QCleanlooksStyle::polish(widget);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QWidget * >::toPython(widget)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

QSize QCleanlooksStyleWrapper::sizeFromContents(QStyle::ContentsType type, const QStyleOption * option, const QSize & size, const QWidget * widget) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "sizeFromContents"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QCleanlooksStyle::sizeFromContents(type, option, size, widget);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NNNN)",
        Shiboken::Converter< ::QStyle::ContentsType >::toPython(type),
        Shiboken::Converter< ::QStyleOption * >::toPython(option),
        Shiboken::Converter< ::QSize >::toPython(size),
        Shiboken::Converter< ::QWidget * >::toPython(widget)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QSize();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QSize >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QCleanlooksStyle.sizeFromContents", Shiboken::SbkType<QSize >()->tp_name, pyResult->ob_type->tp_name);
        return QSize();
    }
    QSize cppResult(Shiboken::Converter< ::QSize >::toCpp(pyResult));
    return cppResult;
}

QPalette QCleanlooksStyleWrapper::standardPalette() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "standardPalette"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QCleanlooksStyle::standardPalette();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QPalette();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QPalette >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QCleanlooksStyle.standardPalette", Shiboken::SbkType<QPalette >()->tp_name, pyResult->ob_type->tp_name);
        return QPalette();
    }
    QPalette cppResult(Shiboken::Converter< ::QPalette >::toCpp(pyResult));
    return cppResult;
}

QPixmap QCleanlooksStyleWrapper::standardPixmap(QStyle::StandardPixmap standardPixmap, const QStyleOption * opt, const QWidget * widget) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "standardPixmap"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QCleanlooksStyle.standardPixmap()' not implemented.");
        return QPixmap();
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NNN)",
        Shiboken::Converter< ::QStyle::StandardPixmap >::toPython(standardPixmap),
        Shiboken::Converter< ::QStyleOption * >::toPython(opt),
        Shiboken::Converter< ::QWidget * >::toPython(widget)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QPixmap();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QPixmap >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QCleanlooksStyle.standardPixmap", Shiboken::SbkType<QPixmap >()->tp_name, pyResult->ob_type->tp_name);
        return QPixmap();
    }
    QPixmap cppResult(Shiboken::Converter< ::QPixmap >::toCpp(pyResult));
    return cppResult;
}

int QCleanlooksStyleWrapper::styleHint(QStyle::StyleHint hint, const QStyleOption * option, const QWidget * widget, QStyleHintReturn * returnData) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "styleHint"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QCleanlooksStyle::styleHint(hint, option, widget, returnData);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NNNN)",
        Shiboken::Converter< ::QStyle::StyleHint >::toPython(hint),
        Shiboken::Converter< ::QStyleOption * >::toPython(option),
        Shiboken::Converter< ::QWidget * >::toPython(widget),
        Shiboken::Converter< ::QStyleHintReturn * >::toPython(returnData)
    ));
    bool invalidadeArg4 = PyTuple_GET_ITEM(pyargs, 3)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QCleanlooksStyle.styleHint", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter< int >::toCpp(pyResult));
    if (invalidadeArg4)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 3));
    return cppResult;
}

QRect QCleanlooksStyleWrapper::subControlRect(QStyle::ComplexControl cc, const QStyleOptionComplex * opt, QStyle::SubControl sc, const QWidget * widget) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "subControlRect"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QCleanlooksStyle::subControlRect(cc, opt, sc, widget);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NNNN)",
        Shiboken::Converter< ::QStyle::ComplexControl >::toPython(cc),
        Shiboken::Converter< ::QStyleOptionComplex * >::toPython(opt),
        Shiboken::Converter< ::QStyle::SubControl >::toPython(sc),
        Shiboken::Converter< ::QWidget * >::toPython(widget)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QRect();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QRect >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QCleanlooksStyle.subControlRect", Shiboken::SbkType<QRect >()->tp_name, pyResult->ob_type->tp_name);
        return QRect();
    }
    QRect cppResult(Shiboken::Converter< ::QRect >::toCpp(pyResult));
    return cppResult;
}

QRect QCleanlooksStyleWrapper::subElementRect(QStyle::SubElement r, const QStyleOption * opt, const QWidget * widget) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "subElementRect"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QCleanlooksStyle::subElementRect(r, opt, widget);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NNN)",
        Shiboken::Converter< ::QStyle::SubElement >::toPython(r),
        Shiboken::Converter< ::QStyleOption * >::toPython(opt),
        Shiboken::Converter< ::QWidget * >::toPython(widget)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QRect();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QRect >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QCleanlooksStyle.subElementRect", Shiboken::SbkType<QRect >()->tp_name, pyResult->ob_type->tp_name);
        return QRect();
    }
    QRect cppResult(Shiboken::Converter< ::QRect >::toCpp(pyResult));
    return cppResult;
}

void QCleanlooksStyleWrapper::timerEvent(QTimerEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "timerEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWindowsStyle::timerEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QTimerEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QCleanlooksStyleWrapper::unpolish(QApplication * app)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "unpolish"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QCleanlooksStyle::unpolish(app);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QApplication * >::toPython(app)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QCleanlooksStyleWrapper::unpolish(QWidget * widget)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "unpolish"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QCleanlooksStyle::unpolish(widget);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QWidget * >::toPython(widget)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

const QMetaObject* QCleanlooksStyleWrapper::metaObject() const
{
    SbkObject* pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    return reinterpret_cast<QMetaObject*>(Shiboken::Object::getTypeUserData(pySelf));
}

int QCleanlooksStyleWrapper::qt_metacall(QMetaObject::Call call, int id, void** args)
{
    int result = QCleanlooksStyle::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

QCleanlooksStyleWrapper::~QCleanlooksStyleWrapper()
{
    SbkObject* wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QCleanlooksStyle_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QCleanlooksStyle >()))
        return -1;

    QCleanlooksStyleWrapper* cptr = 0;
    const char** argNames = 0;
    const QMetaObject* metaObject;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);
    SbkObjectType* type = reinterpret_cast<SbkObjectType*>(self->ob_type);
    SbkObjectType* myType = reinterpret_cast<SbkObjectType*>(SbkPySide_QtGuiTypes[SBK_QCLEANLOOKSSTYLE_IDX]);
    if (type == myType) {
        PyErr_SetString(PyExc_NotImplementedError,
            "'QCleanlooksStyle' represents a C++ abstract class and cannot be instantiated");
        return -1;
    }


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // QCleanlooksStyle()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new QCleanlooksStyleWrapper();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QCleanlooksStyle >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    metaObject = cptr->metaObject(); // <- init python qt properties
    if (kwds && !PySide::fillQtProperties(self, metaObject, kwds, argNames, 0))
        return -1;


    return 1;
}

static PyObject* Sbk_QCleanlooksStyleFunc_drawComplexControl(PyObject* self, PyObject* args)
{
    QCleanlooksStyle* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QCleanlooksStyle* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "drawComplexControl", 4, 4, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: drawComplexControl(QStyle::ComplexControl,const QStyleOptionComplex*,QPainter*,const QWidget*)const
    if (numArgs == 4 && Shiboken::Converter< ::QStyle::ComplexControl >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QStyleOptionComplex * >::isConvertible(pyargs[1]) && Shiboken::Converter< ::QPainter * >::isConvertible(pyargs[2]) && Shiboken::Converter< ::QWidget * >::isConvertible(pyargs[3])) {
        overloadId = 0; // drawComplexControl(QStyle::ComplexControl,const QStyleOptionComplex*,QPainter*,const QWidget*)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QCleanlooksStyleFunc_drawComplexControl_TypeError;

    // Call function/method
    {
        {
            QStyle::ComplexControl cppArg0 = Shiboken::Converter<QStyle::ComplexControl >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QStyleOptionComplex * cppArg1 = Shiboken::Converter<QStyleOptionComplex * >::toCpp(pyargs[1]);
            if (!Shiboken::Object::isValid(pyargs[2]))
                return 0;
            QPainter * cppArg2 = Shiboken::Converter<QPainter * >::toCpp(pyargs[2]);
            if (!Shiboken::Object::isValid(pyargs[3]))
                return 0;
            QWidget * cppArg3 = Shiboken::Converter<QWidget * >::toCpp(pyargs[3]);

            if(!PyErr_Occurred()) {
                // drawComplexControl(QStyle::ComplexControl,const QStyleOptionComplex*,QPainter*,const QWidget*)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QCleanlooksStyle::drawComplexControl(cppArg0, cppArg1, cppArg2, cppArg3):cppSelf->drawComplexControl(cppArg0, cppArg1, cppArg2, cppArg3));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QCleanlooksStyleFunc_drawComplexControl_TypeError:
        const char* overloads[] = {"PySide.QtGui.QStyle.ComplexControl, PySide.QtGui.QStyleOptionComplex, PySide.QtGui.QPainter, PySide.QtGui.QWidget", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QCleanlooksStyle.drawComplexControl", overloads);
        return 0;
}

static PyObject* Sbk_QCleanlooksStyleFunc_drawControl(PyObject* self, PyObject* args)
{
    QCleanlooksStyle* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QCleanlooksStyle* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "drawControl", 4, 4, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: drawControl(QStyle::ControlElement,const QStyleOption*,QPainter*,const QWidget*)const
    if (numArgs == 4 && Shiboken::Converter< ::QStyle::ControlElement >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QStyleOption * >::isConvertible(pyargs[1]) && Shiboken::Converter< ::QPainter * >::isConvertible(pyargs[2]) && Shiboken::Converter< ::QWidget * >::isConvertible(pyargs[3])) {
        overloadId = 0; // drawControl(QStyle::ControlElement,const QStyleOption*,QPainter*,const QWidget*)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QCleanlooksStyleFunc_drawControl_TypeError;

    // Call function/method
    {
        {
            QStyle::ControlElement cppArg0 = Shiboken::Converter<QStyle::ControlElement >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QStyleOption * cppArg1 = Shiboken::Converter<QStyleOption * >::toCpp(pyargs[1]);
            if (!Shiboken::Object::isValid(pyargs[2]))
                return 0;
            QPainter * cppArg2 = Shiboken::Converter<QPainter * >::toCpp(pyargs[2]);
            if (!Shiboken::Object::isValid(pyargs[3]))
                return 0;
            QWidget * cppArg3 = Shiboken::Converter<QWidget * >::toCpp(pyargs[3]);

            if(!PyErr_Occurred()) {
                // drawControl(QStyle::ControlElement,const QStyleOption*,QPainter*,const QWidget*)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QCleanlooksStyle::drawControl(cppArg0, cppArg1, cppArg2, cppArg3):cppSelf->drawControl(cppArg0, cppArg1, cppArg2, cppArg3));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QCleanlooksStyleFunc_drawControl_TypeError:
        const char* overloads[] = {"PySide.QtGui.QStyle.ControlElement, PySide.QtGui.QStyleOption, PySide.QtGui.QPainter, PySide.QtGui.QWidget", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QCleanlooksStyle.drawControl", overloads);
        return 0;
}

static PyObject* Sbk_QCleanlooksStyleFunc_drawItemPixmap(PyObject* self, PyObject* args)
{
    QCleanlooksStyle* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QCleanlooksStyle* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "drawItemPixmap", 4, 4, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: drawItemPixmap(QPainter*,QRect,int,QPixmap)const
    if (numArgs == 4 && Shiboken::Converter< ::QPainter * >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QRect >::isConvertible(pyargs[1]) && SbkNumber_Check(pyargs[2]) && Shiboken::Converter< ::QPixmap >::isConvertible(pyargs[3])) {
        overloadId = 0; // drawItemPixmap(QPainter*,QRect,int,QPixmap)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QCleanlooksStyleFunc_drawItemPixmap_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QPainter * cppArg0 = Shiboken::Converter<QPainter * >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QRect cppArg1 = Shiboken::Converter<QRect >::toCpp(pyargs[1]);
            int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
            if (!Shiboken::Object::isValid(pyargs[3]))
                return 0;
            QPixmap cppArg3 = Shiboken::Converter<QPixmap >::toCpp(pyargs[3]);

            if(!PyErr_Occurred()) {
                // drawItemPixmap(QPainter*,QRect,int,QPixmap)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QCleanlooksStyle::drawItemPixmap(cppArg0, cppArg1, cppArg2, cppArg3):cppSelf->drawItemPixmap(cppArg0, cppArg1, cppArg2, cppArg3));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QCleanlooksStyleFunc_drawItemPixmap_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPainter, PySide.QtCore.QRect, int, PySide.QtGui.QPixmap", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QCleanlooksStyle.drawItemPixmap", overloads);
        return 0;
}

static PyObject* Sbk_QCleanlooksStyleFunc_drawItemText(PyObject* self, PyObject* args, PyObject* kwds)
{
    QCleanlooksStyle* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QCleanlooksStyle* >::toCpp(self);

    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 7) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QCleanlooksStyle.drawItemText(): too many arguments");
        return 0;
    } else if (numArgs < 6) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QCleanlooksStyle.drawItemText(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOOOOO:drawItemText", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4]), &(pyargs[5]), &(pyargs[6])))
        return 0;


    // Overloaded function decisor
    // 0: drawItemText(QPainter*,QRect,int,QPalette,bool,QString,QPalette::ColorRole)const
    if (numArgs >= 6 && Shiboken::Converter< ::QPainter * >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QRect >::isConvertible(pyargs[1]) && SbkNumber_Check(pyargs[2]) && Shiboken::Converter< ::QPalette >::isConvertible(pyargs[3]) && SbkNumber_Check(pyargs[4]) && Shiboken::Converter< QString >::isConvertible(pyargs[5])) {
        if (numArgs == 6) {
            overloadId = 0; // drawItemText(QPainter*,QRect,int,QPalette,bool,QString,QPalette::ColorRole)const
        } else if (Shiboken::Converter< ::QPalette::ColorRole >::isConvertible(pyargs[6])) {
            overloadId = 0; // drawItemText(QPainter*,QRect,int,QPalette,bool,QString,QPalette::ColorRole)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QCleanlooksStyleFunc_drawItemText_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "textRole");
                if (value) {
                    if (pyargs[6])
                        errorArgName = "textRole";
                    else if (Shiboken::Converter< ::QPalette::ColorRole >::isConvertible(value))
                        pyargs[6] = value;
else
                        goto Sbk_QCleanlooksStyleFunc_drawItemText_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QCleanlooksStyle.drawItemText(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QPainter * cppArg0 = Shiboken::Converter<QPainter * >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QRect cppArg1 = Shiboken::Converter<QRect >::toCpp(pyargs[1]);
            int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
            if (!Shiboken::Object::isValid(pyargs[3]))
                return 0;
            QPalette cppArg3 = Shiboken::Converter<QPalette >::toCpp(pyargs[3]);
            bool cppArg4 = Shiboken::Converter<bool >::toCpp(pyargs[4]);
            QString cppArg5 = Shiboken::Converter<QString >::toCpp(pyargs[5]);
            QPalette::ColorRole cppArg6 = pyargs[6] ? Shiboken::Converter<QPalette::ColorRole >::toCpp(pyargs[6]) : QPalette::NoRole;

            if(!PyErr_Occurred()) {
                // drawItemText(QPainter*,QRect,int,QPalette,bool,QString,QPalette::ColorRole)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QCleanlooksStyle::drawItemText(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5, cppArg6):cppSelf->drawItemText(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5, cppArg6));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QCleanlooksStyleFunc_drawItemText_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPainter, PySide.QtCore.QRect, int, PySide.QtGui.QPalette, bool, QString, PySide.QtGui.QPalette.ColorRole = QPalette.NoRole", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QCleanlooksStyle.drawItemText", overloads);
        return 0;
}

static PyObject* Sbk_QCleanlooksStyleFunc_drawPrimitive(PyObject* self, PyObject* args, PyObject* kwds)
{
    QCleanlooksStyle* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QCleanlooksStyle* >::toCpp(self);

    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 4) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QCleanlooksStyle.drawPrimitive(): too many arguments");
        return 0;
    } else if (numArgs < 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QCleanlooksStyle.drawPrimitive(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOO:drawPrimitive", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: drawPrimitive(QStyle::PrimitiveElement,const QStyleOption*,QPainter*,const QWidget*)const
    if (numArgs >= 3 && Shiboken::Converter< ::QStyle::PrimitiveElement >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QStyleOption * >::isConvertible(pyargs[1]) && Shiboken::Converter< ::QPainter * >::isConvertible(pyargs[2])) {
        if (numArgs == 3) {
            overloadId = 0; // drawPrimitive(QStyle::PrimitiveElement,const QStyleOption*,QPainter*,const QWidget*)const
        } else if (Shiboken::Converter< ::QWidget * >::isConvertible(pyargs[3])) {
            overloadId = 0; // drawPrimitive(QStyle::PrimitiveElement,const QStyleOption*,QPainter*,const QWidget*)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QCleanlooksStyleFunc_drawPrimitive_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "widget");
                if (value) {
                    if (pyargs[3])
                        errorArgName = "widget";
                    else if (Shiboken::Converter< ::QWidget * >::isConvertible(value))
                        pyargs[3] = value;
else
                        goto Sbk_QCleanlooksStyleFunc_drawPrimitive_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QCleanlooksStyle.drawPrimitive(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QStyle::PrimitiveElement cppArg0 = Shiboken::Converter<QStyle::PrimitiveElement >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QStyleOption * cppArg1 = Shiboken::Converter<QStyleOption * >::toCpp(pyargs[1]);
            if (!Shiboken::Object::isValid(pyargs[2]))
                return 0;
            QPainter * cppArg2 = Shiboken::Converter<QPainter * >::toCpp(pyargs[2]);
            if (!Shiboken::Object::isValid(pyargs[3]))
                return 0;
            QWidget * cppArg3 = pyargs[3] ? Shiboken::Converter<QWidget * >::toCpp(pyargs[3]) : 0;

            if(!PyErr_Occurred()) {
                // drawPrimitive(QStyle::PrimitiveElement,const QStyleOption*,QPainter*,const QWidget*)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QCleanlooksStyle::drawPrimitive(cppArg0, cppArg1, cppArg2, cppArg3):cppSelf->drawPrimitive(cppArg0, cppArg1, cppArg2, cppArg3));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QCleanlooksStyleFunc_drawPrimitive_TypeError:
        const char* overloads[] = {"PySide.QtGui.QStyle.PrimitiveElement, PySide.QtGui.QStyleOption, PySide.QtGui.QPainter, PySide.QtGui.QWidget = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QCleanlooksStyle.drawPrimitive", overloads);
        return 0;
}

static PyObject* Sbk_QCleanlooksStyleFunc_generatedIconPixmap(PyObject* self, PyObject* args)
{
    QCleanlooksStyle* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QCleanlooksStyle* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "generatedIconPixmap", 3, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: generatedIconPixmap(QIcon::Mode,QPixmap,const QStyleOption*)const
    if (numArgs == 3 && Shiboken::Converter< ::QIcon::Mode >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QPixmap >::isConvertible(pyargs[1]) && Shiboken::Converter< ::QStyleOption * >::isConvertible(pyargs[2])) {
        overloadId = 0; // generatedIconPixmap(QIcon::Mode,QPixmap,const QStyleOption*)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QCleanlooksStyleFunc_generatedIconPixmap_TypeError;

    // Call function/method
    {
        {
            QIcon::Mode cppArg0 = Shiboken::Converter<QIcon::Mode >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QPixmap cppArg1 = Shiboken::Converter<QPixmap >::toCpp(pyargs[1]);
            if (!Shiboken::Object::isValid(pyargs[2]))
                return 0;
            QStyleOption * cppArg2 = Shiboken::Converter<QStyleOption * >::toCpp(pyargs[2]);

            if(!PyErr_Occurred()) {
                // generatedIconPixmap(QIcon::Mode,QPixmap,const QStyleOption*)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPixmap cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QCleanlooksStyle::generatedIconPixmap(cppArg0, cppArg1, cppArg2):cppSelf->generatedIconPixmap(cppArg0, cppArg1, cppArg2));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPixmap >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QCleanlooksStyleFunc_generatedIconPixmap_TypeError:
        const char* overloads[] = {"PySide.QtGui.QIcon.Mode, PySide.QtGui.QPixmap, PySide.QtGui.QStyleOption", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QCleanlooksStyle.generatedIconPixmap", overloads);
        return 0;
}

static PyObject* Sbk_QCleanlooksStyleFunc_hitTestComplexControl(PyObject* self, PyObject* args, PyObject* kwds)
{
    QCleanlooksStyle* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QCleanlooksStyle* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 4) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QCleanlooksStyle.hitTestComplexControl(): too many arguments");
        return 0;
    } else if (numArgs < 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QCleanlooksStyle.hitTestComplexControl(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOO:hitTestComplexControl", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: hitTestComplexControl(QStyle::ComplexControl,const QStyleOptionComplex*,QPoint,const QWidget*)const
    if (numArgs >= 3 && Shiboken::Converter< ::QStyle::ComplexControl >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QStyleOptionComplex * >::isConvertible(pyargs[1]) && Shiboken::Converter< ::QPoint >::isConvertible(pyargs[2])) {
        if (numArgs == 3) {
            overloadId = 0; // hitTestComplexControl(QStyle::ComplexControl,const QStyleOptionComplex*,QPoint,const QWidget*)const
        } else if (Shiboken::Converter< ::QWidget * >::isConvertible(pyargs[3])) {
            overloadId = 0; // hitTestComplexControl(QStyle::ComplexControl,const QStyleOptionComplex*,QPoint,const QWidget*)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QCleanlooksStyleFunc_hitTestComplexControl_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "w");
                if (value) {
                    if (pyargs[3])
                        errorArgName = "w";
                    else if (Shiboken::Converter< ::QWidget * >::isConvertible(value))
                        pyargs[3] = value;
else
                        goto Sbk_QCleanlooksStyleFunc_hitTestComplexControl_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QCleanlooksStyle.hitTestComplexControl(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QStyle::ComplexControl cppArg0 = Shiboken::Converter<QStyle::ComplexControl >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QStyleOptionComplex * cppArg1 = Shiboken::Converter<QStyleOptionComplex * >::toCpp(pyargs[1]);
            if (!Shiboken::Object::isValid(pyargs[2]))
                return 0;
            QPoint cppArg2 = Shiboken::Converter<QPoint >::toCpp(pyargs[2]);
            if (!Shiboken::Object::isValid(pyargs[3]))
                return 0;
            QWidget * cppArg3 = pyargs[3] ? Shiboken::Converter<QWidget * >::toCpp(pyargs[3]) : 0;

            if(!PyErr_Occurred()) {
                // hitTestComplexControl(QStyle::ComplexControl,const QStyleOptionComplex*,QPoint,const QWidget*)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QStyle::SubControl cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QCleanlooksStyle::hitTestComplexControl(cppArg0, cppArg1, cppArg2, cppArg3):cppSelf->hitTestComplexControl(cppArg0, cppArg1, cppArg2, cppArg3));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QStyle::SubControl >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QCleanlooksStyleFunc_hitTestComplexControl_TypeError:
        const char* overloads[] = {"PySide.QtGui.QStyle.ComplexControl, PySide.QtGui.QStyleOptionComplex, PySide.QtCore.QPoint, PySide.QtGui.QWidget = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QCleanlooksStyle.hitTestComplexControl", overloads);
        return 0;
}

static PyObject* Sbk_QCleanlooksStyleFunc_itemPixmapRect(PyObject* self, PyObject* args)
{
    QCleanlooksStyle* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QCleanlooksStyle* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "itemPixmapRect", 3, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: itemPixmapRect(QRect,int,QPixmap)const
    if (numArgs == 3 && Shiboken::Converter< ::QRect >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1]) && Shiboken::Converter< ::QPixmap >::isConvertible(pyargs[2])) {
        overloadId = 0; // itemPixmapRect(QRect,int,QPixmap)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QCleanlooksStyleFunc_itemPixmapRect_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QRect cppArg0 = Shiboken::Converter<QRect >::toCpp(pyargs[0]);
            int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
            if (!Shiboken::Object::isValid(pyargs[2]))
                return 0;
            QPixmap cppArg2 = Shiboken::Converter<QPixmap >::toCpp(pyargs[2]);

            if(!PyErr_Occurred()) {
                // itemPixmapRect(QRect,int,QPixmap)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QRect cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QCleanlooksStyle::itemPixmapRect(cppArg0, cppArg1, cppArg2):cppSelf->itemPixmapRect(cppArg0, cppArg1, cppArg2));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QRect >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QCleanlooksStyleFunc_itemPixmapRect_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRect, int, PySide.QtGui.QPixmap", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QCleanlooksStyle.itemPixmapRect", overloads);
        return 0;
}

static PyObject* Sbk_QCleanlooksStyleFunc_pixelMetric(PyObject* self, PyObject* args, PyObject* kwds)
{
    QCleanlooksStyle* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QCleanlooksStyle* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QCleanlooksStyle.pixelMetric(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QCleanlooksStyle.pixelMetric(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:pixelMetric", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: pixelMetric(QStyle::PixelMetric,const QStyleOption*,const QWidget*)const
    if (Shiboken::Converter< ::QStyle::PixelMetric >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // pixelMetric(QStyle::PixelMetric,const QStyleOption*,const QWidget*)const
        } else if (Shiboken::Converter< ::QStyleOption * >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 0; // pixelMetric(QStyle::PixelMetric,const QStyleOption*,const QWidget*)const
            } else if (Shiboken::Converter< ::QWidget * >::isConvertible(pyargs[2])) {
                overloadId = 0; // pixelMetric(QStyle::PixelMetric,const QStyleOption*,const QWidget*)const
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QCleanlooksStyleFunc_pixelMetric_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "option");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "option";
                    else if (Shiboken::Converter< ::QStyleOption * >::isConvertible(value))
                        pyargs[1] = value;
else
                        goto Sbk_QCleanlooksStyleFunc_pixelMetric_TypeError;
                }
                value = PyDict_GetItemString(kwds, "widget");
                if (value) {
                    if (pyargs[2])
                        errorArgName = "widget";
                    else if (Shiboken::Converter< ::QWidget * >::isConvertible(value))
                        pyargs[2] = value;
else
                        goto Sbk_QCleanlooksStyleFunc_pixelMetric_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QCleanlooksStyle.pixelMetric(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QStyle::PixelMetric cppArg0 = Shiboken::Converter<QStyle::PixelMetric >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QStyleOption * cppArg1 = pyargs[1] ? Shiboken::Converter<QStyleOption * >::toCpp(pyargs[1]) : 0;
            if (!Shiboken::Object::isValid(pyargs[2]))
                return 0;
            QWidget * cppArg2 = pyargs[2] ? Shiboken::Converter<QWidget * >::toCpp(pyargs[2]) : 0;

            if(!PyErr_Occurred()) {
                // pixelMetric(QStyle::PixelMetric,const QStyleOption*,const QWidget*)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QCleanlooksStyle::pixelMetric(cppArg0, cppArg1, cppArg2):cppSelf->pixelMetric(cppArg0, cppArg1, cppArg2));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QCleanlooksStyleFunc_pixelMetric_TypeError:
        const char* overloads[] = {"PySide.QtGui.QStyle.PixelMetric, PySide.QtGui.QStyleOption = None, PySide.QtGui.QWidget = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QCleanlooksStyle.pixelMetric", overloads);
        return 0;
}

static PyObject* Sbk_QCleanlooksStyleFunc_polish(PyObject* self, PyObject* arg)
{
    QCleanlooksStyle* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QCleanlooksStyle* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: polish(QApplication*)
    // 1: polish(QPalette&)
    // 2: polish(QWidget*)
    if (Shiboken::Converter< ::QWidget * >::isConvertible(arg)) {
        overloadId = 2; // polish(QWidget*)
    } else if (Shiboken::Converter< ::QPalette & >::isConvertible(arg)) {
        overloadId = 1; // polish(QPalette&)
    } else if (Shiboken::Converter< ::QApplication * >::isConvertible(arg)) {
        overloadId = 0; // polish(QApplication*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QCleanlooksStyleFunc_polish_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // polish(QApplication*)
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QApplication * cppArg0 = Shiboken::Converter<QApplication * >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // polish(QApplication*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    (Shiboken::Object::isUserType(self) ? cppSelf->::QCleanlooksStyle::polish(cppArg0):cppSelf->polish(cppArg0));
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // polish(QPalette&)
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QPalette & cppArg0 = Shiboken::Converter<QPalette & >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // polish(QPalette&)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    (Shiboken::Object::isUserType(self) ? cppSelf->::QCleanlooksStyle::polish(cppArg0):cppSelf->polish(cppArg0));
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // polish(QWidget*)
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QWidget * cppArg0 = Shiboken::Converter<QWidget * >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // polish(QWidget*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    (Shiboken::Object::isUserType(self) ? cppSelf->::QCleanlooksStyle::polish(cppArg0):cppSelf->polish(cppArg0));
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QCleanlooksStyleFunc_polish_TypeError:
        const char* overloads[] = {"PySide.QtGui.QApplication", "PySide.QtGui.QPalette", "PySide.QtGui.QWidget", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QCleanlooksStyle.polish", overloads);
        return 0;
}

static PyObject* Sbk_QCleanlooksStyleFunc_sizeFromContents(PyObject* self, PyObject* args)
{
    QCleanlooksStyle* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QCleanlooksStyle* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "sizeFromContents", 4, 4, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: sizeFromContents(QStyle::ContentsType,const QStyleOption*,QSize,const QWidget*)const
    if (numArgs == 4 && Shiboken::Converter< ::QStyle::ContentsType >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QStyleOption * >::isConvertible(pyargs[1]) && Shiboken::Converter< ::QSize >::isConvertible(pyargs[2]) && Shiboken::Converter< ::QWidget * >::isConvertible(pyargs[3])) {
        overloadId = 0; // sizeFromContents(QStyle::ContentsType,const QStyleOption*,QSize,const QWidget*)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QCleanlooksStyleFunc_sizeFromContents_TypeError;

    // Call function/method
    {
        {
            QStyle::ContentsType cppArg0 = Shiboken::Converter<QStyle::ContentsType >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QStyleOption * cppArg1 = Shiboken::Converter<QStyleOption * >::toCpp(pyargs[1]);
            if (!Shiboken::Object::isValid(pyargs[2]))
                return 0;
            QSize cppArg2 = Shiboken::Converter<QSize >::toCpp(pyargs[2]);
            if (!Shiboken::Object::isValid(pyargs[3]))
                return 0;
            QWidget * cppArg3 = Shiboken::Converter<QWidget * >::toCpp(pyargs[3]);

            if(!PyErr_Occurred()) {
                // sizeFromContents(QStyle::ContentsType,const QStyleOption*,QSize,const QWidget*)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QSize cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QCleanlooksStyle::sizeFromContents(cppArg0, cppArg1, cppArg2, cppArg3):cppSelf->sizeFromContents(cppArg0, cppArg1, cppArg2, cppArg3));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QSize >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QCleanlooksStyleFunc_sizeFromContents_TypeError:
        const char* overloads[] = {"PySide.QtGui.QStyle.ContentsType, PySide.QtGui.QStyleOption, PySide.QtCore.QSize, PySide.QtGui.QWidget", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QCleanlooksStyle.sizeFromContents", overloads);
        return 0;
}

static PyObject* Sbk_QCleanlooksStyleFunc_standardIconImplementation(PyObject* self, PyObject* args, PyObject* kwds)
{
    QCleanlooksStyle* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QCleanlooksStyle* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QCleanlooksStyle.standardIconImplementation(): too many arguments");
        return 0;
    } else if (numArgs < 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QCleanlooksStyle.standardIconImplementation(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:standardIconImplementation", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: standardIconImplementation(QStyle::StandardPixmap,const QStyleOption*,const QWidget*)const
    if (numArgs >= 2 && Shiboken::Converter< ::QStyle::StandardPixmap >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QStyleOption * >::isConvertible(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 0; // standardIconImplementation(QStyle::StandardPixmap,const QStyleOption*,const QWidget*)const
        } else if (Shiboken::Converter< ::QWidget * >::isConvertible(pyargs[2])) {
            overloadId = 0; // standardIconImplementation(QStyle::StandardPixmap,const QStyleOption*,const QWidget*)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QCleanlooksStyleFunc_standardIconImplementation_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "widget");
                if (value) {
                    if (pyargs[2])
                        errorArgName = "widget";
                    else if (Shiboken::Converter< ::QWidget * >::isConvertible(value))
                        pyargs[2] = value;
else
                        goto Sbk_QCleanlooksStyleFunc_standardIconImplementation_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QCleanlooksStyle.standardIconImplementation(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QStyle::StandardPixmap cppArg0 = Shiboken::Converter<QStyle::StandardPixmap >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QStyleOption * cppArg1 = Shiboken::Converter<QStyleOption * >::toCpp(pyargs[1]);
            if (!Shiboken::Object::isValid(pyargs[2]))
                return 0;
            QWidget * cppArg2 = pyargs[2] ? Shiboken::Converter<QWidget * >::toCpp(pyargs[2]) : 0;

            if(!PyErr_Occurred()) {
                // standardIconImplementation(QStyle::StandardPixmap,const QStyleOption*,const QWidget*)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QIcon cppResult = cppSelf->standardIconImplementation(cppArg0, cppArg1, cppArg2);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QIcon >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QCleanlooksStyleFunc_standardIconImplementation_TypeError:
        const char* overloads[] = {"PySide.QtGui.QStyle.StandardPixmap, PySide.QtGui.QStyleOption, PySide.QtGui.QWidget = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QCleanlooksStyle.standardIconImplementation", overloads);
        return 0;
}

static PyObject* Sbk_QCleanlooksStyleFunc_standardPalette(PyObject* self)
{
    QCleanlooksStyle* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QCleanlooksStyle* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // standardPalette()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPalette cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QCleanlooksStyle::standardPalette():cppSelf->standardPalette());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPalette >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QCleanlooksStyleFunc_styleHint(PyObject* self, PyObject* args, PyObject* kwds)
{
    QCleanlooksStyle* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QCleanlooksStyle* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 4) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QCleanlooksStyle.styleHint(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QCleanlooksStyle.styleHint(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOO:styleHint", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: styleHint(QStyle::StyleHint,const QStyleOption*,const QWidget*,QStyleHintReturn*)const
    if (Shiboken::Converter< ::QStyle::StyleHint >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // styleHint(QStyle::StyleHint,const QStyleOption*,const QWidget*,QStyleHintReturn*)const
        } else if (Shiboken::Converter< ::QStyleOption * >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 0; // styleHint(QStyle::StyleHint,const QStyleOption*,const QWidget*,QStyleHintReturn*)const
            } else if (Shiboken::Converter< ::QWidget * >::isConvertible(pyargs[2])) {
                if (numArgs == 3) {
                    overloadId = 0; // styleHint(QStyle::StyleHint,const QStyleOption*,const QWidget*,QStyleHintReturn*)const
                } else if (Shiboken::Converter< ::QStyleHintReturn * >::isConvertible(pyargs[3])) {
                    overloadId = 0; // styleHint(QStyle::StyleHint,const QStyleOption*,const QWidget*,QStyleHintReturn*)const
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QCleanlooksStyleFunc_styleHint_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "option");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "option";
                    else if (Shiboken::Converter< ::QStyleOption * >::isConvertible(value))
                        pyargs[1] = value;
else
                        goto Sbk_QCleanlooksStyleFunc_styleHint_TypeError;
                }
                value = PyDict_GetItemString(kwds, "widget");
                if (value) {
                    if (pyargs[2])
                        errorArgName = "widget";
                    else if (Shiboken::Converter< ::QWidget * >::isConvertible(value))
                        pyargs[2] = value;
else
                        goto Sbk_QCleanlooksStyleFunc_styleHint_TypeError;
                }
                value = PyDict_GetItemString(kwds, "returnData");
                if (value) {
                    if (pyargs[3])
                        errorArgName = "returnData";
                    else if (Shiboken::Converter< ::QStyleHintReturn * >::isConvertible(value))
                        pyargs[3] = value;
else
                        goto Sbk_QCleanlooksStyleFunc_styleHint_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QCleanlooksStyle.styleHint(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QStyle::StyleHint cppArg0 = Shiboken::Converter<QStyle::StyleHint >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QStyleOption * cppArg1 = pyargs[1] ? Shiboken::Converter<QStyleOption * >::toCpp(pyargs[1]) : 0;
            if (!Shiboken::Object::isValid(pyargs[2]))
                return 0;
            QWidget * cppArg2 = pyargs[2] ? Shiboken::Converter<QWidget * >::toCpp(pyargs[2]) : 0;
            if (!Shiboken::Object::isValid(pyargs[3]))
                return 0;
            QStyleHintReturn * cppArg3 = pyargs[3] ? Shiboken::Converter<QStyleHintReturn * >::toCpp(pyargs[3]) : 0;

            if(!PyErr_Occurred()) {
                // styleHint(QStyle::StyleHint,const QStyleOption*,const QWidget*,QStyleHintReturn*)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QCleanlooksStyle::styleHint(cppArg0, cppArg1, cppArg2, cppArg3):cppSelf->styleHint(cppArg0, cppArg1, cppArg2, cppArg3));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QCleanlooksStyleFunc_styleHint_TypeError:
        const char* overloads[] = {"PySide.QtGui.QStyle.StyleHint, PySide.QtGui.QStyleOption = None, PySide.QtGui.QWidget = None, PySide.QtGui.QStyleHintReturn = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QCleanlooksStyle.styleHint", overloads);
        return 0;
}

static PyObject* Sbk_QCleanlooksStyleFunc_subControlRect(PyObject* self, PyObject* args)
{
    QCleanlooksStyle* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QCleanlooksStyle* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "subControlRect", 4, 4, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: subControlRect(QStyle::ComplexControl,const QStyleOptionComplex*,QStyle::SubControl,const QWidget*)const
    if (numArgs == 4 && Shiboken::Converter< ::QStyle::ComplexControl >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QStyleOptionComplex * >::isConvertible(pyargs[1]) && Shiboken::Converter< ::QStyle::SubControl >::isConvertible(pyargs[2]) && Shiboken::Converter< ::QWidget * >::isConvertible(pyargs[3])) {
        overloadId = 0; // subControlRect(QStyle::ComplexControl,const QStyleOptionComplex*,QStyle::SubControl,const QWidget*)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QCleanlooksStyleFunc_subControlRect_TypeError;

    // Call function/method
    {
        {
            QStyle::ComplexControl cppArg0 = Shiboken::Converter<QStyle::ComplexControl >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QStyleOptionComplex * cppArg1 = Shiboken::Converter<QStyleOptionComplex * >::toCpp(pyargs[1]);
            QStyle::SubControl cppArg2 = Shiboken::Converter<QStyle::SubControl >::toCpp(pyargs[2]);
            if (!Shiboken::Object::isValid(pyargs[3]))
                return 0;
            QWidget * cppArg3 = Shiboken::Converter<QWidget * >::toCpp(pyargs[3]);

            if(!PyErr_Occurred()) {
                // subControlRect(QStyle::ComplexControl,const QStyleOptionComplex*,QStyle::SubControl,const QWidget*)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QRect cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QCleanlooksStyle::subControlRect(cppArg0, cppArg1, cppArg2, cppArg3):cppSelf->subControlRect(cppArg0, cppArg1, cppArg2, cppArg3));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QRect >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QCleanlooksStyleFunc_subControlRect_TypeError:
        const char* overloads[] = {"PySide.QtGui.QStyle.ComplexControl, PySide.QtGui.QStyleOptionComplex, PySide.QtGui.QStyle.SubControl, PySide.QtGui.QWidget", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QCleanlooksStyle.subControlRect", overloads);
        return 0;
}

static PyObject* Sbk_QCleanlooksStyleFunc_subElementRect(PyObject* self, PyObject* args, PyObject* kwds)
{
    QCleanlooksStyle* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QCleanlooksStyle* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QCleanlooksStyle.subElementRect(): too many arguments");
        return 0;
    } else if (numArgs < 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QCleanlooksStyle.subElementRect(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:subElementRect", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: subElementRect(QStyle::SubElement,const QStyleOption*,const QWidget*)const
    if (numArgs >= 2 && Shiboken::Converter< ::QStyle::SubElement >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QStyleOption * >::isConvertible(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 0; // subElementRect(QStyle::SubElement,const QStyleOption*,const QWidget*)const
        } else if (Shiboken::Converter< ::QWidget * >::isConvertible(pyargs[2])) {
            overloadId = 0; // subElementRect(QStyle::SubElement,const QStyleOption*,const QWidget*)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QCleanlooksStyleFunc_subElementRect_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "widget");
                if (value) {
                    if (pyargs[2])
                        errorArgName = "widget";
                    else if (Shiboken::Converter< ::QWidget * >::isConvertible(value))
                        pyargs[2] = value;
else
                        goto Sbk_QCleanlooksStyleFunc_subElementRect_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QCleanlooksStyle.subElementRect(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QStyle::SubElement cppArg0 = Shiboken::Converter<QStyle::SubElement >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QStyleOption * cppArg1 = Shiboken::Converter<QStyleOption * >::toCpp(pyargs[1]);
            if (!Shiboken::Object::isValid(pyargs[2]))
                return 0;
            QWidget * cppArg2 = pyargs[2] ? Shiboken::Converter<QWidget * >::toCpp(pyargs[2]) : 0;

            if(!PyErr_Occurred()) {
                // subElementRect(QStyle::SubElement,const QStyleOption*,const QWidget*)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QRect cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QCleanlooksStyle::subElementRect(cppArg0, cppArg1, cppArg2):cppSelf->subElementRect(cppArg0, cppArg1, cppArg2));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QRect >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QCleanlooksStyleFunc_subElementRect_TypeError:
        const char* overloads[] = {"PySide.QtGui.QStyle.SubElement, PySide.QtGui.QStyleOption, PySide.QtGui.QWidget = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QCleanlooksStyle.subElementRect", overloads);
        return 0;
}

static PyObject* Sbk_QCleanlooksStyleFunc_unpolish(PyObject* self, PyObject* arg)
{
    QCleanlooksStyle* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QCleanlooksStyle* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: unpolish(QApplication*)
    // 1: unpolish(QWidget*)
    if (Shiboken::Converter< ::QWidget * >::isConvertible(arg)) {
        overloadId = 1; // unpolish(QWidget*)
    } else if (Shiboken::Converter< ::QApplication * >::isConvertible(arg)) {
        overloadId = 0; // unpolish(QApplication*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QCleanlooksStyleFunc_unpolish_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // unpolish(QApplication*)
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QApplication * cppArg0 = Shiboken::Converter<QApplication * >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // unpolish(QApplication*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    (Shiboken::Object::isUserType(self) ? cppSelf->::QCleanlooksStyle::unpolish(cppArg0):cppSelf->unpolish(cppArg0));
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // unpolish(QWidget*)
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QWidget * cppArg0 = Shiboken::Converter<QWidget * >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // unpolish(QWidget*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    (Shiboken::Object::isUserType(self) ? cppSelf->::QCleanlooksStyle::unpolish(cppArg0):cppSelf->unpolish(cppArg0));
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QCleanlooksStyleFunc_unpolish_TypeError:
        const char* overloads[] = {"PySide.QtGui.QApplication", "PySide.QtGui.QWidget", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QCleanlooksStyle.unpolish", overloads);
        return 0;
}

static PyMethodDef Sbk_QCleanlooksStyle_methods[] = {
    {"drawComplexControl", (PyCFunction)Sbk_QCleanlooksStyleFunc_drawComplexControl, METH_VARARGS},
    {"drawControl", (PyCFunction)Sbk_QCleanlooksStyleFunc_drawControl, METH_VARARGS},
    {"drawItemPixmap", (PyCFunction)Sbk_QCleanlooksStyleFunc_drawItemPixmap, METH_VARARGS},
    {"drawItemText", (PyCFunction)Sbk_QCleanlooksStyleFunc_drawItemText, METH_VARARGS|METH_KEYWORDS},
    {"drawPrimitive", (PyCFunction)Sbk_QCleanlooksStyleFunc_drawPrimitive, METH_VARARGS|METH_KEYWORDS},
    {"generatedIconPixmap", (PyCFunction)Sbk_QCleanlooksStyleFunc_generatedIconPixmap, METH_VARARGS},
    {"hitTestComplexControl", (PyCFunction)Sbk_QCleanlooksStyleFunc_hitTestComplexControl, METH_VARARGS|METH_KEYWORDS},
    {"itemPixmapRect", (PyCFunction)Sbk_QCleanlooksStyleFunc_itemPixmapRect, METH_VARARGS},
    {"pixelMetric", (PyCFunction)Sbk_QCleanlooksStyleFunc_pixelMetric, METH_VARARGS|METH_KEYWORDS},
    {"polish", (PyCFunction)Sbk_QCleanlooksStyleFunc_polish, METH_O},
    {"sizeFromContents", (PyCFunction)Sbk_QCleanlooksStyleFunc_sizeFromContents, METH_VARARGS},
    {"standardIconImplementation", (PyCFunction)Sbk_QCleanlooksStyleFunc_standardIconImplementation, METH_VARARGS|METH_KEYWORDS},
    {"standardPalette", (PyCFunction)Sbk_QCleanlooksStyleFunc_standardPalette, METH_NOARGS},
    {"styleHint", (PyCFunction)Sbk_QCleanlooksStyleFunc_styleHint, METH_VARARGS|METH_KEYWORDS},
    {"subControlRect", (PyCFunction)Sbk_QCleanlooksStyleFunc_subControlRect, METH_VARARGS},
    {"subElementRect", (PyCFunction)Sbk_QCleanlooksStyleFunc_subElementRect, METH_VARARGS|METH_KEYWORDS},
    {"unpolish", (PyCFunction)Sbk_QCleanlooksStyleFunc_unpolish, METH_O},

    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QCleanlooksStyle_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QCleanlooksStyle",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QCleanlooksStyle_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QCleanlooksStyle_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern

static SbkObjectType* Sbk_QCleanlooksStyle_typeDiscovery(void* cptr, SbkObjectType* instanceType)
{
    if (instanceType == reinterpret_cast<SbkObjectType*>(Shiboken::SbkType<QObject >()) && dynamic_cast<QCleanlooksStyle*>(reinterpret_cast<QObject*>(cptr)))
        return &Sbk_QCleanlooksStyle_Type;
    return 0;
}


void init_QCleanlooksStyle(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QCLEANLOOKSSTYLE_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QCleanlooksStyle_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QCleanlooksStyle_Type);
    Shiboken::ObjectType::setSubTypeInitHook(&Sbk_QCleanlooksStyle_Type, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(&Sbk_QCleanlooksStyle_Type, &QCleanlooksStyle::staticMetaObject);    Sbk_QCleanlooksStyle_Type.super.ht_type.tp_base = SbkPySide_QtGuiTypes[SBK_QWINDOWSSTYLE_IDX];
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QCleanlooksStyle_Type, &Shiboken::callCppDestructor<QCleanlooksStyle >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QCleanlooksStyle_Type) < 0)
        return;

    // Fill type discovery information
    Shiboken::ObjectType::setTypeDiscoveryFunction(&Sbk_QCleanlooksStyle_Type, &Sbk_QCleanlooksStyle_typeDiscovery);
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkObjectType*>(SbkPySide_QtGuiTypes[SBK_QWINDOWSSTYLE_IDX]), &Sbk_QCleanlooksStyle_Type);

    Shiboken::ObjectType::setOriginalName(&Sbk_QCleanlooksStyle_Type, "QCleanlooksStyle*");
    PyModule_AddObject(module, "QCleanlooksStyle",
        ((PyObject*)&Sbk_QCleanlooksStyle_Type));


    Shiboken::TypeResolver::createObjectTypeResolver<QCleanlooksStyle >("QCleanlooksStyle*");
    Shiboken::TypeResolver::createObjectTypeResolver<QCleanlooksStyle >("QCleanlooksStyle$ConcreteWrapper*");
    Shiboken::TypeResolver::createObjectTypeResolver<QCleanlooksStyle >(typeid(QCleanlooksStyle).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QCleanlooksStyle >(typeid(QCleanlooksStyleWrapper).name());
    PySide::initQtMetaType<QCleanlooksStyle* >();
}

