/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qcolor_wrapper.h"

// Extra includes
#include <QStringList>
#include <QVariant>
#include <qcolor.h>
#include <qdatastream.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QColor_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QColor >()))
        return -1;

    QColor* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);

    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 4) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QColor(): too many arguments");
        return -1;
    } else if (numArgs == 2)
        goto Sbk_QColor_Init_TypeError;

    if (!PyArg_ParseTuple(args, "|OOOO:QColor", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return -1;

    // Overloaded function decisor
    // 0: QColor()
    // 1: QColor(QVariant)
    // 2: QColor(Qt::GlobalColor)
    // 3: QColor(QColor)
    // 4: QColor(QString)
    // 5: QColor(int,int,int,int)
    // 6: QColor(uint)
    if (numArgs == 0) {
        overloadId = 0; // QColor()
    } else if (numArgs == 1 && Shiboken::Converter< QString >::isConvertible(pyargs[0])) {
        overloadId = 4; // QColor(QString)
    } else if (numArgs == 1 && Shiboken::Converter< ::Qt::GlobalColor >::isConvertible(pyargs[0])) {
        overloadId = 2; // QColor(Qt::GlobalColor)
    } else if (numArgs == 1 && SbkNumber_Check(pyargs[0])) {
        overloadId = 6; // QColor(uint)
    } else if (numArgs >= 3 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
        if (numArgs == 3) {
            overloadId = 5; // QColor(int,int,int,int)
        } else if (SbkNumber_Check(pyargs[3])) {
            overloadId = 5; // QColor(int,int,int,int)
        }
    } else if (numArgs == 1 && Shiboken::Converter< QVariant >::isConvertible(pyargs[0])) {
        overloadId = 1; // QColor(QVariant)
    } else if (numArgs == 1 && Shiboken::Converter< ::QColor >::isConvertible(pyargs[0])) {
        overloadId = 3; // QColor(QColor)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QColor_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QColor()
            {

                if(!PyErr_Occurred()) {
                    // QColor()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QColor();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // QColor(QVariant)
            {
                QVariant cppArg0 = Shiboken::Converter<QVariant >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QColor(QVariant)
                    // Begin code injection
                    
                    if (cppArg0.type() == QVariant::Color)
                        cptr = new QColor(cppArg0.value<QColor>());
                    else
                        PyErr_SetString(PyExc_TypeError, "QVariant must be holding a QColor");
                    
                    // End of code injection

                }
                break;
            }
            case 2: // QColor(Qt::GlobalColor)
            {
                Qt::GlobalColor cppArg0 = Shiboken::Converter<Qt::GlobalColor >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QColor(Qt::GlobalColor)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QColor(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 3: // QColor(QColor)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QColor cppArg0 = Shiboken::Converter<QColor >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QColor(QColor)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QColor(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 4: // QColor(QString)
            {
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QColor(QString)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QColor(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 5: // QColor(int,int,int,int)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "a");
                    if (value) {
                        if (pyargs[3])
                            errorArgName = "a";
                        else if (SbkNumber_Check(value))
                            pyargs[3] = value;
else
                            goto Sbk_QColor_Init_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QColor(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
                int cppArg3 = pyargs[3] ? Shiboken::Converter<int >::toCpp(pyargs[3]) : 255;

                if(!PyErr_Occurred()) {
                    // QColor(int,int,int,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QColor(cppArg0, cppArg1, cppArg2, cppArg3);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 6: // QColor(uint)
            {
                unsigned int cppArg0 = Shiboken::Converter<unsigned int >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QColor(uint)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QColor(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QColor >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QColor_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QColor_Init_TypeError:
        const char* overloads[] = {"", "QVariant", "PySide.QtCore.Qt.GlobalColor", "PySide.QtGui.QColor", "QString", "int, int, int, int = 255", "unsigned int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QColor", overloads);
        return -1;
}

static PyObject* Sbk_QColorFunc___reduce__(PyObject* self)
{
    QColor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QColor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // __reduce__()
                // Begin code injection
                
                // TEMPLATE - reduce_code - START
                pyResult = Py_BuildValue("(N(iiii))", PyObject_Type(self), cppSelf->red(), cppSelf->green(), cppSelf->blue(), cppSelf->alpha());
                // TEMPLATE - reduce_code - END
                
                // End of code injection


            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QColorFunc_allowX11ColorNames(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // allowX11ColorNames()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = QColor::allowX11ColorNames();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QColorFunc_alpha(PyObject* self)
{
    QColor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QColor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // alpha()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->alpha();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QColorFunc_alphaF(PyObject* self)
{
    QColor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QColor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // alphaF()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qreal cppResult = cppSelf->alphaF();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< double >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QColorFunc_black(PyObject* self)
{
    QColor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QColor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // black()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->black();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QColorFunc_blackF(PyObject* self)
{
    QColor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QColor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // blackF()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qreal cppResult = cppSelf->blackF();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< double >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QColorFunc_blue(PyObject* self)
{
    QColor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QColor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // blue()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->blue();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QColorFunc_blueF(PyObject* self)
{
    QColor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QColor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // blueF()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qreal cppResult = cppSelf->blueF();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< double >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QColorFunc_colorNames(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // colorNames()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QStringList cppResult = QColor::colorNames();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QStringList >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QColorFunc_convertTo(PyObject* self, PyObject* arg)
{
    QColor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QColor* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: convertTo(QColor::Spec)const
    if (Shiboken::Converter< ::QColor::Spec >::isConvertible(arg)) {
        overloadId = 0; // convertTo(QColor::Spec)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QColorFunc_convertTo_TypeError;

    // Call function/method
    {
        {
            QColor::Spec cppArg0 = Shiboken::Converter<QColor::Spec >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // convertTo(QColor::Spec)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QColor cppResult = cppSelf->convertTo(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QColor >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QColorFunc_convertTo_TypeError:
        const char* overloads[] = {"PySide.QtGui.QColor.Spec", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QColor.convertTo", overloads);
        return 0;
}

static PyObject* Sbk_QColorFunc_cyan(PyObject* self)
{
    QColor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QColor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // cyan()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->cyan();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QColorFunc_cyanF(PyObject* self)
{
    QColor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QColor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // cyanF()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qreal cppResult = cppSelf->cyanF();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< double >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QColorFunc_darker(PyObject* self, PyObject* args, PyObject* kwds)
{
    QColor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QColor* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QColor.darker(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:darker", &(pyargs[0])))
        return 0;


    // Overloaded function decisor
    // 0: darker(int)const
    if (numArgs == 0) {
        overloadId = 0; // darker(int)const
    } else if (SbkNumber_Check(pyargs[0])) {
        overloadId = 0; // darker(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QColorFunc_darker_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "f");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "f";
                    else if (SbkNumber_Check(value))
                        pyargs[0] = value;
else
                        goto Sbk_QColorFunc_darker_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QColor.darker(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cppArg0 = pyargs[0] ? Shiboken::Converter<int >::toCpp(pyargs[0]) : 200;

            if(!PyErr_Occurred()) {
                // darker(int)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QColor cppResult = cppSelf->darker(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QColor >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QColorFunc_darker_TypeError:
        const char* overloads[] = {"int = 200", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QColor.darker", overloads);
        return 0;
}

static PyObject* Sbk_QColorFunc_fromCmyk(PyObject* self, PyObject* args, PyObject* kwds)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 5) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QColor.fromCmyk(): too many arguments");
        return 0;
    } else if (numArgs < 4) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QColor.fromCmyk(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOOO:fromCmyk", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4])))
        return 0;


    // Overloaded function decisor
    // 0: fromCmyk(int,int,int,int,int)
    if (numArgs >= 4 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
        if (numArgs == 4) {
            overloadId = 0; // fromCmyk(int,int,int,int,int)
        } else if (SbkNumber_Check(pyargs[4])) {
            overloadId = 0; // fromCmyk(int,int,int,int,int)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QColorFunc_fromCmyk_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "a");
                if (value) {
                    if (pyargs[4])
                        errorArgName = "a";
                    else if (SbkNumber_Check(value))
                        pyargs[4] = value;
else
                        goto Sbk_QColorFunc_fromCmyk_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QColor.fromCmyk(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
            int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
            int cppArg3 = Shiboken::Converter<int >::toCpp(pyargs[3]);
            int cppArg4 = pyargs[4] ? Shiboken::Converter<int >::toCpp(pyargs[4]) : 255;

            if(!PyErr_Occurred()) {
                // fromCmyk(int,int,int,int,int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QColor cppResult = QColor::fromCmyk(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QColor >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QColorFunc_fromCmyk_TypeError:
        const char* overloads[] = {"int, int, int, int, int = 255", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QColor.fromCmyk", overloads);
        return 0;
}

static PyObject* Sbk_QColorFunc_fromCmykF(PyObject* self, PyObject* args, PyObject* kwds)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 5) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QColor.fromCmykF(): too many arguments");
        return 0;
    } else if (numArgs < 4) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QColor.fromCmykF(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOOO:fromCmykF", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4])))
        return 0;


    // Overloaded function decisor
    // 0: fromCmykF(qreal,qreal,qreal,qreal,qreal)
    if (numArgs >= 4 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
        if (numArgs == 4) {
            overloadId = 0; // fromCmykF(qreal,qreal,qreal,qreal,qreal)
        } else if (SbkNumber_Check(pyargs[4])) {
            overloadId = 0; // fromCmykF(qreal,qreal,qreal,qreal,qreal)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QColorFunc_fromCmykF_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "a");
                if (value) {
                    if (pyargs[4])
                        errorArgName = "a";
                    else if (SbkNumber_Check(value))
                        pyargs[4] = value;
else
                        goto Sbk_QColorFunc_fromCmykF_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QColor.fromCmykF(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
            qreal cppArg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
            qreal cppArg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);
            qreal cppArg3 = Shiboken::Converter<qreal >::toCpp(pyargs[3]);
            qreal cppArg4 = pyargs[4] ? Shiboken::Converter<qreal >::toCpp(pyargs[4]) : 1.0;

            if(!PyErr_Occurred()) {
                // fromCmykF(qreal,qreal,qreal,qreal,qreal)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QColor cppResult = QColor::fromCmykF(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QColor >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QColorFunc_fromCmykF_TypeError:
        const char* overloads[] = {"float, float, float, float, float = 1.0", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QColor.fromCmykF", overloads);
        return 0;
}

static PyObject* Sbk_QColorFunc_fromHsl(PyObject* self, PyObject* args, PyObject* kwds)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 4) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QColor.fromHsl(): too many arguments");
        return 0;
    } else if (numArgs < 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QColor.fromHsl(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOO:fromHsl", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: fromHsl(int,int,int,int)
    if (numArgs >= 3 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
        if (numArgs == 3) {
            overloadId = 0; // fromHsl(int,int,int,int)
        } else if (SbkNumber_Check(pyargs[3])) {
            overloadId = 0; // fromHsl(int,int,int,int)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QColorFunc_fromHsl_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "a");
                if (value) {
                    if (pyargs[3])
                        errorArgName = "a";
                    else if (SbkNumber_Check(value))
                        pyargs[3] = value;
else
                        goto Sbk_QColorFunc_fromHsl_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QColor.fromHsl(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
            int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
            int cppArg3 = pyargs[3] ? Shiboken::Converter<int >::toCpp(pyargs[3]) : 255;

            if(!PyErr_Occurred()) {
                // fromHsl(int,int,int,int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QColor cppResult = QColor::fromHsl(cppArg0, cppArg1, cppArg2, cppArg3);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QColor >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QColorFunc_fromHsl_TypeError:
        const char* overloads[] = {"int, int, int, int = 255", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QColor.fromHsl", overloads);
        return 0;
}

static PyObject* Sbk_QColorFunc_fromHslF(PyObject* self, PyObject* args, PyObject* kwds)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 4) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QColor.fromHslF(): too many arguments");
        return 0;
    } else if (numArgs < 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QColor.fromHslF(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOO:fromHslF", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: fromHslF(qreal,qreal,qreal,qreal)
    if (numArgs >= 3 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
        if (numArgs == 3) {
            overloadId = 0; // fromHslF(qreal,qreal,qreal,qreal)
        } else if (SbkNumber_Check(pyargs[3])) {
            overloadId = 0; // fromHslF(qreal,qreal,qreal,qreal)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QColorFunc_fromHslF_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "a");
                if (value) {
                    if (pyargs[3])
                        errorArgName = "a";
                    else if (SbkNumber_Check(value))
                        pyargs[3] = value;
else
                        goto Sbk_QColorFunc_fromHslF_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QColor.fromHslF(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
            qreal cppArg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
            qreal cppArg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);
            qreal cppArg3 = pyargs[3] ? Shiboken::Converter<qreal >::toCpp(pyargs[3]) : 1.0;

            if(!PyErr_Occurred()) {
                // fromHslF(qreal,qreal,qreal,qreal)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QColor cppResult = QColor::fromHslF(cppArg0, cppArg1, cppArg2, cppArg3);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QColor >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QColorFunc_fromHslF_TypeError:
        const char* overloads[] = {"float, float, float, float = 1.0", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QColor.fromHslF", overloads);
        return 0;
}

static PyObject* Sbk_QColorFunc_fromHsv(PyObject* self, PyObject* args, PyObject* kwds)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 4) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QColor.fromHsv(): too many arguments");
        return 0;
    } else if (numArgs < 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QColor.fromHsv(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOO:fromHsv", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: fromHsv(int,int,int,int)
    if (numArgs >= 3 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
        if (numArgs == 3) {
            overloadId = 0; // fromHsv(int,int,int,int)
        } else if (SbkNumber_Check(pyargs[3])) {
            overloadId = 0; // fromHsv(int,int,int,int)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QColorFunc_fromHsv_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "a");
                if (value) {
                    if (pyargs[3])
                        errorArgName = "a";
                    else if (SbkNumber_Check(value))
                        pyargs[3] = value;
else
                        goto Sbk_QColorFunc_fromHsv_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QColor.fromHsv(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
            int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
            int cppArg3 = pyargs[3] ? Shiboken::Converter<int >::toCpp(pyargs[3]) : 255;

            if(!PyErr_Occurred()) {
                // fromHsv(int,int,int,int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QColor cppResult = QColor::fromHsv(cppArg0, cppArg1, cppArg2, cppArg3);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QColor >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QColorFunc_fromHsv_TypeError:
        const char* overloads[] = {"int, int, int, int = 255", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QColor.fromHsv", overloads);
        return 0;
}

static PyObject* Sbk_QColorFunc_fromHsvF(PyObject* self, PyObject* args, PyObject* kwds)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 4) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QColor.fromHsvF(): too many arguments");
        return 0;
    } else if (numArgs < 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QColor.fromHsvF(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOO:fromHsvF", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: fromHsvF(qreal,qreal,qreal,qreal)
    if (numArgs >= 3 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
        if (numArgs == 3) {
            overloadId = 0; // fromHsvF(qreal,qreal,qreal,qreal)
        } else if (SbkNumber_Check(pyargs[3])) {
            overloadId = 0; // fromHsvF(qreal,qreal,qreal,qreal)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QColorFunc_fromHsvF_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "a");
                if (value) {
                    if (pyargs[3])
                        errorArgName = "a";
                    else if (SbkNumber_Check(value))
                        pyargs[3] = value;
else
                        goto Sbk_QColorFunc_fromHsvF_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QColor.fromHsvF(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
            qreal cppArg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
            qreal cppArg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);
            qreal cppArg3 = pyargs[3] ? Shiboken::Converter<qreal >::toCpp(pyargs[3]) : 1.0;

            if(!PyErr_Occurred()) {
                // fromHsvF(qreal,qreal,qreal,qreal)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QColor cppResult = QColor::fromHsvF(cppArg0, cppArg1, cppArg2, cppArg3);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QColor >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QColorFunc_fromHsvF_TypeError:
        const char* overloads[] = {"float, float, float, float = 1.0", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QColor.fromHsvF", overloads);
        return 0;
}

static PyObject* Sbk_QColorFunc_fromRgb(PyObject* self, PyObject* args, PyObject* kwds)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 4) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QColor.fromRgb(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QColor.fromRgb(): not enough arguments");
        return 0;
    } else if (numArgs == 2)
        goto Sbk_QColorFunc_fromRgb_TypeError;

    if (!PyArg_ParseTuple(args, "|OOOO:fromRgb", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: fromRgb(int,int,int,int)
    // 1: fromRgb(uint)
    if (numArgs == 1 && SbkNumber_Check(pyargs[0])) {
        overloadId = 1; // fromRgb(uint)
    } else if (numArgs >= 3 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
        if (numArgs == 3) {
            overloadId = 0; // fromRgb(int,int,int,int)
        } else if (SbkNumber_Check(pyargs[3])) {
            overloadId = 0; // fromRgb(int,int,int,int)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QColorFunc_fromRgb_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // fromRgb(int,int,int,int)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "a");
                    if (value) {
                        if (pyargs[3])
                            errorArgName = "a";
                        else if (SbkNumber_Check(value))
                            pyargs[3] = value;
else
                            goto Sbk_QColorFunc_fromRgb_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QColor.fromRgb(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
                int cppArg3 = pyargs[3] ? Shiboken::Converter<int >::toCpp(pyargs[3]) : 255;

                if(!PyErr_Occurred()) {
                    // fromRgb(int,int,int,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QColor cppResult = QColor::fromRgb(cppArg0, cppArg1, cppArg2, cppArg3);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QColor >::toPython(cppResult);
                }
                break;
            }
            case 1: // fromRgb(uint)
            {
                unsigned int cppArg0 = Shiboken::Converter<unsigned int >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // fromRgb(uint)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QColor cppResult = QColor::fromRgb(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QColor >::toPython(cppResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QColorFunc_fromRgb_TypeError:
        const char* overloads[] = {"int, int, int, int = 255", "unsigned int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QColor.fromRgb", overloads);
        return 0;
}

static PyObject* Sbk_QColorFunc_fromRgbF(PyObject* self, PyObject* args, PyObject* kwds)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 4) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QColor.fromRgbF(): too many arguments");
        return 0;
    } else if (numArgs < 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QColor.fromRgbF(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOO:fromRgbF", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: fromRgbF(qreal,qreal,qreal,qreal)
    if (numArgs >= 3 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
        if (numArgs == 3) {
            overloadId = 0; // fromRgbF(qreal,qreal,qreal,qreal)
        } else if (SbkNumber_Check(pyargs[3])) {
            overloadId = 0; // fromRgbF(qreal,qreal,qreal,qreal)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QColorFunc_fromRgbF_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "a");
                if (value) {
                    if (pyargs[3])
                        errorArgName = "a";
                    else if (SbkNumber_Check(value))
                        pyargs[3] = value;
else
                        goto Sbk_QColorFunc_fromRgbF_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QColor.fromRgbF(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
            qreal cppArg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
            qreal cppArg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);
            qreal cppArg3 = pyargs[3] ? Shiboken::Converter<qreal >::toCpp(pyargs[3]) : 1.0;

            if(!PyErr_Occurred()) {
                // fromRgbF(qreal,qreal,qreal,qreal)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QColor cppResult = QColor::fromRgbF(cppArg0, cppArg1, cppArg2, cppArg3);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QColor >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QColorFunc_fromRgbF_TypeError:
        const char* overloads[] = {"float, float, float, float = 1.0", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QColor.fromRgbF", overloads);
        return 0;
}

static PyObject* Sbk_QColorFunc_fromRgba(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: fromRgba(uint)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // fromRgba(uint)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QColorFunc_fromRgba_TypeError;

    // Call function/method
    {
        {
            unsigned int cppArg0 = Shiboken::Converter<unsigned int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // fromRgba(uint)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QColor cppResult = QColor::fromRgba(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QColor >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QColorFunc_fromRgba_TypeError:
        const char* overloads[] = {"unsigned int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QColor.fromRgba", overloads);
        return 0;
}

static PyObject* Sbk_QColorFunc_getCmyk(PyObject* self)
{
    QColor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QColor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // getCmyk(int*,int*,int*,int*,int*)
                // Begin code injection
                
                // TEMPLATE - fix_int*,int*,int*,int*,int* - START
                int a, b, c, d, e;
                cppSelf->getCmyk(&a, &b, &c, &d, &e);
                pyResult = Shiboken::makeTuple(a, b, c, d, e);
                // TEMPLATE - fix_int*,int*,int*,int*,int* - END
                
                // End of code injection


            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QColorFunc_getCmykF(PyObject* self)
{
    QColor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QColor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // getCmykF(qreal*,qreal*,qreal*,qreal*,qreal*)
                // Begin code injection
                
                // TEMPLATE - fix_qreal*,qreal*,qreal*,qreal*,qreal* - START
                qreal a, b, c, d, e;
                cppSelf->getCmykF(&a, &b, &c, &d, &e);
                pyResult = Shiboken::makeTuple(a, b, c, d, e);
                // TEMPLATE - fix_qreal*,qreal*,qreal*,qreal*,qreal* - END
                
                // End of code injection


            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QColorFunc_getHsl(PyObject* self)
{
    QColor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QColor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // getHsl(int*,int*,int*,int*)const
                // Begin code injection
                
                // TEMPLATE - fix_int*,int*,int*,int* - START
                int a, b, c, d;
                cppSelf->getHsl(&a, &b, &c, &d);
                pyResult = Shiboken::makeTuple(a, b, c, d);
                // TEMPLATE - fix_int*,int*,int*,int* - END
                
                // End of code injection


            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QColorFunc_getHslF(PyObject* self)
{
    QColor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QColor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // getHslF(qreal*,qreal*,qreal*,qreal*)const
                // Begin code injection
                
                // TEMPLATE - fix_qreal*,qreal*,qreal*,qreal* - START
                qreal a, b, c, d;
                cppSelf->getHslF(&a, &b, &c, &d);
                pyResult = Shiboken::makeTuple(a, b, c, d);
                // TEMPLATE - fix_qreal*,qreal*,qreal*,qreal* - END
                
                // End of code injection


            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QColorFunc_getHsv(PyObject* self)
{
    QColor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QColor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // getHsv(int*,int*,int*,int*)const
                // Begin code injection
                
                // TEMPLATE - fix_int*,int*,int*,int* - START
                int a, b, c, d;
                cppSelf->getHsv(&a, &b, &c, &d);
                pyResult = Shiboken::makeTuple(a, b, c, d);
                // TEMPLATE - fix_int*,int*,int*,int* - END
                
                // End of code injection


            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QColorFunc_getHsvF(PyObject* self)
{
    QColor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QColor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // getHsvF(qreal*,qreal*,qreal*,qreal*)const
                // Begin code injection
                
                // TEMPLATE - fix_qreal*,qreal*,qreal*,qreal* - START
                qreal a, b, c, d;
                cppSelf->getHsvF(&a, &b, &c, &d);
                pyResult = Shiboken::makeTuple(a, b, c, d);
                // TEMPLATE - fix_qreal*,qreal*,qreal*,qreal* - END
                
                // End of code injection


            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QColorFunc_getRgb(PyObject* self)
{
    QColor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QColor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // getRgb(int*,int*,int*,int*)const
                // Begin code injection
                
                // TEMPLATE - fix_int*,int*,int*,int* - START
                int a, b, c, d;
                cppSelf->getRgb(&a, &b, &c, &d);
                pyResult = Shiboken::makeTuple(a, b, c, d);
                // TEMPLATE - fix_int*,int*,int*,int* - END
                
                // End of code injection


            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QColorFunc_getRgbF(PyObject* self)
{
    QColor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QColor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // getRgbF(qreal*,qreal*,qreal*,qreal*)const
                // Begin code injection
                
                // TEMPLATE - fix_qreal*,qreal*,qreal*,qreal* - START
                qreal a, b, c, d;
                cppSelf->getRgbF(&a, &b, &c, &d);
                pyResult = Shiboken::makeTuple(a, b, c, d);
                // TEMPLATE - fix_qreal*,qreal*,qreal*,qreal* - END
                
                // End of code injection


            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QColorFunc_green(PyObject* self)
{
    QColor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QColor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // green()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->green();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QColorFunc_greenF(PyObject* self)
{
    QColor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QColor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // greenF()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qreal cppResult = cppSelf->greenF();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< double >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QColorFunc_hslHue(PyObject* self)
{
    QColor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QColor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // hslHue()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->hslHue();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QColorFunc_hslHueF(PyObject* self)
{
    QColor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QColor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // hslHueF()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qreal cppResult = cppSelf->hslHueF();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< double >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QColorFunc_hslSaturation(PyObject* self)
{
    QColor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QColor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // hslSaturation()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->hslSaturation();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QColorFunc_hslSaturationF(PyObject* self)
{
    QColor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QColor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // hslSaturationF()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qreal cppResult = cppSelf->hslSaturationF();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< double >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QColorFunc_hsvHue(PyObject* self)
{
    QColor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QColor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // hsvHue()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->hsvHue();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QColorFunc_hsvHueF(PyObject* self)
{
    QColor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QColor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // hsvHueF()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qreal cppResult = cppSelf->hsvHueF();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< double >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QColorFunc_hsvSaturation(PyObject* self)
{
    QColor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QColor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // hsvSaturation()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->hsvSaturation();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QColorFunc_hsvSaturationF(PyObject* self)
{
    QColor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QColor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // hsvSaturationF()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qreal cppResult = cppSelf->hsvSaturationF();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< double >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QColorFunc_hue(PyObject* self)
{
    QColor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QColor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // hue()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->hue();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QColorFunc_hueF(PyObject* self)
{
    QColor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QColor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // hueF()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qreal cppResult = cppSelf->hueF();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< double >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QColorFunc_isValid(PyObject* self)
{
    QColor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QColor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isValid()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->isValid();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QColorFunc_isValidColor(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: isValidColor(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // isValidColor(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QColorFunc_isValidColor_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // isValidColor(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = QColor::isValidColor(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QColorFunc_isValidColor_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QColor.isValidColor", overloads);
        return 0;
}

static PyObject* Sbk_QColorFunc_lighter(PyObject* self, PyObject* args, PyObject* kwds)
{
    QColor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QColor* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QColor.lighter(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:lighter", &(pyargs[0])))
        return 0;


    // Overloaded function decisor
    // 0: lighter(int)const
    if (numArgs == 0) {
        overloadId = 0; // lighter(int)const
    } else if (SbkNumber_Check(pyargs[0])) {
        overloadId = 0; // lighter(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QColorFunc_lighter_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "f");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "f";
                    else if (SbkNumber_Check(value))
                        pyargs[0] = value;
else
                        goto Sbk_QColorFunc_lighter_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QColor.lighter(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cppArg0 = pyargs[0] ? Shiboken::Converter<int >::toCpp(pyargs[0]) : 150;

            if(!PyErr_Occurred()) {
                // lighter(int)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QColor cppResult = cppSelf->lighter(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QColor >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QColorFunc_lighter_TypeError:
        const char* overloads[] = {"int = 150", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QColor.lighter", overloads);
        return 0;
}

static PyObject* Sbk_QColorFunc_lightness(PyObject* self)
{
    QColor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QColor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // lightness()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->lightness();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QColorFunc_lightnessF(PyObject* self)
{
    QColor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QColor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // lightnessF()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qreal cppResult = cppSelf->lightnessF();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< double >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QColorFunc_magenta(PyObject* self)
{
    QColor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QColor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // magenta()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->magenta();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QColorFunc_magentaF(PyObject* self)
{
    QColor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QColor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // magentaF()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qreal cppResult = cppSelf->magentaF();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< double >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QColorFunc_name(PyObject* self)
{
    QColor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QColor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // name()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = cppSelf->name();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QColorFunc_red(PyObject* self)
{
    QColor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QColor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // red()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->red();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QColorFunc_redF(PyObject* self)
{
    QColor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QColor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // redF()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qreal cppResult = cppSelf->redF();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< double >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QColorFunc_rgb(PyObject* self)
{
    QColor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QColor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // rgb()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                unsigned int cppResult = cppSelf->rgb();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< unsigned int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QColorFunc_rgba(PyObject* self)
{
    QColor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QColor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // rgba()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                unsigned int cppResult = cppSelf->rgba();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< unsigned int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QColorFunc_saturation(PyObject* self)
{
    QColor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QColor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // saturation()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->saturation();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QColorFunc_saturationF(PyObject* self)
{
    QColor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QColor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // saturationF()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qreal cppResult = cppSelf->saturationF();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< double >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QColorFunc_setAllowX11ColorNames(PyObject* self, PyObject* arg)
{
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setAllowX11ColorNames(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setAllowX11ColorNames(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QColorFunc_setAllowX11ColorNames_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setAllowX11ColorNames(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QColor::setAllowX11ColorNames(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QColorFunc_setAllowX11ColorNames_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QColor.setAllowX11ColorNames", overloads);
        return 0;
}

static PyObject* Sbk_QColorFunc_setAlpha(PyObject* self, PyObject* arg)
{
    QColor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QColor* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setAlpha(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setAlpha(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QColorFunc_setAlpha_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setAlpha(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setAlpha(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QColorFunc_setAlpha_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QColor.setAlpha", overloads);
        return 0;
}

static PyObject* Sbk_QColorFunc_setAlphaF(PyObject* self, PyObject* arg)
{
    QColor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QColor* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setAlphaF(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setAlphaF(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QColorFunc_setAlphaF_TypeError;

    // Call function/method
    {
        {
            qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setAlphaF(qreal)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setAlphaF(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QColorFunc_setAlphaF_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QColor.setAlphaF", overloads);
        return 0;
}

static PyObject* Sbk_QColorFunc_setBlue(PyObject* self, PyObject* arg)
{
    QColor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QColor* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setBlue(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setBlue(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QColorFunc_setBlue_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setBlue(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setBlue(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QColorFunc_setBlue_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QColor.setBlue", overloads);
        return 0;
}

static PyObject* Sbk_QColorFunc_setBlueF(PyObject* self, PyObject* arg)
{
    QColor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QColor* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setBlueF(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setBlueF(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QColorFunc_setBlueF_TypeError;

    // Call function/method
    {
        {
            qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setBlueF(qreal)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setBlueF(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QColorFunc_setBlueF_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QColor.setBlueF", overloads);
        return 0;
}

static PyObject* Sbk_QColorFunc_setCmyk(PyObject* self, PyObject* args, PyObject* kwds)
{
    QColor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QColor* >::toCpp(self);

    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 5) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QColor.setCmyk(): too many arguments");
        return 0;
    } else if (numArgs < 4) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QColor.setCmyk(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOOO:setCmyk", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4])))
        return 0;


    // Overloaded function decisor
    // 0: setCmyk(int,int,int,int,int)
    if (numArgs >= 4 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
        if (numArgs == 4) {
            overloadId = 0; // setCmyk(int,int,int,int,int)
        } else if (SbkNumber_Check(pyargs[4])) {
            overloadId = 0; // setCmyk(int,int,int,int,int)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QColorFunc_setCmyk_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "a");
                if (value) {
                    if (pyargs[4])
                        errorArgName = "a";
                    else if (SbkNumber_Check(value))
                        pyargs[4] = value;
else
                        goto Sbk_QColorFunc_setCmyk_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QColor.setCmyk(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
            int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
            int cppArg3 = Shiboken::Converter<int >::toCpp(pyargs[3]);
            int cppArg4 = pyargs[4] ? Shiboken::Converter<int >::toCpp(pyargs[4]) : 255;

            if(!PyErr_Occurred()) {
                // setCmyk(int,int,int,int,int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setCmyk(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QColorFunc_setCmyk_TypeError:
        const char* overloads[] = {"int, int, int, int, int = 255", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QColor.setCmyk", overloads);
        return 0;
}

static PyObject* Sbk_QColorFunc_setCmykF(PyObject* self, PyObject* args, PyObject* kwds)
{
    QColor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QColor* >::toCpp(self);

    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 5) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QColor.setCmykF(): too many arguments");
        return 0;
    } else if (numArgs < 4) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QColor.setCmykF(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOOO:setCmykF", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4])))
        return 0;


    // Overloaded function decisor
    // 0: setCmykF(qreal,qreal,qreal,qreal,qreal)
    if (numArgs >= 4 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
        if (numArgs == 4) {
            overloadId = 0; // setCmykF(qreal,qreal,qreal,qreal,qreal)
        } else if (SbkNumber_Check(pyargs[4])) {
            overloadId = 0; // setCmykF(qreal,qreal,qreal,qreal,qreal)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QColorFunc_setCmykF_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "a");
                if (value) {
                    if (pyargs[4])
                        errorArgName = "a";
                    else if (SbkNumber_Check(value))
                        pyargs[4] = value;
else
                        goto Sbk_QColorFunc_setCmykF_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QColor.setCmykF(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
            qreal cppArg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
            qreal cppArg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);
            qreal cppArg3 = Shiboken::Converter<qreal >::toCpp(pyargs[3]);
            qreal cppArg4 = pyargs[4] ? Shiboken::Converter<qreal >::toCpp(pyargs[4]) : 1.0;

            if(!PyErr_Occurred()) {
                // setCmykF(qreal,qreal,qreal,qreal,qreal)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setCmykF(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QColorFunc_setCmykF_TypeError:
        const char* overloads[] = {"float, float, float, float, float = 1.0", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QColor.setCmykF", overloads);
        return 0;
}

static PyObject* Sbk_QColorFunc_setGreen(PyObject* self, PyObject* arg)
{
    QColor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QColor* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setGreen(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setGreen(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QColorFunc_setGreen_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setGreen(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setGreen(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QColorFunc_setGreen_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QColor.setGreen", overloads);
        return 0;
}

static PyObject* Sbk_QColorFunc_setGreenF(PyObject* self, PyObject* arg)
{
    QColor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QColor* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setGreenF(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setGreenF(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QColorFunc_setGreenF_TypeError;

    // Call function/method
    {
        {
            qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setGreenF(qreal)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setGreenF(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QColorFunc_setGreenF_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QColor.setGreenF", overloads);
        return 0;
}

static PyObject* Sbk_QColorFunc_setHsl(PyObject* self, PyObject* args, PyObject* kwds)
{
    QColor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QColor* >::toCpp(self);

    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 4) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QColor.setHsl(): too many arguments");
        return 0;
    } else if (numArgs < 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QColor.setHsl(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOO:setHsl", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: setHsl(int,int,int,int)
    if (numArgs >= 3 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
        if (numArgs == 3) {
            overloadId = 0; // setHsl(int,int,int,int)
        } else if (SbkNumber_Check(pyargs[3])) {
            overloadId = 0; // setHsl(int,int,int,int)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QColorFunc_setHsl_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "a");
                if (value) {
                    if (pyargs[3])
                        errorArgName = "a";
                    else if (SbkNumber_Check(value))
                        pyargs[3] = value;
else
                        goto Sbk_QColorFunc_setHsl_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QColor.setHsl(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
            int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
            int cppArg3 = pyargs[3] ? Shiboken::Converter<int >::toCpp(pyargs[3]) : 255;

            if(!PyErr_Occurred()) {
                // setHsl(int,int,int,int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setHsl(cppArg0, cppArg1, cppArg2, cppArg3);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QColorFunc_setHsl_TypeError:
        const char* overloads[] = {"int, int, int, int = 255", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QColor.setHsl", overloads);
        return 0;
}

static PyObject* Sbk_QColorFunc_setHslF(PyObject* self, PyObject* args, PyObject* kwds)
{
    QColor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QColor* >::toCpp(self);

    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 4) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QColor.setHslF(): too many arguments");
        return 0;
    } else if (numArgs < 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QColor.setHslF(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOO:setHslF", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: setHslF(qreal,qreal,qreal,qreal)
    if (numArgs >= 3 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
        if (numArgs == 3) {
            overloadId = 0; // setHslF(qreal,qreal,qreal,qreal)
        } else if (SbkNumber_Check(pyargs[3])) {
            overloadId = 0; // setHslF(qreal,qreal,qreal,qreal)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QColorFunc_setHslF_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "a");
                if (value) {
                    if (pyargs[3])
                        errorArgName = "a";
                    else if (SbkNumber_Check(value))
                        pyargs[3] = value;
else
                        goto Sbk_QColorFunc_setHslF_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QColor.setHslF(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
            qreal cppArg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
            qreal cppArg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);
            qreal cppArg3 = pyargs[3] ? Shiboken::Converter<qreal >::toCpp(pyargs[3]) : 1.0;

            if(!PyErr_Occurred()) {
                // setHslF(qreal,qreal,qreal,qreal)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setHslF(cppArg0, cppArg1, cppArg2, cppArg3);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QColorFunc_setHslF_TypeError:
        const char* overloads[] = {"float, float, float, float = 1.0", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QColor.setHslF", overloads);
        return 0;
}

static PyObject* Sbk_QColorFunc_setHsv(PyObject* self, PyObject* args, PyObject* kwds)
{
    QColor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QColor* >::toCpp(self);

    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 4) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QColor.setHsv(): too many arguments");
        return 0;
    } else if (numArgs < 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QColor.setHsv(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOO:setHsv", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: setHsv(int,int,int,int)
    if (numArgs >= 3 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
        if (numArgs == 3) {
            overloadId = 0; // setHsv(int,int,int,int)
        } else if (SbkNumber_Check(pyargs[3])) {
            overloadId = 0; // setHsv(int,int,int,int)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QColorFunc_setHsv_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "a");
                if (value) {
                    if (pyargs[3])
                        errorArgName = "a";
                    else if (SbkNumber_Check(value))
                        pyargs[3] = value;
else
                        goto Sbk_QColorFunc_setHsv_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QColor.setHsv(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
            int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
            int cppArg3 = pyargs[3] ? Shiboken::Converter<int >::toCpp(pyargs[3]) : 255;

            if(!PyErr_Occurred()) {
                // setHsv(int,int,int,int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setHsv(cppArg0, cppArg1, cppArg2, cppArg3);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QColorFunc_setHsv_TypeError:
        const char* overloads[] = {"int, int, int, int = 255", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QColor.setHsv", overloads);
        return 0;
}

static PyObject* Sbk_QColorFunc_setHsvF(PyObject* self, PyObject* args, PyObject* kwds)
{
    QColor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QColor* >::toCpp(self);

    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 4) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QColor.setHsvF(): too many arguments");
        return 0;
    } else if (numArgs < 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QColor.setHsvF(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOO:setHsvF", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: setHsvF(qreal,qreal,qreal,qreal)
    if (numArgs >= 3 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
        if (numArgs == 3) {
            overloadId = 0; // setHsvF(qreal,qreal,qreal,qreal)
        } else if (SbkNumber_Check(pyargs[3])) {
            overloadId = 0; // setHsvF(qreal,qreal,qreal,qreal)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QColorFunc_setHsvF_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "a");
                if (value) {
                    if (pyargs[3])
                        errorArgName = "a";
                    else if (SbkNumber_Check(value))
                        pyargs[3] = value;
else
                        goto Sbk_QColorFunc_setHsvF_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QColor.setHsvF(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
            qreal cppArg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
            qreal cppArg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);
            qreal cppArg3 = pyargs[3] ? Shiboken::Converter<qreal >::toCpp(pyargs[3]) : 1.0;

            if(!PyErr_Occurred()) {
                // setHsvF(qreal,qreal,qreal,qreal)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setHsvF(cppArg0, cppArg1, cppArg2, cppArg3);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QColorFunc_setHsvF_TypeError:
        const char* overloads[] = {"float, float, float, float = 1.0", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QColor.setHsvF", overloads);
        return 0;
}

static PyObject* Sbk_QColorFunc_setNamedColor(PyObject* self, PyObject* arg)
{
    QColor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QColor* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setNamedColor(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // setNamedColor(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QColorFunc_setNamedColor_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setNamedColor(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setNamedColor(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QColorFunc_setNamedColor_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QColor.setNamedColor", overloads);
        return 0;
}

static PyObject* Sbk_QColorFunc_setRed(PyObject* self, PyObject* arg)
{
    QColor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QColor* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setRed(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setRed(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QColorFunc_setRed_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setRed(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setRed(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QColorFunc_setRed_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QColor.setRed", overloads);
        return 0;
}

static PyObject* Sbk_QColorFunc_setRedF(PyObject* self, PyObject* arg)
{
    QColor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QColor* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setRedF(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setRedF(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QColorFunc_setRedF_TypeError;

    // Call function/method
    {
        {
            qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setRedF(qreal)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setRedF(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QColorFunc_setRedF_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QColor.setRedF", overloads);
        return 0;
}

static PyObject* Sbk_QColorFunc_setRgb(PyObject* self, PyObject* args, PyObject* kwds)
{
    QColor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QColor* >::toCpp(self);

    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 4) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QColor.setRgb(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QColor.setRgb(): not enough arguments");
        return 0;
    } else if (numArgs == 2)
        goto Sbk_QColorFunc_setRgb_TypeError;

    if (!PyArg_ParseTuple(args, "|OOOO:setRgb", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: setRgb(int,int,int,int)
    // 1: setRgb(uint)
    if (numArgs == 1 && SbkNumber_Check(pyargs[0])) {
        overloadId = 1; // setRgb(uint)
    } else if (numArgs >= 3 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
        if (numArgs == 3) {
            overloadId = 0; // setRgb(int,int,int,int)
        } else if (SbkNumber_Check(pyargs[3])) {
            overloadId = 0; // setRgb(int,int,int,int)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QColorFunc_setRgb_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setRgb(int,int,int,int)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "a");
                    if (value) {
                        if (pyargs[3])
                            errorArgName = "a";
                        else if (SbkNumber_Check(value))
                            pyargs[3] = value;
else
                            goto Sbk_QColorFunc_setRgb_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QColor.setRgb(): got multiple values for keyword argument '%s'", errorArgName);
                        return 0;
                    }
                }
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
                int cppArg3 = pyargs[3] ? Shiboken::Converter<int >::toCpp(pyargs[3]) : 255;

                if(!PyErr_Occurred()) {
                    // setRgb(int,int,int,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setRgb(cppArg0, cppArg1, cppArg2, cppArg3);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // setRgb(uint)
            {
                unsigned int cppArg0 = Shiboken::Converter<unsigned int >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // setRgb(uint)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setRgb(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QColorFunc_setRgb_TypeError:
        const char* overloads[] = {"int, int, int, int = 255", "unsigned int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QColor.setRgb", overloads);
        return 0;
}

static PyObject* Sbk_QColorFunc_setRgbF(PyObject* self, PyObject* args, PyObject* kwds)
{
    QColor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QColor* >::toCpp(self);

    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 4) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QColor.setRgbF(): too many arguments");
        return 0;
    } else if (numArgs < 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QColor.setRgbF(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOO:setRgbF", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: setRgbF(qreal,qreal,qreal,qreal)
    if (numArgs >= 3 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
        if (numArgs == 3) {
            overloadId = 0; // setRgbF(qreal,qreal,qreal,qreal)
        } else if (SbkNumber_Check(pyargs[3])) {
            overloadId = 0; // setRgbF(qreal,qreal,qreal,qreal)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QColorFunc_setRgbF_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "a");
                if (value) {
                    if (pyargs[3])
                        errorArgName = "a";
                    else if (SbkNumber_Check(value))
                        pyargs[3] = value;
else
                        goto Sbk_QColorFunc_setRgbF_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QColor.setRgbF(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
            qreal cppArg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
            qreal cppArg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);
            qreal cppArg3 = pyargs[3] ? Shiboken::Converter<qreal >::toCpp(pyargs[3]) : 1.0;

            if(!PyErr_Occurred()) {
                // setRgbF(qreal,qreal,qreal,qreal)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setRgbF(cppArg0, cppArg1, cppArg2, cppArg3);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QColorFunc_setRgbF_TypeError:
        const char* overloads[] = {"float, float, float, float = 1.0", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QColor.setRgbF", overloads);
        return 0;
}

static PyObject* Sbk_QColorFunc_setRgba(PyObject* self, PyObject* arg)
{
    QColor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QColor* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setRgba(uint)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setRgba(uint)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QColorFunc_setRgba_TypeError;

    // Call function/method
    {
        {
            unsigned int cppArg0 = Shiboken::Converter<unsigned int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setRgba(uint)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setRgba(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QColorFunc_setRgba_TypeError:
        const char* overloads[] = {"unsigned int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QColor.setRgba", overloads);
        return 0;
}

static PyObject* Sbk_QColorFunc_spec(PyObject* self)
{
    QColor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QColor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // spec()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QColor::Spec cppResult = cppSelf->spec();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QColor::Spec >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QColorFunc_toCmyk(PyObject* self)
{
    QColor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QColor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // toCmyk()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QColor cppResult = cppSelf->toCmyk();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QColor >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QColorFunc_toHsl(PyObject* self)
{
    QColor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QColor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // toHsl()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QColor cppResult = cppSelf->toHsl();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QColor >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QColorFunc_toHsv(PyObject* self)
{
    QColor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QColor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // toHsv()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QColor cppResult = cppSelf->toHsv();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QColor >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QColorFunc_toRgb(PyObject* self)
{
    QColor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QColor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // toRgb()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QColor cppResult = cppSelf->toRgb();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QColor >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QColorFunc_value(PyObject* self)
{
    QColor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QColor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // value()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->value();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QColorFunc_valueF(PyObject* self)
{
    QColor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QColor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // valueF()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qreal cppResult = cppSelf->valueF();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< double >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QColorFunc_yellow(PyObject* self)
{
    QColor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QColor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // yellow()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->yellow();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QColorFunc_yellowF(PyObject* self)
{
    QColor* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QColor* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // yellowF()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qreal cppResult = cppSelf->yellowF();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< double >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject *Sbk_QColor___copy__(PyObject *self)
{
        QColor* cppSelf = 0;
        if (!Shiboken::Object::isValid(self))
            return 0;
        cppSelf = Shiboken::Converter<QColor*>::toCpp(self);
        PyObject* pyResult = 0;
        QColor* copy = new QColor(*cppSelf);
        pyResult = Shiboken::Converter<QColor*>::toPython(copy);
        Shiboken::Object::getOwnership(pyResult);

        if (PyErr_Occurred() || !pyResult) {
            Py_XDECREF(pyResult);
            return 0;
        }
        return pyResult;
}

static PyMethodDef Sbk_QColor_methods[] = {
    {"__reduce__", (PyCFunction)Sbk_QColorFunc___reduce__, METH_NOARGS},
    {"allowX11ColorNames", (PyCFunction)Sbk_QColorFunc_allowX11ColorNames, METH_NOARGS|METH_STATIC},
    {"alpha", (PyCFunction)Sbk_QColorFunc_alpha, METH_NOARGS},
    {"alphaF", (PyCFunction)Sbk_QColorFunc_alphaF, METH_NOARGS},
    {"black", (PyCFunction)Sbk_QColorFunc_black, METH_NOARGS},
    {"blackF", (PyCFunction)Sbk_QColorFunc_blackF, METH_NOARGS},
    {"blue", (PyCFunction)Sbk_QColorFunc_blue, METH_NOARGS},
    {"blueF", (PyCFunction)Sbk_QColorFunc_blueF, METH_NOARGS},
    {"colorNames", (PyCFunction)Sbk_QColorFunc_colorNames, METH_NOARGS|METH_STATIC},
    {"convertTo", (PyCFunction)Sbk_QColorFunc_convertTo, METH_O},
    {"cyan", (PyCFunction)Sbk_QColorFunc_cyan, METH_NOARGS},
    {"cyanF", (PyCFunction)Sbk_QColorFunc_cyanF, METH_NOARGS},
    {"darker", (PyCFunction)Sbk_QColorFunc_darker, METH_VARARGS|METH_KEYWORDS},
    {"fromCmyk", (PyCFunction)Sbk_QColorFunc_fromCmyk, METH_VARARGS|METH_KEYWORDS|METH_STATIC},
    {"fromCmykF", (PyCFunction)Sbk_QColorFunc_fromCmykF, METH_VARARGS|METH_KEYWORDS|METH_STATIC},
    {"fromHsl", (PyCFunction)Sbk_QColorFunc_fromHsl, METH_VARARGS|METH_KEYWORDS|METH_STATIC},
    {"fromHslF", (PyCFunction)Sbk_QColorFunc_fromHslF, METH_VARARGS|METH_KEYWORDS|METH_STATIC},
    {"fromHsv", (PyCFunction)Sbk_QColorFunc_fromHsv, METH_VARARGS|METH_KEYWORDS|METH_STATIC},
    {"fromHsvF", (PyCFunction)Sbk_QColorFunc_fromHsvF, METH_VARARGS|METH_KEYWORDS|METH_STATIC},
    {"fromRgb", (PyCFunction)Sbk_QColorFunc_fromRgb, METH_VARARGS|METH_KEYWORDS|METH_STATIC},
    {"fromRgbF", (PyCFunction)Sbk_QColorFunc_fromRgbF, METH_VARARGS|METH_KEYWORDS|METH_STATIC},
    {"fromRgba", (PyCFunction)Sbk_QColorFunc_fromRgba, METH_O|METH_STATIC},
    {"getCmyk", (PyCFunction)Sbk_QColorFunc_getCmyk, METH_NOARGS},
    {"getCmykF", (PyCFunction)Sbk_QColorFunc_getCmykF, METH_NOARGS},
    {"getHsl", (PyCFunction)Sbk_QColorFunc_getHsl, METH_NOARGS},
    {"getHslF", (PyCFunction)Sbk_QColorFunc_getHslF, METH_NOARGS},
    {"getHsv", (PyCFunction)Sbk_QColorFunc_getHsv, METH_NOARGS},
    {"getHsvF", (PyCFunction)Sbk_QColorFunc_getHsvF, METH_NOARGS},
    {"getRgb", (PyCFunction)Sbk_QColorFunc_getRgb, METH_NOARGS},
    {"getRgbF", (PyCFunction)Sbk_QColorFunc_getRgbF, METH_NOARGS},
    {"green", (PyCFunction)Sbk_QColorFunc_green, METH_NOARGS},
    {"greenF", (PyCFunction)Sbk_QColorFunc_greenF, METH_NOARGS},
    {"hslHue", (PyCFunction)Sbk_QColorFunc_hslHue, METH_NOARGS},
    {"hslHueF", (PyCFunction)Sbk_QColorFunc_hslHueF, METH_NOARGS},
    {"hslSaturation", (PyCFunction)Sbk_QColorFunc_hslSaturation, METH_NOARGS},
    {"hslSaturationF", (PyCFunction)Sbk_QColorFunc_hslSaturationF, METH_NOARGS},
    {"hsvHue", (PyCFunction)Sbk_QColorFunc_hsvHue, METH_NOARGS},
    {"hsvHueF", (PyCFunction)Sbk_QColorFunc_hsvHueF, METH_NOARGS},
    {"hsvSaturation", (PyCFunction)Sbk_QColorFunc_hsvSaturation, METH_NOARGS},
    {"hsvSaturationF", (PyCFunction)Sbk_QColorFunc_hsvSaturationF, METH_NOARGS},
    {"hue", (PyCFunction)Sbk_QColorFunc_hue, METH_NOARGS},
    {"hueF", (PyCFunction)Sbk_QColorFunc_hueF, METH_NOARGS},
    {"isValid", (PyCFunction)Sbk_QColorFunc_isValid, METH_NOARGS},
    {"isValidColor", (PyCFunction)Sbk_QColorFunc_isValidColor, METH_O|METH_STATIC},
    {"lighter", (PyCFunction)Sbk_QColorFunc_lighter, METH_VARARGS|METH_KEYWORDS},
    {"lightness", (PyCFunction)Sbk_QColorFunc_lightness, METH_NOARGS},
    {"lightnessF", (PyCFunction)Sbk_QColorFunc_lightnessF, METH_NOARGS},
    {"magenta", (PyCFunction)Sbk_QColorFunc_magenta, METH_NOARGS},
    {"magentaF", (PyCFunction)Sbk_QColorFunc_magentaF, METH_NOARGS},
    {"name", (PyCFunction)Sbk_QColorFunc_name, METH_NOARGS},
    {"red", (PyCFunction)Sbk_QColorFunc_red, METH_NOARGS},
    {"redF", (PyCFunction)Sbk_QColorFunc_redF, METH_NOARGS},
    {"rgb", (PyCFunction)Sbk_QColorFunc_rgb, METH_NOARGS},
    {"rgba", (PyCFunction)Sbk_QColorFunc_rgba, METH_NOARGS},
    {"saturation", (PyCFunction)Sbk_QColorFunc_saturation, METH_NOARGS},
    {"saturationF", (PyCFunction)Sbk_QColorFunc_saturationF, METH_NOARGS},
    {"setAllowX11ColorNames", (PyCFunction)Sbk_QColorFunc_setAllowX11ColorNames, METH_O|METH_STATIC},
    {"setAlpha", (PyCFunction)Sbk_QColorFunc_setAlpha, METH_O},
    {"setAlphaF", (PyCFunction)Sbk_QColorFunc_setAlphaF, METH_O},
    {"setBlue", (PyCFunction)Sbk_QColorFunc_setBlue, METH_O},
    {"setBlueF", (PyCFunction)Sbk_QColorFunc_setBlueF, METH_O},
    {"setCmyk", (PyCFunction)Sbk_QColorFunc_setCmyk, METH_VARARGS|METH_KEYWORDS},
    {"setCmykF", (PyCFunction)Sbk_QColorFunc_setCmykF, METH_VARARGS|METH_KEYWORDS},
    {"setGreen", (PyCFunction)Sbk_QColorFunc_setGreen, METH_O},
    {"setGreenF", (PyCFunction)Sbk_QColorFunc_setGreenF, METH_O},
    {"setHsl", (PyCFunction)Sbk_QColorFunc_setHsl, METH_VARARGS|METH_KEYWORDS},
    {"setHslF", (PyCFunction)Sbk_QColorFunc_setHslF, METH_VARARGS|METH_KEYWORDS},
    {"setHsv", (PyCFunction)Sbk_QColorFunc_setHsv, METH_VARARGS|METH_KEYWORDS},
    {"setHsvF", (PyCFunction)Sbk_QColorFunc_setHsvF, METH_VARARGS|METH_KEYWORDS},
    {"setNamedColor", (PyCFunction)Sbk_QColorFunc_setNamedColor, METH_O},
    {"setRed", (PyCFunction)Sbk_QColorFunc_setRed, METH_O},
    {"setRedF", (PyCFunction)Sbk_QColorFunc_setRedF, METH_O},
    {"setRgb", (PyCFunction)Sbk_QColorFunc_setRgb, METH_VARARGS|METH_KEYWORDS},
    {"setRgbF", (PyCFunction)Sbk_QColorFunc_setRgbF, METH_VARARGS|METH_KEYWORDS},
    {"setRgba", (PyCFunction)Sbk_QColorFunc_setRgba, METH_O},
    {"spec", (PyCFunction)Sbk_QColorFunc_spec, METH_NOARGS},
    {"toCmyk", (PyCFunction)Sbk_QColorFunc_toCmyk, METH_NOARGS},
    {"toHsl", (PyCFunction)Sbk_QColorFunc_toHsl, METH_NOARGS},
    {"toHsv", (PyCFunction)Sbk_QColorFunc_toHsv, METH_NOARGS},
    {"toRgb", (PyCFunction)Sbk_QColorFunc_toRgb, METH_NOARGS},
    {"value", (PyCFunction)Sbk_QColorFunc_value, METH_NOARGS},
    {"valueF", (PyCFunction)Sbk_QColorFunc_valueF, METH_NOARGS},
    {"yellow", (PyCFunction)Sbk_QColorFunc_yellow, METH_NOARGS},
    {"yellowF", (PyCFunction)Sbk_QColorFunc_yellowF, METH_NOARGS},

    {"__copy__", (PyCFunction)Sbk_QColor___copy__, METH_NOARGS},
    {0} // Sentinel
};

static PyObject* Sbk_QColorFunc___lshift__(PyObject* self, PyObject* arg)
{
    QColor* cppSelf = 0;
    bool isReverse = Shiboken::Converter< ::QColor >::checkType(arg) && !Shiboken::Converter< ::QColor >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QColor* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && Shiboken::Object::checkType(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rlshift__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rlshift__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator<<(QDataStream&,QColor)
    if (isReverse && Shiboken::Converter< ::QDataStream & >::isConvertible(arg)) {
        overloadId = 0; // operator<<(QDataStream&,QColor)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QColorFunc___lshift___TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QDataStream & cppArg0 = Shiboken::Converter<QDataStream & >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // operator<<(QDataStream&,QColor) [reverse operator]
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDataStream & cppResult = (cppArg0) << (*cppSelf);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDataStream & >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QColorFunc___lshift___TypeError:
        const char* overloads[] = {"PySide.QtCore.QDataStream", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QColor.__lshift__", overloads);
        return 0;
}

static PyObject* Sbk_QColorFunc___rshift__(PyObject* self, PyObject* arg)
{
    QColor* cppSelf = 0;
    bool isReverse = Shiboken::Converter< ::QColor >::checkType(arg) && !Shiboken::Converter< ::QColor >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QColor* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && Shiboken::Object::checkType(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rrshift__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rrshift__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator>>(QDataStream&,QColor&)
    if (isReverse && Shiboken::Converter< ::QDataStream & >::isConvertible(arg)) {
        overloadId = 0; // operator>>(QDataStream&,QColor&)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QColorFunc___rshift___TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QDataStream & cppArg0 = Shiboken::Converter<QDataStream & >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // operator>>(QDataStream&,QColor&) [reverse operator]
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDataStream & cppResult = (cppArg0) >> (*cppSelf);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDataStream & >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QColorFunc___rshift___TypeError:
        const char* overloads[] = {"PySide.QtCore.QDataStream", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QColor.__rshift__", overloads);
        return 0;
}

// type has number operators
static PyNumberMethods Sbk_QColor_as_number = {
    /*nb_add*/                  (binaryfunc)0,
    /*nb_subtract*/             (binaryfunc)0,
    /*nb_multiply*/             (binaryfunc)0,
    /*nb_divide*/               (binaryfunc)0,
    /*nb_remainder*/            (binaryfunc)0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             (unaryfunc)0,
    /*nb_positive*/             (unaryfunc)0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              0,
    /*nb_invert*/               (unaryfunc)0,
    /*nb_lshift*/               (binaryfunc)Sbk_QColorFunc___lshift__,
    /*nb_rshift*/               (binaryfunc)Sbk_QColorFunc___rshift__,
    /*nb_and*/                  (binaryfunc)0,
    /*nb_xor*/                  (binaryfunc)0,
    /*nb_or*/                   (binaryfunc)0,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          (binaryfunc)0,
    /*nb_inplace_subtract*/     (binaryfunc)0,
    /*nb_inplace_multiply*/     (binaryfunc)0,
    /*nb_inplace_divide*/       (binaryfunc)0,
    /*nb_inplace_remainder*/    (binaryfunc)0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       (binaryfunc)0,
    /*nb_inplace_rshift*/       (binaryfunc)0,
    /*nb_inplace_and*/          (binaryfunc)0,
    /*nb_inplace_xor*/          (binaryfunc)0,
    /*nb_inplace_or*/           (binaryfunc)0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          (binaryfunc)0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};

// Rich comparison
static PyObject* Sbk_QColor_richcompare(PyObject* self, PyObject* arg, int op)
{
    PyObject* pyResult = 0;
    QColor& cppSelf = *Shiboken::Converter< QColor* >::toCpp(self);

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter< ::QColor >::isConvertible(arg)) {
                // operator!=(const QColor & c) const
                QColor cppArg0 = Shiboken::Converter< ::QColor >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf != cppArg0);
            } else goto Sbk_QColor_RichComparison_TypeError;

            break;
        case Py_EQ:
            if (Shiboken::Converter< ::QColor >::isConvertible(arg)) {
                // operator==(const QColor & c) const
                QColor cppArg0 = Shiboken::Converter< ::QColor >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf == cppArg0);
            } else goto Sbk_QColor_RichComparison_TypeError;

            break;
        default:
            goto Sbk_QColor_RichComparison_TypeError;
    }

    if (pyResult && !PyErr_Occurred())
        return pyResult;
    Sbk_QColor_RichComparison_TypeError:
    PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
    return 0;

}

} // extern "C"

extern "C"
{
static PyObject* Sbk_QColor__repr__(PyObject* pyObj)
{
    QBuffer buffer;
    buffer.open(QBuffer::ReadWrite);
    QDebug dbg(&buffer);
    dbg << Shiboken::Converter< ::QColor >::toCpp(pyObj);
    buffer.close();
    return PyString_FromFormat("<PySide.QtGui.%s at %p>", buffer.data().constData(), pyObj);
}
} // extern C

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QColor_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QColor",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Sbk_QColor__repr__,
    /*tp_as_number*/        &Sbk_QColor_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      Sbk_QColor_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QColor_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QColor_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QColor(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QCOLOR_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QColor_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QColor_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QColor_Type, &Shiboken::callCppDestructor<QColor >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QColor_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QColor_Type, "QColor");
    PyModule_AddObject(module, "QColor",
        ((PyObject*)&Sbk_QColor_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: Spec
    PyTypeObject* SbkPySide_QtGui_QColor_Spec = Shiboken::Enum::newType("Spec");
    SbkPySide_QtGuiTypes[SBK_QCOLOR_SPEC_IDX] = SbkPySide_QtGui_QColor_Spec;
    if (PyType_Ready(SbkPySide_QtGui_QColor_Spec) < 0)
        return;
    PyDict_SetItemString(Sbk_QColor_Type.super.ht_type.tp_dict,
            "Spec",((PyObject*)SbkPySide_QtGui_QColor_Spec));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QColor_Spec,(long) QColor::Invalid, "Invalid");
    PyDict_SetItemString(Sbk_QColor_Type.super.ht_type.tp_dict,"Invalid", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QColor_Spec->tp_dict,"Invalid", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QColor_Spec,(long) QColor::Rgb, "Rgb");
    PyDict_SetItemString(Sbk_QColor_Type.super.ht_type.tp_dict,"Rgb", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QColor_Spec->tp_dict,"Rgb", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QColor_Spec,(long) QColor::Hsv, "Hsv");
    PyDict_SetItemString(Sbk_QColor_Type.super.ht_type.tp_dict,"Hsv", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QColor_Spec->tp_dict,"Hsv", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QColor_Spec,(long) QColor::Cmyk, "Cmyk");
    PyDict_SetItemString(Sbk_QColor_Type.super.ht_type.tp_dict,"Cmyk", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QColor_Spec->tp_dict,"Cmyk", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QColor_Spec,(long) QColor::Hsl, "Hsl");
    PyDict_SetItemString(Sbk_QColor_Type.super.ht_type.tp_dict,"Hsl", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QColor_Spec->tp_dict,"Hsl", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QColor::Spec");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::Spec");
    // end of enum Spec


    Shiboken::TypeResolver::createValueTypeResolver<QColor >("QColor");
    Shiboken::TypeResolver::createObjectTypeResolver<QColor >("QColor*");
    Shiboken::TypeResolver::createValueTypeResolver<QColor >(typeid(QColor).name());
    PySide::initQtMetaType<QColor >();
}

