/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include <set>
#include "pyside_qtgui_python.h"

#include "qdragenterevent_wrapper.h"

// Extra includes
#include <qmimedata.h>
#include <qpoint.h>
#include <qrect.h>
#include <qwidget.h>


// Native ---------------------------------------------------------

QDragEnterEventWrapper::QDragEnterEventWrapper(const QPoint & pos, QFlags<Qt::DropAction> actions, const QMimeData * data, QFlags<Qt::MouseButton> buttons, QFlags<Qt::KeyboardModifier> modifiers) : QDragEnterEvent(pos, actions, data, buttons, modifiers) {
    // ... middle
}

QDragEnterEventWrapper::~QDragEnterEventWrapper()
{
    SbkObject* wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QDragEnterEvent_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QDragEnterEvent >()))
        return -1;

    QDragEnterEventWrapper* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QDragEnterEvent", 5, 5, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4])))
        return -1;

    // Overloaded function decisor
    // 0: QDragEnterEvent(QPoint,QFlags<Qt::DropAction>,const QMimeData*,QFlags<Qt::MouseButton>,QFlags<Qt::KeyboardModifier>)
    if (numArgs == 5 && Shiboken::Converter< ::QPoint >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QFlags<Qt::DropAction> >::isConvertible(pyargs[1]) && Shiboken::Converter< ::QMimeData * >::isConvertible(pyargs[2]) && Shiboken::Converter< ::QFlags<Qt::MouseButton> >::isConvertible(pyargs[3]) && Shiboken::Converter< ::QFlags<Qt::KeyboardModifier> >::isConvertible(pyargs[4])) {
        overloadId = 0; // QDragEnterEvent(QPoint,QFlags<Qt::DropAction>,const QMimeData*,QFlags<Qt::MouseButton>,QFlags<Qt::KeyboardModifier>)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDragEnterEvent_Init_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(pyargs[0]))
                return -1;
            QPoint cppArg0 = Shiboken::Converter<QPoint >::toCpp(pyargs[0]);
            QFlags<Qt::DropAction> cppArg1 = Shiboken::Converter<QFlags<Qt::DropAction> >::toCpp(pyargs[1]);
            if (!Shiboken::Object::isValid(pyargs[2]))
                return -1;
            QMimeData * cppArg2 = Shiboken::Converter<QMimeData * >::toCpp(pyargs[2]);
            QFlags<Qt::MouseButton> cppArg3 = Shiboken::Converter<QFlags<Qt::MouseButton> >::toCpp(pyargs[3]);
            QFlags<Qt::KeyboardModifier> cppArg4 = Shiboken::Converter<QFlags<Qt::KeyboardModifier> >::toCpp(pyargs[4]);

            if(!PyErr_Occurred()) {
                // QDragEnterEvent(QPoint,QFlags<Qt::DropAction>,const QMimeData*,QFlags<Qt::MouseButton>,QFlags<Qt::KeyboardModifier>)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new QDragEnterEventWrapper(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QDragEnterEvent >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QDragEnterEvent_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QDragEnterEvent_Init_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint, PySide.QtCore.Qt.DropActions, PySide.QtCore.QMimeData, PySide.QtCore.Qt.MouseButtons, PySide.QtCore.Qt.KeyboardModifiers", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QDragEnterEvent", overloads);
        return -1;
}

static PyMethodDef Sbk_QDragEnterEvent_methods[] = {

    {0} // Sentinel
};

} // extern "C"

static void* Sbk_QDragEnterEventSpecialCastFunction(void* obj, SbkObjectType* desiredType)
{
    QDragEnterEvent* me = reinterpret_cast<QDragEnterEvent*>(obj);
    if (desiredType == reinterpret_cast<SbkObjectType*>(SbkPySide_QtGuiTypes[SBK_QDRAGMOVEEVENT_IDX]))
        return static_cast<QDragMoveEvent*>(me);
    else if (desiredType == reinterpret_cast<SbkObjectType*>(SbkPySide_QtGuiTypes[SBK_QDROPEVENT_IDX]))
        return static_cast<QDropEvent*>(me);
    else if (desiredType == reinterpret_cast<SbkObjectType*>(SbkPySide_QtCoreTypes[SBK_QEVENT_IDX]))
        return static_cast<QEvent*>(me);
    return me;
}


// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QDragEnterEvent_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QDragEnterEvent",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QDragEnterEvent_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QDragEnterEvent_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern

static SbkObjectType* Sbk_QDragEnterEvent_typeDiscovery(void* cptr, SbkObjectType* instanceType)
{
     if ( reinterpret_cast<QDragEnterEvent*>(cptr)->type() == QEvent::DragEnter)
        return &Sbk_QDragEnterEvent_Type;
    return 0;
}


void init_QDragEnterEvent(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QDRAGENTEREVENT_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QDragEnterEvent_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QDragEnterEvent_Type);
    Sbk_QDragEnterEvent_Type.super.ht_type.tp_base = SbkPySide_QtGuiTypes[SBK_QDRAGMOVEEVENT_IDX];
    MultipleInheritanceInitFunction func;
    func = Shiboken::ObjectType::getMultipleIheritanceFunction(reinterpret_cast<SbkObjectType*>(SbkPySide_QtGuiTypes[SBK_QDROPEVENT_IDX]));
    Shiboken::ObjectType::setMultipleIheritanceFunction(&Sbk_QDragEnterEvent_Type, func);
    Shiboken::ObjectType::setCastFunction(&Sbk_QDragEnterEvent_Type, &Sbk_QDragEnterEventSpecialCastFunction);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QDragEnterEvent_Type, &Shiboken::callCppDestructor<QDragEnterEvent >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QDragEnterEvent_Type) < 0)
        return;

    // Fill type discovery information
    Shiboken::ObjectType::setTypeDiscoveryFunction(&Sbk_QDragEnterEvent_Type, &Sbk_QDragEnterEvent_typeDiscovery);
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkObjectType*>(SbkPySide_QtGuiTypes[SBK_QDRAGMOVEEVENT_IDX]), &Sbk_QDragEnterEvent_Type);

    Shiboken::ObjectType::setOriginalName(&Sbk_QDragEnterEvent_Type, "QDragEnterEvent*");
    PyModule_AddObject(module, "QDragEnterEvent",
        ((PyObject*)&Sbk_QDragEnterEvent_Type));


    Shiboken::TypeResolver::createObjectTypeResolver<QDragEnterEvent >("QDragEnterEvent*");
    Shiboken::TypeResolver::createObjectTypeResolver<QDragEnterEvent >(typeid(QDragEnterEvent).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QDragEnterEvent >(typeid(QDragEnterEventWrapper).name());
    PySide::initQtMetaType<QDragEnterEvent* >();
}

