/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qfontdatabase_wrapper.h"

// Extra includes
#include <QList>
#include <QStringList>
#include <qbytearray.h>
#include <qfont.h>
#include <qfontinfo.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QFontDatabase_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QFontDatabase >()))
        return -1;

    QFontDatabase* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QFontDatabase", 0, 1, &(pyargs[0])))
        return -1;

    // Overloaded function decisor
    // 0: QFontDatabase()
    // 1: QFontDatabase(QFontDatabase)
    if (numArgs == 0) {
        overloadId = 0; // QFontDatabase()
    } else if (numArgs == 1 && Shiboken::Converter< ::QFontDatabase >::isConvertible(pyargs[0])) {
        overloadId = 1; // QFontDatabase(QFontDatabase)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFontDatabase_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QFontDatabase()
            {

                if(!PyErr_Occurred()) {
                    // QFontDatabase()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QFontDatabase();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // QFontDatabase(QFontDatabase)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QFontDatabase cppArg0 = Shiboken::Converter<QFontDatabase >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QFontDatabase(QFontDatabase)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QFontDatabase(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QFontDatabase >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QFontDatabase_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QFontDatabase_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtGui.QFontDatabase", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QFontDatabase", overloads);
        return -1;
}

static PyObject* Sbk_QFontDatabaseFunc_addApplicationFont(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: addApplicationFont(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // addApplicationFont(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFontDatabaseFunc_addApplicationFont_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // addApplicationFont(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = QFontDatabase::addApplicationFont(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QFontDatabaseFunc_addApplicationFont_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFontDatabase.addApplicationFont", overloads);
        return 0;
}

static PyObject* Sbk_QFontDatabaseFunc_addApplicationFontFromData(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: addApplicationFontFromData(QByteArray)
    if (Shiboken::Converter< ::QByteArray >::isConvertible(arg)) {
        overloadId = 0; // addApplicationFontFromData(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFontDatabaseFunc_addApplicationFontFromData_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QByteArray cppArg0 = Shiboken::Converter<QByteArray >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // addApplicationFontFromData(QByteArray)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = QFontDatabase::addApplicationFontFromData(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QFontDatabaseFunc_addApplicationFontFromData_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFontDatabase.addApplicationFontFromData", overloads);
        return 0;
}

static PyObject* Sbk_QFontDatabaseFunc_applicationFontFamilies(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: applicationFontFamilies(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // applicationFontFamilies(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFontDatabaseFunc_applicationFontFamilies_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // applicationFontFamilies(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QStringList cppResult = QFontDatabase::applicationFontFamilies(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QStringList >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QFontDatabaseFunc_applicationFontFamilies_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFontDatabase.applicationFontFamilies", overloads);
        return 0;
}

static PyObject* Sbk_QFontDatabaseFunc_bold(PyObject* self, PyObject* args)
{
    QFontDatabase* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFontDatabase* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "bold", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: bold(QString,QString)const
    if (numArgs == 2 && Shiboken::Converter< QString >::isConvertible(pyargs[0]) && Shiboken::Converter< QString >::isConvertible(pyargs[1])) {
        overloadId = 0; // bold(QString,QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFontDatabaseFunc_bold_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QString cppArg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // bold(QString,QString)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->bold(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QFontDatabaseFunc_bold_TypeError:
        const char* overloads[] = {"QString, QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QFontDatabase.bold", overloads);
        return 0;
}

static PyObject* Sbk_QFontDatabaseFunc_families(PyObject* self, PyObject* args, PyObject* kwds)
{
    QFontDatabase* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFontDatabase* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QFontDatabase.families(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:families", &(pyargs[0])))
        return 0;


    // Overloaded function decisor
    // 0: families(QFontDatabase::WritingSystem)const
    if (numArgs == 0) {
        overloadId = 0; // families(QFontDatabase::WritingSystem)const
    } else if (Shiboken::Converter< ::QFontDatabase::WritingSystem >::isConvertible(pyargs[0])) {
        overloadId = 0; // families(QFontDatabase::WritingSystem)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFontDatabaseFunc_families_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "writingSystem");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "writingSystem";
                    else if (Shiboken::Converter< ::QFontDatabase::WritingSystem >::isConvertible(value))
                        pyargs[0] = value;
else
                        goto Sbk_QFontDatabaseFunc_families_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QFontDatabase.families(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QFontDatabase::WritingSystem cppArg0 = pyargs[0] ? Shiboken::Converter<QFontDatabase::WritingSystem >::toCpp(pyargs[0]) : QFontDatabase::Any;

            if(!PyErr_Occurred()) {
                // families(QFontDatabase::WritingSystem)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QStringList cppResult = cppSelf->families(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QStringList >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QFontDatabaseFunc_families_TypeError:
        const char* overloads[] = {"PySide.QtGui.QFontDatabase.WritingSystem = Any", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QFontDatabase.families", overloads);
        return 0;
}

static PyObject* Sbk_QFontDatabaseFunc_font(PyObject* self, PyObject* args)
{
    QFontDatabase* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFontDatabase* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "font", 3, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: font(QString,QString,int)const
    if (numArgs == 3 && Shiboken::Converter< QString >::isConvertible(pyargs[0]) && Shiboken::Converter< QString >::isConvertible(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
        overloadId = 0; // font(QString,QString,int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFontDatabaseFunc_font_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QString cppArg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);
            int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

            if(!PyErr_Occurred()) {
                // font(QString,QString,int)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QFont cppResult = cppSelf->font(cppArg0, cppArg1, cppArg2);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QFont >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QFontDatabaseFunc_font_TypeError:
        const char* overloads[] = {"QString, QString, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QFontDatabase.font", overloads);
        return 0;
}

static PyObject* Sbk_QFontDatabaseFunc_isBitmapScalable(PyObject* self, PyObject* args, PyObject* kwds)
{
    QFontDatabase* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFontDatabase* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QFontDatabase.isBitmapScalable(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QFontDatabase.isBitmapScalable(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:isBitmapScalable", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: isBitmapScalable(QString,QString)const
    if (Shiboken::Converter< QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // isBitmapScalable(QString,QString)const
        } else if (Shiboken::Converter< QString >::isConvertible(pyargs[1])) {
            overloadId = 0; // isBitmapScalable(QString,QString)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFontDatabaseFunc_isBitmapScalable_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "style");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "style";
                    else if (Shiboken::Converter< QString >::isConvertible(value))
                        pyargs[1] = value;
else
                        goto Sbk_QFontDatabaseFunc_isBitmapScalable_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QFontDatabase.isBitmapScalable(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QString cppArg1 = pyargs[1] ? Shiboken::Converter<QString >::toCpp(pyargs[1]) : QString();

            if(!PyErr_Occurred()) {
                // isBitmapScalable(QString,QString)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->isBitmapScalable(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QFontDatabaseFunc_isBitmapScalable_TypeError:
        const char* overloads[] = {"QString, QString = QString()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QFontDatabase.isBitmapScalable", overloads);
        return 0;
}

static PyObject* Sbk_QFontDatabaseFunc_isFixedPitch(PyObject* self, PyObject* args, PyObject* kwds)
{
    QFontDatabase* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFontDatabase* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QFontDatabase.isFixedPitch(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QFontDatabase.isFixedPitch(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:isFixedPitch", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: isFixedPitch(QString,QString)const
    if (Shiboken::Converter< QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // isFixedPitch(QString,QString)const
        } else if (Shiboken::Converter< QString >::isConvertible(pyargs[1])) {
            overloadId = 0; // isFixedPitch(QString,QString)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFontDatabaseFunc_isFixedPitch_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "style");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "style";
                    else if (Shiboken::Converter< QString >::isConvertible(value))
                        pyargs[1] = value;
else
                        goto Sbk_QFontDatabaseFunc_isFixedPitch_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QFontDatabase.isFixedPitch(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QString cppArg1 = pyargs[1] ? Shiboken::Converter<QString >::toCpp(pyargs[1]) : QString();

            if(!PyErr_Occurred()) {
                // isFixedPitch(QString,QString)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->isFixedPitch(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QFontDatabaseFunc_isFixedPitch_TypeError:
        const char* overloads[] = {"QString, QString = QString()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QFontDatabase.isFixedPitch", overloads);
        return 0;
}

static PyObject* Sbk_QFontDatabaseFunc_isScalable(PyObject* self, PyObject* args, PyObject* kwds)
{
    QFontDatabase* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFontDatabase* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QFontDatabase.isScalable(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QFontDatabase.isScalable(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:isScalable", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: isScalable(QString,QString)const
    if (Shiboken::Converter< QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // isScalable(QString,QString)const
        } else if (Shiboken::Converter< QString >::isConvertible(pyargs[1])) {
            overloadId = 0; // isScalable(QString,QString)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFontDatabaseFunc_isScalable_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "style");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "style";
                    else if (Shiboken::Converter< QString >::isConvertible(value))
                        pyargs[1] = value;
else
                        goto Sbk_QFontDatabaseFunc_isScalable_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QFontDatabase.isScalable(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QString cppArg1 = pyargs[1] ? Shiboken::Converter<QString >::toCpp(pyargs[1]) : QString();

            if(!PyErr_Occurred()) {
                // isScalable(QString,QString)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->isScalable(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QFontDatabaseFunc_isScalable_TypeError:
        const char* overloads[] = {"QString, QString = QString()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QFontDatabase.isScalable", overloads);
        return 0;
}

static PyObject* Sbk_QFontDatabaseFunc_isSmoothlyScalable(PyObject* self, PyObject* args, PyObject* kwds)
{
    QFontDatabase* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFontDatabase* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QFontDatabase.isSmoothlyScalable(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QFontDatabase.isSmoothlyScalable(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:isSmoothlyScalable", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: isSmoothlyScalable(QString,QString)const
    if (Shiboken::Converter< QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // isSmoothlyScalable(QString,QString)const
        } else if (Shiboken::Converter< QString >::isConvertible(pyargs[1])) {
            overloadId = 0; // isSmoothlyScalable(QString,QString)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFontDatabaseFunc_isSmoothlyScalable_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "style");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "style";
                    else if (Shiboken::Converter< QString >::isConvertible(value))
                        pyargs[1] = value;
else
                        goto Sbk_QFontDatabaseFunc_isSmoothlyScalable_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QFontDatabase.isSmoothlyScalable(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QString cppArg1 = pyargs[1] ? Shiboken::Converter<QString >::toCpp(pyargs[1]) : QString();

            if(!PyErr_Occurred()) {
                // isSmoothlyScalable(QString,QString)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->isSmoothlyScalable(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QFontDatabaseFunc_isSmoothlyScalable_TypeError:
        const char* overloads[] = {"QString, QString = QString()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QFontDatabase.isSmoothlyScalable", overloads);
        return 0;
}

static PyObject* Sbk_QFontDatabaseFunc_italic(PyObject* self, PyObject* args)
{
    QFontDatabase* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFontDatabase* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "italic", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: italic(QString,QString)const
    if (numArgs == 2 && Shiboken::Converter< QString >::isConvertible(pyargs[0]) && Shiboken::Converter< QString >::isConvertible(pyargs[1])) {
        overloadId = 0; // italic(QString,QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFontDatabaseFunc_italic_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QString cppArg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // italic(QString,QString)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->italic(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QFontDatabaseFunc_italic_TypeError:
        const char* overloads[] = {"QString, QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QFontDatabase.italic", overloads);
        return 0;
}

static PyObject* Sbk_QFontDatabaseFunc_pointSizes(PyObject* self, PyObject* args, PyObject* kwds)
{
    QFontDatabase* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFontDatabase* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QFontDatabase.pointSizes(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QFontDatabase.pointSizes(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:pointSizes", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: pointSizes(QString,QString)
    if (Shiboken::Converter< QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // pointSizes(QString,QString)
        } else if (Shiboken::Converter< QString >::isConvertible(pyargs[1])) {
            overloadId = 0; // pointSizes(QString,QString)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFontDatabaseFunc_pointSizes_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "style");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "style";
                    else if (Shiboken::Converter< QString >::isConvertible(value))
                        pyargs[1] = value;
else
                        goto Sbk_QFontDatabaseFunc_pointSizes_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QFontDatabase.pointSizes(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QString cppArg1 = pyargs[1] ? Shiboken::Converter<QString >::toCpp(pyargs[1]) : QString();

            if(!PyErr_Occurred()) {
                // pointSizes(QString,QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QList<int > cppResult = cppSelf->pointSizes(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QList<int > >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QFontDatabaseFunc_pointSizes_TypeError:
        const char* overloads[] = {"QString, QString = QString()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QFontDatabase.pointSizes", overloads);
        return 0;
}

static PyObject* Sbk_QFontDatabaseFunc_removeAllApplicationFonts(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // removeAllApplicationFonts()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = QFontDatabase::removeAllApplicationFonts();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QFontDatabaseFunc_removeApplicationFont(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: removeApplicationFont(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // removeApplicationFont(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFontDatabaseFunc_removeApplicationFont_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // removeApplicationFont(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = QFontDatabase::removeApplicationFont(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QFontDatabaseFunc_removeApplicationFont_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFontDatabase.removeApplicationFont", overloads);
        return 0;
}

static PyObject* Sbk_QFontDatabaseFunc_smoothSizes(PyObject* self, PyObject* args)
{
    QFontDatabase* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFontDatabase* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "smoothSizes", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: smoothSizes(QString,QString)
    if (numArgs == 2 && Shiboken::Converter< QString >::isConvertible(pyargs[0]) && Shiboken::Converter< QString >::isConvertible(pyargs[1])) {
        overloadId = 0; // smoothSizes(QString,QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFontDatabaseFunc_smoothSizes_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QString cppArg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // smoothSizes(QString,QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QList<int > cppResult = cppSelf->smoothSizes(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QList<int > >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QFontDatabaseFunc_smoothSizes_TypeError:
        const char* overloads[] = {"QString, QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QFontDatabase.smoothSizes", overloads);
        return 0;
}

static PyObject* Sbk_QFontDatabaseFunc_standardSizes(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // standardSizes()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QList<int > cppResult = QFontDatabase::standardSizes();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QList<int > >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QFontDatabaseFunc_styleString(PyObject* self, PyObject* arg)
{
    QFontDatabase* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFontDatabase* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: styleString(QFont)
    // 1: styleString(QFontInfo)
    if (Shiboken::Converter< ::QFont >::isConvertible(arg)) {
        overloadId = 0; // styleString(QFont)
    } else if (Shiboken::Converter< ::QFontInfo >::isConvertible(arg)) {
        overloadId = 1; // styleString(QFontInfo)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFontDatabaseFunc_styleString_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // styleString(QFont)
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QFont cppArg0 = Shiboken::Converter<QFont >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // styleString(QFont)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QString cppResult = cppSelf->styleString(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< QString >::toPython(cppResult);
                }
                break;
            }
            case 1: // styleString(QFontInfo)
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QFontInfo cppArg0 = Shiboken::Converter<QFontInfo >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // styleString(QFontInfo)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QString cppResult = cppSelf->styleString(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< QString >::toPython(cppResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QFontDatabaseFunc_styleString_TypeError:
        const char* overloads[] = {"PySide.QtGui.QFont", "PySide.QtGui.QFontInfo", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFontDatabase.styleString", overloads);
        return 0;
}

static PyObject* Sbk_QFontDatabaseFunc_styles(PyObject* self, PyObject* arg)
{
    QFontDatabase* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFontDatabase* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: styles(QString)const
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // styles(QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFontDatabaseFunc_styles_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // styles(QString)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QStringList cppResult = cppSelf->styles(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QStringList >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QFontDatabaseFunc_styles_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFontDatabase.styles", overloads);
        return 0;
}

static PyObject* Sbk_QFontDatabaseFunc_supportsThreadedFontRendering(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // supportsThreadedFontRendering()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = QFontDatabase::supportsThreadedFontRendering();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QFontDatabaseFunc_weight(PyObject* self, PyObject* args)
{
    QFontDatabase* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFontDatabase* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "weight", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: weight(QString,QString)const
    if (numArgs == 2 && Shiboken::Converter< QString >::isConvertible(pyargs[0]) && Shiboken::Converter< QString >::isConvertible(pyargs[1])) {
        overloadId = 0; // weight(QString,QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFontDatabaseFunc_weight_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QString cppArg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // weight(QString,QString)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->weight(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QFontDatabaseFunc_weight_TypeError:
        const char* overloads[] = {"QString, QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QFontDatabase.weight", overloads);
        return 0;
}

static PyObject* Sbk_QFontDatabaseFunc_writingSystemName(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: writingSystemName(QFontDatabase::WritingSystem)
    if (Shiboken::Converter< ::QFontDatabase::WritingSystem >::isConvertible(arg)) {
        overloadId = 0; // writingSystemName(QFontDatabase::WritingSystem)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFontDatabaseFunc_writingSystemName_TypeError;

    // Call function/method
    {
        {
            QFontDatabase::WritingSystem cppArg0 = Shiboken::Converter<QFontDatabase::WritingSystem >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // writingSystemName(QFontDatabase::WritingSystem)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = QFontDatabase::writingSystemName(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QFontDatabaseFunc_writingSystemName_TypeError:
        const char* overloads[] = {"PySide.QtGui.QFontDatabase.WritingSystem", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFontDatabase.writingSystemName", overloads);
        return 0;
}

static PyObject* Sbk_QFontDatabaseFunc_writingSystemSample(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: writingSystemSample(QFontDatabase::WritingSystem)
    if (Shiboken::Converter< ::QFontDatabase::WritingSystem >::isConvertible(arg)) {
        overloadId = 0; // writingSystemSample(QFontDatabase::WritingSystem)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFontDatabaseFunc_writingSystemSample_TypeError;

    // Call function/method
    {
        {
            QFontDatabase::WritingSystem cppArg0 = Shiboken::Converter<QFontDatabase::WritingSystem >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // writingSystemSample(QFontDatabase::WritingSystem)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = QFontDatabase::writingSystemSample(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QFontDatabaseFunc_writingSystemSample_TypeError:
        const char* overloads[] = {"PySide.QtGui.QFontDatabase.WritingSystem", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QFontDatabase.writingSystemSample", overloads);
        return 0;
}

static PyObject* Sbk_QFontDatabaseFunc_writingSystems(PyObject* self, PyObject* args)
{
    QFontDatabase* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QFontDatabase* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "writingSystems", 0, 1, &(pyargs[0])))
        return 0;


    // Overloaded function decisor
    // 0: writingSystems()const
    // 1: writingSystems(QString)const
    if (numArgs == 0) {
        overloadId = 0; // writingSystems()const
    } else if (numArgs == 1 && Shiboken::Converter< QString >::isConvertible(pyargs[0])) {
        overloadId = 1; // writingSystems(QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QFontDatabaseFunc_writingSystems_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // writingSystems()const
            {

                if(!PyErr_Occurred()) {
                    // writingSystems()const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QList<QFontDatabase::WritingSystem > cppResult = cppSelf->writingSystems();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QList<QFontDatabase::WritingSystem > >::toPython(cppResult);
                }
                break;
            }
            case 1: // writingSystems(QString)const
            {
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // writingSystems(QString)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QList<QFontDatabase::WritingSystem > cppResult = cppSelf->writingSystems(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QList<QFontDatabase::WritingSystem > >::toPython(cppResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QFontDatabaseFunc_writingSystems_TypeError:
        const char* overloads[] = {"", "QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QFontDatabase.writingSystems", overloads);
        return 0;
}

static PyObject *Sbk_QFontDatabase___copy__(PyObject *self)
{
        QFontDatabase* cppSelf = 0;
        if (!Shiboken::Object::isValid(self))
            return 0;
        cppSelf = Shiboken::Converter<QFontDatabase*>::toCpp(self);
        PyObject* pyResult = 0;
        QFontDatabase* copy = new QFontDatabase(*cppSelf);
        pyResult = Shiboken::Converter<QFontDatabase*>::toPython(copy);
        Shiboken::Object::getOwnership(pyResult);

        if (PyErr_Occurred() || !pyResult) {
            Py_XDECREF(pyResult);
            return 0;
        }
        return pyResult;
}

static PyMethodDef Sbk_QFontDatabase_methods[] = {
    {"addApplicationFont", (PyCFunction)Sbk_QFontDatabaseFunc_addApplicationFont, METH_O|METH_STATIC},
    {"addApplicationFontFromData", (PyCFunction)Sbk_QFontDatabaseFunc_addApplicationFontFromData, METH_O|METH_STATIC},
    {"applicationFontFamilies", (PyCFunction)Sbk_QFontDatabaseFunc_applicationFontFamilies, METH_O|METH_STATIC},
    {"bold", (PyCFunction)Sbk_QFontDatabaseFunc_bold, METH_VARARGS},
    {"families", (PyCFunction)Sbk_QFontDatabaseFunc_families, METH_VARARGS|METH_KEYWORDS},
    {"font", (PyCFunction)Sbk_QFontDatabaseFunc_font, METH_VARARGS},
    {"isBitmapScalable", (PyCFunction)Sbk_QFontDatabaseFunc_isBitmapScalable, METH_VARARGS|METH_KEYWORDS},
    {"isFixedPitch", (PyCFunction)Sbk_QFontDatabaseFunc_isFixedPitch, METH_VARARGS|METH_KEYWORDS},
    {"isScalable", (PyCFunction)Sbk_QFontDatabaseFunc_isScalable, METH_VARARGS|METH_KEYWORDS},
    {"isSmoothlyScalable", (PyCFunction)Sbk_QFontDatabaseFunc_isSmoothlyScalable, METH_VARARGS|METH_KEYWORDS},
    {"italic", (PyCFunction)Sbk_QFontDatabaseFunc_italic, METH_VARARGS},
    {"pointSizes", (PyCFunction)Sbk_QFontDatabaseFunc_pointSizes, METH_VARARGS|METH_KEYWORDS},
    {"removeAllApplicationFonts", (PyCFunction)Sbk_QFontDatabaseFunc_removeAllApplicationFonts, METH_NOARGS|METH_STATIC},
    {"removeApplicationFont", (PyCFunction)Sbk_QFontDatabaseFunc_removeApplicationFont, METH_O|METH_STATIC},
    {"smoothSizes", (PyCFunction)Sbk_QFontDatabaseFunc_smoothSizes, METH_VARARGS},
    {"standardSizes", (PyCFunction)Sbk_QFontDatabaseFunc_standardSizes, METH_NOARGS|METH_STATIC},
    {"styleString", (PyCFunction)Sbk_QFontDatabaseFunc_styleString, METH_O},
    {"styles", (PyCFunction)Sbk_QFontDatabaseFunc_styles, METH_O},
    {"supportsThreadedFontRendering", (PyCFunction)Sbk_QFontDatabaseFunc_supportsThreadedFontRendering, METH_NOARGS|METH_STATIC},
    {"weight", (PyCFunction)Sbk_QFontDatabaseFunc_weight, METH_VARARGS},
    {"writingSystemName", (PyCFunction)Sbk_QFontDatabaseFunc_writingSystemName, METH_O|METH_STATIC},
    {"writingSystemSample", (PyCFunction)Sbk_QFontDatabaseFunc_writingSystemSample, METH_O|METH_STATIC},
    {"writingSystems", (PyCFunction)Sbk_QFontDatabaseFunc_writingSystems, METH_VARARGS},

    {"__copy__", (PyCFunction)Sbk_QFontDatabase___copy__, METH_NOARGS},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QFontDatabase_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QFontDatabase",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QFontDatabase_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QFontDatabase_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QFontDatabase(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QFONTDATABASE_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QFontDatabase_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QFontDatabase_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QFontDatabase_Type, &Shiboken::callCppDestructor<QFontDatabase >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QFontDatabase_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QFontDatabase_Type, "QFontDatabase");
    PyModule_AddObject(module, "QFontDatabase",
        ((PyObject*)&Sbk_QFontDatabase_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: WritingSystem
    PyTypeObject* SbkPySide_QtGui_QFontDatabase_WritingSystem = Shiboken::Enum::newType("WritingSystem");
    SbkPySide_QtGuiTypes[SBK_QFONTDATABASE_WRITINGSYSTEM_IDX] = SbkPySide_QtGui_QFontDatabase_WritingSystem;
    if (PyType_Ready(SbkPySide_QtGui_QFontDatabase_WritingSystem) < 0)
        return;
    PyDict_SetItemString(Sbk_QFontDatabase_Type.super.ht_type.tp_dict,
            "WritingSystem",((PyObject*)SbkPySide_QtGui_QFontDatabase_WritingSystem));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFontDatabase_WritingSystem,(long) QFontDatabase::Any, "Any");
    PyDict_SetItemString(Sbk_QFontDatabase_Type.super.ht_type.tp_dict,"Any", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFontDatabase_WritingSystem->tp_dict,"Any", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFontDatabase_WritingSystem,(long) QFontDatabase::Latin, "Latin");
    PyDict_SetItemString(Sbk_QFontDatabase_Type.super.ht_type.tp_dict,"Latin", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFontDatabase_WritingSystem->tp_dict,"Latin", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFontDatabase_WritingSystem,(long) QFontDatabase::Greek, "Greek");
    PyDict_SetItemString(Sbk_QFontDatabase_Type.super.ht_type.tp_dict,"Greek", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFontDatabase_WritingSystem->tp_dict,"Greek", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFontDatabase_WritingSystem,(long) QFontDatabase::Cyrillic, "Cyrillic");
    PyDict_SetItemString(Sbk_QFontDatabase_Type.super.ht_type.tp_dict,"Cyrillic", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFontDatabase_WritingSystem->tp_dict,"Cyrillic", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFontDatabase_WritingSystem,(long) QFontDatabase::Armenian, "Armenian");
    PyDict_SetItemString(Sbk_QFontDatabase_Type.super.ht_type.tp_dict,"Armenian", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFontDatabase_WritingSystem->tp_dict,"Armenian", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFontDatabase_WritingSystem,(long) QFontDatabase::Hebrew, "Hebrew");
    PyDict_SetItemString(Sbk_QFontDatabase_Type.super.ht_type.tp_dict,"Hebrew", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFontDatabase_WritingSystem->tp_dict,"Hebrew", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFontDatabase_WritingSystem,(long) QFontDatabase::Arabic, "Arabic");
    PyDict_SetItemString(Sbk_QFontDatabase_Type.super.ht_type.tp_dict,"Arabic", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFontDatabase_WritingSystem->tp_dict,"Arabic", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFontDatabase_WritingSystem,(long) QFontDatabase::Syriac, "Syriac");
    PyDict_SetItemString(Sbk_QFontDatabase_Type.super.ht_type.tp_dict,"Syriac", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFontDatabase_WritingSystem->tp_dict,"Syriac", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFontDatabase_WritingSystem,(long) QFontDatabase::Thaana, "Thaana");
    PyDict_SetItemString(Sbk_QFontDatabase_Type.super.ht_type.tp_dict,"Thaana", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFontDatabase_WritingSystem->tp_dict,"Thaana", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFontDatabase_WritingSystem,(long) QFontDatabase::Devanagari, "Devanagari");
    PyDict_SetItemString(Sbk_QFontDatabase_Type.super.ht_type.tp_dict,"Devanagari", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFontDatabase_WritingSystem->tp_dict,"Devanagari", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFontDatabase_WritingSystem,(long) QFontDatabase::Bengali, "Bengali");
    PyDict_SetItemString(Sbk_QFontDatabase_Type.super.ht_type.tp_dict,"Bengali", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFontDatabase_WritingSystem->tp_dict,"Bengali", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFontDatabase_WritingSystem,(long) QFontDatabase::Gurmukhi, "Gurmukhi");
    PyDict_SetItemString(Sbk_QFontDatabase_Type.super.ht_type.tp_dict,"Gurmukhi", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFontDatabase_WritingSystem->tp_dict,"Gurmukhi", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFontDatabase_WritingSystem,(long) QFontDatabase::Gujarati, "Gujarati");
    PyDict_SetItemString(Sbk_QFontDatabase_Type.super.ht_type.tp_dict,"Gujarati", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFontDatabase_WritingSystem->tp_dict,"Gujarati", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFontDatabase_WritingSystem,(long) QFontDatabase::Oriya, "Oriya");
    PyDict_SetItemString(Sbk_QFontDatabase_Type.super.ht_type.tp_dict,"Oriya", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFontDatabase_WritingSystem->tp_dict,"Oriya", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFontDatabase_WritingSystem,(long) QFontDatabase::Tamil, "Tamil");
    PyDict_SetItemString(Sbk_QFontDatabase_Type.super.ht_type.tp_dict,"Tamil", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFontDatabase_WritingSystem->tp_dict,"Tamil", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFontDatabase_WritingSystem,(long) QFontDatabase::Telugu, "Telugu");
    PyDict_SetItemString(Sbk_QFontDatabase_Type.super.ht_type.tp_dict,"Telugu", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFontDatabase_WritingSystem->tp_dict,"Telugu", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFontDatabase_WritingSystem,(long) QFontDatabase::Kannada, "Kannada");
    PyDict_SetItemString(Sbk_QFontDatabase_Type.super.ht_type.tp_dict,"Kannada", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFontDatabase_WritingSystem->tp_dict,"Kannada", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFontDatabase_WritingSystem,(long) QFontDatabase::Malayalam, "Malayalam");
    PyDict_SetItemString(Sbk_QFontDatabase_Type.super.ht_type.tp_dict,"Malayalam", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFontDatabase_WritingSystem->tp_dict,"Malayalam", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFontDatabase_WritingSystem,(long) QFontDatabase::Sinhala, "Sinhala");
    PyDict_SetItemString(Sbk_QFontDatabase_Type.super.ht_type.tp_dict,"Sinhala", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFontDatabase_WritingSystem->tp_dict,"Sinhala", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFontDatabase_WritingSystem,(long) QFontDatabase::Thai, "Thai");
    PyDict_SetItemString(Sbk_QFontDatabase_Type.super.ht_type.tp_dict,"Thai", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFontDatabase_WritingSystem->tp_dict,"Thai", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFontDatabase_WritingSystem,(long) QFontDatabase::Lao, "Lao");
    PyDict_SetItemString(Sbk_QFontDatabase_Type.super.ht_type.tp_dict,"Lao", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFontDatabase_WritingSystem->tp_dict,"Lao", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFontDatabase_WritingSystem,(long) QFontDatabase::Tibetan, "Tibetan");
    PyDict_SetItemString(Sbk_QFontDatabase_Type.super.ht_type.tp_dict,"Tibetan", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFontDatabase_WritingSystem->tp_dict,"Tibetan", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFontDatabase_WritingSystem,(long) QFontDatabase::Myanmar, "Myanmar");
    PyDict_SetItemString(Sbk_QFontDatabase_Type.super.ht_type.tp_dict,"Myanmar", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFontDatabase_WritingSystem->tp_dict,"Myanmar", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFontDatabase_WritingSystem,(long) QFontDatabase::Georgian, "Georgian");
    PyDict_SetItemString(Sbk_QFontDatabase_Type.super.ht_type.tp_dict,"Georgian", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFontDatabase_WritingSystem->tp_dict,"Georgian", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFontDatabase_WritingSystem,(long) QFontDatabase::Khmer, "Khmer");
    PyDict_SetItemString(Sbk_QFontDatabase_Type.super.ht_type.tp_dict,"Khmer", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFontDatabase_WritingSystem->tp_dict,"Khmer", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFontDatabase_WritingSystem,(long) QFontDatabase::SimplifiedChinese, "SimplifiedChinese");
    PyDict_SetItemString(Sbk_QFontDatabase_Type.super.ht_type.tp_dict,"SimplifiedChinese", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFontDatabase_WritingSystem->tp_dict,"SimplifiedChinese", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFontDatabase_WritingSystem,(long) QFontDatabase::TraditionalChinese, "TraditionalChinese");
    PyDict_SetItemString(Sbk_QFontDatabase_Type.super.ht_type.tp_dict,"TraditionalChinese", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFontDatabase_WritingSystem->tp_dict,"TraditionalChinese", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFontDatabase_WritingSystem,(long) QFontDatabase::Japanese, "Japanese");
    PyDict_SetItemString(Sbk_QFontDatabase_Type.super.ht_type.tp_dict,"Japanese", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFontDatabase_WritingSystem->tp_dict,"Japanese", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFontDatabase_WritingSystem,(long) QFontDatabase::Korean, "Korean");
    PyDict_SetItemString(Sbk_QFontDatabase_Type.super.ht_type.tp_dict,"Korean", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFontDatabase_WritingSystem->tp_dict,"Korean", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFontDatabase_WritingSystem,(long) QFontDatabase::Vietnamese, "Vietnamese");
    PyDict_SetItemString(Sbk_QFontDatabase_Type.super.ht_type.tp_dict,"Vietnamese", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFontDatabase_WritingSystem->tp_dict,"Vietnamese", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFontDatabase_WritingSystem,(long) QFontDatabase::Symbol, "Symbol");
    PyDict_SetItemString(Sbk_QFontDatabase_Type.super.ht_type.tp_dict,"Symbol", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFontDatabase_WritingSystem->tp_dict,"Symbol", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFontDatabase_WritingSystem,(long) QFontDatabase::Other, "Other");
    PyDict_SetItemString(Sbk_QFontDatabase_Type.super.ht_type.tp_dict,"Other", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFontDatabase_WritingSystem->tp_dict,"Other", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFontDatabase_WritingSystem,(long) QFontDatabase::Ogham, "Ogham");
    PyDict_SetItemString(Sbk_QFontDatabase_Type.super.ht_type.tp_dict,"Ogham", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFontDatabase_WritingSystem->tp_dict,"Ogham", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFontDatabase_WritingSystem,(long) QFontDatabase::Runic, "Runic");
    PyDict_SetItemString(Sbk_QFontDatabase_Type.super.ht_type.tp_dict,"Runic", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFontDatabase_WritingSystem->tp_dict,"Runic", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFontDatabase_WritingSystem,(long) QFontDatabase::Nko, "Nko");
    PyDict_SetItemString(Sbk_QFontDatabase_Type.super.ht_type.tp_dict,"Nko", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFontDatabase_WritingSystem->tp_dict,"Nko", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QFontDatabase_WritingSystem,(long) QFontDatabase::WritingSystemsCount, "WritingSystemsCount");
    PyDict_SetItemString(Sbk_QFontDatabase_Type.super.ht_type.tp_dict,"WritingSystemsCount", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QFontDatabase_WritingSystem->tp_dict,"WritingSystemsCount", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QFontDatabase::WritingSystem");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::WritingSystem");
    // end of enum WritingSystem


    Shiboken::TypeResolver::createValueTypeResolver<QFontDatabase >("QFontDatabase");
    Shiboken::TypeResolver::createObjectTypeResolver<QFontDatabase >("QFontDatabase*");
    Shiboken::TypeResolver::createValueTypeResolver<QFontDatabase >(typeid(QFontDatabase).name());
    PySide::initQtMetaType<QFontDatabase >();
}

