/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qgesturerecognizer_wrapper.h"

// Extra includes
#include <qcoreevent.h>
#include <qgesture.h>
#include <qgesturerecognizer.h>
#include <qobject.h>


// Native ---------------------------------------------------------

QGestureRecognizerWrapper::QGestureRecognizerWrapper() : QGestureRecognizer() {
    // ... middle
}

QGesture * QGestureRecognizerWrapper::create(QObject * target)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "create"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QGestureRecognizer::create(target);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QObject * >::toPython(target)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return 0;
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QGesture * >::isConvertible(pyResult);
    typeIsValid = typeIsValid || (pyResult == Py_None);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QGestureRecognizer.create", Shiboken::SbkType<QGesture >()->tp_name, pyResult->ob_type->tp_name);
        return 0;
    }
    QGesture * cppResult(Shiboken::Converter< ::QGesture * >::toCpp(pyResult));
    return cppResult;
}

QFlags<QGestureRecognizer::ResultFlag> QGestureRecognizerWrapper::recognize(QGesture * state, QObject * watched, QEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "recognize"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QGestureRecognizer.recognize()' not implemented.");
        return QFlags<QGestureRecognizer::ResultFlag>();
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NNN)",
        Shiboken::Converter< ::QGesture * >::toPython(state),
        Shiboken::Converter< ::QObject * >::toPython(watched),
        Shiboken::Converter< ::QEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QFlags<QGestureRecognizer::ResultFlag>();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QFlags<QGestureRecognizer::ResultFlag> >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QGestureRecognizer.recognize", Shiboken::SbkType<QFlags<QGestureRecognizer::ResultFlag> >()->tp_name, pyResult->ob_type->tp_name);
        return QFlags<QGestureRecognizer::ResultFlag>();
    }
    QFlags<QGestureRecognizer::ResultFlag> cppResult(Shiboken::Converter< ::QFlags<QGestureRecognizer::ResultFlag> >::toCpp(pyResult));
    return cppResult;
}

void QGestureRecognizerWrapper::reset(QGesture * state)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "reset"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QGestureRecognizer::reset(state);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QGesture * >::toPython(state)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

QGestureRecognizerWrapper::~QGestureRecognizerWrapper()
{
    SbkObject* wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QGestureRecognizer_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QGestureRecognizer >()))
        return -1;

    QGestureRecognizerWrapper* cptr = 0;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);
    SbkObjectType* type = reinterpret_cast<SbkObjectType*>(self->ob_type);
    SbkObjectType* myType = reinterpret_cast<SbkObjectType*>(SbkPySide_QtGuiTypes[SBK_QGESTURERECOGNIZER_IDX]);
    if (type == myType) {
        PyErr_SetString(PyExc_NotImplementedError,
            "'QGestureRecognizer' represents a C++ abstract class and cannot be instantiated");
        return -1;
    }


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // QGestureRecognizer()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new QGestureRecognizerWrapper();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QGestureRecognizer >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject* Sbk_QGestureRecognizerFunc_create(PyObject* self, PyObject* arg)
{
    QGestureRecognizer* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGestureRecognizer* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: create(QObject*)
    if (Shiboken::Converter< ::QObject * >::isConvertible(arg)) {
        overloadId = 0; // create(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGestureRecognizerFunc_create_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QObject * cppArg0 = Shiboken::Converter<QObject * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // create(QObject*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QGesture * cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QGestureRecognizer::create(cppArg0):cppSelf->create(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QGesture * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QGestureRecognizerFunc_create_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGestureRecognizer.create", overloads);
        return 0;
}

static PyObject* Sbk_QGestureRecognizerFunc_recognize(PyObject* self, PyObject* args)
{
    QGestureRecognizer* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGestureRecognizer* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "recognize", 3, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: recognize(QGesture*,QObject*,QEvent*)
    if (numArgs == 3 && Shiboken::Converter< ::QGesture * >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QObject * >::isConvertible(pyargs[1]) && Shiboken::Converter< ::QEvent * >::isConvertible(pyargs[2])) {
        overloadId = 0; // recognize(QGesture*,QObject*,QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGestureRecognizerFunc_recognize_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QGesture * cppArg0 = Shiboken::Converter<QGesture * >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QObject * cppArg1 = Shiboken::Converter<QObject * >::toCpp(pyargs[1]);
            if (!Shiboken::Object::isValid(pyargs[2]))
                return 0;
            QEvent * cppArg2 = Shiboken::Converter<QEvent * >::toCpp(pyargs[2]);

            if(!PyErr_Occurred()) {
                // recognize(QGesture*,QObject*,QEvent*)
                if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self))) {
                    PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QGestureRecognizer.recognize()' not implemented.");
                    return 0;
                }
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QFlags<QGestureRecognizer::ResultFlag> cppResult = cppSelf->recognize(cppArg0, cppArg1, cppArg2);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QFlags<QGestureRecognizer::ResultFlag> >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QGestureRecognizerFunc_recognize_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGesture, PySide.QtCore.QObject, PySide.QtCore.QEvent", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGestureRecognizer.recognize", overloads);
        return 0;
}

static PyObject* Sbk_QGestureRecognizerFunc_registerRecognizer(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: registerRecognizer(QGestureRecognizer*)
    if (Shiboken::Converter< ::QGestureRecognizer * >::isConvertible(arg)) {
        overloadId = 0; // registerRecognizer(QGestureRecognizer*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGestureRecognizerFunc_registerRecognizer_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QGestureRecognizer * cppArg0 = Shiboken::Converter<QGestureRecognizer * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // registerRecognizer(QGestureRecognizer*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                Qt::GestureType cppResult = QGestureRecognizer::registerRecognizer(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::Qt::GestureType >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QGestureRecognizerFunc_registerRecognizer_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGestureRecognizer", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGestureRecognizer.registerRecognizer", overloads);
        return 0;
}

static PyObject* Sbk_QGestureRecognizerFunc_reset(PyObject* self, PyObject* arg)
{
    QGestureRecognizer* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGestureRecognizer* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: reset(QGesture*)
    if (Shiboken::Converter< ::QGesture * >::isConvertible(arg)) {
        overloadId = 0; // reset(QGesture*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGestureRecognizerFunc_reset_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QGesture * cppArg0 = Shiboken::Converter<QGesture * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // reset(QGesture*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QGestureRecognizer::reset(cppArg0):cppSelf->reset(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGestureRecognizerFunc_reset_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGesture", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGestureRecognizer.reset", overloads);
        return 0;
}

static PyObject* Sbk_QGestureRecognizerFunc_unregisterRecognizer(PyObject* self, PyObject* arg)
{
    int overloadId = -1;

    // Overloaded function decisor
    // 0: unregisterRecognizer(Qt::GestureType)
    if (Shiboken::Converter< ::Qt::GestureType >::isConvertible(arg)) {
        overloadId = 0; // unregisterRecognizer(Qt::GestureType)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGestureRecognizerFunc_unregisterRecognizer_TypeError;

    // Call function/method
    {
        {
            Qt::GestureType cppArg0 = Shiboken::Converter<Qt::GestureType >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // unregisterRecognizer(Qt::GestureType)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QGestureRecognizer::unregisterRecognizer(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGestureRecognizerFunc_unregisterRecognizer_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.GestureType", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGestureRecognizer.unregisterRecognizer", overloads);
        return 0;
}

static PyMethodDef Sbk_QGestureRecognizer_methods[] = {
    {"create", (PyCFunction)Sbk_QGestureRecognizerFunc_create, METH_O},
    {"recognize", (PyCFunction)Sbk_QGestureRecognizerFunc_recognize, METH_VARARGS},
    {"registerRecognizer", (PyCFunction)Sbk_QGestureRecognizerFunc_registerRecognizer, METH_O|METH_STATIC},
    {"reset", (PyCFunction)Sbk_QGestureRecognizerFunc_reset, METH_O},
    {"unregisterRecognizer", (PyCFunction)Sbk_QGestureRecognizerFunc_unregisterRecognizer, METH_O|METH_STATIC},

    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QGestureRecognizer_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QGestureRecognizer",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QGestureRecognizer_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QGestureRecognizer_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern

PyObject* SbkPySide_QtGui_QGestureRecognizer_ResultFlag___and__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QGestureRecognizer::Result >::toPython(
        Shiboken::Converter<QGestureRecognizer::Result>::toCpp(self)
        & Shiboken::Converter< QGestureRecognizer::Result >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtGui_QGestureRecognizer_ResultFlag___or__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QGestureRecognizer::Result >::toPython(
        Shiboken::Converter<QGestureRecognizer::Result>::toCpp(self)
        | Shiboken::Converter< QGestureRecognizer::Result >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtGui_QGestureRecognizer_ResultFlag___xor__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QGestureRecognizer::Result >::toPython(
        Shiboken::Converter<QGestureRecognizer::Result>::toCpp(self)
        ^ Shiboken::Converter< QGestureRecognizer::Result >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtGui_QGestureRecognizer_ResultFlag___invert__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QGestureRecognizer::Result >::toPython(
        ~Shiboken::Converter<QGestureRecognizer::Result >::toCpp(self)
    );
}


static PyNumberMethods SbkPySide_QtGui_QGestureRecognizer_ResultFlag_as_number = {
    /*nb_add*/                  0,
    /*nb_subtract*/             0,
    /*nb_multiply*/             0,
    /*nb_divide*/               0,
    /*nb_remainder*/            0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             0,
    /*nb_positive*/             0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              0,
    /*nb_invert*/               (unaryfunc)SbkPySide_QtGui_QGestureRecognizer_ResultFlag___invert__,
    /*nb_lshift*/               0,
    /*nb_rshift*/               0,
    /*nb_and*/                  (binaryfunc)SbkPySide_QtGui_QGestureRecognizer_ResultFlag___and__,
    /*nb_xor*/                  (binaryfunc)SbkPySide_QtGui_QGestureRecognizer_ResultFlag___xor__,
    /*nb_or*/                   (binaryfunc)SbkPySide_QtGui_QGestureRecognizer_ResultFlag___or__,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          0,
    /*nb_inplace_subtract*/     0,
    /*nb_inplace_multiply*/     0,
    /*nb_inplace_divide*/       0,
    /*nb_inplace_remainder*/    0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       0,
    /*nb_inplace_rshift*/       0,
    /*nb_inplace_and*/          0,
    /*nb_inplace_xor*/          0,
    /*nb_inplace_or*/           0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};


// forward declaration of new function
static PyTypeObject SbkPySide_QtGui_QGestureRecognizer_Result_Type = {
    PyObject_HEAD_INIT(&PyType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "Result",
    /*tp_basicsize*/        0,
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        &SbkPySide_QtGui_QGestureRecognizer_ResultFlag_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT | Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              PyInt_Type.tp_new,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};



void init_QGestureRecognizer(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QGESTURERECOGNIZER_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QGestureRecognizer_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QGestureRecognizer_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QGestureRecognizer_Type, &Shiboken::callCppDestructor<QGestureRecognizer >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QGestureRecognizer_Type) < 0)
        return;

    // Fill type discovery information

    Shiboken::ObjectType::setOriginalName(&Sbk_QGestureRecognizer_Type, "QGestureRecognizer*");
    PyModule_AddObject(module, "QGestureRecognizer",
        ((PyObject*)&Sbk_QGestureRecognizer_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: ResultFlag
    PyTypeObject* SbkPySide_QtGui_QGestureRecognizer_ResultFlag = Shiboken::Enum::newType("ResultFlag");
    SbkPySide_QtGui_QGestureRecognizer_ResultFlag->tp_as_number = &SbkPySide_QtGui_QGestureRecognizer_ResultFlag_as_number;
    SbkPySide_QtGuiTypes[SBK_QGESTURERECOGNIZER_RESULTFLAG_IDX] = SbkPySide_QtGui_QGestureRecognizer_ResultFlag;
    if (PyType_Ready(SbkPySide_QtGui_QGestureRecognizer_ResultFlag) < 0)
        return;
    PyDict_SetItemString(Sbk_QGestureRecognizer_Type.super.ht_type.tp_dict,
            "ResultFlag",((PyObject*)SbkPySide_QtGui_QGestureRecognizer_ResultFlag));

    // init flags class: QFlags<QGestureRecognizer::ResultFlag>
    SbkPySide_QtGuiTypes[SBK_QFLAGS_QGESTURERECOGNIZER_RESULTFLAG__IDX] = &SbkPySide_QtGui_QGestureRecognizer_Result_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QGestureRecognizer_Result_Type) < 0)
        return;
    PyDict_SetItemString(Sbk_QGestureRecognizer_Type.super.ht_type.tp_dict,
            "Result",((PyObject*)&SbkPySide_QtGui_QGestureRecognizer_Result_Type));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QGestureRecognizer_ResultFlag,(long) QGestureRecognizer::Ignore, "Ignore");
    PyDict_SetItemString(Sbk_QGestureRecognizer_Type.super.ht_type.tp_dict,"Ignore", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QGestureRecognizer_ResultFlag->tp_dict,"Ignore", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QGestureRecognizer_ResultFlag,(long) QGestureRecognizer::MayBeGesture, "MayBeGesture");
    PyDict_SetItemString(Sbk_QGestureRecognizer_Type.super.ht_type.tp_dict,"MayBeGesture", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QGestureRecognizer_ResultFlag->tp_dict,"MayBeGesture", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QGestureRecognizer_ResultFlag,(long) QGestureRecognizer::TriggerGesture, "TriggerGesture");
    PyDict_SetItemString(Sbk_QGestureRecognizer_Type.super.ht_type.tp_dict,"TriggerGesture", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QGestureRecognizer_ResultFlag->tp_dict,"TriggerGesture", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QGestureRecognizer_ResultFlag,(long) QGestureRecognizer::FinishGesture, "FinishGesture");
    PyDict_SetItemString(Sbk_QGestureRecognizer_Type.super.ht_type.tp_dict,"FinishGesture", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QGestureRecognizer_ResultFlag->tp_dict,"FinishGesture", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QGestureRecognizer_ResultFlag,(long) QGestureRecognizer::CancelGesture, "CancelGesture");
    PyDict_SetItemString(Sbk_QGestureRecognizer_Type.super.ht_type.tp_dict,"CancelGesture", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QGestureRecognizer_ResultFlag->tp_dict,"CancelGesture", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QGestureRecognizer_ResultFlag,(long) QGestureRecognizer::ResultState_Mask, "ResultState_Mask");
    PyDict_SetItemString(Sbk_QGestureRecognizer_Type.super.ht_type.tp_dict,"ResultState_Mask", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QGestureRecognizer_ResultFlag->tp_dict,"ResultState_Mask", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QGestureRecognizer_ResultFlag,(long) QGestureRecognizer::ConsumeEventHint, "ConsumeEventHint");
    PyDict_SetItemString(Sbk_QGestureRecognizer_Type.super.ht_type.tp_dict,"ConsumeEventHint", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QGestureRecognizer_ResultFlag->tp_dict,"ConsumeEventHint", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QGestureRecognizer_ResultFlag,(long) QGestureRecognizer::ResultHint_Mask, "ResultHint_Mask");
    PyDict_SetItemString(Sbk_QGestureRecognizer_Type.super.ht_type.tp_dict,"ResultHint_Mask", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QGestureRecognizer_ResultFlag->tp_dict,"ResultHint_Mask", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QGestureRecognizer::ResultFlag");
    Shiboken::TypeResolver::createValueTypeResolver<int>("QGestureRecognizer$ConcreteWrapper::ResultFlag");
    // end of enum ResultFlag


    Shiboken::TypeResolver::createObjectTypeResolver<QGestureRecognizer >("QGestureRecognizer*");
    Shiboken::TypeResolver::createObjectTypeResolver<QGestureRecognizer >("QGestureRecognizer$ConcreteWrapper*");
    Shiboken::TypeResolver::createObjectTypeResolver<QGestureRecognizer >(typeid(QGestureRecognizer).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QGestureRecognizer >(typeid(QGestureRecognizerWrapper).name());
    PySide::initQtMetaType<QGestureRecognizer* >();
}

