/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include "pyside_qtgui_python.h"

#include "qgraphicseffect_wrapper.h"

// Extra includes
#include <QList>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qgraphicseffect.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpainter.h>
#include <qpixmap.h>
#include <qpoint.h>
#include <qrect.h>
#include <qthread.h>


// Native ---------------------------------------------------------

QGraphicsEffectWrapper::QGraphicsEffectWrapper(QObject * parent) : QGraphicsEffect(parent) {
    // ... middle
}

QRectF QGraphicsEffectWrapper::boundingRectFor(const QRectF & sourceRect) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "boundingRectFor"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QGraphicsEffect::boundingRectFor(sourceRect);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QRectF >::toPython(sourceRect)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QRectF();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QRectF >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QGraphicsEffect.boundingRectFor", Shiboken::SbkType<QRectF >()->tp_name, pyResult->ob_type->tp_name);
        return QRectF();
    }
    QRectF cppResult(Shiboken::Converter< ::QRectF >::toCpp(pyResult));
    return cppResult;
}

void QGraphicsEffectWrapper::childEvent(QChildEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "childEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::childEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QChildEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QGraphicsEffectWrapper::connectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "connectNotify"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QGraphicsEffectWrapper::customEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "customEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::customEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QGraphicsEffectWrapper::disconnectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QGraphicsEffectWrapper::draw(QPainter * painter)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "draw"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QGraphicsEffect.draw()' not implemented.");
        return ;
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QPainter * >::toPython(painter)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

bool QGraphicsEffectWrapper::event(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "event"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::event(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QGraphicsEffect.event", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
    return cppResult;
}

bool QGraphicsEffectWrapper::eventFilter(QObject * arg__1, QEvent * arg__2)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "eventFilter"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::eventFilter(arg__1, arg__2);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QObject * >::toPython(arg__1),
        Shiboken::Converter< ::QEvent * >::toPython(arg__2)
    ));
    bool invalidadeArg2 = PyTuple_GET_ITEM(pyargs, 1)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QGraphicsEffect.eventFilter", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    if (invalidadeArg2)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 1));
    return cppResult;
}

void QGraphicsEffectWrapper::sourceChanged(QFlags<QGraphicsEffect::ChangeFlag> flags)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "sourceChanged"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QGraphicsEffect::sourceChanged(flags);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QFlags<QGraphicsEffect::ChangeFlag> >::toPython(flags)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QGraphicsEffectWrapper::timerEvent(QTimerEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "timerEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::timerEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QTimerEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

const QMetaObject* QGraphicsEffectWrapper::metaObject() const
{
    SbkObject* pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    return reinterpret_cast<QMetaObject*>(Shiboken::Object::getTypeUserData(pySelf));
}

int QGraphicsEffectWrapper::qt_metacall(QMetaObject::Call call, int id, void** args)
{
    int result = QGraphicsEffect::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

QGraphicsEffectWrapper::~QGraphicsEffectWrapper()
{
    SbkObject* wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QGraphicsEffect_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QGraphicsEffect >()))
        return -1;

    QGraphicsEffectWrapper* cptr = 0;
    int overloadId = -1;
    const char* argNames[] = {"parent"};
    const QMetaObject* metaObject;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);
    SbkObjectType* type = reinterpret_cast<SbkObjectType*>(self->ob_type);
    SbkObjectType* myType = reinterpret_cast<SbkObjectType*>(SbkPySide_QtGuiTypes[SBK_QGRAPHICSEFFECT_IDX]);
    if (type == myType) {
        PyErr_SetString(PyExc_NotImplementedError,
            "'QGraphicsEffect' represents a C++ abstract class and cannot be instantiated");
        return -1;
    }



    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_ParseTuple(args, "|O:QGraphicsEffect", &(pyargs[0])))
        return -1;

    // Overloaded function decisor
    // 0: QGraphicsEffect(QObject*)
    if (numArgs == 0) {
        overloadId = 0; // QGraphicsEffect(QObject*)
    } else if (Shiboken::Converter< ::QObject * >::isConvertible(pyargs[0])) {
        overloadId = 0; // QGraphicsEffect(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsEffect_Init_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "parent");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "parent";
                    else if (Shiboken::Converter< ::QObject * >::isConvertible(value))
                        pyargs[0] = value;
else
                        goto Sbk_QGraphicsEffect_Init_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsEffect(): got multiple values for keyword argument '%s'", errorArgName);
                    return -1;
                }
            }
            if (!Shiboken::Object::isValid(pyargs[0]))
                return -1;
            QObject * cppArg0 = pyargs[0] ? Shiboken::Converter<QObject * >::toCpp(pyargs[0]) : 0;

            if(!PyErr_Occurred()) {
                // QGraphicsEffect(QObject*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new QGraphicsEffectWrapper(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                Shiboken::Object::setParent(pyargs[0], self);
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QGraphicsEffect >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QGraphicsEffect_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    metaObject = cptr->metaObject(); // <- init python qt properties
    if (kwds && !PySide::fillQtProperties(self, metaObject, kwds, argNames, 1))
        return -1;


    return 1;

    Sbk_QGraphicsEffect_Init_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsEffect", overloads);
        return -1;
}

static PyObject* Sbk_QGraphicsEffectFunc_boundingRect(PyObject* self)
{
    QGraphicsEffect* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsEffect* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // boundingRect()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QRectF cppResult = cppSelf->boundingRect();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QRectF >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGraphicsEffectFunc_boundingRectFor(PyObject* self, PyObject* arg)
{
    QGraphicsEffect* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsEffect* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: boundingRectFor(QRectF)const
    if (Shiboken::Converter< ::QRectF >::isConvertible(arg)) {
        overloadId = 0; // boundingRectFor(QRectF)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsEffectFunc_boundingRectFor_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QRectF cppArg0 = Shiboken::Converter<QRectF >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // boundingRectFor(QRectF)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QRectF cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QGraphicsEffect::boundingRectFor(cppArg0):cppSelf->boundingRectFor(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QRectF >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QGraphicsEffectFunc_boundingRectFor_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRectF", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsEffect.boundingRectFor", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsEffectFunc_draw(PyObject* self, PyObject* arg)
{
    QGraphicsEffect* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsEffect* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: draw(QPainter*)
    if (Shiboken::Converter< ::QPainter * >::isConvertible(arg)) {
        overloadId = 0; // draw(QPainter*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsEffectFunc_draw_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QPainter * cppArg0 = Shiboken::Converter<QPainter * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // draw(QPainter*)
                if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self))) {
                    PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QGraphicsEffect.draw()' not implemented.");
                    return 0;
                }
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->draw(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGraphicsEffectFunc_draw_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPainter", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsEffect.draw", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsEffectFunc_drawSource(PyObject* self, PyObject* arg)
{
    QGraphicsEffect* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsEffect* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: drawSource(QPainter*)
    if (Shiboken::Converter< ::QPainter * >::isConvertible(arg)) {
        overloadId = 0; // drawSource(QPainter*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsEffectFunc_drawSource_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QPainter * cppArg0 = Shiboken::Converter<QPainter * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // drawSource(QPainter*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->drawSource(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGraphicsEffectFunc_drawSource_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPainter", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsEffect.drawSource", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsEffectFunc_isEnabled(PyObject* self)
{
    QGraphicsEffect* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsEffect* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isEnabled()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->isEnabled();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGraphicsEffectFunc_setEnabled(PyObject* self, PyObject* arg)
{
    QGraphicsEffect* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsEffect* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setEnabled(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setEnabled(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsEffectFunc_setEnabled_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setEnabled(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setEnabled(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGraphicsEffectFunc_setEnabled_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsEffect.setEnabled", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsEffectFunc_sourceBoundingRect(PyObject* self, PyObject* args, PyObject* kwds)
{
    QGraphicsEffect* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsEffect* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsEffect.sourceBoundingRect(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:sourceBoundingRect", &(pyargs[0])))
        return 0;


    // Overloaded function decisor
    // 0: sourceBoundingRect(Qt::CoordinateSystem)const
    if (numArgs == 0) {
        overloadId = 0; // sourceBoundingRect(Qt::CoordinateSystem)const
    } else if (Shiboken::Converter< ::Qt::CoordinateSystem >::isConvertible(pyargs[0])) {
        overloadId = 0; // sourceBoundingRect(Qt::CoordinateSystem)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsEffectFunc_sourceBoundingRect_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "system");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "system";
                    else if (Shiboken::Converter< ::Qt::CoordinateSystem >::isConvertible(value))
                        pyargs[0] = value;
else
                        goto Sbk_QGraphicsEffectFunc_sourceBoundingRect_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsEffect.sourceBoundingRect(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            Qt::CoordinateSystem cppArg0 = pyargs[0] ? Shiboken::Converter<Qt::CoordinateSystem >::toCpp(pyargs[0]) : Qt::LogicalCoordinates;

            if(!PyErr_Occurred()) {
                // sourceBoundingRect(Qt::CoordinateSystem)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QRectF cppResult = cppSelf->sourceBoundingRect(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QRectF >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QGraphicsEffectFunc_sourceBoundingRect_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.CoordinateSystem = Qt.LogicalCoordinates", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsEffect.sourceBoundingRect", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsEffectFunc_sourceChanged(PyObject* self, PyObject* arg)
{
    QGraphicsEffect* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsEffect* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: sourceChanged(QFlags<QGraphicsEffect::ChangeFlag>)
    if (Shiboken::Converter< ::QFlags<QGraphicsEffect::ChangeFlag> >::isConvertible(arg)) {
        overloadId = 0; // sourceChanged(QFlags<QGraphicsEffect::ChangeFlag>)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsEffectFunc_sourceChanged_TypeError;

    // Call function/method
    {
        {
            QFlags<QGraphicsEffect::ChangeFlag> cppArg0 = Shiboken::Converter<QFlags<QGraphicsEffect::ChangeFlag> >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // sourceChanged(QFlags<QGraphicsEffect::ChangeFlag>)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QGraphicsEffect::sourceChanged(cppArg0):cppSelf->sourceChanged(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGraphicsEffectFunc_sourceChanged_TypeError:
        const char* overloads[] = {"PySide.QtGui.QGraphicsEffect.ChangeFlags", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsEffect.sourceChanged", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsEffectFunc_sourceIsPixmap(PyObject* self)
{
    QGraphicsEffect* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsEffect* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // sourceIsPixmap()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->sourceIsPixmap();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGraphicsEffectFunc_sourcePixmap(PyObject* self, PyObject* args, PyObject* kwds)
{
    QGraphicsEffect* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsEffect* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 3) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QGraphicsEffect.sourcePixmap(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOO:sourcePixmap", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: sourcePixmap(Qt::CoordinateSystem,QPoint*,QGraphicsEffect::PixmapPadMode)const
    if (numArgs == 0) {
        overloadId = 0; // sourcePixmap(Qt::CoordinateSystem,QPoint*,QGraphicsEffect::PixmapPadMode)const
    } else if (Shiboken::Converter< ::Qt::CoordinateSystem >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // sourcePixmap(Qt::CoordinateSystem,QPoint*,QGraphicsEffect::PixmapPadMode)const
        } else if (Shiboken::Converter< ::QPoint * >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 0; // sourcePixmap(Qt::CoordinateSystem,QPoint*,QGraphicsEffect::PixmapPadMode)const
            } else if (Shiboken::Converter< ::QGraphicsEffect::PixmapPadMode >::isConvertible(pyargs[2])) {
                overloadId = 0; // sourcePixmap(Qt::CoordinateSystem,QPoint*,QGraphicsEffect::PixmapPadMode)const
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsEffectFunc_sourcePixmap_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "system");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "system";
                    else if (Shiboken::Converter< ::Qt::CoordinateSystem >::isConvertible(value))
                        pyargs[0] = value;
else
                        goto Sbk_QGraphicsEffectFunc_sourcePixmap_TypeError;
                }
                value = PyDict_GetItemString(kwds, "offset");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "offset";
                    else if (Shiboken::Converter< ::QPoint * >::isConvertible(value))
                        pyargs[1] = value;
else
                        goto Sbk_QGraphicsEffectFunc_sourcePixmap_TypeError;
                }
                value = PyDict_GetItemString(kwds, "mode");
                if (value) {
                    if (pyargs[2])
                        errorArgName = "mode";
                    else if (Shiboken::Converter< ::QGraphicsEffect::PixmapPadMode >::isConvertible(value))
                        pyargs[2] = value;
else
                        goto Sbk_QGraphicsEffectFunc_sourcePixmap_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QGraphicsEffect.sourcePixmap(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            Qt::CoordinateSystem cppArg0 = pyargs[0] ? Shiboken::Converter<Qt::CoordinateSystem >::toCpp(pyargs[0]) : Qt::LogicalCoordinates;
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QPoint * cppArg1 = pyargs[1] ? Shiboken::Converter<QPoint * >::toCpp(pyargs[1]) : 0;
            QGraphicsEffect::PixmapPadMode cppArg2 = pyargs[2] ? Shiboken::Converter<QGraphicsEffect::PixmapPadMode >::toCpp(pyargs[2]) : QGraphicsEffect::PadToEffectiveBoundingRect;

            if(!PyErr_Occurred()) {
                // sourcePixmap(Qt::CoordinateSystem,QPoint*,QGraphicsEffect::PixmapPadMode)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPixmap cppResult = cppSelf->sourcePixmap(cppArg0, cppArg1, cppArg2);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPixmap >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QGraphicsEffectFunc_sourcePixmap_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.CoordinateSystem = Qt.LogicalCoordinates, PySide.QtCore.QPoint = None, PySide.QtGui.QGraphicsEffect.PixmapPadMode = PadToEffectiveBoundingRect", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QGraphicsEffect.sourcePixmap", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsEffectFunc_update(PyObject* self)
{
    QGraphicsEffect* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsEffect* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // update()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->update();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QGraphicsEffectFunc_updateBoundingRect(PyObject* self)
{
    QGraphicsEffect* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsEffect* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // updateBoundingRect()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->updateBoundingRect();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyMethodDef Sbk_QGraphicsEffect_methods[] = {
    {"boundingRect", (PyCFunction)Sbk_QGraphicsEffectFunc_boundingRect, METH_NOARGS},
    {"boundingRectFor", (PyCFunction)Sbk_QGraphicsEffectFunc_boundingRectFor, METH_O},
    {"draw", (PyCFunction)Sbk_QGraphicsEffectFunc_draw, METH_O},
    {"drawSource", (PyCFunction)Sbk_QGraphicsEffectFunc_drawSource, METH_O},
    {"isEnabled", (PyCFunction)Sbk_QGraphicsEffectFunc_isEnabled, METH_NOARGS},
    {"setEnabled", (PyCFunction)Sbk_QGraphicsEffectFunc_setEnabled, METH_O},
    {"sourceBoundingRect", (PyCFunction)Sbk_QGraphicsEffectFunc_sourceBoundingRect, METH_VARARGS|METH_KEYWORDS},
    {"sourceChanged", (PyCFunction)Sbk_QGraphicsEffectFunc_sourceChanged, METH_O},
    {"sourceIsPixmap", (PyCFunction)Sbk_QGraphicsEffectFunc_sourceIsPixmap, METH_NOARGS},
    {"sourcePixmap", (PyCFunction)Sbk_QGraphicsEffectFunc_sourcePixmap, METH_VARARGS|METH_KEYWORDS},
    {"update", (PyCFunction)Sbk_QGraphicsEffectFunc_update, METH_NOARGS},
    {"updateBoundingRect", (PyCFunction)Sbk_QGraphicsEffectFunc_updateBoundingRect, METH_NOARGS},

    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QGraphicsEffect_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QGraphicsEffect",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QGraphicsEffect_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QGraphicsEffect_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern

static SbkObjectType* Sbk_QGraphicsEffect_typeDiscovery(void* cptr, SbkObjectType* instanceType)
{
    if (instanceType == reinterpret_cast<SbkObjectType*>(Shiboken::SbkType<QObject >()) && dynamic_cast<QGraphicsEffect*>(reinterpret_cast<QObject*>(cptr)))
        return &Sbk_QGraphicsEffect_Type;
    return 0;
}

PyObject* SbkPySide_QtGui_QGraphicsEffect_ChangeFlag___and__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QGraphicsEffect::ChangeFlags >::toPython(
        Shiboken::Converter<QGraphicsEffect::ChangeFlags>::toCpp(self)
        & Shiboken::Converter< QGraphicsEffect::ChangeFlags >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtGui_QGraphicsEffect_ChangeFlag___or__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QGraphicsEffect::ChangeFlags >::toPython(
        Shiboken::Converter<QGraphicsEffect::ChangeFlags>::toCpp(self)
        | Shiboken::Converter< QGraphicsEffect::ChangeFlags >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtGui_QGraphicsEffect_ChangeFlag___xor__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QGraphicsEffect::ChangeFlags >::toPython(
        Shiboken::Converter<QGraphicsEffect::ChangeFlags>::toCpp(self)
        ^ Shiboken::Converter< QGraphicsEffect::ChangeFlags >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtGui_QGraphicsEffect_ChangeFlag___invert__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QGraphicsEffect::ChangeFlags >::toPython(
        ~Shiboken::Converter<QGraphicsEffect::ChangeFlags >::toCpp(self)
    );
}


static PyNumberMethods SbkPySide_QtGui_QGraphicsEffect_ChangeFlag_as_number = {
    /*nb_add*/                  0,
    /*nb_subtract*/             0,
    /*nb_multiply*/             0,
    /*nb_divide*/               0,
    /*nb_remainder*/            0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             0,
    /*nb_positive*/             0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              0,
    /*nb_invert*/               (unaryfunc)SbkPySide_QtGui_QGraphicsEffect_ChangeFlag___invert__,
    /*nb_lshift*/               0,
    /*nb_rshift*/               0,
    /*nb_and*/                  (binaryfunc)SbkPySide_QtGui_QGraphicsEffect_ChangeFlag___and__,
    /*nb_xor*/                  (binaryfunc)SbkPySide_QtGui_QGraphicsEffect_ChangeFlag___xor__,
    /*nb_or*/                   (binaryfunc)SbkPySide_QtGui_QGraphicsEffect_ChangeFlag___or__,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          0,
    /*nb_inplace_subtract*/     0,
    /*nb_inplace_multiply*/     0,
    /*nb_inplace_divide*/       0,
    /*nb_inplace_remainder*/    0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       0,
    /*nb_inplace_rshift*/       0,
    /*nb_inplace_and*/          0,
    /*nb_inplace_xor*/          0,
    /*nb_inplace_or*/           0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};


// forward declaration of new function
static PyTypeObject SbkPySide_QtGui_QGraphicsEffect_ChangeFlags_Type = {
    PyObject_HEAD_INIT(&PyType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "ChangeFlags",
    /*tp_basicsize*/        0,
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        &SbkPySide_QtGui_QGraphicsEffect_ChangeFlag_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT | Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              PyInt_Type.tp_new,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};



void init_QGraphicsEffect(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QGRAPHICSEFFECT_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QGraphicsEffect_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QGraphicsEffect_Type);
    Shiboken::ObjectType::setSubTypeInitHook(&Sbk_QGraphicsEffect_Type, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(&Sbk_QGraphicsEffect_Type, &QGraphicsEffect::staticMetaObject);    Sbk_QGraphicsEffect_Type.super.ht_type.tp_base = SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX];
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QGraphicsEffect_Type, &Shiboken::callCppDestructor<QGraphicsEffect >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QGraphicsEffect_Type) < 0)
        return;

    // Fill type discovery information
    Shiboken::ObjectType::setTypeDiscoveryFunction(&Sbk_QGraphicsEffect_Type, &Sbk_QGraphicsEffect_typeDiscovery);
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkObjectType*>(SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX]), &Sbk_QGraphicsEffect_Type);

    Shiboken::ObjectType::setOriginalName(&Sbk_QGraphicsEffect_Type, "QGraphicsEffect*");
    PyModule_AddObject(module, "QGraphicsEffect",
        ((PyObject*)&Sbk_QGraphicsEffect_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: PixmapPadMode
    PyTypeObject* SbkPySide_QtGui_QGraphicsEffect_PixmapPadMode = Shiboken::Enum::newType("PixmapPadMode");
    SbkPySide_QtGuiTypes[SBK_QGRAPHICSEFFECT_PIXMAPPADMODE_IDX] = SbkPySide_QtGui_QGraphicsEffect_PixmapPadMode;
    if (PyType_Ready(SbkPySide_QtGui_QGraphicsEffect_PixmapPadMode) < 0)
        return;
    PyDict_SetItemString(Sbk_QGraphicsEffect_Type.super.ht_type.tp_dict,
            "PixmapPadMode",((PyObject*)SbkPySide_QtGui_QGraphicsEffect_PixmapPadMode));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QGraphicsEffect_PixmapPadMode,(long) QGraphicsEffect::NoPad, "NoPad");
    PyDict_SetItemString(Sbk_QGraphicsEffect_Type.super.ht_type.tp_dict,"NoPad", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QGraphicsEffect_PixmapPadMode->tp_dict,"NoPad", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QGraphicsEffect_PixmapPadMode,(long) QGraphicsEffect::PadToTransparentBorder, "PadToTransparentBorder");
    PyDict_SetItemString(Sbk_QGraphicsEffect_Type.super.ht_type.tp_dict,"PadToTransparentBorder", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QGraphicsEffect_PixmapPadMode->tp_dict,"PadToTransparentBorder", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QGraphicsEffect_PixmapPadMode,(long) QGraphicsEffect::PadToEffectiveBoundingRect, "PadToEffectiveBoundingRect");
    PyDict_SetItemString(Sbk_QGraphicsEffect_Type.super.ht_type.tp_dict,"PadToEffectiveBoundingRect", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QGraphicsEffect_PixmapPadMode->tp_dict,"PadToEffectiveBoundingRect", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QGraphicsEffect::PixmapPadMode");
    Shiboken::TypeResolver::createValueTypeResolver<int>("QGraphicsEffect$ConcreteWrapper::PixmapPadMode");
    // end of enum PixmapPadMode

    // init enum: ChangeFlag
    PyTypeObject* SbkPySide_QtGui_QGraphicsEffect_ChangeFlag = Shiboken::Enum::newType("ChangeFlag");
    SbkPySide_QtGui_QGraphicsEffect_ChangeFlag->tp_as_number = &SbkPySide_QtGui_QGraphicsEffect_ChangeFlag_as_number;
    SbkPySide_QtGuiTypes[SBK_QGRAPHICSEFFECT_CHANGEFLAG_IDX] = SbkPySide_QtGui_QGraphicsEffect_ChangeFlag;
    if (PyType_Ready(SbkPySide_QtGui_QGraphicsEffect_ChangeFlag) < 0)
        return;
    PyDict_SetItemString(Sbk_QGraphicsEffect_Type.super.ht_type.tp_dict,
            "ChangeFlag",((PyObject*)SbkPySide_QtGui_QGraphicsEffect_ChangeFlag));

    // init flags class: QFlags<QGraphicsEffect::ChangeFlag>
    SbkPySide_QtGuiTypes[SBK_QFLAGS_QGRAPHICSEFFECT_CHANGEFLAG__IDX] = &SbkPySide_QtGui_QGraphicsEffect_ChangeFlags_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QGraphicsEffect_ChangeFlags_Type) < 0)
        return;
    PyDict_SetItemString(Sbk_QGraphicsEffect_Type.super.ht_type.tp_dict,
            "ChangeFlags",((PyObject*)&SbkPySide_QtGui_QGraphicsEffect_ChangeFlags_Type));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QGraphicsEffect_ChangeFlag,(long) QGraphicsEffect::SourceAttached, "SourceAttached");
    PyDict_SetItemString(Sbk_QGraphicsEffect_Type.super.ht_type.tp_dict,"SourceAttached", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QGraphicsEffect_ChangeFlag->tp_dict,"SourceAttached", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QGraphicsEffect_ChangeFlag,(long) QGraphicsEffect::SourceDetached, "SourceDetached");
    PyDict_SetItemString(Sbk_QGraphicsEffect_Type.super.ht_type.tp_dict,"SourceDetached", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QGraphicsEffect_ChangeFlag->tp_dict,"SourceDetached", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QGraphicsEffect_ChangeFlag,(long) QGraphicsEffect::SourceBoundingRectChanged, "SourceBoundingRectChanged");
    PyDict_SetItemString(Sbk_QGraphicsEffect_Type.super.ht_type.tp_dict,"SourceBoundingRectChanged", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QGraphicsEffect_ChangeFlag->tp_dict,"SourceBoundingRectChanged", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QGraphicsEffect_ChangeFlag,(long) QGraphicsEffect::SourceInvalidated, "SourceInvalidated");
    PyDict_SetItemString(Sbk_QGraphicsEffect_Type.super.ht_type.tp_dict,"SourceInvalidated", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QGraphicsEffect_ChangeFlag->tp_dict,"SourceInvalidated", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QGraphicsEffect::ChangeFlag");
    Shiboken::TypeResolver::createValueTypeResolver<int>("QGraphicsEffect$ConcreteWrapper::ChangeFlag");
    // end of enum ChangeFlag

    // Initialize signals
    PySideSignal* signal_item;

    signal_item = PySide::Signal::newObject("enabledChanged", "bool", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QGraphicsEffect_Type, "enabledChanged", signal_item);
    Py_DECREF((PyObject*) signal_item);


    Shiboken::TypeResolver::createObjectTypeResolver<QGraphicsEffect >("QGraphicsEffect*");
    Shiboken::TypeResolver::createObjectTypeResolver<QGraphicsEffect >("QGraphicsEffect$ConcreteWrapper*");
    Shiboken::TypeResolver::createObjectTypeResolver<QGraphicsEffect >(typeid(QGraphicsEffect).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QGraphicsEffect >(typeid(QGraphicsEffectWrapper).name());
    PySide::initQtMetaType<QGraphicsEffect* >();
}

