/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qgraphicsscenemoveevent_wrapper.h"

// Extra includes
#include <qgraphicssceneevent.h>
#include <qpoint.h>
#include <qwidget.h>


// Native ---------------------------------------------------------

QGraphicsSceneMoveEventWrapper::QGraphicsSceneMoveEventWrapper() : QGraphicsSceneMoveEvent() {
    // ... middle
}

QGraphicsSceneMoveEventWrapper::~QGraphicsSceneMoveEventWrapper()
{
    SbkObject* wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QGraphicsSceneMoveEvent_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QGraphicsSceneMoveEvent >()))
        return -1;

    QGraphicsSceneMoveEventWrapper* cptr = 0;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // QGraphicsSceneMoveEvent()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new QGraphicsSceneMoveEventWrapper();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QGraphicsSceneMoveEvent >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject* Sbk_QGraphicsSceneMoveEventFunc_newPos(PyObject* self)
{
    QGraphicsSceneMoveEvent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsSceneMoveEvent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // newPos()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPointF cppResult = cppSelf->newPos();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPointF >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGraphicsSceneMoveEventFunc_oldPos(PyObject* self)
{
    QGraphicsSceneMoveEvent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsSceneMoveEvent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // oldPos()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPointF cppResult = cppSelf->oldPos();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPointF >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGraphicsSceneMoveEventFunc_setNewPos(PyObject* self, PyObject* arg)
{
    QGraphicsSceneMoveEvent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsSceneMoveEvent* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setNewPos(QPointF)
    if (Shiboken::Converter< ::QPointF >::isConvertible(arg)) {
        overloadId = 0; // setNewPos(QPointF)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsSceneMoveEventFunc_setNewPos_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QPointF cppArg0 = Shiboken::Converter<QPointF >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setNewPos(QPointF)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setNewPos(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGraphicsSceneMoveEventFunc_setNewPos_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsSceneMoveEvent.setNewPos", overloads);
        return 0;
}

static PyObject* Sbk_QGraphicsSceneMoveEventFunc_setOldPos(PyObject* self, PyObject* arg)
{
    QGraphicsSceneMoveEvent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGraphicsSceneMoveEvent* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setOldPos(QPointF)
    if (Shiboken::Converter< ::QPointF >::isConvertible(arg)) {
        overloadId = 0; // setOldPos(QPointF)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGraphicsSceneMoveEventFunc_setOldPos_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QPointF cppArg0 = Shiboken::Converter<QPointF >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setOldPos(QPointF)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setOldPos(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGraphicsSceneMoveEventFunc_setOldPos_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QGraphicsSceneMoveEvent.setOldPos", overloads);
        return 0;
}

static PyMethodDef Sbk_QGraphicsSceneMoveEvent_methods[] = {
    {"newPos", (PyCFunction)Sbk_QGraphicsSceneMoveEventFunc_newPos, METH_NOARGS},
    {"oldPos", (PyCFunction)Sbk_QGraphicsSceneMoveEventFunc_oldPos, METH_NOARGS},
    {"setNewPos", (PyCFunction)Sbk_QGraphicsSceneMoveEventFunc_setNewPos, METH_O},
    {"setOldPos", (PyCFunction)Sbk_QGraphicsSceneMoveEventFunc_setOldPos, METH_O},

    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QGraphicsSceneMoveEvent_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QGraphicsSceneMoveEvent",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QGraphicsSceneMoveEvent_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QGraphicsSceneMoveEvent_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern

static SbkObjectType* Sbk_QGraphicsSceneMoveEvent_typeDiscovery(void* cptr, SbkObjectType* instanceType)
{
     if ( reinterpret_cast<QGraphicsSceneMoveEvent*>(cptr)->type() == QEvent::GraphicsSceneMove)
        return &Sbk_QGraphicsSceneMoveEvent_Type;
    return 0;
}


void init_QGraphicsSceneMoveEvent(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QGRAPHICSSCENEMOVEEVENT_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QGraphicsSceneMoveEvent_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QGraphicsSceneMoveEvent_Type);
    Sbk_QGraphicsSceneMoveEvent_Type.super.ht_type.tp_base = SbkPySide_QtGuiTypes[SBK_QGRAPHICSSCENEEVENT_IDX];
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QGraphicsSceneMoveEvent_Type, &Shiboken::callCppDestructor<QGraphicsSceneMoveEvent >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QGraphicsSceneMoveEvent_Type) < 0)
        return;

    // Fill type discovery information
    Shiboken::ObjectType::setTypeDiscoveryFunction(&Sbk_QGraphicsSceneMoveEvent_Type, &Sbk_QGraphicsSceneMoveEvent_typeDiscovery);
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkObjectType*>(SbkPySide_QtGuiTypes[SBK_QGRAPHICSSCENEEVENT_IDX]), &Sbk_QGraphicsSceneMoveEvent_Type);

    Shiboken::ObjectType::setOriginalName(&Sbk_QGraphicsSceneMoveEvent_Type, "QGraphicsSceneMoveEvent*");
    PyModule_AddObject(module, "QGraphicsSceneMoveEvent",
        ((PyObject*)&Sbk_QGraphicsSceneMoveEvent_Type));


    Shiboken::TypeResolver::createObjectTypeResolver<QGraphicsSceneMoveEvent >("QGraphicsSceneMoveEvent*");
    Shiboken::TypeResolver::createObjectTypeResolver<QGraphicsSceneMoveEvent >(typeid(QGraphicsSceneMoveEvent).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QGraphicsSceneMoveEvent >(typeid(QGraphicsSceneMoveEventWrapper).name());
    PySide::initQtMetaType<QGraphicsSceneMoveEvent* >();
}

