/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <set>
#include "pyside_qtgui_python.h"

#include "qlayout_wrapper.h"

// Extra includes
#include <QList>
#include "glue/qlayout_help_functions.h"
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qlayout.h>
#include <qlayoutitem.h>
#include <qmargins.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qrect.h>
#include <qsize.h>
#include <qthread.h>
#include <qwidget.h>


// Native ---------------------------------------------------------

QLayoutWrapper::QLayoutWrapper() : QLayout() {
    // ... middle
}

QLayoutWrapper::QLayoutWrapper(QWidget * parent) : QLayout(parent) {
    // ... middle
}

void QLayoutWrapper::addItem(QLayoutItem * arg__1)
{

    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "addItem"));
    if (py_override.isNull()) {

        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QLayout.addItem()' not implemented.");
        return ;
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QLayoutItem * >::toPython(arg__1)
    ));


    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }

}

void QLayoutWrapper::childEvent(QChildEvent * e)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "childEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QLayout::childEvent(e);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QChildEvent * >::toPython(e)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QLayoutWrapper::connectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "connectNotify"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

int QLayoutWrapper::count() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "count"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QLayout.count()' not implemented.");
        return int(0);
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QLayout.count", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter< int >::toCpp(pyResult));
    return cppResult;
}

void QLayoutWrapper::customEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "customEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::customEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QLayoutWrapper::disconnectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

bool QLayoutWrapper::event(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "event"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::event(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QLayout.event", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    return cppResult;
}

bool QLayoutWrapper::eventFilter(QObject * arg__1, QEvent * arg__2)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "eventFilter"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::eventFilter(arg__1, arg__2);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QObject * >::toPython(arg__1),
        Shiboken::Converter< ::QEvent * >::toPython(arg__2)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QLayout.eventFilter", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    return cppResult;
}

QFlags<Qt::Orientation> QLayoutWrapper::expandingDirections() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "expandingDirections"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QLayout::expandingDirections();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QFlags<Qt::Orientation>();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QFlags<Qt::Orientation> >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QLayout.expandingDirections", Shiboken::SbkType<QFlags<Qt::Orientation> >()->tp_name, pyResult->ob_type->tp_name);
        return QFlags<Qt::Orientation>();
    }
    QFlags<Qt::Orientation> cppResult(Shiboken::Converter< ::QFlags<Qt::Orientation> >::toCpp(pyResult));
    return cppResult;
}

QRect QLayoutWrapper::geometry() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "geometry"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QLayout::geometry();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QRect();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QRect >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QLayout.geometry", Shiboken::SbkType<QRect >()->tp_name, pyResult->ob_type->tp_name);
        return QRect();
    }
    QRect cppResult(Shiboken::Converter< ::QRect >::toCpp(pyResult));
    return cppResult;
}

bool QLayoutWrapper::hasHeightForWidth() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "hasHeightForWidth"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QLayoutItem::hasHeightForWidth();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QLayout.hasHeightForWidth", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    return cppResult;
}

int QLayoutWrapper::heightForWidth(int arg__1) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "heightForWidth"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QLayoutItem::heightForWidth(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(i)",
        arg__1
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QLayout.heightForWidth", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter< int >::toCpp(pyResult));
    return cppResult;
}

int QLayoutWrapper::indexOf(QWidget * arg__1) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "indexOf"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QLayout::indexOf(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QWidget * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QLayout.indexOf", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter< int >::toCpp(pyResult));
    return cppResult;
}

void QLayoutWrapper::invalidate()
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "invalidate"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QLayout::invalidate();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

bool QLayoutWrapper::isEmpty() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "isEmpty"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QLayout::isEmpty();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QLayout.isEmpty", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    return cppResult;
}

QLayoutItem * QLayoutWrapper::itemAt(int index) const
{

    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "itemAt"));
    if (py_override.isNull()) {

        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QLayout.itemAt()' not implemented.");
        return 0;
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(i)",
        index
    ));


    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return 0;
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QLayoutItem * >::isConvertible(pyResult);
    typeIsValid = typeIsValid || (pyResult == Py_None);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QLayout.itemAt", Shiboken::SbkType<QLayoutItem >()->tp_name, pyResult->ob_type->tp_name);
        return 0;
    }
    QLayoutItem * cppResult(Shiboken::Converter< ::QLayoutItem * >::toCpp(pyResult));

    return cppResult;
}

QLayout * QLayoutWrapper::layout()
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "layout"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QLayout::layout();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return 0;
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QLayout * >::isConvertible(pyResult);
    typeIsValid = typeIsValid || (pyResult == Py_None);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QLayout.layout", Shiboken::SbkType<QLayout >()->tp_name, pyResult->ob_type->tp_name);
        return 0;
    }
    QLayout * cppResult(Shiboken::Converter< ::QLayout * >::toCpp(pyResult));
    return cppResult;
}

QSize QLayoutWrapper::maximumSize() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "maximumSize"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QLayout::maximumSize();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QSize();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QSize >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QLayout.maximumSize", Shiboken::SbkType<QSize >()->tp_name, pyResult->ob_type->tp_name);
        return QSize();
    }
    QSize cppResult(Shiboken::Converter< ::QSize >::toCpp(pyResult));
    return cppResult;
}

int QLayoutWrapper::minimumHeightForWidth(int arg__1) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "minimumHeightForWidth"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QLayoutItem::minimumHeightForWidth(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(i)",
        arg__1
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QLayout.minimumHeightForWidth", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter< int >::toCpp(pyResult));
    return cppResult;
}

QSize QLayoutWrapper::minimumSize() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "minimumSize"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QLayout::minimumSize();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QSize();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QSize >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QLayout.minimumSize", Shiboken::SbkType<QSize >()->tp_name, pyResult->ob_type->tp_name);
        return QSize();
    }
    QSize cppResult(Shiboken::Converter< ::QSize >::toCpp(pyResult));
    return cppResult;
}

void QLayoutWrapper::setGeometry(const QRect & arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "setGeometry"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QLayout::setGeometry(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QRect >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

QSize QLayoutWrapper::sizeHint() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "sizeHint"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QLayout.sizeHint()' not implemented.");
        return QSize();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QSize();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QSize >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QLayout.sizeHint", Shiboken::SbkType<QSize >()->tp_name, pyResult->ob_type->tp_name);
        return QSize();
    }
    QSize cppResult(Shiboken::Converter< ::QSize >::toCpp(pyResult));
    return cppResult;
}

QSpacerItem * QLayoutWrapper::spacerItem()
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "spacerItem"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QLayoutItem::spacerItem();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return 0;
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QSpacerItem * >::isConvertible(pyResult);
    typeIsValid = typeIsValid || (pyResult == Py_None);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QLayout.spacerItem", Shiboken::SbkType<QSpacerItem >()->tp_name, pyResult->ob_type->tp_name);
        return 0;
    }
    QSpacerItem * cppResult(Shiboken::Converter< ::QSpacerItem * >::toCpp(pyResult));
    return cppResult;
}

QLayoutItem * QLayoutWrapper::takeAt(int index)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "takeAt"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QLayout.takeAt()' not implemented.");
        return 0;
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(i)",
        index
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return 0;
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QLayoutItem * >::isConvertible(pyResult);
    typeIsValid = typeIsValid || (pyResult == Py_None);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QLayout.takeAt", Shiboken::SbkType<QLayoutItem >()->tp_name, pyResult->ob_type->tp_name);
        return 0;
    }
    QLayoutItem * cppResult(Shiboken::Converter< ::QLayoutItem * >::toCpp(pyResult));
    return cppResult;
}

void QLayoutWrapper::timerEvent(QTimerEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "timerEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::timerEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QTimerEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

QWidget * QLayoutWrapper::widget()
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "widget"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QLayoutItem::widget();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return 0;
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QWidget * >::isConvertible(pyResult);
    typeIsValid = typeIsValid || (pyResult == Py_None);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QLayout.widget", Shiboken::SbkType<QWidget >()->tp_name, pyResult->ob_type->tp_name);
        return 0;
    }
    QWidget * cppResult(Shiboken::Converter< ::QWidget * >::toCpp(pyResult));
    return cppResult;
}

const QMetaObject* QLayoutWrapper::metaObject() const
{
    SbkObject* pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    return reinterpret_cast<QMetaObject*>(Shiboken::Object::getTypeUserData(pySelf));
}

int QLayoutWrapper::qt_metacall(QMetaObject::Call call, int id, void** args)
{
    int result = QLayout::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

QLayoutWrapper::~QLayoutWrapper()
{
    SbkObject* wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QLayout_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QLayout >()))
        return -1;

    QLayoutWrapper* cptr = 0;
    int overloadId = -1;
    const char** argNames = 0;
    const QMetaObject* metaObject;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);
    SbkObjectType* type = reinterpret_cast<SbkObjectType*>(self->ob_type);
    SbkObjectType* myType = reinterpret_cast<SbkObjectType*>(SbkPySide_QtGuiTypes[SBK_QLAYOUT_IDX]);
    if (type == myType) {
        PyErr_SetString(PyExc_NotImplementedError,
            "'QLayout' represents a C++ abstract class and cannot be instantiated");
        return -1;
    }

        Shiboken::ObjectType::copyMultimpleheritance(type, myType);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QLayout", 0, 1, &(pyargs[0])))
        return -1;

    // Overloaded function decisor
    // 0: QLayout()
    // 1: QLayout(QWidget*)
    if (numArgs == 0) {
        overloadId = 0; // QLayout()
    } else if (numArgs == 1 && Shiboken::Converter< ::QWidget * >::isConvertible(pyargs[0])) {
        overloadId = 1; // QLayout(QWidget*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QLayout_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QLayout()
            {

                if(!PyErr_Occurred()) {
                    // QLayout()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QLayoutWrapper();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // QLayout(QWidget*)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QWidget * cppArg0 = Shiboken::Converter<QWidget * >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QLayout(QWidget*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QLayoutWrapper(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    Shiboken::Object::setParent(pyargs[0], self);
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QLayout >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QLayout_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    metaObject = cptr->metaObject(); // <- init python qt properties
    if (kwds && !PySide::fillQtProperties(self, metaObject, kwds, argNames, 0))
        return -1;


    return 1;

    Sbk_QLayout_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtGui.QWidget", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QLayout", overloads);
        return -1;
}

static PyObject* Sbk_QLayoutFunc_activate(PyObject* self)
{
    QLayout* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QLayout* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // activate()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->activate();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QLayoutFunc_addChildLayout(PyObject* self, PyObject* arg)
{
    QLayout* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QLayout* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: addChildLayout(QLayout*)
    if (Shiboken::Converter< ::QLayout * >::isConvertible(arg)) {
        overloadId = 0; // addChildLayout(QLayout*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QLayoutFunc_addChildLayout_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QLayout * cppArg0 = Shiboken::Converter<QLayout * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // addChildLayout(QLayout*)
                // Begin code injection
                
                addLayoutOwnership(cppSelf, cppArg0);
                
                // End of code injection

                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->addChildLayout(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS

            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QLayoutFunc_addChildLayout_TypeError:
        const char* overloads[] = {"PySide.QtGui.QLayout", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QLayout.addChildLayout", overloads);
        return 0;
}

static PyObject* Sbk_QLayoutFunc_addChildWidget(PyObject* self, PyObject* arg)
{
    QLayout* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QLayout* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: addChildWidget(QWidget*)
    if (Shiboken::Converter< ::QWidget * >::isConvertible(arg)) {
        overloadId = 0; // addChildWidget(QWidget*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QLayoutFunc_addChildWidget_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QWidget * cppArg0 = Shiboken::Converter<QWidget * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // addChildWidget(QWidget*)
                // Begin code injection
                
                addLayoutOwnership(cppSelf, cppArg0);
                
                // End of code injection

                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->addChildWidget(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS

            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QLayoutFunc_addChildWidget_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWidget", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QLayout.addChildWidget", overloads);
        return 0;
}

static PyObject* Sbk_QLayoutFunc_addItem(PyObject* self, PyObject* arg)
{
    QLayout* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QLayout* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: addItem(QLayoutItem*)
    if (Shiboken::Converter< ::QLayoutItem * >::isConvertible(arg)) {
        overloadId = 0; // addItem(QLayoutItem*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QLayoutFunc_addItem_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QLayoutItem * cppArg0 = Shiboken::Converter<QLayoutItem * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // addItem(QLayoutItem*)
                if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self))) {
                    PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QLayout.addItem()' not implemented.");
                    return 0;
                }
                // Begin code injection
                
                addLayoutOwnership(cppSelf, cppArg0);
                
                // End of code injection

                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->addItem(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS

            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QLayoutFunc_addItem_TypeError:
        const char* overloads[] = {"PySide.QtGui.QLayoutItem", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QLayout.addItem", overloads);
        return 0;
}

static PyObject* Sbk_QLayoutFunc_addWidget(PyObject* self, PyObject* arg)
{
    QLayout* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QLayout* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: addWidget(QWidget*)
    if (Shiboken::Converter< ::QWidget * >::isConvertible(arg)) {
        overloadId = 0; // addWidget(QWidget*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QLayoutFunc_addWidget_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QWidget * cppArg0 = Shiboken::Converter<QWidget * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // addWidget(QWidget*)
                // Begin code injection
                
                addLayoutOwnership(cppSelf, cppArg0);
                
                // End of code injection

                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->addWidget(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS

            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QLayoutFunc_addWidget_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWidget", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QLayout.addWidget", overloads);
        return 0;
}

static PyObject* Sbk_QLayoutFunc_alignmentRect(PyObject* self, PyObject* arg)
{
    QLayout* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QLayout* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: alignmentRect(QRect)const
    if (Shiboken::Converter< ::QRect >::isConvertible(arg)) {
        overloadId = 0; // alignmentRect(QRect)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QLayoutFunc_alignmentRect_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QRect cppArg0 = Shiboken::Converter<QRect >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // alignmentRect(QRect)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QRect cppResult = cppSelf->alignmentRect(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QRect >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QLayoutFunc_alignmentRect_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRect", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QLayout.alignmentRect", overloads);
        return 0;
}

static PyObject* Sbk_QLayoutFunc_childEvent(PyObject* self, PyObject* arg)
{
    QLayout* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QLayout* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: childEvent(QChildEvent*)
    if (Shiboken::Converter< ::QChildEvent * >::isConvertible(arg)) {
        overloadId = 0; // childEvent(QChildEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QLayoutFunc_childEvent_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QChildEvent * cppArg0 = Shiboken::Converter<QChildEvent * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // childEvent(QChildEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QLayout::childEvent(cppArg0):cppSelf->childEvent(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QLayoutFunc_childEvent_TypeError:
        const char* overloads[] = {"PySide.QtCore.QChildEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QLayout.childEvent", overloads);
        return 0;
}

static PyObject* Sbk_QLayoutFunc_closestAcceptableSize(PyObject* self, PyObject* args)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "closestAcceptableSize", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: closestAcceptableSize(const QWidget*,QSize)
    if (numArgs == 2 && Shiboken::Converter< ::QWidget * >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QSize >::isConvertible(pyargs[1])) {
        overloadId = 0; // closestAcceptableSize(const QWidget*,QSize)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QLayoutFunc_closestAcceptableSize_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QWidget * cppArg0 = Shiboken::Converter<QWidget * >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QSize cppArg1 = Shiboken::Converter<QSize >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // closestAcceptableSize(const QWidget*,QSize)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QSize cppResult = QLayout::closestAcceptableSize(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QSize >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QLayoutFunc_closestAcceptableSize_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWidget, PySide.QtCore.QSize", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QLayout.closestAcceptableSize", overloads);
        return 0;
}

static PyObject* Sbk_QLayoutFunc_contentsMargins(PyObject* self)
{
    QLayout* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QLayout* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // contentsMargins()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QMargins cppResult = cppSelf->contentsMargins();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QMargins >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QLayoutFunc_contentsRect(PyObject* self)
{
    QLayout* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QLayout* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // contentsRect()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QRect cppResult = cppSelf->contentsRect();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QRect >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QLayoutFunc_count(PyObject* self)
{
    QLayout* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QLayout* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // count()const
                if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self))) {
                    PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QLayout.count()' not implemented.");
                    return 0;
                }
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->count();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QLayoutFunc_expandingDirections(PyObject* self)
{
    QLayout* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QLayout* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // expandingDirections()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QFlags<Qt::Orientation> cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QLayout::expandingDirections():cppSelf->expandingDirections());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QFlags<Qt::Orientation> >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QLayoutFunc_geometry(PyObject* self)
{
    QLayout* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QLayout* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // geometry()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QRect cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QLayout::geometry():cppSelf->geometry());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QRect >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QLayoutFunc_indexOf(PyObject* self, PyObject* arg)
{
    QLayout* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QLayout* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: indexOf(QWidget*)const
    if (Shiboken::Converter< ::QWidget * >::isConvertible(arg)) {
        overloadId = 0; // indexOf(QWidget*)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QLayoutFunc_indexOf_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QWidget * cppArg0 = Shiboken::Converter<QWidget * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // indexOf(QWidget*)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QLayout::indexOf(cppArg0):cppSelf->indexOf(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QLayoutFunc_indexOf_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWidget", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QLayout.indexOf", overloads);
        return 0;
}

static PyObject* Sbk_QLayoutFunc_invalidate(PyObject* self)
{
    QLayout* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QLayout* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // invalidate()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QLayout::invalidate():cppSelf->invalidate());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QLayoutFunc_isEmpty(PyObject* self)
{
    QLayout* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QLayout* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isEmpty()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QLayout::isEmpty():cppSelf->isEmpty());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QLayoutFunc_isEnabled(PyObject* self)
{
    QLayout* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QLayout* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isEnabled()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->isEnabled();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QLayoutFunc_itemAt(PyObject* self, PyObject* arg)
{
    QLayout* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QLayout* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: itemAt(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // itemAt(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QLayoutFunc_itemAt_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // itemAt(int)const
                if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self))) {
                    PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QLayout.itemAt()' not implemented.");
                    return 0;
                }

                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QLayoutItem * cppResult = cppSelf->itemAt(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QLayoutItem * >::toPython(cppResult);

                // Begin code injection
                
                addLayoutOwnership(cppSelf, cppResult);
                
                // End of code injection

                // Ownership transferences.
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QLayoutFunc_itemAt_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QLayout.itemAt", overloads);
        return 0;
}

static PyObject* Sbk_QLayoutFunc_layout(PyObject* self)
{
    QLayout* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QLayout* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // layout()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QLayout * cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QLayout::layout():cppSelf->layout());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QLayout * >::toPython(cppResult);

                // Ownership transferences.
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QLayoutFunc_margin(PyObject* self)
{
    QLayout* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QLayout* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // margin()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->margin();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QLayoutFunc_maximumSize(PyObject* self)
{
    QLayout* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QLayout* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // maximumSize()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QSize cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QLayout::maximumSize():cppSelf->maximumSize());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QSize >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QLayoutFunc_menuBar(PyObject* self)
{
    QLayout* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QLayout* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // menuBar()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QWidget * cppResult = cppSelf->menuBar();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QWidget * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QLayoutFunc_minimumSize(PyObject* self)
{
    QLayout* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QLayout* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // minimumSize()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QSize cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QLayout::minimumSize():cppSelf->minimumSize());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QSize >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QLayoutFunc_parentWidget(PyObject* self)
{
    QLayout* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QLayout* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // parentWidget()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QWidget * cppResult = cppSelf->parentWidget();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QWidget * >::toPython(cppResult);
                Shiboken::Object::setParent(pyResult, self);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QLayoutFunc_removeItem(PyObject* self, PyObject* arg)
{
    QLayout* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QLayout* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: removeItem(QLayoutItem*)
    if (Shiboken::Converter< ::QLayoutItem * >::isConvertible(arg)) {
        overloadId = 0; // removeItem(QLayoutItem*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QLayoutFunc_removeItem_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QLayoutItem * cppArg0 = Shiboken::Converter<QLayoutItem * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // removeItem(QLayoutItem*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->removeItem(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QLayoutFunc_removeItem_TypeError:
        const char* overloads[] = {"PySide.QtGui.QLayoutItem", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QLayout.removeItem", overloads);
        return 0;
}

static PyObject* Sbk_QLayoutFunc_removeWidget(PyObject* self, PyObject* arg)
{
    QLayout* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QLayout* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: removeWidget(QWidget*)
    if (Shiboken::Converter< ::QWidget * >::isConvertible(arg)) {
        overloadId = 0; // removeWidget(QWidget*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QLayoutFunc_removeWidget_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QWidget * cppArg0 = Shiboken::Converter<QWidget * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // removeWidget(QWidget*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->removeWidget(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QLayoutFunc_removeWidget_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWidget", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QLayout.removeWidget", overloads);
        return 0;
}

static PyObject* Sbk_QLayoutFunc_setAlignment(PyObject* self, PyObject* args)
{
    QLayout* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QLayout* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setAlignment", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setAlignment(QFlags<Qt::AlignmentFlag>)
    // 1: setAlignment(QLayout*,QFlags<Qt::AlignmentFlag>)
    // 2: setAlignment(QWidget*,QFlags<Qt::AlignmentFlag>)
    if (numArgs == 2 && Shiboken::Converter< ::QWidget * >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QFlags<Qt::AlignmentFlag> >::isConvertible(pyargs[1])) {
        overloadId = 2; // setAlignment(QWidget*,QFlags<Qt::AlignmentFlag>)
    } else if (numArgs == 2 && Shiboken::Converter< ::QLayout * >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QFlags<Qt::AlignmentFlag> >::isConvertible(pyargs[1])) {
        overloadId = 1; // setAlignment(QLayout*,QFlags<Qt::AlignmentFlag>)
    } else if (numArgs == 1 && Shiboken::Converter< ::QFlags<Qt::AlignmentFlag> >::isConvertible(pyargs[0])) {
        overloadId = 0; // setAlignment(QFlags<Qt::AlignmentFlag>)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QLayoutFunc_setAlignment_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setAlignment(QFlags<Qt::AlignmentFlag>)
            {
                QFlags<Qt::AlignmentFlag> cppArg0 = Shiboken::Converter<QFlags<Qt::AlignmentFlag> >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // setAlignment(QFlags<Qt::AlignmentFlag>)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setAlignment(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Py_None;
                    Py_INCREF(Py_None);
                }
                break;
            }
            case 1: // setAlignment(QLayout*,QFlags<Qt::AlignmentFlag>)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QLayout * cppArg0 = Shiboken::Converter<QLayout * >::toCpp(pyargs[0]);
                QFlags<Qt::AlignmentFlag> cppArg1 = Shiboken::Converter<QFlags<Qt::AlignmentFlag> >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // setAlignment(QLayout*,QFlags<Qt::AlignmentFlag>)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    bool cppResult = cppSelf->setAlignment(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< bool >::toPython(cppResult);
                }
                break;
            }
            case 2: // setAlignment(QWidget*,QFlags<Qt::AlignmentFlag>)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QWidget * cppArg0 = Shiboken::Converter<QWidget * >::toCpp(pyargs[0]);
                QFlags<Qt::AlignmentFlag> cppArg1 = Shiboken::Converter<QFlags<Qt::AlignmentFlag> >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // setAlignment(QWidget*,QFlags<Qt::AlignmentFlag>)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    bool cppResult = cppSelf->setAlignment(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< bool >::toPython(cppResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QLayoutFunc_setAlignment_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.Alignment", "PySide.QtGui.QLayout, PySide.QtCore.Qt.Alignment", "PySide.QtGui.QWidget, PySide.QtCore.Qt.Alignment", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QLayout.setAlignment", overloads);
        return 0;
}

static PyObject* Sbk_QLayoutFunc_setContentsMargins(PyObject* self, PyObject* args)
{
    QLayout* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QLayout* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs == 2 || numArgs == 3)
        goto Sbk_QLayoutFunc_setContentsMargins_TypeError;

    if (!PyArg_UnpackTuple(args, "setContentsMargins", 1, 4, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: setContentsMargins(QMargins)
    // 1: setContentsMargins(int,int,int,int)
    if (numArgs == 4 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
        overloadId = 1; // setContentsMargins(int,int,int,int)
    } else if (numArgs == 1 && Shiboken::Converter< ::QMargins >::isConvertible(pyargs[0])) {
        overloadId = 0; // setContentsMargins(QMargins)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QLayoutFunc_setContentsMargins_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setContentsMargins(QMargins)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QMargins cppArg0 = Shiboken::Converter<QMargins >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // setContentsMargins(QMargins)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setContentsMargins(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // setContentsMargins(int,int,int,int)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);
                int cppArg3 = Shiboken::Converter<int >::toCpp(pyargs[3]);

                if(!PyErr_Occurred()) {
                    // setContentsMargins(int,int,int,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setContentsMargins(cppArg0, cppArg1, cppArg2, cppArg3);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QLayoutFunc_setContentsMargins_TypeError:
        const char* overloads[] = {"PySide.QtCore.QMargins", "int, int, int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QLayout.setContentsMargins", overloads);
        return 0;
}

static PyObject* Sbk_QLayoutFunc_setEnabled(PyObject* self, PyObject* arg)
{
    QLayout* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QLayout* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setEnabled(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setEnabled(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QLayoutFunc_setEnabled_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setEnabled(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setEnabled(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QLayoutFunc_setEnabled_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QLayout.setEnabled", overloads);
        return 0;
}

static PyObject* Sbk_QLayoutFunc_setGeometry(PyObject* self, PyObject* arg)
{
    QLayout* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QLayout* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setGeometry(QRect)
    if (Shiboken::Converter< ::QRect >::isConvertible(arg)) {
        overloadId = 0; // setGeometry(QRect)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QLayoutFunc_setGeometry_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QRect cppArg0 = Shiboken::Converter<QRect >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setGeometry(QRect)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QLayout::setGeometry(cppArg0):cppSelf->setGeometry(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QLayoutFunc_setGeometry_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRect", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QLayout.setGeometry", overloads);
        return 0;
}

static PyObject* Sbk_QLayoutFunc_setMargin(PyObject* self, PyObject* arg)
{
    QLayout* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QLayout* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setMargin(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setMargin(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QLayoutFunc_setMargin_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setMargin(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setMargin(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QLayoutFunc_setMargin_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QLayout.setMargin", overloads);
        return 0;
}

static PyObject* Sbk_QLayoutFunc_setMenuBar(PyObject* self, PyObject* arg)
{
    QLayout* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QLayout* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setMenuBar(QWidget*)
    if (Shiboken::Converter< ::QWidget * >::isConvertible(arg)) {
        overloadId = 0; // setMenuBar(QWidget*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QLayoutFunc_setMenuBar_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QWidget * cppArg0 = Shiboken::Converter<QWidget * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setMenuBar(QWidget*)
                // Begin code injection
                
                addLayoutOwnership(cppSelf, cppArg0);
                
                // End of code injection

                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setMenuBar(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS

            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QLayoutFunc_setMenuBar_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWidget", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QLayout.setMenuBar", overloads);
        return 0;
}

static PyObject* Sbk_QLayoutFunc_setSizeConstraint(PyObject* self, PyObject* arg)
{
    QLayout* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QLayout* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setSizeConstraint(QLayout::SizeConstraint)
    if (Shiboken::Converter< ::QLayout::SizeConstraint >::isConvertible(arg)) {
        overloadId = 0; // setSizeConstraint(QLayout::SizeConstraint)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QLayoutFunc_setSizeConstraint_TypeError;

    // Call function/method
    {
        {
            QLayout::SizeConstraint cppArg0 = Shiboken::Converter<QLayout::SizeConstraint >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setSizeConstraint(QLayout::SizeConstraint)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setSizeConstraint(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QLayoutFunc_setSizeConstraint_TypeError:
        const char* overloads[] = {"PySide.QtGui.QLayout.SizeConstraint", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QLayout.setSizeConstraint", overloads);
        return 0;
}

static PyObject* Sbk_QLayoutFunc_setSpacing(PyObject* self, PyObject* arg)
{
    QLayout* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QLayout* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setSpacing(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setSpacing(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QLayoutFunc_setSpacing_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setSpacing(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setSpacing(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QLayoutFunc_setSpacing_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QLayout.setSpacing", overloads);
        return 0;
}

static PyObject* Sbk_QLayoutFunc_sizeConstraint(PyObject* self)
{
    QLayout* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QLayout* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // sizeConstraint()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QLayout::SizeConstraint cppResult = cppSelf->sizeConstraint();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QLayout::SizeConstraint >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QLayoutFunc_spacing(PyObject* self)
{
    QLayout* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QLayout* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // spacing()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->spacing();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QLayoutFunc_takeAt(PyObject* self, PyObject* arg)
{
    QLayout* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QLayout* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: takeAt(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // takeAt(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QLayoutFunc_takeAt_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // takeAt(int)
                if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self))) {
                    PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QLayout.takeAt()' not implemented.");
                    return 0;
                }
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QLayoutItem * cppResult = cppSelf->takeAt(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QLayoutItem * >::toPython(cppResult);
                Shiboken::Object::setParent(Py_None, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QLayoutFunc_takeAt_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QLayout.takeAt", overloads);
        return 0;
}

static PyObject* Sbk_QLayoutFunc_totalHeightForWidth(PyObject* self, PyObject* arg)
{
    QLayout* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QLayout* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: totalHeightForWidth(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // totalHeightForWidth(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QLayoutFunc_totalHeightForWidth_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // totalHeightForWidth(int)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->totalHeightForWidth(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QLayoutFunc_totalHeightForWidth_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QLayout.totalHeightForWidth", overloads);
        return 0;
}

static PyObject* Sbk_QLayoutFunc_totalMaximumSize(PyObject* self)
{
    QLayout* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QLayout* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // totalMaximumSize()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QSize cppResult = cppSelf->totalMaximumSize();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QSize >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QLayoutFunc_totalMinimumSize(PyObject* self)
{
    QLayout* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QLayout* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // totalMinimumSize()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QSize cppResult = cppSelf->totalMinimumSize();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QSize >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QLayoutFunc_totalSizeHint(PyObject* self)
{
    QLayout* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QLayout* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // totalSizeHint()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QSize cppResult = cppSelf->totalSizeHint();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QSize >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QLayoutFunc_update(PyObject* self)
{
    QLayout* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QLayout* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // update()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->update();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QLayoutFunc_widgetEvent(PyObject* self, PyObject* arg)
{
    QLayout* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QLayout* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: widgetEvent(QEvent*)
    if (Shiboken::Converter< ::QEvent * >::isConvertible(arg)) {
        overloadId = 0; // widgetEvent(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QLayoutFunc_widgetEvent_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QEvent * cppArg0 = Shiboken::Converter<QEvent * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // widgetEvent(QEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->widgetEvent(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QLayoutFunc_widgetEvent_TypeError:
        const char* overloads[] = {"PySide.QtCore.QEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QLayout.widgetEvent", overloads);
        return 0;
}

static PyMethodDef Sbk_QLayout_methods[] = {
    {"activate", (PyCFunction)Sbk_QLayoutFunc_activate, METH_NOARGS},
    {"addChildLayout", (PyCFunction)Sbk_QLayoutFunc_addChildLayout, METH_O},
    {"addChildWidget", (PyCFunction)Sbk_QLayoutFunc_addChildWidget, METH_O},
    {"addItem", (PyCFunction)Sbk_QLayoutFunc_addItem, METH_O},
    {"addWidget", (PyCFunction)Sbk_QLayoutFunc_addWidget, METH_O},
    {"alignmentRect", (PyCFunction)Sbk_QLayoutFunc_alignmentRect, METH_O},
    {"childEvent", (PyCFunction)Sbk_QLayoutFunc_childEvent, METH_O},
    {"closestAcceptableSize", (PyCFunction)Sbk_QLayoutFunc_closestAcceptableSize, METH_VARARGS|METH_STATIC},
    {"contentsMargins", (PyCFunction)Sbk_QLayoutFunc_contentsMargins, METH_NOARGS},
    {"contentsRect", (PyCFunction)Sbk_QLayoutFunc_contentsRect, METH_NOARGS},
    {"count", (PyCFunction)Sbk_QLayoutFunc_count, METH_NOARGS},
    {"expandingDirections", (PyCFunction)Sbk_QLayoutFunc_expandingDirections, METH_NOARGS},
    {"geometry", (PyCFunction)Sbk_QLayoutFunc_geometry, METH_NOARGS},
    {"indexOf", (PyCFunction)Sbk_QLayoutFunc_indexOf, METH_O},
    {"invalidate", (PyCFunction)Sbk_QLayoutFunc_invalidate, METH_NOARGS},
    {"isEmpty", (PyCFunction)Sbk_QLayoutFunc_isEmpty, METH_NOARGS},
    {"isEnabled", (PyCFunction)Sbk_QLayoutFunc_isEnabled, METH_NOARGS},
    {"itemAt", (PyCFunction)Sbk_QLayoutFunc_itemAt, METH_O},
    {"layout", (PyCFunction)Sbk_QLayoutFunc_layout, METH_NOARGS},
    {"margin", (PyCFunction)Sbk_QLayoutFunc_margin, METH_NOARGS},
    {"maximumSize", (PyCFunction)Sbk_QLayoutFunc_maximumSize, METH_NOARGS},
    {"menuBar", (PyCFunction)Sbk_QLayoutFunc_menuBar, METH_NOARGS},
    {"minimumSize", (PyCFunction)Sbk_QLayoutFunc_minimumSize, METH_NOARGS},
    {"parentWidget", (PyCFunction)Sbk_QLayoutFunc_parentWidget, METH_NOARGS},
    {"removeItem", (PyCFunction)Sbk_QLayoutFunc_removeItem, METH_O},
    {"removeWidget", (PyCFunction)Sbk_QLayoutFunc_removeWidget, METH_O},
    {"setAlignment", (PyCFunction)Sbk_QLayoutFunc_setAlignment, METH_VARARGS},
    {"setContentsMargins", (PyCFunction)Sbk_QLayoutFunc_setContentsMargins, METH_VARARGS},
    {"setEnabled", (PyCFunction)Sbk_QLayoutFunc_setEnabled, METH_O},
    {"setGeometry", (PyCFunction)Sbk_QLayoutFunc_setGeometry, METH_O},
    {"setMargin", (PyCFunction)Sbk_QLayoutFunc_setMargin, METH_O},
    {"setMenuBar", (PyCFunction)Sbk_QLayoutFunc_setMenuBar, METH_O},
    {"setSizeConstraint", (PyCFunction)Sbk_QLayoutFunc_setSizeConstraint, METH_O},
    {"setSpacing", (PyCFunction)Sbk_QLayoutFunc_setSpacing, METH_O},
    {"sizeConstraint", (PyCFunction)Sbk_QLayoutFunc_sizeConstraint, METH_NOARGS},
    {"spacing", (PyCFunction)Sbk_QLayoutFunc_spacing, METH_NOARGS},
    {"takeAt", (PyCFunction)Sbk_QLayoutFunc_takeAt, METH_O},
    {"totalHeightForWidth", (PyCFunction)Sbk_QLayoutFunc_totalHeightForWidth, METH_O},
    {"totalMaximumSize", (PyCFunction)Sbk_QLayoutFunc_totalMaximumSize, METH_NOARGS},
    {"totalMinimumSize", (PyCFunction)Sbk_QLayoutFunc_totalMinimumSize, METH_NOARGS},
    {"totalSizeHint", (PyCFunction)Sbk_QLayoutFunc_totalSizeHint, METH_NOARGS},
    {"update", (PyCFunction)Sbk_QLayoutFunc_update, METH_NOARGS},
    {"widgetEvent", (PyCFunction)Sbk_QLayoutFunc_widgetEvent, METH_O},

    {0} // Sentinel
};

} // extern "C"

static int mi_offsets[] = { -1, -1, -1, -1, -1 };
int*
Sbk_QLayout_mi_init(const void* cptr)
{
    if (mi_offsets[0] == -1) {
        std::set<int> offsets;
        std::set<int>::iterator it;
        const QLayout* class_ptr = reinterpret_cast<const QLayout*>(cptr);
        size_t base = (size_t) class_ptr;
        offsets.insert(((size_t) static_cast<const QObject*>(class_ptr)) - base);
        offsets.insert(((size_t) static_cast<const QObject*>((QLayout*)((void*)class_ptr))) - base);
        offsets.insert(((size_t) static_cast<const QLayoutItem*>(class_ptr)) - base);
        offsets.insert(((size_t) static_cast<const QLayoutItem*>((QLayout*)((void*)class_ptr))) - base);

        offsets.erase(0);

        int i = 0;
        for (it = offsets.begin(); it != offsets.end(); it++) {
            mi_offsets[i] = *it;
            i++;
        }
    }
    return mi_offsets;
}
static void* Sbk_QLayoutSpecialCastFunction(void* obj, SbkObjectType* desiredType)
{
    QLayout* me = reinterpret_cast<QLayout*>(obj);
    if (desiredType == reinterpret_cast<SbkObjectType*>(SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX]))
        return static_cast<QObject*>(me);
    else if (desiredType == reinterpret_cast<SbkObjectType*>(SbkPySide_QtGuiTypes[SBK_QLAYOUTITEM_IDX]))
        return static_cast<QLayoutItem*>(me);
    return me;
}


// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QLayout_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QLayout",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QLayout_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QLayout_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern

static SbkObjectType* Sbk_QLayout_typeDiscovery(void* cptr, SbkObjectType* instanceType)
{
    if (instanceType == reinterpret_cast<SbkObjectType*>(Shiboken::SbkType<QObject >()) && dynamic_cast<QLayout*>(reinterpret_cast<QObject*>(cptr)))
        return &Sbk_QLayout_Type;
    if (instanceType == reinterpret_cast<SbkObjectType*>(Shiboken::SbkType<QLayoutItem >()) && dynamic_cast<QLayout*>(reinterpret_cast<QLayoutItem*>(cptr)))
        return &Sbk_QLayout_Type;
    return 0;
}


void init_QLayout(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QLAYOUT_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QLayout_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QLayout_Type);
    Shiboken::ObjectType::setSubTypeInitHook(&Sbk_QLayout_Type, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(&Sbk_QLayout_Type, &QLayout::staticMetaObject);    Sbk_QLayout_Type.super.ht_type.tp_base = SbkPySide_QtGuiTypes[SBK_QLAYOUTITEM_IDX];
    Sbk_QLayout_Type.super.ht_type.tp_bases = PyTuple_Pack(2,
        (PyTypeObject*)SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX], (PyTypeObject*)SbkPySide_QtGuiTypes[SBK_QLAYOUTITEM_IDX]);

    MultipleInheritanceInitFunction func;
    func = Sbk_QLayout_mi_init;
    Shiboken::ObjectType::setMultipleIheritanceFunction(&Sbk_QLayout_Type, func);
    Shiboken::ObjectType::setCastFunction(&Sbk_QLayout_Type, &Sbk_QLayoutSpecialCastFunction);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QLayout_Type, &Shiboken::callCppDestructor<QLayout >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QLayout_Type) < 0)
        return;

    // Fill type discovery information
    Shiboken::ObjectType::setTypeDiscoveryFunction(&Sbk_QLayout_Type, &Sbk_QLayout_typeDiscovery);
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkObjectType*>(SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX]), &Sbk_QLayout_Type);
    bm.addClassInheritance(reinterpret_cast<SbkObjectType*>(SbkPySide_QtGuiTypes[SBK_QLAYOUTITEM_IDX]), &Sbk_QLayout_Type);

    Shiboken::ObjectType::setOriginalName(&Sbk_QLayout_Type, "QLayout*");
    PyModule_AddObject(module, "QLayout",
        ((PyObject*)&Sbk_QLayout_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: SizeConstraint
    PyTypeObject* SbkPySide_QtGui_QLayout_SizeConstraint = Shiboken::Enum::newType("SizeConstraint");
    SbkPySide_QtGuiTypes[SBK_QLAYOUT_SIZECONSTRAINT_IDX] = SbkPySide_QtGui_QLayout_SizeConstraint;
    if (PyType_Ready(SbkPySide_QtGui_QLayout_SizeConstraint) < 0)
        return;
    PyDict_SetItemString(Sbk_QLayout_Type.super.ht_type.tp_dict,
            "SizeConstraint",((PyObject*)SbkPySide_QtGui_QLayout_SizeConstraint));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QLayout_SizeConstraint,(long) QLayout::SetDefaultConstraint, "SetDefaultConstraint");
    PyDict_SetItemString(Sbk_QLayout_Type.super.ht_type.tp_dict,"SetDefaultConstraint", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QLayout_SizeConstraint->tp_dict,"SetDefaultConstraint", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QLayout_SizeConstraint,(long) QLayout::SetNoConstraint, "SetNoConstraint");
    PyDict_SetItemString(Sbk_QLayout_Type.super.ht_type.tp_dict,"SetNoConstraint", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QLayout_SizeConstraint->tp_dict,"SetNoConstraint", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QLayout_SizeConstraint,(long) QLayout::SetMinimumSize, "SetMinimumSize");
    PyDict_SetItemString(Sbk_QLayout_Type.super.ht_type.tp_dict,"SetMinimumSize", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QLayout_SizeConstraint->tp_dict,"SetMinimumSize", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QLayout_SizeConstraint,(long) QLayout::SetFixedSize, "SetFixedSize");
    PyDict_SetItemString(Sbk_QLayout_Type.super.ht_type.tp_dict,"SetFixedSize", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QLayout_SizeConstraint->tp_dict,"SetFixedSize", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QLayout_SizeConstraint,(long) QLayout::SetMaximumSize, "SetMaximumSize");
    PyDict_SetItemString(Sbk_QLayout_Type.super.ht_type.tp_dict,"SetMaximumSize", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QLayout_SizeConstraint->tp_dict,"SetMaximumSize", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QLayout_SizeConstraint,(long) QLayout::SetMinAndMaxSize, "SetMinAndMaxSize");
    PyDict_SetItemString(Sbk_QLayout_Type.super.ht_type.tp_dict,"SetMinAndMaxSize", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QLayout_SizeConstraint->tp_dict,"SetMinAndMaxSize", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QLayout::SizeConstraint");
    Shiboken::TypeResolver::createValueTypeResolver<int>("QLayout$ConcreteWrapper::SizeConstraint");
    // end of enum SizeConstraint


    Shiboken::TypeResolver::createObjectTypeResolver<QLayout >("QLayout*");
    Shiboken::TypeResolver::createObjectTypeResolver<QLayout >("QLayout$ConcreteWrapper*");
    Shiboken::TypeResolver::createObjectTypeResolver<QLayout >(typeid(QLayout).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QLayout >(typeid(QLayoutWrapper).name());
    PySide::initQtMetaType<QLayout* >();
}

