/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qmouseevent_wrapper.h"

// Extra includes
#include <qevent.h>
#include <qpoint.h>


// Native ---------------------------------------------------------

QMouseEventWrapper::QMouseEventWrapper(QEvent::Type type, const QPoint & pos, Qt::MouseButton button, QFlags<Qt::MouseButton> buttons, QFlags<Qt::KeyboardModifier> modifiers) : QMouseEvent(type, pos, button, buttons, modifiers) {
    // ... middle
}

QMouseEventWrapper::QMouseEventWrapper(QEvent::Type type, const QPoint & pos, const QPoint & globalPos, Qt::MouseButton button, QFlags<Qt::MouseButton> buttons, QFlags<Qt::KeyboardModifier> modifiers) : QMouseEvent(type, pos, globalPos, button, buttons, modifiers) {
    // ... middle
}

QMouseEventWrapper::~QMouseEventWrapper()
{
    SbkObject* wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QMouseEvent_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QMouseEvent >()))
        return -1;

    QMouseEventWrapper* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QMouseEvent", 5, 6, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4]), &(pyargs[5])))
        return -1;

    // Overloaded function decisor
    // 0: QMouseEvent(QEvent::Type,QPoint,Qt::MouseButton,QFlags<Qt::MouseButton>,QFlags<Qt::KeyboardModifier>)
    // 1: QMouseEvent(QEvent::Type,QPoint,QPoint,Qt::MouseButton,QFlags<Qt::MouseButton>,QFlags<Qt::KeyboardModifier>)
    if (numArgs >= 2 && Shiboken::Converter< ::QEvent::Type >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QPoint >::isConvertible(pyargs[1])) {
        if (numArgs == 6 && Shiboken::Converter< ::QPoint >::isConvertible(pyargs[2]) && Shiboken::Converter< ::Qt::MouseButton >::isConvertible(pyargs[3]) && Shiboken::Converter< ::QFlags<Qt::MouseButton> >::isConvertible(pyargs[4]) && Shiboken::Converter< ::QFlags<Qt::KeyboardModifier> >::isConvertible(pyargs[5])) {
            overloadId = 1; // QMouseEvent(QEvent::Type,QPoint,QPoint,Qt::MouseButton,QFlags<Qt::MouseButton>,QFlags<Qt::KeyboardModifier>)
        } else if (numArgs == 5 && Shiboken::Converter< ::Qt::MouseButton >::isConvertible(pyargs[2]) && Shiboken::Converter< ::QFlags<Qt::MouseButton> >::isConvertible(pyargs[3]) && Shiboken::Converter< ::QFlags<Qt::KeyboardModifier> >::isConvertible(pyargs[4])) {
            overloadId = 0; // QMouseEvent(QEvent::Type,QPoint,Qt::MouseButton,QFlags<Qt::MouseButton>,QFlags<Qt::KeyboardModifier>)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QMouseEvent_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QMouseEvent(QEvent::Type,QPoint,Qt::MouseButton,QFlags<Qt::MouseButton>,QFlags<Qt::KeyboardModifier>)
            {
                QEvent::Type cppArg0 = Shiboken::Converter<QEvent::Type >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return -1;
                QPoint cppArg1 = Shiboken::Converter<QPoint >::toCpp(pyargs[1]);
                Qt::MouseButton cppArg2 = Shiboken::Converter<Qt::MouseButton >::toCpp(pyargs[2]);
                QFlags<Qt::MouseButton> cppArg3 = Shiboken::Converter<QFlags<Qt::MouseButton> >::toCpp(pyargs[3]);
                QFlags<Qt::KeyboardModifier> cppArg4 = Shiboken::Converter<QFlags<Qt::KeyboardModifier> >::toCpp(pyargs[4]);

                if(!PyErr_Occurred()) {
                    // QMouseEvent(QEvent::Type,QPoint,Qt::MouseButton,QFlags<Qt::MouseButton>,QFlags<Qt::KeyboardModifier>)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QMouseEventWrapper(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // QMouseEvent(QEvent::Type,QPoint,QPoint,Qt::MouseButton,QFlags<Qt::MouseButton>,QFlags<Qt::KeyboardModifier>)
            {
                QEvent::Type cppArg0 = Shiboken::Converter<QEvent::Type >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return -1;
                QPoint cppArg1 = Shiboken::Converter<QPoint >::toCpp(pyargs[1]);
                if (!Shiboken::Object::isValid(pyargs[2]))
                    return -1;
                QPoint cppArg2 = Shiboken::Converter<QPoint >::toCpp(pyargs[2]);
                Qt::MouseButton cppArg3 = Shiboken::Converter<Qt::MouseButton >::toCpp(pyargs[3]);
                QFlags<Qt::MouseButton> cppArg4 = Shiboken::Converter<QFlags<Qt::MouseButton> >::toCpp(pyargs[4]);
                QFlags<Qt::KeyboardModifier> cppArg5 = Shiboken::Converter<QFlags<Qt::KeyboardModifier> >::toCpp(pyargs[5]);

                if(!PyErr_Occurred()) {
                    // QMouseEvent(QEvent::Type,QPoint,QPoint,Qt::MouseButton,QFlags<Qt::MouseButton>,QFlags<Qt::KeyboardModifier>)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QMouseEventWrapper(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QMouseEvent >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QMouseEvent_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QMouseEvent_Init_TypeError:
        const char* overloads[] = {"PySide.QtCore.QEvent.Type, PySide.QtCore.QPoint, PySide.QtCore.Qt.MouseButton, PySide.QtCore.Qt.MouseButtons, PySide.QtCore.Qt.KeyboardModifiers", "PySide.QtCore.QEvent.Type, PySide.QtCore.QPoint, PySide.QtCore.QPoint, PySide.QtCore.Qt.MouseButton, PySide.QtCore.Qt.MouseButtons, PySide.QtCore.Qt.KeyboardModifiers", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QMouseEvent", overloads);
        return -1;
}

static PyObject* Sbk_QMouseEventFunc_button(PyObject* self)
{
    QMouseEvent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMouseEvent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // button()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                Qt::MouseButton cppResult = cppSelf->button();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::Qt::MouseButton >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QMouseEventFunc_buttons(PyObject* self)
{
    QMouseEvent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMouseEvent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // buttons()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QFlags<Qt::MouseButton> cppResult = cppSelf->buttons();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QFlags<Qt::MouseButton> >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QMouseEventFunc_createExtendedMouseEvent(PyObject* self, PyObject* args)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "createExtendedMouseEvent", 6, 6, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4]), &(pyargs[5])))
        return 0;


    // Overloaded function decisor
    // 0: createExtendedMouseEvent(QEvent::Type,QPointF,QPoint,Qt::MouseButton,QFlags<Qt::MouseButton>,QFlags<Qt::KeyboardModifier>)
    if (numArgs == 6 && Shiboken::Converter< ::QEvent::Type >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QPointF >::isConvertible(pyargs[1]) && Shiboken::Converter< ::QPoint >::isConvertible(pyargs[2]) && Shiboken::Converter< ::Qt::MouseButton >::isConvertible(pyargs[3]) && Shiboken::Converter< ::QFlags<Qt::MouseButton> >::isConvertible(pyargs[4]) && Shiboken::Converter< ::QFlags<Qt::KeyboardModifier> >::isConvertible(pyargs[5])) {
        overloadId = 0; // createExtendedMouseEvent(QEvent::Type,QPointF,QPoint,Qt::MouseButton,QFlags<Qt::MouseButton>,QFlags<Qt::KeyboardModifier>)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QMouseEventFunc_createExtendedMouseEvent_TypeError;

    // Call function/method
    {
        {
            QEvent::Type cppArg0 = Shiboken::Converter<QEvent::Type >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QPointF cppArg1 = Shiboken::Converter<QPointF >::toCpp(pyargs[1]);
            if (!Shiboken::Object::isValid(pyargs[2]))
                return 0;
            QPoint cppArg2 = Shiboken::Converter<QPoint >::toCpp(pyargs[2]);
            Qt::MouseButton cppArg3 = Shiboken::Converter<Qt::MouseButton >::toCpp(pyargs[3]);
            QFlags<Qt::MouseButton> cppArg4 = Shiboken::Converter<QFlags<Qt::MouseButton> >::toCpp(pyargs[4]);
            QFlags<Qt::KeyboardModifier> cppArg5 = Shiboken::Converter<QFlags<Qt::KeyboardModifier> >::toCpp(pyargs[5]);

            if(!PyErr_Occurred()) {
                // createExtendedMouseEvent(QEvent::Type,QPointF,QPoint,Qt::MouseButton,QFlags<Qt::MouseButton>,QFlags<Qt::KeyboardModifier>)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QMouseEvent * cppResult = QMouseEvent::createExtendedMouseEvent(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QMouseEvent * >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QMouseEventFunc_createExtendedMouseEvent_TypeError:
        const char* overloads[] = {"PySide.QtCore.QEvent.Type, PySide.QtCore.QPointF, PySide.QtCore.QPoint, PySide.QtCore.Qt.MouseButton, PySide.QtCore.Qt.MouseButtons, PySide.QtCore.Qt.KeyboardModifiers", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QMouseEvent.createExtendedMouseEvent", overloads);
        return 0;
}

static PyObject* Sbk_QMouseEventFunc_globalPos(PyObject* self)
{
    QMouseEvent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMouseEvent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // globalPos()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                const QPoint & cppResult = cppSelf->globalPos();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPoint >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QMouseEventFunc_globalX(PyObject* self)
{
    QMouseEvent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMouseEvent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // globalX()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->globalX();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QMouseEventFunc_globalY(PyObject* self)
{
    QMouseEvent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMouseEvent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // globalY()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->globalY();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QMouseEventFunc_hasExtendedInfo(PyObject* self)
{
    QMouseEvent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMouseEvent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // hasExtendedInfo()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->hasExtendedInfo();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QMouseEventFunc_pos(PyObject* self)
{
    QMouseEvent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMouseEvent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // pos()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                const QPoint & cppResult = cppSelf->pos();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPoint >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QMouseEventFunc_posF(PyObject* self)
{
    QMouseEvent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMouseEvent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // posF()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPointF cppResult = cppSelf->posF();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPointF >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QMouseEventFunc_x(PyObject* self)
{
    QMouseEvent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMouseEvent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // x()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->x();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QMouseEventFunc_y(PyObject* self)
{
    QMouseEvent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QMouseEvent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // y()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->y();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef Sbk_QMouseEvent_methods[] = {
    {"button", (PyCFunction)Sbk_QMouseEventFunc_button, METH_NOARGS},
    {"buttons", (PyCFunction)Sbk_QMouseEventFunc_buttons, METH_NOARGS},
    {"createExtendedMouseEvent", (PyCFunction)Sbk_QMouseEventFunc_createExtendedMouseEvent, METH_VARARGS|METH_STATIC},
    {"globalPos", (PyCFunction)Sbk_QMouseEventFunc_globalPos, METH_NOARGS},
    {"globalX", (PyCFunction)Sbk_QMouseEventFunc_globalX, METH_NOARGS},
    {"globalY", (PyCFunction)Sbk_QMouseEventFunc_globalY, METH_NOARGS},
    {"hasExtendedInfo", (PyCFunction)Sbk_QMouseEventFunc_hasExtendedInfo, METH_NOARGS},
    {"pos", (PyCFunction)Sbk_QMouseEventFunc_pos, METH_NOARGS},
    {"posF", (PyCFunction)Sbk_QMouseEventFunc_posF, METH_NOARGS},
    {"x", (PyCFunction)Sbk_QMouseEventFunc_x, METH_NOARGS},
    {"y", (PyCFunction)Sbk_QMouseEventFunc_y, METH_NOARGS},

    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QMouseEvent_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QMouseEvent",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QMouseEvent_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QMouseEvent_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern

static SbkObjectType* Sbk_QMouseEvent_typeDiscovery(void* cptr, SbkObjectType* instanceType)
{
     if ( reinterpret_cast<QMouseEvent*>(cptr)->type() == QEvent::MouseButtonDblClick ||  reinterpret_cast<QMouseEvent*>(cptr)->type() == QEvent::MouseButtonPress ||  reinterpret_cast<QMouseEvent*>(cptr)->type() == QEvent::MouseButtonRelease ||  reinterpret_cast<QMouseEvent*>(cptr)->type() == QEvent::MouseMove)
        return &Sbk_QMouseEvent_Type;
    return 0;
}


void init_QMouseEvent(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QMOUSEEVENT_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QMouseEvent_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QMouseEvent_Type);
    Sbk_QMouseEvent_Type.super.ht_type.tp_base = SbkPySide_QtGuiTypes[SBK_QINPUTEVENT_IDX];
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QMouseEvent_Type, &Shiboken::callCppDestructor<QMouseEvent >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QMouseEvent_Type) < 0)
        return;

    // Fill type discovery information
    Shiboken::ObjectType::setTypeDiscoveryFunction(&Sbk_QMouseEvent_Type, &Sbk_QMouseEvent_typeDiscovery);
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkObjectType*>(SbkPySide_QtGuiTypes[SBK_QINPUTEVENT_IDX]), &Sbk_QMouseEvent_Type);

    Shiboken::ObjectType::setOriginalName(&Sbk_QMouseEvent_Type, "QMouseEvent*");
    PyModule_AddObject(module, "QMouseEvent",
        ((PyObject*)&Sbk_QMouseEvent_Type));


    Shiboken::TypeResolver::createObjectTypeResolver<QMouseEvent >("QMouseEvent*");
    Shiboken::TypeResolver::createObjectTypeResolver<QMouseEvent >(typeid(QMouseEvent).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QMouseEvent >(typeid(QMouseEventWrapper).name());
    PySide::initQtMetaType<QMouseEvent* >();
}

