/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qpainterpath_element_wrapper.h"

// Extra includes
#include <QPainterPath>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QPainterPath_Element_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QPainterPath::Element >()))
        return -1;

    QPainterPath::Element* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "Element", 0, 1, &(pyargs[0])))
        return -1;

    // Overloaded function decisor
    // 0: Element()
    // 1: Element(QPainterPath::Element)
    if (numArgs == 0) {
        overloadId = 0; // Element()
    } else if (numArgs == 1 && Shiboken::Converter< ::QPainterPath::Element >::isConvertible(pyargs[0])) {
        overloadId = 1; // Element(QPainterPath::Element)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPainterPath_Element_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // Element()
            {

                if(!PyErr_Occurred()) {
                    // Element()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QPainterPath::Element();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // Element(QPainterPath::Element)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QPainterPath::Element cppArg0 = Shiboken::Converter<QPainterPath::Element >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // Element(QPainterPath::Element)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QPainterPath::Element(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QPainterPath::Element >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QPainterPath_Element_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QPainterPath_Element_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtGui.QPainterPath::Element", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.Element", overloads);
        return -1;
}

static PyObject* Sbk_QPainterPath_ElementFunc_isCurveTo(PyObject* self)
{
    QPainterPath::Element* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainterPath::Element* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isCurveTo()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->isCurveTo();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPainterPath_ElementFunc_isLineTo(PyObject* self)
{
    QPainterPath::Element* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainterPath::Element* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isLineTo()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->isLineTo();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPainterPath_ElementFunc_isMoveTo(PyObject* self)
{
    QPainterPath::Element* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPainterPath::Element* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isMoveTo()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->isMoveTo();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject *Sbk_QPainterPath_Element___copy__(PyObject *self)
{
        QPainterPath::Element* cppSelf = 0;
        if (!Shiboken::Object::isValid(self))
            return 0;
        cppSelf = Shiboken::Converter<QPainterPath::Element*>::toCpp(self);
        PyObject* pyResult = 0;
        QPainterPath::Element* copy = new QPainterPath::Element(*cppSelf);
        pyResult = Shiboken::Converter<QPainterPath::Element*>::toPython(copy);
        Shiboken::Object::getOwnership(pyResult);

        if (PyErr_Occurred() || !pyResult) {
            Py_XDECREF(pyResult);
            return 0;
        }
        return pyResult;
}

static PyMethodDef Sbk_QPainterPath_Element_methods[] = {
    {"isCurveTo", (PyCFunction)Sbk_QPainterPath_ElementFunc_isCurveTo, METH_NOARGS},
    {"isLineTo", (PyCFunction)Sbk_QPainterPath_ElementFunc_isLineTo, METH_NOARGS},
    {"isMoveTo", (PyCFunction)Sbk_QPainterPath_ElementFunc_isMoveTo, METH_NOARGS},

    {"__copy__", (PyCFunction)Sbk_QPainterPath_Element___copy__, METH_NOARGS},
    {0} // Sentinel
};

// Rich comparison
static PyObject* Sbk_QPainterPath_Element_richcompare(PyObject* self, PyObject* arg, int op)
{
    PyObject* pyResult = 0;
    QPainterPath::Element& cppSelf = *Shiboken::Converter< QPainterPath::Element* >::toCpp(self);

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter< ::QPainterPath::Element >::isConvertible(arg)) {
                // operator!=(const QPainterPath::Element & e) const
                QPainterPath::Element cppArg0 = Shiboken::Converter< ::QPainterPath::Element >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf != cppArg0);
            } else goto Sbk_QPainterPath_Element_RichComparison_TypeError;

            break;
        case Py_EQ:
            if (Shiboken::Converter< ::QPainterPath::Element >::isConvertible(arg)) {
                // operator==(const QPainterPath::Element & e) const
                QPainterPath::Element cppArg0 = Shiboken::Converter< ::QPainterPath::Element >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf == cppArg0);
            } else goto Sbk_QPainterPath_Element_RichComparison_TypeError;

            break;
        default:
            goto Sbk_QPainterPath_Element_RichComparison_TypeError;
    }

    if (pyResult && !PyErr_Occurred())
        return pyResult;
    Sbk_QPainterPath_Element_RichComparison_TypeError:
    PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
    return 0;

}

static PyObject* Sbk_QPainterPath_Element_get_x(PyObject* self, void*)
{
    PyObject* val = Shiboken::Converter< double >::toPython( Shiboken::Converter< QPainterPath::Element* >::toCpp(self)->x);
    return val;

}
static int Sbk_QPainterPath_Element_set_x(PyObject* self, PyObject* value, void*)
{
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'x' may not be deleted");
        return -1;
    }
    if (!SbkNumber_Check(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'x', 'qreal' or convertible type expected");
        return -1;
    }

    Shiboken::Converter< QPainterPath::Element* >::toCpp(self)->x = Shiboken::Converter< double >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QPainterPath_Element_get_y(PyObject* self, void*)
{
    PyObject* val = Shiboken::Converter< double >::toPython( Shiboken::Converter< QPainterPath::Element* >::toCpp(self)->y);
    return val;

}
static int Sbk_QPainterPath_Element_set_y(PyObject* self, PyObject* value, void*)
{
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'y' may not be deleted");
        return -1;
    }
    if (!SbkNumber_Check(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'y', 'qreal' or convertible type expected");
        return -1;
    }

    Shiboken::Converter< QPainterPath::Element* >::toCpp(self)->y = Shiboken::Converter< double >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QPainterPath_Element_get_type(PyObject* self, void*)
{
    PyObject* val = Shiboken::Converter< ::QPainterPath::ElementType >::toPython( Shiboken::Converter< QPainterPath::Element* >::toCpp(self)->type);
    return val;

}
static int Sbk_QPainterPath_Element_set_type(PyObject* self, PyObject* value, void*)
{
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'type' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter< ::QPainterPath::ElementType >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'type', 'ElementType' or convertible type expected");
        return -1;
    }

    Shiboken::Converter< QPainterPath::Element* >::toCpp(self)->type = Shiboken::Converter< ::QPainterPath::ElementType >::toCpp(value);

    return 0;
}

// Getters and Setters for Element
static PyGetSetDef Sbk_QPainterPath_Element_getsetlist[] = {
    {const_cast<char*>("x"), Sbk_QPainterPath_Element_get_x, Sbk_QPainterPath_Element_set_x},
    {const_cast<char*>("y"), Sbk_QPainterPath_Element_get_y, Sbk_QPainterPath_Element_set_y},
    {const_cast<char*>("type"), Sbk_QPainterPath_Element_get_type, Sbk_QPainterPath_Element_set_type},
    {0}  // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QPainterPath_Element_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.Element",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      Sbk_QPainterPath_Element_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QPainterPath_Element_methods,
    /*tp_members*/          0,
    /*tp_getset*/           Sbk_QPainterPath_Element_getsetlist,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QPainterPath_Element_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QPainterPath_Element(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QPAINTERPATH_ELEMENT_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QPainterPath_Element_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QPainterPath_Element_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QPainterPath_Element_Type, &Shiboken::callCppDestructor<QPainterPath::Element >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QPainterPath_Element_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QPainterPath_Element_Type, "QPainterPath::Element");
    PyDict_SetItemString(module,"Element", (PyObject*)&Sbk_QPainterPath_Element_Type);

    Shiboken::TypeResolver::createValueTypeResolver<QPainterPath::Element >("QPainterPath::Element");
    Shiboken::TypeResolver::createObjectTypeResolver<QPainterPath::Element >("QPainterPath::Element*");
    Shiboken::TypeResolver::createValueTypeResolver<QPainterPath::Element >(typeid(QPainterPath::Element).name());
    PySide::initQtMetaType<QPainterPath::Element >();
}

