/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qpalette_wrapper.h"

// Extra includes
#include <qbrush.h>
#include <qcolor.h>
#include <qdatastream.h>
#include <qpalette.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QPalette_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QPalette >()))
        return -1;

    QPalette* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs == 3 || numArgs == 4 || numArgs == 5 || numArgs == 6 || numArgs == 7 || numArgs == 8)
        goto Sbk_QPalette_Init_TypeError;

    if (!PyArg_UnpackTuple(args, "QPalette", 0, 9, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4]), &(pyargs[5]), &(pyargs[6]), &(pyargs[7]), &(pyargs[8])))
        return -1;

    // Overloaded function decisor
    // 0: QPalette()
    // 1: QPalette(Qt::GlobalColor)
    // 2: QPalette(QBrush,QBrush,QBrush,QBrush,QBrush,QBrush,QBrush,QBrush,QBrush)
    // 3: QPalette(QColor)
    // 4: QPalette(QColor,QColor)
    // 5: QPalette(QPalette)
    if (numArgs == 0) {
        overloadId = 0; // QPalette()
    } else if (numArgs == 1 && Shiboken::Converter< ::Qt::GlobalColor >::isConvertible(pyargs[0])) {
        overloadId = 1; // QPalette(Qt::GlobalColor)
    } else if (Shiboken::Converter< ::QColor >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 3; // QPalette(QColor)
        } else if (numArgs == 2 && Shiboken::Converter< ::QColor >::isConvertible(pyargs[1])) {
            overloadId = 4; // QPalette(QColor,QColor)
        }
    } else if (numArgs == 1 && Shiboken::Converter< ::QPalette >::isConvertible(pyargs[0])) {
        overloadId = 5; // QPalette(QPalette)
    } else if (numArgs == 9 && Shiboken::Converter< ::QBrush >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QBrush >::isConvertible(pyargs[1]) && Shiboken::Converter< ::QBrush >::isConvertible(pyargs[2]) && Shiboken::Converter< ::QBrush >::isConvertible(pyargs[3]) && Shiboken::Converter< ::QBrush >::isConvertible(pyargs[4]) && Shiboken::Converter< ::QBrush >::isConvertible(pyargs[5]) && Shiboken::Converter< ::QBrush >::isConvertible(pyargs[6]) && Shiboken::Converter< ::QBrush >::isConvertible(pyargs[7]) && Shiboken::Converter< ::QBrush >::isConvertible(pyargs[8])) {
        overloadId = 2; // QPalette(QBrush,QBrush,QBrush,QBrush,QBrush,QBrush,QBrush,QBrush,QBrush)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPalette_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QPalette()
            {

                if(!PyErr_Occurred()) {
                    // QPalette()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QPalette();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // QPalette(Qt::GlobalColor)
            {
                Qt::GlobalColor cppArg0 = Shiboken::Converter<Qt::GlobalColor >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QPalette(Qt::GlobalColor)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QPalette(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // QPalette(QBrush,QBrush,QBrush,QBrush,QBrush,QBrush,QBrush,QBrush,QBrush)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QBrush cppArg0 = Shiboken::Converter<QBrush >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return -1;
                QBrush cppArg1 = Shiboken::Converter<QBrush >::toCpp(pyargs[1]);
                if (!Shiboken::Object::isValid(pyargs[2]))
                    return -1;
                QBrush cppArg2 = Shiboken::Converter<QBrush >::toCpp(pyargs[2]);
                if (!Shiboken::Object::isValid(pyargs[3]))
                    return -1;
                QBrush cppArg3 = Shiboken::Converter<QBrush >::toCpp(pyargs[3]);
                if (!Shiboken::Object::isValid(pyargs[4]))
                    return -1;
                QBrush cppArg4 = Shiboken::Converter<QBrush >::toCpp(pyargs[4]);
                if (!Shiboken::Object::isValid(pyargs[5]))
                    return -1;
                QBrush cppArg5 = Shiboken::Converter<QBrush >::toCpp(pyargs[5]);
                if (!Shiboken::Object::isValid(pyargs[6]))
                    return -1;
                QBrush cppArg6 = Shiboken::Converter<QBrush >::toCpp(pyargs[6]);
                if (!Shiboken::Object::isValid(pyargs[7]))
                    return -1;
                QBrush cppArg7 = Shiboken::Converter<QBrush >::toCpp(pyargs[7]);
                if (!Shiboken::Object::isValid(pyargs[8]))
                    return -1;
                QBrush cppArg8 = Shiboken::Converter<QBrush >::toCpp(pyargs[8]);

                if(!PyErr_Occurred()) {
                    // QPalette(QBrush,QBrush,QBrush,QBrush,QBrush,QBrush,QBrush,QBrush,QBrush)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QPalette(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5, cppArg6, cppArg7, cppArg8);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 3: // QPalette(QColor)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QColor cppArg0 = Shiboken::Converter<QColor >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QPalette(QColor)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QPalette(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 4: // QPalette(QColor,QColor)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QColor cppArg0 = Shiboken::Converter<QColor >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return -1;
                QColor cppArg1 = Shiboken::Converter<QColor >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // QPalette(QColor,QColor)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QPalette(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 5: // QPalette(QPalette)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QPalette cppArg0 = Shiboken::Converter<QPalette >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QPalette(QPalette)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QPalette(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QPalette >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QPalette_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QPalette_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtCore.Qt.GlobalColor", "PySide.QtGui.QBrush, PySide.QtGui.QBrush, PySide.QtGui.QBrush, PySide.QtGui.QBrush, PySide.QtGui.QBrush, PySide.QtGui.QBrush, PySide.QtGui.QBrush, PySide.QtGui.QBrush, PySide.QtGui.QBrush", "PySide.QtGui.QColor", "PySide.QtGui.QColor, PySide.QtGui.QColor", "PySide.QtGui.QPalette", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPalette", overloads);
        return -1;
}

static PyObject* Sbk_QPaletteFunc_alternateBase(PyObject* self)
{
    QPalette* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPalette* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // alternateBase()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                const QBrush & cppResult = cppSelf->alternateBase();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QBrush >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPaletteFunc_base(PyObject* self)
{
    QPalette* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPalette* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // base()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                const QBrush & cppResult = cppSelf->base();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QBrush >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPaletteFunc_brightText(PyObject* self)
{
    QPalette* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPalette* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // brightText()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                const QBrush & cppResult = cppSelf->brightText();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QBrush >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPaletteFunc_brush(PyObject* self, PyObject* args)
{
    QPalette* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPalette* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "brush", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: brush(QPalette::ColorGroup,QPalette::ColorRole)const
    // 1: brush(QPalette::ColorRole)const
    if (numArgs == 1 && Shiboken::Converter< ::QPalette::ColorRole >::isConvertible(pyargs[0])) {
        overloadId = 1; // brush(QPalette::ColorRole)const
    } else if (numArgs == 2 && Shiboken::Converter< ::QPalette::ColorGroup >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QPalette::ColorRole >::isConvertible(pyargs[1])) {
        overloadId = 0; // brush(QPalette::ColorGroup,QPalette::ColorRole)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPaletteFunc_brush_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // brush(QPalette::ColorGroup,QPalette::ColorRole)const
            {
                QPalette::ColorGroup cppArg0 = Shiboken::Converter<QPalette::ColorGroup >::toCpp(pyargs[0]);
                QPalette::ColorRole cppArg1 = Shiboken::Converter<QPalette::ColorRole >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // brush(QPalette::ColorGroup,QPalette::ColorRole)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    const QBrush & cppResult = cppSelf->brush(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QBrush >::toPython(cppResult);
                }
                break;
            }
            case 1: // brush(QPalette::ColorRole)const
            {
                QPalette::ColorRole cppArg0 = Shiboken::Converter<QPalette::ColorRole >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // brush(QPalette::ColorRole)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    const QBrush & cppResult = cppSelf->brush(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QBrush >::toPython(cppResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QPaletteFunc_brush_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPalette.ColorGroup, PySide.QtGui.QPalette.ColorRole", "PySide.QtGui.QPalette.ColorRole", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPalette.brush", overloads);
        return 0;
}

static PyObject* Sbk_QPaletteFunc_button(PyObject* self)
{
    QPalette* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPalette* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // button()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                const QBrush & cppResult = cppSelf->button();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QBrush >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPaletteFunc_buttonText(PyObject* self)
{
    QPalette* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPalette* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // buttonText()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                const QBrush & cppResult = cppSelf->buttonText();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QBrush >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPaletteFunc_cacheKey(PyObject* self)
{
    QPalette* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPalette* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // cacheKey()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qint64 cppResult = cppSelf->cacheKey();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< long long >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPaletteFunc_color(PyObject* self, PyObject* args)
{
    QPalette* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPalette* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "color", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: color(QPalette::ColorGroup,QPalette::ColorRole)const
    // 1: color(QPalette::ColorRole)const
    if (numArgs == 1 && Shiboken::Converter< ::QPalette::ColorRole >::isConvertible(pyargs[0])) {
        overloadId = 1; // color(QPalette::ColorRole)const
    } else if (numArgs == 2 && Shiboken::Converter< ::QPalette::ColorGroup >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QPalette::ColorRole >::isConvertible(pyargs[1])) {
        overloadId = 0; // color(QPalette::ColorGroup,QPalette::ColorRole)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPaletteFunc_color_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // color(QPalette::ColorGroup,QPalette::ColorRole)const
            {
                QPalette::ColorGroup cppArg0 = Shiboken::Converter<QPalette::ColorGroup >::toCpp(pyargs[0]);
                QPalette::ColorRole cppArg1 = Shiboken::Converter<QPalette::ColorRole >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // color(QPalette::ColorGroup,QPalette::ColorRole)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    const QColor & cppResult = cppSelf->color(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QColor >::toPython(cppResult);
                }
                break;
            }
            case 1: // color(QPalette::ColorRole)const
            {
                QPalette::ColorRole cppArg0 = Shiboken::Converter<QPalette::ColorRole >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // color(QPalette::ColorRole)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    const QColor & cppResult = cppSelf->color(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QColor >::toPython(cppResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QPaletteFunc_color_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPalette.ColorGroup, PySide.QtGui.QPalette.ColorRole", "PySide.QtGui.QPalette.ColorRole", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPalette.color", overloads);
        return 0;
}

static PyObject* Sbk_QPaletteFunc_currentColorGroup(PyObject* self)
{
    QPalette* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPalette* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // currentColorGroup()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPalette::ColorGroup cppResult = cppSelf->currentColorGroup();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPalette::ColorGroup >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPaletteFunc_dark(PyObject* self)
{
    QPalette* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPalette* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // dark()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                const QBrush & cppResult = cppSelf->dark();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QBrush >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPaletteFunc_highlight(PyObject* self)
{
    QPalette* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPalette* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // highlight()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                const QBrush & cppResult = cppSelf->highlight();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QBrush >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPaletteFunc_highlightedText(PyObject* self)
{
    QPalette* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPalette* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // highlightedText()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                const QBrush & cppResult = cppSelf->highlightedText();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QBrush >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPaletteFunc_isBrushSet(PyObject* self, PyObject* args)
{
    QPalette* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPalette* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "isBrushSet", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: isBrushSet(QPalette::ColorGroup,QPalette::ColorRole)const
    if (numArgs == 2 && Shiboken::Converter< ::QPalette::ColorGroup >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QPalette::ColorRole >::isConvertible(pyargs[1])) {
        overloadId = 0; // isBrushSet(QPalette::ColorGroup,QPalette::ColorRole)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPaletteFunc_isBrushSet_TypeError;

    // Call function/method
    {
        {
            QPalette::ColorGroup cppArg0 = Shiboken::Converter<QPalette::ColorGroup >::toCpp(pyargs[0]);
            QPalette::ColorRole cppArg1 = Shiboken::Converter<QPalette::ColorRole >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // isBrushSet(QPalette::ColorGroup,QPalette::ColorRole)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->isBrushSet(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QPaletteFunc_isBrushSet_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPalette.ColorGroup, PySide.QtGui.QPalette.ColorRole", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPalette.isBrushSet", overloads);
        return 0;
}

static PyObject* Sbk_QPaletteFunc_isCopyOf(PyObject* self, PyObject* arg)
{
    QPalette* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPalette* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: isCopyOf(QPalette)const
    if (Shiboken::Converter< ::QPalette >::isConvertible(arg)) {
        overloadId = 0; // isCopyOf(QPalette)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPaletteFunc_isCopyOf_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QPalette cppArg0 = Shiboken::Converter<QPalette >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // isCopyOf(QPalette)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->isCopyOf(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QPaletteFunc_isCopyOf_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPalette", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPalette.isCopyOf", overloads);
        return 0;
}

static PyObject* Sbk_QPaletteFunc_isEqual(PyObject* self, PyObject* args)
{
    QPalette* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPalette* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "isEqual", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: isEqual(QPalette::ColorGroup,QPalette::ColorGroup)const
    if (numArgs == 2 && Shiboken::Converter< ::QPalette::ColorGroup >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QPalette::ColorGroup >::isConvertible(pyargs[1])) {
        overloadId = 0; // isEqual(QPalette::ColorGroup,QPalette::ColorGroup)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPaletteFunc_isEqual_TypeError;

    // Call function/method
    {
        {
            QPalette::ColorGroup cppArg0 = Shiboken::Converter<QPalette::ColorGroup >::toCpp(pyargs[0]);
            QPalette::ColorGroup cppArg1 = Shiboken::Converter<QPalette::ColorGroup >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // isEqual(QPalette::ColorGroup,QPalette::ColorGroup)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->isEqual(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QPaletteFunc_isEqual_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPalette.ColorGroup, PySide.QtGui.QPalette.ColorGroup", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPalette.isEqual", overloads);
        return 0;
}

static PyObject* Sbk_QPaletteFunc_light(PyObject* self)
{
    QPalette* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPalette* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // light()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                const QBrush & cppResult = cppSelf->light();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QBrush >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPaletteFunc_link(PyObject* self)
{
    QPalette* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPalette* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // link()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                const QBrush & cppResult = cppSelf->link();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QBrush >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPaletteFunc_linkVisited(PyObject* self)
{
    QPalette* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPalette* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // linkVisited()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                const QBrush & cppResult = cppSelf->linkVisited();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QBrush >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPaletteFunc_mid(PyObject* self)
{
    QPalette* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPalette* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // mid()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                const QBrush & cppResult = cppSelf->mid();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QBrush >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPaletteFunc_midlight(PyObject* self)
{
    QPalette* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPalette* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // midlight()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                const QBrush & cppResult = cppSelf->midlight();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QBrush >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPaletteFunc_resolve(PyObject* self, PyObject* args)
{
    QPalette* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPalette* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "resolve", 0, 1, &(pyargs[0])))
        return 0;


    // Overloaded function decisor
    // 0: resolve()const
    // 1: resolve(QPalette)const
    // 2: resolve(uint)
    if (numArgs == 0) {
        overloadId = 0; // resolve()const
    } else if (numArgs == 1 && SbkNumber_Check(pyargs[0])) {
        overloadId = 2; // resolve(uint)
    } else if (numArgs == 1 && Shiboken::Converter< ::QPalette >::isConvertible(pyargs[0])) {
        overloadId = 1; // resolve(QPalette)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPaletteFunc_resolve_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // resolve()const
            {

                if(!PyErr_Occurred()) {
                    // resolve()const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    uint cppResult = cppSelf->resolve();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< unsigned int >::toPython(cppResult);
                }
                break;
            }
            case 1: // resolve(QPalette)const
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QPalette cppArg0 = Shiboken::Converter<QPalette >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // resolve(QPalette)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QPalette cppResult = cppSelf->resolve(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QPalette >::toPython(cppResult);
                }
                break;
            }
            case 2: // resolve(uint)
            {
                uint cppArg0 = Shiboken::Converter<uint >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // resolve(uint)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->resolve(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Py_None;
                    Py_INCREF(Py_None);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QPaletteFunc_resolve_TypeError:
        const char* overloads[] = {"", "PySide.QtGui.QPalette", "unsigned int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPalette.resolve", overloads);
        return 0;
}

static PyObject* Sbk_QPaletteFunc_setBrush(PyObject* self, PyObject* args)
{
    QPalette* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPalette* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setBrush", 2, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: setBrush(QPalette::ColorGroup,QPalette::ColorRole,QBrush)
    // 1: setBrush(QPalette::ColorRole,QBrush)
    if (numArgs == 2 && Shiboken::Converter< ::QPalette::ColorRole >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QBrush >::isConvertible(pyargs[1])) {
        overloadId = 1; // setBrush(QPalette::ColorRole,QBrush)
    } else if (numArgs == 3 && Shiboken::Converter< ::QPalette::ColorGroup >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QPalette::ColorRole >::isConvertible(pyargs[1]) && Shiboken::Converter< ::QBrush >::isConvertible(pyargs[2])) {
        overloadId = 0; // setBrush(QPalette::ColorGroup,QPalette::ColorRole,QBrush)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPaletteFunc_setBrush_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setBrush(QPalette::ColorGroup,QPalette::ColorRole,QBrush)
            {
                QPalette::ColorGroup cppArg0 = Shiboken::Converter<QPalette::ColorGroup >::toCpp(pyargs[0]);
                QPalette::ColorRole cppArg1 = Shiboken::Converter<QPalette::ColorRole >::toCpp(pyargs[1]);
                if (!Shiboken::Object::isValid(pyargs[2]))
                    return 0;
                QBrush cppArg2 = Shiboken::Converter<QBrush >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                    // setBrush(QPalette::ColorGroup,QPalette::ColorRole,QBrush)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setBrush(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // setBrush(QPalette::ColorRole,QBrush)
            {
                QPalette::ColorRole cppArg0 = Shiboken::Converter<QPalette::ColorRole >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QBrush cppArg1 = Shiboken::Converter<QBrush >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // setBrush(QPalette::ColorRole,QBrush)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setBrush(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPaletteFunc_setBrush_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPalette.ColorGroup, PySide.QtGui.QPalette.ColorRole, PySide.QtGui.QBrush", "PySide.QtGui.QPalette.ColorRole, PySide.QtGui.QBrush", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPalette.setBrush", overloads);
        return 0;
}

static PyObject* Sbk_QPaletteFunc_setColor(PyObject* self, PyObject* args)
{
    QPalette* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPalette* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setColor", 2, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: setColor(QPalette::ColorGroup,QPalette::ColorRole,QColor)
    // 1: setColor(QPalette::ColorRole,QColor)
    if (numArgs == 2 && Shiboken::Converter< ::QPalette::ColorRole >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QColor >::isConvertible(pyargs[1])) {
        overloadId = 1; // setColor(QPalette::ColorRole,QColor)
    } else if (numArgs == 3 && Shiboken::Converter< ::QPalette::ColorGroup >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QPalette::ColorRole >::isConvertible(pyargs[1]) && Shiboken::Converter< ::QColor >::isConvertible(pyargs[2])) {
        overloadId = 0; // setColor(QPalette::ColorGroup,QPalette::ColorRole,QColor)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPaletteFunc_setColor_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setColor(QPalette::ColorGroup,QPalette::ColorRole,QColor)
            {
                QPalette::ColorGroup cppArg0 = Shiboken::Converter<QPalette::ColorGroup >::toCpp(pyargs[0]);
                QPalette::ColorRole cppArg1 = Shiboken::Converter<QPalette::ColorRole >::toCpp(pyargs[1]);
                if (!Shiboken::Object::isValid(pyargs[2]))
                    return 0;
                QColor cppArg2 = Shiboken::Converter<QColor >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                    // setColor(QPalette::ColorGroup,QPalette::ColorRole,QColor)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setColor(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // setColor(QPalette::ColorRole,QColor)
            {
                QPalette::ColorRole cppArg0 = Shiboken::Converter<QPalette::ColorRole >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QColor cppArg1 = Shiboken::Converter<QColor >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // setColor(QPalette::ColorRole,QColor)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setColor(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPaletteFunc_setColor_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPalette.ColorGroup, PySide.QtGui.QPalette.ColorRole, PySide.QtGui.QColor", "PySide.QtGui.QPalette.ColorRole, PySide.QtGui.QColor", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPalette.setColor", overloads);
        return 0;
}

static PyObject* Sbk_QPaletteFunc_setColorGroup(PyObject* self, PyObject* args)
{
    QPalette* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPalette* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setColorGroup", 10, 10, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4]), &(pyargs[5]), &(pyargs[6]), &(pyargs[7]), &(pyargs[8]), &(pyargs[9])))
        return 0;


    // Overloaded function decisor
    // 0: setColorGroup(QPalette::ColorGroup,QBrush,QBrush,QBrush,QBrush,QBrush,QBrush,QBrush,QBrush,QBrush)
    if (numArgs == 10 && Shiboken::Converter< ::QPalette::ColorGroup >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QBrush >::isConvertible(pyargs[1]) && Shiboken::Converter< ::QBrush >::isConvertible(pyargs[2]) && Shiboken::Converter< ::QBrush >::isConvertible(pyargs[3]) && Shiboken::Converter< ::QBrush >::isConvertible(pyargs[4]) && Shiboken::Converter< ::QBrush >::isConvertible(pyargs[5]) && Shiboken::Converter< ::QBrush >::isConvertible(pyargs[6]) && Shiboken::Converter< ::QBrush >::isConvertible(pyargs[7]) && Shiboken::Converter< ::QBrush >::isConvertible(pyargs[8]) && Shiboken::Converter< ::QBrush >::isConvertible(pyargs[9])) {
        overloadId = 0; // setColorGroup(QPalette::ColorGroup,QBrush,QBrush,QBrush,QBrush,QBrush,QBrush,QBrush,QBrush,QBrush)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPaletteFunc_setColorGroup_TypeError;

    // Call function/method
    {
        {
            QPalette::ColorGroup cppArg0 = Shiboken::Converter<QPalette::ColorGroup >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QBrush cppArg1 = Shiboken::Converter<QBrush >::toCpp(pyargs[1]);
            if (!Shiboken::Object::isValid(pyargs[2]))
                return 0;
            QBrush cppArg2 = Shiboken::Converter<QBrush >::toCpp(pyargs[2]);
            if (!Shiboken::Object::isValid(pyargs[3]))
                return 0;
            QBrush cppArg3 = Shiboken::Converter<QBrush >::toCpp(pyargs[3]);
            if (!Shiboken::Object::isValid(pyargs[4]))
                return 0;
            QBrush cppArg4 = Shiboken::Converter<QBrush >::toCpp(pyargs[4]);
            if (!Shiboken::Object::isValid(pyargs[5]))
                return 0;
            QBrush cppArg5 = Shiboken::Converter<QBrush >::toCpp(pyargs[5]);
            if (!Shiboken::Object::isValid(pyargs[6]))
                return 0;
            QBrush cppArg6 = Shiboken::Converter<QBrush >::toCpp(pyargs[6]);
            if (!Shiboken::Object::isValid(pyargs[7]))
                return 0;
            QBrush cppArg7 = Shiboken::Converter<QBrush >::toCpp(pyargs[7]);
            if (!Shiboken::Object::isValid(pyargs[8]))
                return 0;
            QBrush cppArg8 = Shiboken::Converter<QBrush >::toCpp(pyargs[8]);
            if (!Shiboken::Object::isValid(pyargs[9]))
                return 0;
            QBrush cppArg9 = Shiboken::Converter<QBrush >::toCpp(pyargs[9]);

            if(!PyErr_Occurred()) {
                // setColorGroup(QPalette::ColorGroup,QBrush,QBrush,QBrush,QBrush,QBrush,QBrush,QBrush,QBrush,QBrush)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setColorGroup(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5, cppArg6, cppArg7, cppArg8, cppArg9);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPaletteFunc_setColorGroup_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPalette.ColorGroup, PySide.QtGui.QBrush, PySide.QtGui.QBrush, PySide.QtGui.QBrush, PySide.QtGui.QBrush, PySide.QtGui.QBrush, PySide.QtGui.QBrush, PySide.QtGui.QBrush, PySide.QtGui.QBrush, PySide.QtGui.QBrush", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPalette.setColorGroup", overloads);
        return 0;
}

static PyObject* Sbk_QPaletteFunc_setCurrentColorGroup(PyObject* self, PyObject* arg)
{
    QPalette* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPalette* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setCurrentColorGroup(QPalette::ColorGroup)
    if (Shiboken::Converter< ::QPalette::ColorGroup >::isConvertible(arg)) {
        overloadId = 0; // setCurrentColorGroup(QPalette::ColorGroup)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPaletteFunc_setCurrentColorGroup_TypeError;

    // Call function/method
    {
        {
            QPalette::ColorGroup cppArg0 = Shiboken::Converter<QPalette::ColorGroup >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setCurrentColorGroup(QPalette::ColorGroup)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setCurrentColorGroup(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPaletteFunc_setCurrentColorGroup_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPalette.ColorGroup", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPalette.setCurrentColorGroup", overloads);
        return 0;
}

static PyObject* Sbk_QPaletteFunc_shadow(PyObject* self)
{
    QPalette* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPalette* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // shadow()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                const QBrush & cppResult = cppSelf->shadow();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QBrush >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPaletteFunc_text(PyObject* self)
{
    QPalette* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPalette* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // text()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                const QBrush & cppResult = cppSelf->text();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QBrush >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPaletteFunc_toolTipBase(PyObject* self)
{
    QPalette* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPalette* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // toolTipBase()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                const QBrush & cppResult = cppSelf->toolTipBase();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QBrush >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPaletteFunc_toolTipText(PyObject* self)
{
    QPalette* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPalette* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // toolTipText()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                const QBrush & cppResult = cppSelf->toolTipText();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QBrush >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPaletteFunc_window(PyObject* self)
{
    QPalette* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPalette* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // window()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                const QBrush & cppResult = cppSelf->window();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QBrush >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPaletteFunc_windowText(PyObject* self)
{
    QPalette* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPalette* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // windowText()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                const QBrush & cppResult = cppSelf->windowText();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QBrush >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject *Sbk_QPalette___copy__(PyObject *self)
{
        QPalette* cppSelf = 0;
        if (!Shiboken::Object::isValid(self))
            return 0;
        cppSelf = Shiboken::Converter<QPalette*>::toCpp(self);
        PyObject* pyResult = 0;
        QPalette* copy = new QPalette(*cppSelf);
        pyResult = Shiboken::Converter<QPalette*>::toPython(copy);
        Shiboken::Object::getOwnership(pyResult);

        if (PyErr_Occurred() || !pyResult) {
            Py_XDECREF(pyResult);
            return 0;
        }
        return pyResult;
}

static PyMethodDef Sbk_QPalette_methods[] = {
    {"alternateBase", (PyCFunction)Sbk_QPaletteFunc_alternateBase, METH_NOARGS},
    {"base", (PyCFunction)Sbk_QPaletteFunc_base, METH_NOARGS},
    {"brightText", (PyCFunction)Sbk_QPaletteFunc_brightText, METH_NOARGS},
    {"brush", (PyCFunction)Sbk_QPaletteFunc_brush, METH_VARARGS},
    {"button", (PyCFunction)Sbk_QPaletteFunc_button, METH_NOARGS},
    {"buttonText", (PyCFunction)Sbk_QPaletteFunc_buttonText, METH_NOARGS},
    {"cacheKey", (PyCFunction)Sbk_QPaletteFunc_cacheKey, METH_NOARGS},
    {"color", (PyCFunction)Sbk_QPaletteFunc_color, METH_VARARGS},
    {"currentColorGroup", (PyCFunction)Sbk_QPaletteFunc_currentColorGroup, METH_NOARGS},
    {"dark", (PyCFunction)Sbk_QPaletteFunc_dark, METH_NOARGS},
    {"highlight", (PyCFunction)Sbk_QPaletteFunc_highlight, METH_NOARGS},
    {"highlightedText", (PyCFunction)Sbk_QPaletteFunc_highlightedText, METH_NOARGS},
    {"isBrushSet", (PyCFunction)Sbk_QPaletteFunc_isBrushSet, METH_VARARGS},
    {"isCopyOf", (PyCFunction)Sbk_QPaletteFunc_isCopyOf, METH_O},
    {"isEqual", (PyCFunction)Sbk_QPaletteFunc_isEqual, METH_VARARGS},
    {"light", (PyCFunction)Sbk_QPaletteFunc_light, METH_NOARGS},
    {"link", (PyCFunction)Sbk_QPaletteFunc_link, METH_NOARGS},
    {"linkVisited", (PyCFunction)Sbk_QPaletteFunc_linkVisited, METH_NOARGS},
    {"mid", (PyCFunction)Sbk_QPaletteFunc_mid, METH_NOARGS},
    {"midlight", (PyCFunction)Sbk_QPaletteFunc_midlight, METH_NOARGS},
    {"resolve", (PyCFunction)Sbk_QPaletteFunc_resolve, METH_VARARGS},
    {"setBrush", (PyCFunction)Sbk_QPaletteFunc_setBrush, METH_VARARGS},
    {"setColor", (PyCFunction)Sbk_QPaletteFunc_setColor, METH_VARARGS},
    {"setColorGroup", (PyCFunction)Sbk_QPaletteFunc_setColorGroup, METH_VARARGS},
    {"setCurrentColorGroup", (PyCFunction)Sbk_QPaletteFunc_setCurrentColorGroup, METH_O},
    {"shadow", (PyCFunction)Sbk_QPaletteFunc_shadow, METH_NOARGS},
    {"text", (PyCFunction)Sbk_QPaletteFunc_text, METH_NOARGS},
    {"toolTipBase", (PyCFunction)Sbk_QPaletteFunc_toolTipBase, METH_NOARGS},
    {"toolTipText", (PyCFunction)Sbk_QPaletteFunc_toolTipText, METH_NOARGS},
    {"window", (PyCFunction)Sbk_QPaletteFunc_window, METH_NOARGS},
    {"windowText", (PyCFunction)Sbk_QPaletteFunc_windowText, METH_NOARGS},

    {"__copy__", (PyCFunction)Sbk_QPalette___copy__, METH_NOARGS},
    {0} // Sentinel
};

static PyObject* Sbk_QPaletteFunc___lshift__(PyObject* self, PyObject* arg)
{
    QPalette* cppSelf = 0;
    bool isReverse = Shiboken::Converter< ::QPalette >::checkType(arg) && !Shiboken::Converter< ::QPalette >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPalette* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && Shiboken::Object::checkType(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rlshift__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rlshift__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator<<(QDataStream&,QPalette)
    if (isReverse && Shiboken::Converter< ::QDataStream & >::isConvertible(arg)) {
        overloadId = 0; // operator<<(QDataStream&,QPalette)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPaletteFunc___lshift___TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QDataStream & cppArg0 = Shiboken::Converter<QDataStream & >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // operator<<(QDataStream&,QPalette) [reverse operator]
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDataStream & cppResult = (cppArg0) << (*cppSelf);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDataStream & >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QPaletteFunc___lshift___TypeError:
        const char* overloads[] = {"PySide.QtCore.QDataStream", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPalette.__lshift__", overloads);
        return 0;
}

static PyObject* Sbk_QPaletteFunc___rshift__(PyObject* self, PyObject* arg)
{
    QPalette* cppSelf = 0;
    bool isReverse = Shiboken::Converter< ::QPalette >::checkType(arg) && !Shiboken::Converter< ::QPalette >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPalette* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && Shiboken::Object::checkType(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rrshift__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rrshift__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator>>(QDataStream&,QPalette&)
    if (isReverse && Shiboken::Converter< ::QDataStream & >::isConvertible(arg)) {
        overloadId = 0; // operator>>(QDataStream&,QPalette&)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPaletteFunc___rshift___TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QDataStream & cppArg0 = Shiboken::Converter<QDataStream & >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // operator>>(QDataStream&,QPalette&) [reverse operator]
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDataStream & cppResult = (cppArg0) >> (*cppSelf);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDataStream & >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QPaletteFunc___rshift___TypeError:
        const char* overloads[] = {"PySide.QtCore.QDataStream", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPalette.__rshift__", overloads);
        return 0;
}

// type has number operators
static PyNumberMethods Sbk_QPalette_as_number = {
    /*nb_add*/                  (binaryfunc)0,
    /*nb_subtract*/             (binaryfunc)0,
    /*nb_multiply*/             (binaryfunc)0,
    /*nb_divide*/               (binaryfunc)0,
    /*nb_remainder*/            (binaryfunc)0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             (unaryfunc)0,
    /*nb_positive*/             (unaryfunc)0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              0,
    /*nb_invert*/               (unaryfunc)0,
    /*nb_lshift*/               (binaryfunc)Sbk_QPaletteFunc___lshift__,
    /*nb_rshift*/               (binaryfunc)Sbk_QPaletteFunc___rshift__,
    /*nb_and*/                  (binaryfunc)0,
    /*nb_xor*/                  (binaryfunc)0,
    /*nb_or*/                   (binaryfunc)0,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          (binaryfunc)0,
    /*nb_inplace_subtract*/     (binaryfunc)0,
    /*nb_inplace_multiply*/     (binaryfunc)0,
    /*nb_inplace_divide*/       (binaryfunc)0,
    /*nb_inplace_remainder*/    (binaryfunc)0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       (binaryfunc)0,
    /*nb_inplace_rshift*/       (binaryfunc)0,
    /*nb_inplace_and*/          (binaryfunc)0,
    /*nb_inplace_xor*/          (binaryfunc)0,
    /*nb_inplace_or*/           (binaryfunc)0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          (binaryfunc)0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};

// Rich comparison
static PyObject* Sbk_QPalette_richcompare(PyObject* self, PyObject* arg, int op)
{
    PyObject* pyResult = 0;
    QPalette& cppSelf = *Shiboken::Converter< QPalette* >::toCpp(self);

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter< ::QPalette >::isConvertible(arg)) {
                // operator!=(const QPalette & p) const
                QPalette cppArg0 = Shiboken::Converter< ::QPalette >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf != cppArg0);
            } else goto Sbk_QPalette_RichComparison_TypeError;

            break;
        case Py_EQ:
            if (Shiboken::Converter< ::QPalette >::isConvertible(arg)) {
                // operator==(const QPalette & p) const
                QPalette cppArg0 = Shiboken::Converter< ::QPalette >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf == cppArg0);
            } else goto Sbk_QPalette_RichComparison_TypeError;

            break;
        default:
            goto Sbk_QPalette_RichComparison_TypeError;
    }

    if (pyResult && !PyErr_Occurred())
        return pyResult;
    Sbk_QPalette_RichComparison_TypeError:
    PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
    return 0;

}

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QPalette_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QPalette",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        &Sbk_QPalette_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      Sbk_QPalette_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QPalette_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QPalette_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QPalette(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QPALETTE_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QPalette_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QPalette_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QPalette_Type, &Shiboken::callCppDestructor<QPalette >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QPalette_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QPalette_Type, "QPalette");
    PyModule_AddObject(module, "QPalette",
        ((PyObject*)&Sbk_QPalette_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: ColorGroup
    PyTypeObject* SbkPySide_QtGui_QPalette_ColorGroup = Shiboken::Enum::newType("ColorGroup");
    SbkPySide_QtGuiTypes[SBK_QPALETTE_COLORGROUP_IDX] = SbkPySide_QtGui_QPalette_ColorGroup;
    if (PyType_Ready(SbkPySide_QtGui_QPalette_ColorGroup) < 0)
        return;
    PyDict_SetItemString(Sbk_QPalette_Type.super.ht_type.tp_dict,
            "ColorGroup",((PyObject*)SbkPySide_QtGui_QPalette_ColorGroup));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPalette_ColorGroup,(long) QPalette::Active, "Active");
    PyDict_SetItemString(Sbk_QPalette_Type.super.ht_type.tp_dict,"Active", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPalette_ColorGroup->tp_dict,"Active", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPalette_ColorGroup,(long) QPalette::Disabled, "Disabled");
    PyDict_SetItemString(Sbk_QPalette_Type.super.ht_type.tp_dict,"Disabled", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPalette_ColorGroup->tp_dict,"Disabled", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPalette_ColorGroup,(long) QPalette::Inactive, "Inactive");
    PyDict_SetItemString(Sbk_QPalette_Type.super.ht_type.tp_dict,"Inactive", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPalette_ColorGroup->tp_dict,"Inactive", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPalette_ColorGroup,(long) QPalette::NColorGroups, "NColorGroups");
    PyDict_SetItemString(Sbk_QPalette_Type.super.ht_type.tp_dict,"NColorGroups", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPalette_ColorGroup->tp_dict,"NColorGroups", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPalette_ColorGroup,(long) QPalette::Current, "Current");
    PyDict_SetItemString(Sbk_QPalette_Type.super.ht_type.tp_dict,"Current", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPalette_ColorGroup->tp_dict,"Current", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPalette_ColorGroup,(long) QPalette::All, "All");
    PyDict_SetItemString(Sbk_QPalette_Type.super.ht_type.tp_dict,"All", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPalette_ColorGroup->tp_dict,"All", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPalette_ColorGroup,(long) QPalette::Normal, "Normal");
    PyDict_SetItemString(Sbk_QPalette_Type.super.ht_type.tp_dict,"Normal", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPalette_ColorGroup->tp_dict,"Normal", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QPalette::ColorGroup");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::ColorGroup");
    // end of enum ColorGroup

    // init enum: ColorRole
    PyTypeObject* SbkPySide_QtGui_QPalette_ColorRole = Shiboken::Enum::newType("ColorRole");
    SbkPySide_QtGuiTypes[SBK_QPALETTE_COLORROLE_IDX] = SbkPySide_QtGui_QPalette_ColorRole;
    if (PyType_Ready(SbkPySide_QtGui_QPalette_ColorRole) < 0)
        return;
    PyDict_SetItemString(Sbk_QPalette_Type.super.ht_type.tp_dict,
            "ColorRole",((PyObject*)SbkPySide_QtGui_QPalette_ColorRole));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPalette_ColorRole,(long) QPalette::WindowText, "WindowText");
    PyDict_SetItemString(Sbk_QPalette_Type.super.ht_type.tp_dict,"WindowText", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPalette_ColorRole->tp_dict,"WindowText", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPalette_ColorRole,(long) QPalette::Button, "Button");
    PyDict_SetItemString(Sbk_QPalette_Type.super.ht_type.tp_dict,"Button", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPalette_ColorRole->tp_dict,"Button", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPalette_ColorRole,(long) QPalette::Light, "Light");
    PyDict_SetItemString(Sbk_QPalette_Type.super.ht_type.tp_dict,"Light", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPalette_ColorRole->tp_dict,"Light", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPalette_ColorRole,(long) QPalette::Midlight, "Midlight");
    PyDict_SetItemString(Sbk_QPalette_Type.super.ht_type.tp_dict,"Midlight", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPalette_ColorRole->tp_dict,"Midlight", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPalette_ColorRole,(long) QPalette::Dark, "Dark");
    PyDict_SetItemString(Sbk_QPalette_Type.super.ht_type.tp_dict,"Dark", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPalette_ColorRole->tp_dict,"Dark", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPalette_ColorRole,(long) QPalette::Mid, "Mid");
    PyDict_SetItemString(Sbk_QPalette_Type.super.ht_type.tp_dict,"Mid", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPalette_ColorRole->tp_dict,"Mid", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPalette_ColorRole,(long) QPalette::Text, "Text");
    PyDict_SetItemString(Sbk_QPalette_Type.super.ht_type.tp_dict,"Text", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPalette_ColorRole->tp_dict,"Text", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPalette_ColorRole,(long) QPalette::BrightText, "BrightText");
    PyDict_SetItemString(Sbk_QPalette_Type.super.ht_type.tp_dict,"BrightText", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPalette_ColorRole->tp_dict,"BrightText", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPalette_ColorRole,(long) QPalette::ButtonText, "ButtonText");
    PyDict_SetItemString(Sbk_QPalette_Type.super.ht_type.tp_dict,"ButtonText", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPalette_ColorRole->tp_dict,"ButtonText", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPalette_ColorRole,(long) QPalette::Base, "Base");
    PyDict_SetItemString(Sbk_QPalette_Type.super.ht_type.tp_dict,"Base", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPalette_ColorRole->tp_dict,"Base", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPalette_ColorRole,(long) QPalette::Window, "Window");
    PyDict_SetItemString(Sbk_QPalette_Type.super.ht_type.tp_dict,"Window", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPalette_ColorRole->tp_dict,"Window", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPalette_ColorRole,(long) QPalette::Shadow, "Shadow");
    PyDict_SetItemString(Sbk_QPalette_Type.super.ht_type.tp_dict,"Shadow", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPalette_ColorRole->tp_dict,"Shadow", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPalette_ColorRole,(long) QPalette::Highlight, "Highlight");
    PyDict_SetItemString(Sbk_QPalette_Type.super.ht_type.tp_dict,"Highlight", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPalette_ColorRole->tp_dict,"Highlight", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPalette_ColorRole,(long) QPalette::HighlightedText, "HighlightedText");
    PyDict_SetItemString(Sbk_QPalette_Type.super.ht_type.tp_dict,"HighlightedText", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPalette_ColorRole->tp_dict,"HighlightedText", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPalette_ColorRole,(long) QPalette::Link, "Link");
    PyDict_SetItemString(Sbk_QPalette_Type.super.ht_type.tp_dict,"Link", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPalette_ColorRole->tp_dict,"Link", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPalette_ColorRole,(long) QPalette::LinkVisited, "LinkVisited");
    PyDict_SetItemString(Sbk_QPalette_Type.super.ht_type.tp_dict,"LinkVisited", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPalette_ColorRole->tp_dict,"LinkVisited", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPalette_ColorRole,(long) QPalette::AlternateBase, "AlternateBase");
    PyDict_SetItemString(Sbk_QPalette_Type.super.ht_type.tp_dict,"AlternateBase", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPalette_ColorRole->tp_dict,"AlternateBase", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPalette_ColorRole,(long) QPalette::NoRole, "NoRole");
    PyDict_SetItemString(Sbk_QPalette_Type.super.ht_type.tp_dict,"NoRole", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPalette_ColorRole->tp_dict,"NoRole", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPalette_ColorRole,(long) QPalette::ToolTipBase, "ToolTipBase");
    PyDict_SetItemString(Sbk_QPalette_Type.super.ht_type.tp_dict,"ToolTipBase", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPalette_ColorRole->tp_dict,"ToolTipBase", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPalette_ColorRole,(long) QPalette::ToolTipText, "ToolTipText");
    PyDict_SetItemString(Sbk_QPalette_Type.super.ht_type.tp_dict,"ToolTipText", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPalette_ColorRole->tp_dict,"ToolTipText", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPalette_ColorRole,(long) QPalette::NColorRoles, "NColorRoles");
    PyDict_SetItemString(Sbk_QPalette_Type.super.ht_type.tp_dict,"NColorRoles", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPalette_ColorRole->tp_dict,"NColorRoles", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPalette_ColorRole,(long) QPalette::Foreground, "Foreground");
    PyDict_SetItemString(Sbk_QPalette_Type.super.ht_type.tp_dict,"Foreground", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPalette_ColorRole->tp_dict,"Foreground", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPalette_ColorRole,(long) QPalette::Background, "Background");
    PyDict_SetItemString(Sbk_QPalette_Type.super.ht_type.tp_dict,"Background", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPalette_ColorRole->tp_dict,"Background", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QPalette::ColorRole");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::ColorRole");
    // end of enum ColorRole


    Shiboken::TypeResolver::createValueTypeResolver<QPalette >("QPalette");
    Shiboken::TypeResolver::createObjectTypeResolver<QPalette >("QPalette*");
    Shiboken::TypeResolver::createValueTypeResolver<QPalette >(typeid(QPalette).name());
    PySide::initQtMetaType<QPalette >();
}

