/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qpixmapcache_wrapper.h"

// Extra includes
#include <qpixmap.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QPixmapCache_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QPixmapCache >()))
        return -1;

    QPixmapCache* cptr = 0;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // QPixmapCache()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new QPixmapCache();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QPixmapCache >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject* Sbk_QPixmapCacheFunc_cacheLimit(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // cacheLimit()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = QPixmapCache::cacheLimit();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPixmapCacheFunc_clear(PyObject* self)
{

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // clear()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPixmapCache::clear();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QPixmapCacheFunc_find(PyObject* self, PyObject* args)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "find", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: find(QString,QPixmap*)
    if (numArgs == 2 && Shiboken::Converter< QString >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QPixmap * >::isConvertible(pyargs[1])) {
        overloadId = 0; // find(QString,QPixmap*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPixmapCacheFunc_find_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QPixmap * cppArg1 = Shiboken::Converter<QPixmap * >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // find(QString,QPixmap*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = QPixmapCache::find(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QPixmapCacheFunc_find_TypeError:
        const char* overloads[] = {"QString, PySide.QtGui.QPixmap", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPixmapCache.find", overloads);
        return 0;
}

static PyObject* Sbk_QPixmapCacheFunc_insert(PyObject* self, PyObject* args)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "insert", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: insert(QString,QPixmap)
    if (numArgs == 2 && Shiboken::Converter< QString >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QPixmap >::isConvertible(pyargs[1])) {
        overloadId = 0; // insert(QString,QPixmap)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPixmapCacheFunc_insert_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QPixmap cppArg1 = Shiboken::Converter<QPixmap >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // insert(QString,QPixmap)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = QPixmapCache::insert(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QPixmapCacheFunc_insert_TypeError:
        const char* overloads[] = {"QString, PySide.QtGui.QPixmap", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPixmapCache.insert", overloads);
        return 0;
}

static PyObject* Sbk_QPixmapCacheFunc_remove(PyObject* self, PyObject* arg)
{
    int overloadId = -1;

    // Overloaded function decisor
    // 0: remove(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // remove(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPixmapCacheFunc_remove_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // remove(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPixmapCache::remove(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPixmapCacheFunc_remove_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPixmapCache.remove", overloads);
        return 0;
}

static PyObject* Sbk_QPixmapCacheFunc_setCacheLimit(PyObject* self, PyObject* arg)
{
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setCacheLimit(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setCacheLimit(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPixmapCacheFunc_setCacheLimit_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setCacheLimit(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPixmapCache::setCacheLimit(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPixmapCacheFunc_setCacheLimit_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPixmapCache.setCacheLimit", overloads);
        return 0;
}

static PyMethodDef Sbk_QPixmapCache_methods[] = {
    {"cacheLimit", (PyCFunction)Sbk_QPixmapCacheFunc_cacheLimit, METH_NOARGS|METH_STATIC},
    {"clear", (PyCFunction)Sbk_QPixmapCacheFunc_clear, METH_NOARGS|METH_STATIC},
    {"find", (PyCFunction)Sbk_QPixmapCacheFunc_find, METH_VARARGS|METH_STATIC},
    {"insert", (PyCFunction)Sbk_QPixmapCacheFunc_insert, METH_VARARGS|METH_STATIC},
    {"remove", (PyCFunction)Sbk_QPixmapCacheFunc_remove, METH_O|METH_STATIC},
    {"setCacheLimit", (PyCFunction)Sbk_QPixmapCacheFunc_setCacheLimit, METH_O|METH_STATIC},

    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QPixmapCache_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QPixmapCache",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QPixmapCache_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QPixmapCache_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QPixmapCache(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QPIXMAPCACHE_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QPixmapCache_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QPixmapCache_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QPixmapCache_Type, &Shiboken::callCppDestructor<QPixmapCache >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QPixmapCache_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QPixmapCache_Type, "QPixmapCache*");
    PyModule_AddObject(module, "QPixmapCache",
        ((PyObject*)&Sbk_QPixmapCache_Type));


    Shiboken::TypeResolver::createObjectTypeResolver<QPixmapCache >("QPixmapCache*");
    Shiboken::TypeResolver::createObjectTypeResolver<QPixmapCache >(typeid(QPixmapCache).name());
    PySide::initQtMetaType<QPixmapCache* >();
}

