/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qpolygonf_wrapper.h"

// Extra includes
#include <QList>
#include <QMatrix>
#include <QTransform>
#include <QVector>
#include <qdatastream.h>
#include <qpoint.h>
#include <qpolygon.h>
#include <qrect.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QPolygonF_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QPolygonF >()))
        return -1;

    QPolygonF* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QPolygonF", 0, 1, &(pyargs[0])))
        return -1;

    // Overloaded function decisor
    // 0: QPolygonF()
    // 1: QPolygonF(QPolygon)
    // 2: QPolygonF(QPolygonF)
    // 3: QPolygonF(QRectF)
    // 4: QPolygonF(QVector<QPointF>)
    // 5: QPolygonF(int)
    if (numArgs == 0) {
        overloadId = 0; // QPolygonF()
    } else if (numArgs == 1 && SbkNumber_Check(pyargs[0])) {
        overloadId = 5; // QPolygonF(int)
    } else if (numArgs == 1 && Shiboken::Converter< ::QVector<QPointF > >::isConvertible(pyargs[0])) {
        overloadId = 4; // QPolygonF(QVector<QPointF>)
    } else if (numArgs == 1 && Shiboken::Converter< ::QRectF >::isConvertible(pyargs[0])) {
        overloadId = 3; // QPolygonF(QRectF)
    } else if (numArgs == 1 && Shiboken::Converter< ::QPolygon >::isConvertible(pyargs[0])) {
        overloadId = 1; // QPolygonF(QPolygon)
    } else if (numArgs == 1 && Shiboken::Converter< ::QPolygonF >::isConvertible(pyargs[0])) {
        overloadId = 2; // QPolygonF(QPolygonF)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPolygonF_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QPolygonF()
            {

                if(!PyErr_Occurred()) {
                    // QPolygonF()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QPolygonF();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // QPolygonF(QPolygon)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QPolygon cppArg0 = Shiboken::Converter<QPolygon >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QPolygonF(QPolygon)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QPolygonF(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // QPolygonF(QPolygonF)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QPolygonF cppArg0 = Shiboken::Converter<QPolygonF >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QPolygonF(QPolygonF)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QPolygonF(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 3: // QPolygonF(QRectF)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QRectF cppArg0 = Shiboken::Converter<QRectF >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QPolygonF(QRectF)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QPolygonF(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 4: // QPolygonF(QVector<QPointF>)
            {
                QVector<QPointF > cppArg0 = Shiboken::Converter<QVector<QPointF > >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QPolygonF(QVector<QPointF>)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QPolygonF(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 5: // QPolygonF(int)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QPolygonF(int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QPolygonF(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QPolygonF >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QPolygonF_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QPolygonF_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtGui.QPolygon", "PySide.QtGui.QPolygonF", "PySide.QtCore.QRectF", "list", "int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPolygonF", overloads);
        return -1;
}

static PyObject* Sbk_QPolygonFFunc_append(PyObject* self, PyObject* arg)
{
    QPolygonF* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPolygonF* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: append(QPointF)
    if (Shiboken::Converter< ::QPointF >::isConvertible(arg)) {
        overloadId = 0; // append(QPointF)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPolygonFFunc_append_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QPointF cppArg0 = Shiboken::Converter<QPointF >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // append(QPointF)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->append(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPolygonFFunc_append_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPolygonF.append", overloads);
        return 0;
}

static PyObject* Sbk_QPolygonFFunc_at(PyObject* self, PyObject* arg)
{
    QPolygonF* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPolygonF* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: at(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // at(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPolygonFFunc_at_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // at(int)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                const QPointF & cppResult = cppSelf->at(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPointF >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QPolygonFFunc_at_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPolygonF.at", overloads);
        return 0;
}

static PyObject* Sbk_QPolygonFFunc_boundingRect(PyObject* self)
{
    QPolygonF* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPolygonF* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // boundingRect()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QRectF cppResult = cppSelf->boundingRect();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QRectF >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPolygonFFunc_capacity(PyObject* self)
{
    QPolygonF* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPolygonF* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // capacity()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->capacity();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPolygonFFunc_clear(PyObject* self)
{
    QPolygonF* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPolygonF* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // clear()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->clear();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QPolygonFFunc_constData(PyObject* self)
{
    QPolygonF* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPolygonF* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // constData()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                const QPointF * cppResult = cppSelf->constData();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPointF * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPolygonFFunc_contains(PyObject* self, PyObject* arg)
{
    QPolygonF* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPolygonF* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: contains(QPointF)const
    if (Shiboken::Converter< ::QPointF >::isConvertible(arg)) {
        overloadId = 0; // contains(QPointF)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPolygonFFunc_contains_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QPointF cppArg0 = Shiboken::Converter<QPointF >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // contains(QPointF)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->contains(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QPolygonFFunc_contains_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPolygonF.contains", overloads);
        return 0;
}

static PyObject* Sbk_QPolygonFFunc_containsPoint(PyObject* self, PyObject* args)
{
    QPolygonF* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPolygonF* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "containsPoint", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: containsPoint(QPointF,Qt::FillRule)const
    if (numArgs == 2 && Shiboken::Converter< ::QPointF >::isConvertible(pyargs[0]) && Shiboken::Converter< ::Qt::FillRule >::isConvertible(pyargs[1])) {
        overloadId = 0; // containsPoint(QPointF,Qt::FillRule)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPolygonFFunc_containsPoint_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QPointF cppArg0 = Shiboken::Converter<QPointF >::toCpp(pyargs[0]);
            Qt::FillRule cppArg1 = Shiboken::Converter<Qt::FillRule >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // containsPoint(QPointF,Qt::FillRule)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->containsPoint(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QPolygonFFunc_containsPoint_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF, PySide.QtCore.Qt.FillRule", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPolygonF.containsPoint", overloads);
        return 0;
}

static PyObject* Sbk_QPolygonFFunc_count(PyObject* self, PyObject* args)
{
    QPolygonF* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPolygonF* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "count", 0, 1, &(pyargs[0])))
        return 0;


    // Overloaded function decisor
    // 0: count()const
    // 1: count(QPointF)const
    if (numArgs == 0) {
        overloadId = 0; // count()const
    } else if (numArgs == 1 && Shiboken::Converter< ::QPointF >::isConvertible(pyargs[0])) {
        overloadId = 1; // count(QPointF)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPolygonFFunc_count_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // count()const
            {

                if(!PyErr_Occurred()) {
                    // count()const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    int cppResult = cppSelf->count();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< int >::toPython(cppResult);
                }
                break;
            }
            case 1: // count(QPointF)const
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QPointF cppArg0 = Shiboken::Converter<QPointF >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // count(QPointF)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    int cppResult = cppSelf->count(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< int >::toPython(cppResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QPolygonFFunc_count_TypeError:
        const char* overloads[] = {"", "PySide.QtCore.QPointF", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPolygonF.count", overloads);
        return 0;
}

static PyObject* Sbk_QPolygonFFunc_data(PyObject* self)
{
    QPolygonF* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPolygonF* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // data()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPointF * cppResult = cppSelf->data();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPointF * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPolygonFFunc_empty(PyObject* self)
{
    QPolygonF* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPolygonF* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // empty()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->empty();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPolygonFFunc_endsWith(PyObject* self, PyObject* arg)
{
    QPolygonF* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPolygonF* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: endsWith(QPointF)const
    if (Shiboken::Converter< ::QPointF >::isConvertible(arg)) {
        overloadId = 0; // endsWith(QPointF)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPolygonFFunc_endsWith_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QPointF cppArg0 = Shiboken::Converter<QPointF >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // endsWith(QPointF)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->endsWith(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QPolygonFFunc_endsWith_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPolygonF.endsWith", overloads);
        return 0;
}

static PyObject* Sbk_QPolygonFFunc_erase(PyObject* self, PyObject* args)
{
    QPolygonF* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPolygonF* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "erase", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: erase(QPointF*,QPointF*)
    if (numArgs == 2 && Shiboken::Converter< ::QPointF * >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QPointF * >::isConvertible(pyargs[1])) {
        overloadId = 0; // erase(QPointF*,QPointF*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPolygonFFunc_erase_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QPointF * cppArg0 = Shiboken::Converter<QPointF * >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QPointF * cppArg1 = Shiboken::Converter<QPointF * >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // erase(QPointF*,QPointF*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPointF * cppResult = cppSelf->erase(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPointF * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QPolygonFFunc_erase_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF, PySide.QtCore.QPointF", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPolygonF.erase", overloads);
        return 0;
}

static PyObject* Sbk_QPolygonFFunc_fill(PyObject* self, PyObject* args, PyObject* kwds)
{
    QPolygonF* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPolygonF* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPolygonF.fill(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPolygonF.fill(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:fill", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: fill(QPointF,int)
    if (Shiboken::Converter< ::QPointF >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // fill(QPointF,int)
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 0; // fill(QPointF,int)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPolygonFFunc_fill_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "size");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "size";
                    else if (SbkNumber_Check(value))
                        pyargs[1] = value;
else
                        goto Sbk_QPolygonFFunc_fill_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPolygonF.fill(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QPointF cppArg0 = Shiboken::Converter<QPointF >::toCpp(pyargs[0]);
            int cppArg1 = pyargs[1] ? Shiboken::Converter<int >::toCpp(pyargs[1]) : -1;

            if(!PyErr_Occurred()) {
                // fill(QPointF,int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QVector<QPointF > & cppResult = cppSelf->fill(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QVector<QPointF > >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QPolygonFFunc_fill_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF, int = -1", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPolygonF.fill", overloads);
        return 0;
}

static PyObject* Sbk_QPolygonFFunc_first(PyObject* self)
{
    QPolygonF* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPolygonF* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // first()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPointF & cppResult = cppSelf->first();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPointF & >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPolygonFFunc_fromList(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: fromList(QList<QPointF>)
    if (Shiboken::Converter< ::QList<QPointF > >::isConvertible(arg)) {
        overloadId = 0; // fromList(QList<QPointF>)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPolygonFFunc_fromList_TypeError;

    // Call function/method
    {
        {
            QList<QPointF > cppArg0 = Shiboken::Converter<QList<QPointF > >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // fromList(QList<QPointF>)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QVector<QPointF > cppResult = QPolygonF::fromList(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QVector<QPointF > >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QPolygonFFunc_fromList_TypeError:
        const char* overloads[] = {"list", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPolygonF.fromList", overloads);
        return 0;
}

static PyObject* Sbk_QPolygonFFunc_front(PyObject* self)
{
    QPolygonF* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPolygonF* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // front()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPointF & cppResult = cppSelf->front();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPointF & >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPolygonFFunc_indexOf(PyObject* self, PyObject* args, PyObject* kwds)
{
    QPolygonF* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPolygonF* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPolygonF.indexOf(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPolygonF.indexOf(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:indexOf", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: indexOf(QPointF,int)const
    if (Shiboken::Converter< ::QPointF >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // indexOf(QPointF,int)const
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 0; // indexOf(QPointF,int)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPolygonFFunc_indexOf_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "from");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "from";
                    else if (SbkNumber_Check(value))
                        pyargs[1] = value;
else
                        goto Sbk_QPolygonFFunc_indexOf_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPolygonF.indexOf(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QPointF cppArg0 = Shiboken::Converter<QPointF >::toCpp(pyargs[0]);
            int cppArg1 = pyargs[1] ? Shiboken::Converter<int >::toCpp(pyargs[1]) : 0;

            if(!PyErr_Occurred()) {
                // indexOf(QPointF,int)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->indexOf(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QPolygonFFunc_indexOf_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF, int = 0", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPolygonF.indexOf", overloads);
        return 0;
}

static PyObject* Sbk_QPolygonFFunc_insert(PyObject* self, PyObject* args)
{
    QPolygonF* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPolygonF* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "insert", 2, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: insert(QPointF*,int,QPointF)
    // 1: insert(int,QPointF)
    // 2: insert(int,int,QPointF)
    if (SbkNumber_Check(pyargs[0])) {
        if (numArgs == 3 && SbkNumber_Check(pyargs[1]) && Shiboken::Converter< ::QPointF >::isConvertible(pyargs[2])) {
            overloadId = 2; // insert(int,int,QPointF)
        } else if (numArgs == 2 && Shiboken::Converter< ::QPointF >::isConvertible(pyargs[1])) {
            overloadId = 1; // insert(int,QPointF)
        }
    } else if (numArgs == 3 && Shiboken::Converter< ::QPointF * >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1]) && Shiboken::Converter< ::QPointF >::isConvertible(pyargs[2])) {
        overloadId = 0; // insert(QPointF*,int,QPointF)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPolygonFFunc_insert_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // insert(QPointF*,int,QPointF)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QPointF * cppArg0 = Shiboken::Converter<QPointF * >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                if (!Shiboken::Object::isValid(pyargs[2]))
                    return 0;
                QPointF cppArg2 = Shiboken::Converter<QPointF >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                    // insert(QPointF*,int,QPointF)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QPointF * cppResult = cppSelf->insert(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QPointF * >::toPython(cppResult);
                    Shiboken::Object::setParent(self, pyResult);
                }
                break;
            }
            case 1: // insert(int,QPointF)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QPointF cppArg1 = Shiboken::Converter<QPointF >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // insert(int,QPointF)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->insert(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Py_None;
                    Py_INCREF(Py_None);
                }
                break;
            }
            case 2: // insert(int,int,QPointF)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                if (!Shiboken::Object::isValid(pyargs[2]))
                    return 0;
                QPointF cppArg2 = Shiboken::Converter<QPointF >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                    // insert(int,int,QPointF)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->insert(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Py_None;
                    Py_INCREF(Py_None);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QPolygonFFunc_insert_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF, int, PySide.QtCore.QPointF", "int, PySide.QtCore.QPointF", "int, int, PySide.QtCore.QPointF", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPolygonF.insert", overloads);
        return 0;
}

static PyObject* Sbk_QPolygonFFunc_intersected(PyObject* self, PyObject* arg)
{
    QPolygonF* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPolygonF* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: intersected(QPolygonF)const
    if (Shiboken::Converter< ::QPolygonF >::isConvertible(arg)) {
        overloadId = 0; // intersected(QPolygonF)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPolygonFFunc_intersected_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QPolygonF cppArg0 = Shiboken::Converter<QPolygonF >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // intersected(QPolygonF)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPolygonF cppResult = cppSelf->intersected(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPolygonF >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QPolygonFFunc_intersected_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPolygonF", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPolygonF.intersected", overloads);
        return 0;
}

static PyObject* Sbk_QPolygonFFunc_isClosed(PyObject* self)
{
    QPolygonF* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPolygonF* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isClosed()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->isClosed();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPolygonFFunc_isEmpty(PyObject* self)
{
    QPolygonF* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPolygonF* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isEmpty()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->isEmpty();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPolygonFFunc_isSharedWith(PyObject* self, PyObject* arg)
{
    QPolygonF* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPolygonF* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: isSharedWith(QVector<QPointF>)const
    if (Shiboken::Converter< ::QVector<QPointF > >::isConvertible(arg)) {
        overloadId = 0; // isSharedWith(QVector<QPointF>)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPolygonFFunc_isSharedWith_TypeError;

    // Call function/method
    {
        {
            QVector<QPointF > cppArg0 = Shiboken::Converter<QVector<QPointF > >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // isSharedWith(QVector<QPointF>)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->isSharedWith(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QPolygonFFunc_isSharedWith_TypeError:
        const char* overloads[] = {"list", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPolygonF.isSharedWith", overloads);
        return 0;
}

static PyObject* Sbk_QPolygonFFunc_last(PyObject* self)
{
    QPolygonF* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPolygonF* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // last()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPointF & cppResult = cppSelf->last();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPointF & >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPolygonFFunc_lastIndexOf(PyObject* self, PyObject* args, PyObject* kwds)
{
    QPolygonF* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPolygonF* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPolygonF.lastIndexOf(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPolygonF.lastIndexOf(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:lastIndexOf", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: lastIndexOf(QPointF,int)const
    if (Shiboken::Converter< ::QPointF >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // lastIndexOf(QPointF,int)const
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 0; // lastIndexOf(QPointF,int)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPolygonFFunc_lastIndexOf_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "from");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "from";
                    else if (SbkNumber_Check(value))
                        pyargs[1] = value;
else
                        goto Sbk_QPolygonFFunc_lastIndexOf_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPolygonF.lastIndexOf(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QPointF cppArg0 = Shiboken::Converter<QPointF >::toCpp(pyargs[0]);
            int cppArg1 = pyargs[1] ? Shiboken::Converter<int >::toCpp(pyargs[1]) : -1;

            if(!PyErr_Occurred()) {
                // lastIndexOf(QPointF,int)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->lastIndexOf(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QPolygonFFunc_lastIndexOf_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF, int = -1", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPolygonF.lastIndexOf", overloads);
        return 0;
}

static PyObject* Sbk_QPolygonFFunc_mid(PyObject* self, PyObject* args, PyObject* kwds)
{
    QPolygonF* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPolygonF* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPolygonF.mid(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QPolygonF.mid(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:mid", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: mid(int,int)const
    if (SbkNumber_Check(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // mid(int,int)const
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 0; // mid(int,int)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPolygonFFunc_mid_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "length");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "length";
                    else if (SbkNumber_Check(value))
                        pyargs[1] = value;
else
                        goto Sbk_QPolygonFFunc_mid_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QPolygonF.mid(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            int cppArg1 = pyargs[1] ? Shiboken::Converter<int >::toCpp(pyargs[1]) : -1;

            if(!PyErr_Occurred()) {
                // mid(int,int)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QVector<QPointF > cppResult = cppSelf->mid(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QVector<QPointF > >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QPolygonFFunc_mid_TypeError:
        const char* overloads[] = {"int, int = -1", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPolygonF.mid", overloads);
        return 0;
}

static PyObject* Sbk_QPolygonFFunc_pop_back(PyObject* self)
{
    QPolygonF* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPolygonF* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // pop_back()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->pop_back();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QPolygonFFunc_pop_front(PyObject* self)
{
    QPolygonF* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPolygonF* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // pop_front()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->pop_front();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QPolygonFFunc_prepend(PyObject* self, PyObject* arg)
{
    QPolygonF* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPolygonF* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: prepend(QPointF)
    if (Shiboken::Converter< ::QPointF >::isConvertible(arg)) {
        overloadId = 0; // prepend(QPointF)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPolygonFFunc_prepend_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QPointF cppArg0 = Shiboken::Converter<QPointF >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // prepend(QPointF)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->prepend(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPolygonFFunc_prepend_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPolygonF.prepend", overloads);
        return 0;
}

static PyObject* Sbk_QPolygonFFunc_push_back(PyObject* self, PyObject* arg)
{
    QPolygonF* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPolygonF* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: push_back(QPointF)
    if (Shiboken::Converter< ::QPointF >::isConvertible(arg)) {
        overloadId = 0; // push_back(QPointF)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPolygonFFunc_push_back_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QPointF cppArg0 = Shiboken::Converter<QPointF >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // push_back(QPointF)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->push_back(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPolygonFFunc_push_back_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPolygonF.push_back", overloads);
        return 0;
}

static PyObject* Sbk_QPolygonFFunc_push_front(PyObject* self, PyObject* arg)
{
    QPolygonF* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPolygonF* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: push_front(QPointF)
    if (Shiboken::Converter< ::QPointF >::isConvertible(arg)) {
        overloadId = 0; // push_front(QPointF)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPolygonFFunc_push_front_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QPointF cppArg0 = Shiboken::Converter<QPointF >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // push_front(QPointF)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->push_front(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPolygonFFunc_push_front_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPolygonF.push_front", overloads);
        return 0;
}

static PyObject* Sbk_QPolygonFFunc_remove(PyObject* self, PyObject* args)
{
    QPolygonF* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPolygonF* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "remove", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: remove(int)
    // 1: remove(int,int)
    if (SbkNumber_Check(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // remove(int)
        } else if (numArgs == 2 && SbkNumber_Check(pyargs[1])) {
            overloadId = 1; // remove(int,int)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPolygonFFunc_remove_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // remove(int)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // remove(int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->remove(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // remove(int,int)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // remove(int,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->remove(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPolygonFFunc_remove_TypeError:
        const char* overloads[] = {"int", "int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPolygonF.remove", overloads);
        return 0;
}

static PyObject* Sbk_QPolygonFFunc_replace(PyObject* self, PyObject* args)
{
    QPolygonF* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPolygonF* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "replace", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: replace(int,QPointF)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && Shiboken::Converter< ::QPointF >::isConvertible(pyargs[1])) {
        overloadId = 0; // replace(int,QPointF)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPolygonFFunc_replace_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QPointF cppArg1 = Shiboken::Converter<QPointF >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // replace(int,QPointF)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->replace(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPolygonFFunc_replace_TypeError:
        const char* overloads[] = {"int, PySide.QtCore.QPointF", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPolygonF.replace", overloads);
        return 0;
}

static PyObject* Sbk_QPolygonFFunc_reserve(PyObject* self, PyObject* arg)
{
    QPolygonF* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPolygonF* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: reserve(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // reserve(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPolygonFFunc_reserve_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // reserve(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->reserve(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPolygonFFunc_reserve_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPolygonF.reserve", overloads);
        return 0;
}

static PyObject* Sbk_QPolygonFFunc_resize(PyObject* self, PyObject* arg)
{
    QPolygonF* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPolygonF* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: resize(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // resize(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPolygonFFunc_resize_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // resize(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->resize(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPolygonFFunc_resize_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPolygonF.resize", overloads);
        return 0;
}

static PyObject* Sbk_QPolygonFFunc_setSharable(PyObject* self, PyObject* arg)
{
    QPolygonF* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPolygonF* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setSharable(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setSharable(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPolygonFFunc_setSharable_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setSharable(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setSharable(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPolygonFFunc_setSharable_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPolygonF.setSharable", overloads);
        return 0;
}

static PyObject* Sbk_QPolygonFFunc_size(PyObject* self)
{
    QPolygonF* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPolygonF* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // size()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->size();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPolygonFFunc_squeeze(PyObject* self)
{
    QPolygonF* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPolygonF* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // squeeze()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->squeeze();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QPolygonFFunc_startsWith(PyObject* self, PyObject* arg)
{
    QPolygonF* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPolygonF* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: startsWith(QPointF)const
    if (Shiboken::Converter< ::QPointF >::isConvertible(arg)) {
        overloadId = 0; // startsWith(QPointF)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPolygonFFunc_startsWith_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QPointF cppArg0 = Shiboken::Converter<QPointF >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // startsWith(QPointF)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->startsWith(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QPolygonFFunc_startsWith_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPolygonF.startsWith", overloads);
        return 0;
}

static PyObject* Sbk_QPolygonFFunc_subtracted(PyObject* self, PyObject* arg)
{
    QPolygonF* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPolygonF* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: subtracted(QPolygonF)const
    if (Shiboken::Converter< ::QPolygonF >::isConvertible(arg)) {
        overloadId = 0; // subtracted(QPolygonF)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPolygonFFunc_subtracted_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QPolygonF cppArg0 = Shiboken::Converter<QPolygonF >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // subtracted(QPolygonF)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPolygonF cppResult = cppSelf->subtracted(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPolygonF >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QPolygonFFunc_subtracted_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPolygonF", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPolygonF.subtracted", overloads);
        return 0;
}

static PyObject* Sbk_QPolygonFFunc_toList(PyObject* self)
{
    QPolygonF* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPolygonF* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // toList()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QList<QPointF > cppResult = cppSelf->toList();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QList<QPointF > >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPolygonFFunc_toPolygon(PyObject* self)
{
    QPolygonF* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPolygonF* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // toPolygon()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPolygon cppResult = cppSelf->toPolygon();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPolygon >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPolygonFFunc_translate(PyObject* self, PyObject* args)
{
    QPolygonF* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPolygonF* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "translate", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: translate(QPointF)
    // 1: translate(qreal,qreal)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 1; // translate(qreal,qreal)
    } else if (numArgs == 1 && Shiboken::Converter< ::QPointF >::isConvertible(pyargs[0])) {
        overloadId = 0; // translate(QPointF)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPolygonFFunc_translate_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // translate(QPointF)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QPointF cppArg0 = Shiboken::Converter<QPointF >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // translate(QPointF)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->translate(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // translate(qreal,qreal)
            {
                qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cppArg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // translate(qreal,qreal)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->translate(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPolygonFFunc_translate_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF", "float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPolygonF.translate", overloads);
        return 0;
}

static PyObject* Sbk_QPolygonFFunc_translated(PyObject* self, PyObject* args)
{
    QPolygonF* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPolygonF* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "translated", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: translated(QPointF)const
    // 1: translated(qreal,qreal)const
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 1; // translated(qreal,qreal)const
    } else if (numArgs == 1 && Shiboken::Converter< ::QPointF >::isConvertible(pyargs[0])) {
        overloadId = 0; // translated(QPointF)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPolygonFFunc_translated_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // translated(QPointF)const
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QPointF cppArg0 = Shiboken::Converter<QPointF >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // translated(QPointF)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QPolygonF cppResult = cppSelf->translated(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QPolygonF >::toPython(cppResult);
                }
                break;
            }
            case 1: // translated(qreal,qreal)const
            {
                qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cppArg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // translated(qreal,qreal)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QPolygonF cppResult = cppSelf->translated(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QPolygonF >::toPython(cppResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QPolygonFFunc_translated_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF", "float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPolygonF.translated", overloads);
        return 0;
}

static PyObject* Sbk_QPolygonFFunc_united(PyObject* self, PyObject* arg)
{
    QPolygonF* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPolygonF* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: united(QPolygonF)const
    if (Shiboken::Converter< ::QPolygonF >::isConvertible(arg)) {
        overloadId = 0; // united(QPolygonF)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPolygonFFunc_united_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QPolygonF cppArg0 = Shiboken::Converter<QPolygonF >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // united(QPolygonF)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPolygonF cppResult = cppSelf->united(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPolygonF >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QPolygonFFunc_united_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPolygonF", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPolygonF.united", overloads);
        return 0;
}

static PyObject* Sbk_QPolygonFFunc_value(PyObject* self, PyObject* args)
{
    QPolygonF* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPolygonF* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "value", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: value(int)const
    // 1: value(int,QPointF)const
    if (SbkNumber_Check(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // value(int)const
        } else if (numArgs == 2 && Shiboken::Converter< ::QPointF >::isConvertible(pyargs[1])) {
            overloadId = 1; // value(int,QPointF)const
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPolygonFFunc_value_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // value(int)const
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // value(int)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QPointF cppResult = cppSelf->value(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QPointF >::toPython(cppResult);
                }
                break;
            }
            case 1: // value(int,QPointF)const
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                if (!Shiboken::Object::isValid(pyargs[1]))
                    return 0;
                QPointF cppArg1 = Shiboken::Converter<QPointF >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // value(int,QPointF)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QPointF cppResult = cppSelf->value(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QPointF >::toPython(cppResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QPolygonFFunc_value_TypeError:
        const char* overloads[] = {"int", "int, PySide.QtCore.QPointF", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPolygonF.value", overloads);
        return 0;
}

static PyObject *Sbk_QPolygonF___copy__(PyObject *self)
{
        QPolygonF* cppSelf = 0;
        if (!Shiboken::Object::isValid(self))
            return 0;
        cppSelf = Shiboken::Converter<QPolygonF*>::toCpp(self);
        PyObject* pyResult = 0;
        QPolygonF* copy = new QPolygonF(*cppSelf);
        pyResult = Shiboken::Converter<QPolygonF*>::toPython(copy);
        Shiboken::Object::getOwnership(pyResult);

        if (PyErr_Occurred() || !pyResult) {
            Py_XDECREF(pyResult);
            return 0;
        }
        return pyResult;
}

static PyMethodDef Sbk_QPolygonF_methods[] = {
    {"append", (PyCFunction)Sbk_QPolygonFFunc_append, METH_O},
    {"at", (PyCFunction)Sbk_QPolygonFFunc_at, METH_O},
    {"boundingRect", (PyCFunction)Sbk_QPolygonFFunc_boundingRect, METH_NOARGS},
    {"capacity", (PyCFunction)Sbk_QPolygonFFunc_capacity, METH_NOARGS},
    {"clear", (PyCFunction)Sbk_QPolygonFFunc_clear, METH_NOARGS},
    {"constData", (PyCFunction)Sbk_QPolygonFFunc_constData, METH_NOARGS},
    {"contains", (PyCFunction)Sbk_QPolygonFFunc_contains, METH_O},
    {"containsPoint", (PyCFunction)Sbk_QPolygonFFunc_containsPoint, METH_VARARGS},
    {"count", (PyCFunction)Sbk_QPolygonFFunc_count, METH_VARARGS},
    {"data", (PyCFunction)Sbk_QPolygonFFunc_data, METH_NOARGS},
    {"empty", (PyCFunction)Sbk_QPolygonFFunc_empty, METH_NOARGS},
    {"endsWith", (PyCFunction)Sbk_QPolygonFFunc_endsWith, METH_O},
    {"erase", (PyCFunction)Sbk_QPolygonFFunc_erase, METH_VARARGS},
    {"fill", (PyCFunction)Sbk_QPolygonFFunc_fill, METH_VARARGS|METH_KEYWORDS},
    {"first", (PyCFunction)Sbk_QPolygonFFunc_first, METH_NOARGS},
    {"fromList", (PyCFunction)Sbk_QPolygonFFunc_fromList, METH_O|METH_STATIC},
    {"front", (PyCFunction)Sbk_QPolygonFFunc_front, METH_NOARGS},
    {"indexOf", (PyCFunction)Sbk_QPolygonFFunc_indexOf, METH_VARARGS|METH_KEYWORDS},
    {"insert", (PyCFunction)Sbk_QPolygonFFunc_insert, METH_VARARGS},
    {"intersected", (PyCFunction)Sbk_QPolygonFFunc_intersected, METH_O},
    {"isClosed", (PyCFunction)Sbk_QPolygonFFunc_isClosed, METH_NOARGS},
    {"isEmpty", (PyCFunction)Sbk_QPolygonFFunc_isEmpty, METH_NOARGS},
    {"isSharedWith", (PyCFunction)Sbk_QPolygonFFunc_isSharedWith, METH_O},
    {"last", (PyCFunction)Sbk_QPolygonFFunc_last, METH_NOARGS},
    {"lastIndexOf", (PyCFunction)Sbk_QPolygonFFunc_lastIndexOf, METH_VARARGS|METH_KEYWORDS},
    {"mid", (PyCFunction)Sbk_QPolygonFFunc_mid, METH_VARARGS|METH_KEYWORDS},
    {"pop_back", (PyCFunction)Sbk_QPolygonFFunc_pop_back, METH_NOARGS},
    {"pop_front", (PyCFunction)Sbk_QPolygonFFunc_pop_front, METH_NOARGS},
    {"prepend", (PyCFunction)Sbk_QPolygonFFunc_prepend, METH_O},
    {"push_back", (PyCFunction)Sbk_QPolygonFFunc_push_back, METH_O},
    {"push_front", (PyCFunction)Sbk_QPolygonFFunc_push_front, METH_O},
    {"remove", (PyCFunction)Sbk_QPolygonFFunc_remove, METH_VARARGS},
    {"replace", (PyCFunction)Sbk_QPolygonFFunc_replace, METH_VARARGS},
    {"reserve", (PyCFunction)Sbk_QPolygonFFunc_reserve, METH_O},
    {"resize", (PyCFunction)Sbk_QPolygonFFunc_resize, METH_O},
    {"setSharable", (PyCFunction)Sbk_QPolygonFFunc_setSharable, METH_O},
    {"size", (PyCFunction)Sbk_QPolygonFFunc_size, METH_NOARGS},
    {"squeeze", (PyCFunction)Sbk_QPolygonFFunc_squeeze, METH_NOARGS},
    {"startsWith", (PyCFunction)Sbk_QPolygonFFunc_startsWith, METH_O},
    {"subtracted", (PyCFunction)Sbk_QPolygonFFunc_subtracted, METH_O},
    {"toList", (PyCFunction)Sbk_QPolygonFFunc_toList, METH_NOARGS},
    {"toPolygon", (PyCFunction)Sbk_QPolygonFFunc_toPolygon, METH_NOARGS},
    {"translate", (PyCFunction)Sbk_QPolygonFFunc_translate, METH_VARARGS},
    {"translated", (PyCFunction)Sbk_QPolygonFFunc_translated, METH_VARARGS},
    {"united", (PyCFunction)Sbk_QPolygonFFunc_united, METH_O},
    {"value", (PyCFunction)Sbk_QPolygonFFunc_value, METH_VARARGS},

    {"__copy__", (PyCFunction)Sbk_QPolygonF___copy__, METH_NOARGS},
    {0} // Sentinel
};

static PyObject* Sbk_QPolygonFFunc___mul__(PyObject* self, PyObject* arg)
{
    QPolygonF* cppSelf = 0;
    bool isReverse = Shiboken::Converter< ::QPolygonF >::checkType(arg) && !Shiboken::Converter< ::QPolygonF >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPolygonF* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && Shiboken::Object::checkType(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rmul__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rmul__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator*(QPolygonF,QMatrix)
    // 1: operator*(QPolygonF,QTransform)
    if (!isReverse && Shiboken::Converter< ::QTransform >::isConvertible(arg)) {
        overloadId = 1; // operator*(QPolygonF,QTransform)
    } else if (!isReverse && Shiboken::Converter< ::QMatrix >::isConvertible(arg)) {
        overloadId = 0; // operator*(QPolygonF,QMatrix)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPolygonFFunc___mul___TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // operator*(QPolygonF,QMatrix)
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QMatrix cppArg0 = Shiboken::Converter<QMatrix >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // operator*(QPolygonF,QMatrix)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QPolygonF cppResult = (*cppSelf) * (cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QPolygonF >::toPython(cppResult);
                }
                break;
            }
            case 1: // operator*(QPolygonF,QTransform)
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QTransform cppArg0 = Shiboken::Converter<QTransform >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // operator*(QPolygonF,QTransform)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QPolygonF cppResult = (*cppSelf) * (cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QPolygonF >::toPython(cppResult);
                }
                break;
            }
        }
    }


    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QPolygonFFunc___mul___TypeError:
        const char* overloads[] = {"PySide.QtGui.QMatrix", "PySide.QtGui.QTransform", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPolygonF.__mul__", overloads);
        return 0;
}

static PyObject* Sbk_QPolygonFFunc___add__(PyObject* self, PyObject* arg)
{
    QPolygonF* cppSelf = 0;
    bool isReverse = Shiboken::Converter< ::QPolygonF >::checkType(arg) && !Shiboken::Converter< ::QPolygonF >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPolygonF* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && Shiboken::Object::checkType(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__radd__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__radd__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator+(QVector<QPointF>)const
    if (!isReverse && Shiboken::Converter< ::QVector<QPointF > >::isConvertible(arg)) {
        overloadId = 0; // operator+(QVector<QPointF>)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPolygonFFunc___add___TypeError;

    // Call function/method
    {
        {
            QVector<QPointF > cppArg0 = Shiboken::Converter<QVector<QPointF > >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // operator+(QVector<QPointF>)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QVector<QPointF > cppResult = (*cppSelf) + cppArg0;
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QVector<QPointF > >::toPython(cppResult);
            }
        }
    }


    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QPolygonFFunc___add___TypeError:
        const char* overloads[] = {"list", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPolygonF.__add__", overloads);
        return 0;
}

static PyObject* Sbk_QPolygonFFunc___iadd__(PyObject* self, PyObject* arg)
{
    QPolygonF* cppSelf = 0;
    bool isReverse = Shiboken::Converter< ::QPolygonF >::checkType(arg) && !Shiboken::Converter< ::QPolygonF >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPolygonF* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: operator+=(QPointF)
    // 1: operator+=(QVector<QPointF>)
    if (!isReverse && Shiboken::Converter< ::QPointF >::isConvertible(arg)) {
        overloadId = 0; // operator+=(QPointF)
    } else if (!isReverse && Shiboken::Converter< ::QVector<QPointF > >::isConvertible(arg)) {
        overloadId = 1; // operator+=(QVector<QPointF>)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPolygonFFunc___iadd___TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // operator+=(QPointF)
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QPointF cppArg0 = Shiboken::Converter<QPointF >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // operator+=(QPointF)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    (*cppSelf) += (cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // operator+=(QVector<QPointF>)
            {
                QVector<QPointF > cppArg0 = Shiboken::Converter<QVector<QPointF > >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // operator+=(QVector<QPointF>)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    (*cppSelf) += cppArg0;
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_INCREF(self);
    return self;

    Sbk_QPolygonFFunc___iadd___TypeError:
        const char* overloads[] = {"PySide.QtCore.QPointF", "list", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPolygonF.__iadd__", overloads);
        return 0;
}

static PyObject* Sbk_QPolygonFFunc___lshift__(PyObject* self, PyObject* arg)
{
    QPolygonF* cppSelf = 0;
    bool isReverse = Shiboken::Converter< ::QPolygonF >::checkType(arg) && !Shiboken::Converter< ::QPolygonF >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPolygonF* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && Shiboken::Object::checkType(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rlshift__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rlshift__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator<<(QDataStream&,QPolygonF)
    if (isReverse && Shiboken::Converter< ::QDataStream & >::isConvertible(arg)) {
        overloadId = 0; // operator<<(QDataStream&,QPolygonF)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPolygonFFunc___lshift___TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QDataStream & cppArg0 = Shiboken::Converter<QDataStream & >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // operator<<(QDataStream&,QPolygonF) [reverse operator]
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDataStream & cppResult = (cppArg0) << (*cppSelf);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDataStream & >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QPolygonFFunc___lshift___TypeError:
        const char* overloads[] = {"PySide.QtCore.QDataStream", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPolygonF.__lshift__", overloads);
        return 0;
}

static PyObject* Sbk_QPolygonFFunc___rshift__(PyObject* self, PyObject* arg)
{
    QPolygonF* cppSelf = 0;
    bool isReverse = Shiboken::Converter< ::QPolygonF >::checkType(arg) && !Shiboken::Converter< ::QPolygonF >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPolygonF* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && Shiboken::Object::checkType(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rrshift__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rrshift__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator>>(QDataStream&,QPolygonF&)
    if (isReverse && Shiboken::Converter< ::QDataStream & >::isConvertible(arg)) {
        overloadId = 0; // operator>>(QDataStream&,QPolygonF&)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPolygonFFunc___rshift___TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QDataStream & cppArg0 = Shiboken::Converter<QDataStream & >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // operator>>(QDataStream&,QPolygonF&) [reverse operator]
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDataStream & cppResult = (cppArg0) >> (*cppSelf);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDataStream & >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QPolygonFFunc___rshift___TypeError:
        const char* overloads[] = {"PySide.QtCore.QDataStream", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPolygonF.__rshift__", overloads);
        return 0;
}

// type has number operators
static PyNumberMethods Sbk_QPolygonF_as_number = {
    /*nb_add*/                  (binaryfunc)Sbk_QPolygonFFunc___add__,
    /*nb_subtract*/             (binaryfunc)0,
    /*nb_multiply*/             (binaryfunc)Sbk_QPolygonFFunc___mul__,
    /*nb_divide*/               (binaryfunc)0,
    /*nb_remainder*/            (binaryfunc)0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             (unaryfunc)0,
    /*nb_positive*/             (unaryfunc)0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              0,
    /*nb_invert*/               (unaryfunc)0,
    /*nb_lshift*/               (binaryfunc)Sbk_QPolygonFFunc___lshift__,
    /*nb_rshift*/               (binaryfunc)Sbk_QPolygonFFunc___rshift__,
    /*nb_and*/                  (binaryfunc)0,
    /*nb_xor*/                  (binaryfunc)0,
    /*nb_or*/                   (binaryfunc)0,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          (binaryfunc)Sbk_QPolygonFFunc___iadd__,
    /*nb_inplace_subtract*/     (binaryfunc)0,
    /*nb_inplace_multiply*/     (binaryfunc)0,
    /*nb_inplace_divide*/       (binaryfunc)0,
    /*nb_inplace_remainder*/    (binaryfunc)0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       (binaryfunc)0,
    /*nb_inplace_rshift*/       (binaryfunc)0,
    /*nb_inplace_and*/          (binaryfunc)0,
    /*nb_inplace_xor*/          (binaryfunc)0,
    /*nb_inplace_or*/           (binaryfunc)0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          (binaryfunc)0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};

Py_ssize_t Sbk_QPolygonF__len__(PyObject* self)
{
    if (!Shiboken::Object::isValid(self))
        return 0;

    QPolygonF &cppSelf = Shiboken::Converter<QPolygonF& >::toCpp(self);
    return cppSelf.size();
}
PyObject* Sbk_QPolygonF__getitem__(PyObject* self, Py_ssize_t _i)
{
    if (!Shiboken::Object::isValid(self))
        return 0;

    QPolygonF &cppSelf = Shiboken::Converter<QPolygonF& >::toCpp(self);
    if (_i < 0 || _i >= (Py_ssize_t) cppSelf.size()) {
        PyErr_SetString(PyExc_IndexError, "index out of bounds");
        return 0;
    }
    QPolygonF::iterator _item = cppSelf.begin();
    for(Py_ssize_t pos=0; pos < _i; pos++) _item++;
    return Shiboken::Converter<QPolygonF::value_type>::toPython(*_item);
}
int Sbk_QPolygonF__setitem__(PyObject* self, Py_ssize_t _i, PyObject* _value)
{
    if (!Shiboken::Object::isValid(self))
        return -1;
    QPolygonF &cppSelf = Shiboken::Converter<QPolygonF& >::toCpp(self);
    if (_i < 0 || _i >= (Py_ssize_t) cppSelf.size()) {
        PyErr_SetString(PyExc_IndexError, "list assignment index out of range");
        return -1;
    }
    QPolygonF::iterator _item = cppSelf.begin();
    for(Py_ssize_t pos=0; pos < _i; pos++) _item++;
    QPolygonF::value_type cppValue = Shiboken::Converter<QPolygonF::value_type>::toCpp(_value);
    *_item = cppValue;
    return 0;
}
static PySequenceMethods PyQPolygonF_as_sequence = {
    /*sq_length*/ Sbk_QPolygonF__len__,
    /*sq_concat*/ 0,
    /*sq_repeat*/ 0,
    /*sq_item*/ Sbk_QPolygonF__getitem__,
    /*sq_slice*/ 0,
    /*sq_ass_item*/ Sbk_QPolygonF__setitem__,
    /*sq_ass_slice*/ 0,
    /*sq_contains*/ 0,
    /*sq_inplace_concat*/ 0,
    /*sq_inplace_repeat*/ 0
};

// Rich comparison
static PyObject* Sbk_QPolygonF_richcompare(PyObject* self, PyObject* arg, int op)
{
    PyObject* pyResult = 0;
    QPolygonF& cppSelf = *Shiboken::Converter< QPolygonF* >::toCpp(self);

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter< ::QVector<QPointF > >::isConvertible(arg)) {
                // operator!=(const QVector<QPointF > & v) const
                QVector<QPointF > cppArg0 = Shiboken::Converter< ::QVector<QPointF > >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf != cppArg0);
            } else goto Sbk_QPolygonF_RichComparison_TypeError;

            break;
        case Py_EQ:
            if (Shiboken::Converter< ::QVector<QPointF > >::isConvertible(arg)) {
                // operator==(const QVector<QPointF > & v) const
                QVector<QPointF > cppArg0 = Shiboken::Converter< ::QVector<QPointF > >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf == cppArg0);
            } else goto Sbk_QPolygonF_RichComparison_TypeError;

            break;
        default:
            goto Sbk_QPolygonF_RichComparison_TypeError;
    }

    if (pyResult && !PyErr_Occurred())
        return pyResult;
    Sbk_QPolygonF_RichComparison_TypeError:
    PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
    return 0;

}

} // extern "C"

extern "C"
{
static PyObject* Sbk_QPolygonF__repr__(PyObject* pyObj)
{
    QBuffer buffer;
    buffer.open(QBuffer::ReadWrite);
    QDebug dbg(&buffer);
    dbg << Shiboken::Converter< ::QPolygonF >::toCpp(pyObj);
    buffer.close();
    return PyString_FromFormat("<PySide.QtGui.%s at %p>", buffer.data().constData(), pyObj);
}
} // extern C

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QPolygonF_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QPolygonF",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Sbk_QPolygonF__repr__,
    /*tp_as_number*/        &Sbk_QPolygonF_as_number,
    /*tp_as_sequence*/      &PyQPolygonF_as_sequence,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      Sbk_QPolygonF_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QPolygonF_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QPolygonF_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QPolygonF(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QPOLYGONF_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QPolygonF_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QPolygonF_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QPolygonF_Type, &Shiboken::callCppDestructor<QPolygonF >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QPolygonF_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QPolygonF_Type, "QPolygonF");
    PyModule_AddObject(module, "QPolygonF",
        ((PyObject*)&Sbk_QPolygonF_Type));


    Shiboken::TypeResolver::createValueTypeResolver<QPolygonF >("QPolygonF");
    Shiboken::TypeResolver::createObjectTypeResolver<QPolygonF >("QPolygonF*");
    Shiboken::TypeResolver::createValueTypeResolver<QPolygonF >(typeid(QPolygonF).name());
    PySide::initQtMetaType<QPolygonF >();
}

