/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qprintengine_wrapper.h"

// Extra includes


// Native ---------------------------------------------------------

QPrintEngineWrapper::QPrintEngineWrapper() : QPrintEngine() {
    // ... middle
}

bool QPrintEngineWrapper::abort()
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "abort"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QPrintEngine.abort()' not implemented.");
        return bool(0);
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QPrintEngine.abort", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    return cppResult;
}

int QPrintEngineWrapper::metric(QPaintDevice::PaintDeviceMetric arg__1) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "metric"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QPrintEngine.metric()' not implemented.");
        return int(0);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QPaintDevice::PaintDeviceMetric >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QPrintEngine.metric", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter< int >::toCpp(pyResult));
    return cppResult;
}

bool QPrintEngineWrapper::newPage()
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "newPage"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QPrintEngine.newPage()' not implemented.");
        return bool(0);
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QPrintEngine.newPage", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    return cppResult;
}

QPrinter::PrinterState QPrintEngineWrapper::printerState() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "printerState"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QPrintEngine.printerState()' not implemented.");
        return QPrinter::PrinterState();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QPrinter::PrinterState();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QPrinter::PrinterState >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QPrintEngine.printerState", Shiboken::SbkType<QPrinter::PrinterState >()->tp_name, pyResult->ob_type->tp_name);
        return QPrinter::PrinterState();
    }
    QPrinter::PrinterState cppResult(Shiboken::Converter< ::QPrinter::PrinterState >::toCpp(pyResult));
    return cppResult;
}

QVariant QPrintEngineWrapper::property(QPrintEngine::PrintEnginePropertyKey key) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "property"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QPrintEngine.property()' not implemented.");
        return QVariant(0);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QPrintEngine::PrintEnginePropertyKey >::toPython(key)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QVariant(0);
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< QVariant >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QPrintEngine.property", "QVariant", pyResult->ob_type->tp_name);
        return QVariant(0);
    }
    QVariant cppResult(Shiboken::Converter< QVariant >::toCpp(pyResult));
    return cppResult;
}

void QPrintEngineWrapper::setProperty(QPrintEngine::PrintEnginePropertyKey key, const QVariant & value)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "setProperty"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QPrintEngine.setProperty()' not implemented.");
        return ;
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QPrintEngine::PrintEnginePropertyKey >::toPython(key),
        Shiboken::Converter< QVariant >::toPython(value)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

QPrintEngineWrapper::~QPrintEngineWrapper()
{
    SbkObject* wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QPrintEngine_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QPrintEngine >()))
        return -1;

    QPrintEngineWrapper* cptr = 0;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);
    SbkObjectType* type = reinterpret_cast<SbkObjectType*>(self->ob_type);
    SbkObjectType* myType = reinterpret_cast<SbkObjectType*>(SbkPySide_QtGuiTypes[SBK_QPRINTENGINE_IDX]);
    if (type == myType) {
        PyErr_SetString(PyExc_NotImplementedError,
            "'QPrintEngine' represents a C++ abstract class and cannot be instantiated");
        return -1;
    }


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // QPrintEngine()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new QPrintEngineWrapper();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QPrintEngine >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject* Sbk_QPrintEngineFunc_abort(PyObject* self)
{
    QPrintEngine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPrintEngine* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // abort()
                if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self))) {
                    PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QPrintEngine.abort()' not implemented.");
                    return 0;
                }
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->abort();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPrintEngineFunc_metric(PyObject* self, PyObject* arg)
{
    QPrintEngine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPrintEngine* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: metric(QPaintDevice::PaintDeviceMetric)const
    if (Shiboken::Converter< ::QPaintDevice::PaintDeviceMetric >::isConvertible(arg)) {
        overloadId = 0; // metric(QPaintDevice::PaintDeviceMetric)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPrintEngineFunc_metric_TypeError;

    // Call function/method
    {
        {
            QPaintDevice::PaintDeviceMetric cppArg0 = Shiboken::Converter<QPaintDevice::PaintDeviceMetric >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // metric(QPaintDevice::PaintDeviceMetric)const
                if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self))) {
                    PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QPrintEngine.metric()' not implemented.");
                    return 0;
                }
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->metric(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QPrintEngineFunc_metric_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPaintDevice.PaintDeviceMetric", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPrintEngine.metric", overloads);
        return 0;
}

static PyObject* Sbk_QPrintEngineFunc_newPage(PyObject* self)
{
    QPrintEngine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPrintEngine* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // newPage()
                if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self))) {
                    PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QPrintEngine.newPage()' not implemented.");
                    return 0;
                }
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->newPage();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPrintEngineFunc_printerState(PyObject* self)
{
    QPrintEngine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPrintEngine* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // printerState()const
                if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self))) {
                    PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QPrintEngine.printerState()' not implemented.");
                    return 0;
                }
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPrinter::PrinterState cppResult = cppSelf->printerState();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPrinter::PrinterState >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QPrintEngineFunc_property(PyObject* self, PyObject* arg)
{
    QPrintEngine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPrintEngine* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: property(QPrintEngine::PrintEnginePropertyKey)const
    if (Shiboken::Converter< ::QPrintEngine::PrintEnginePropertyKey >::isConvertible(arg)) {
        overloadId = 0; // property(QPrintEngine::PrintEnginePropertyKey)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPrintEngineFunc_property_TypeError;

    // Call function/method
    {
        {
            QPrintEngine::PrintEnginePropertyKey cppArg0 = Shiboken::Converter<QPrintEngine::PrintEnginePropertyKey >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // property(QPrintEngine::PrintEnginePropertyKey)const
                if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self))) {
                    PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QPrintEngine.property()' not implemented.");
                    return 0;
                }
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QVariant cppResult = cppSelf->property(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QVariant >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QPrintEngineFunc_property_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPrintEngine.PrintEnginePropertyKey", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QPrintEngine.property", overloads);
        return 0;
}

static PyObject* Sbk_QPrintEngineFunc_setProperty(PyObject* self, PyObject* args)
{
    QPrintEngine* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QPrintEngine* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setProperty", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setProperty(QPrintEngine::PrintEnginePropertyKey,QVariant)
    if (numArgs == 2 && Shiboken::Converter< ::QPrintEngine::PrintEnginePropertyKey >::isConvertible(pyargs[0]) && Shiboken::Converter< QVariant >::isConvertible(pyargs[1])) {
        overloadId = 0; // setProperty(QPrintEngine::PrintEnginePropertyKey,QVariant)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QPrintEngineFunc_setProperty_TypeError;

    // Call function/method
    {
        {
            QPrintEngine::PrintEnginePropertyKey cppArg0 = Shiboken::Converter<QPrintEngine::PrintEnginePropertyKey >::toCpp(pyargs[0]);
            QVariant cppArg1 = Shiboken::Converter<QVariant >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // setProperty(QPrintEngine::PrintEnginePropertyKey,QVariant)
                if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self))) {
                    PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QPrintEngine.setProperty()' not implemented.");
                    return 0;
                }
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setProperty(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QPrintEngineFunc_setProperty_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPrintEngine.PrintEnginePropertyKey, QVariant", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QPrintEngine.setProperty", overloads);
        return 0;
}

static PyMethodDef Sbk_QPrintEngine_methods[] = {
    {"abort", (PyCFunction)Sbk_QPrintEngineFunc_abort, METH_NOARGS},
    {"metric", (PyCFunction)Sbk_QPrintEngineFunc_metric, METH_O},
    {"newPage", (PyCFunction)Sbk_QPrintEngineFunc_newPage, METH_NOARGS},
    {"printerState", (PyCFunction)Sbk_QPrintEngineFunc_printerState, METH_NOARGS},
    {"property", (PyCFunction)Sbk_QPrintEngineFunc_property, METH_O},
    {"setProperty", (PyCFunction)Sbk_QPrintEngineFunc_setProperty, METH_VARARGS},

    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QPrintEngine_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QPrintEngine",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QPrintEngine_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QPrintEngine_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QPrintEngine(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QPRINTENGINE_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QPrintEngine_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QPrintEngine_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QPrintEngine_Type, &Shiboken::callCppDestructor<QPrintEngine >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QPrintEngine_Type) < 0)
        return;

    // Fill type discovery information

    Shiboken::ObjectType::setOriginalName(&Sbk_QPrintEngine_Type, "QPrintEngine*");
    PyModule_AddObject(module, "QPrintEngine",
        ((PyObject*)&Sbk_QPrintEngine_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: PrintEnginePropertyKey
    PyTypeObject* SbkPySide_QtGui_QPrintEngine_PrintEnginePropertyKey = Shiboken::Enum::newType("PrintEnginePropertyKey");
    SbkPySide_QtGuiTypes[SBK_QPRINTENGINE_PRINTENGINEPROPERTYKEY_IDX] = SbkPySide_QtGui_QPrintEngine_PrintEnginePropertyKey;
    if (PyType_Ready(SbkPySide_QtGui_QPrintEngine_PrintEnginePropertyKey) < 0)
        return;
    PyDict_SetItemString(Sbk_QPrintEngine_Type.super.ht_type.tp_dict,
            "PrintEnginePropertyKey",((PyObject*)SbkPySide_QtGui_QPrintEngine_PrintEnginePropertyKey));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPrintEngine_PrintEnginePropertyKey,(long) QPrintEngine::PPK_CollateCopies, "PPK_CollateCopies");
    PyDict_SetItemString(Sbk_QPrintEngine_Type.super.ht_type.tp_dict,"PPK_CollateCopies", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPrintEngine_PrintEnginePropertyKey->tp_dict,"PPK_CollateCopies", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPrintEngine_PrintEnginePropertyKey,(long) QPrintEngine::PPK_ColorMode, "PPK_ColorMode");
    PyDict_SetItemString(Sbk_QPrintEngine_Type.super.ht_type.tp_dict,"PPK_ColorMode", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPrintEngine_PrintEnginePropertyKey->tp_dict,"PPK_ColorMode", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPrintEngine_PrintEnginePropertyKey,(long) QPrintEngine::PPK_Creator, "PPK_Creator");
    PyDict_SetItemString(Sbk_QPrintEngine_Type.super.ht_type.tp_dict,"PPK_Creator", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPrintEngine_PrintEnginePropertyKey->tp_dict,"PPK_Creator", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPrintEngine_PrintEnginePropertyKey,(long) QPrintEngine::PPK_DocumentName, "PPK_DocumentName");
    PyDict_SetItemString(Sbk_QPrintEngine_Type.super.ht_type.tp_dict,"PPK_DocumentName", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPrintEngine_PrintEnginePropertyKey->tp_dict,"PPK_DocumentName", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPrintEngine_PrintEnginePropertyKey,(long) QPrintEngine::PPK_FullPage, "PPK_FullPage");
    PyDict_SetItemString(Sbk_QPrintEngine_Type.super.ht_type.tp_dict,"PPK_FullPage", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPrintEngine_PrintEnginePropertyKey->tp_dict,"PPK_FullPage", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPrintEngine_PrintEnginePropertyKey,(long) QPrintEngine::PPK_NumberOfCopies, "PPK_NumberOfCopies");
    PyDict_SetItemString(Sbk_QPrintEngine_Type.super.ht_type.tp_dict,"PPK_NumberOfCopies", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPrintEngine_PrintEnginePropertyKey->tp_dict,"PPK_NumberOfCopies", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPrintEngine_PrintEnginePropertyKey,(long) QPrintEngine::PPK_Orientation, "PPK_Orientation");
    PyDict_SetItemString(Sbk_QPrintEngine_Type.super.ht_type.tp_dict,"PPK_Orientation", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPrintEngine_PrintEnginePropertyKey->tp_dict,"PPK_Orientation", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPrintEngine_PrintEnginePropertyKey,(long) QPrintEngine::PPK_OutputFileName, "PPK_OutputFileName");
    PyDict_SetItemString(Sbk_QPrintEngine_Type.super.ht_type.tp_dict,"PPK_OutputFileName", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPrintEngine_PrintEnginePropertyKey->tp_dict,"PPK_OutputFileName", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPrintEngine_PrintEnginePropertyKey,(long) QPrintEngine::PPK_PageOrder, "PPK_PageOrder");
    PyDict_SetItemString(Sbk_QPrintEngine_Type.super.ht_type.tp_dict,"PPK_PageOrder", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPrintEngine_PrintEnginePropertyKey->tp_dict,"PPK_PageOrder", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPrintEngine_PrintEnginePropertyKey,(long) QPrintEngine::PPK_PageRect, "PPK_PageRect");
    PyDict_SetItemString(Sbk_QPrintEngine_Type.super.ht_type.tp_dict,"PPK_PageRect", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPrintEngine_PrintEnginePropertyKey->tp_dict,"PPK_PageRect", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPrintEngine_PrintEnginePropertyKey,(long) QPrintEngine::PPK_PageSize, "PPK_PageSize");
    PyDict_SetItemString(Sbk_QPrintEngine_Type.super.ht_type.tp_dict,"PPK_PageSize", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPrintEngine_PrintEnginePropertyKey->tp_dict,"PPK_PageSize", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPrintEngine_PrintEnginePropertyKey,(long) QPrintEngine::PPK_PaperRect, "PPK_PaperRect");
    PyDict_SetItemString(Sbk_QPrintEngine_Type.super.ht_type.tp_dict,"PPK_PaperRect", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPrintEngine_PrintEnginePropertyKey->tp_dict,"PPK_PaperRect", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPrintEngine_PrintEnginePropertyKey,(long) QPrintEngine::PPK_PaperSource, "PPK_PaperSource");
    PyDict_SetItemString(Sbk_QPrintEngine_Type.super.ht_type.tp_dict,"PPK_PaperSource", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPrintEngine_PrintEnginePropertyKey->tp_dict,"PPK_PaperSource", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPrintEngine_PrintEnginePropertyKey,(long) QPrintEngine::PPK_PrinterName, "PPK_PrinterName");
    PyDict_SetItemString(Sbk_QPrintEngine_Type.super.ht_type.tp_dict,"PPK_PrinterName", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPrintEngine_PrintEnginePropertyKey->tp_dict,"PPK_PrinterName", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPrintEngine_PrintEnginePropertyKey,(long) QPrintEngine::PPK_PrinterProgram, "PPK_PrinterProgram");
    PyDict_SetItemString(Sbk_QPrintEngine_Type.super.ht_type.tp_dict,"PPK_PrinterProgram", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPrintEngine_PrintEnginePropertyKey->tp_dict,"PPK_PrinterProgram", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPrintEngine_PrintEnginePropertyKey,(long) QPrintEngine::PPK_Resolution, "PPK_Resolution");
    PyDict_SetItemString(Sbk_QPrintEngine_Type.super.ht_type.tp_dict,"PPK_Resolution", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPrintEngine_PrintEnginePropertyKey->tp_dict,"PPK_Resolution", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPrintEngine_PrintEnginePropertyKey,(long) QPrintEngine::PPK_SelectionOption, "PPK_SelectionOption");
    PyDict_SetItemString(Sbk_QPrintEngine_Type.super.ht_type.tp_dict,"PPK_SelectionOption", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPrintEngine_PrintEnginePropertyKey->tp_dict,"PPK_SelectionOption", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPrintEngine_PrintEnginePropertyKey,(long) QPrintEngine::PPK_SupportedResolutions, "PPK_SupportedResolutions");
    PyDict_SetItemString(Sbk_QPrintEngine_Type.super.ht_type.tp_dict,"PPK_SupportedResolutions", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPrintEngine_PrintEnginePropertyKey->tp_dict,"PPK_SupportedResolutions", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPrintEngine_PrintEnginePropertyKey,(long) QPrintEngine::PPK_WindowsPageSize, "PPK_WindowsPageSize");
    PyDict_SetItemString(Sbk_QPrintEngine_Type.super.ht_type.tp_dict,"PPK_WindowsPageSize", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPrintEngine_PrintEnginePropertyKey->tp_dict,"PPK_WindowsPageSize", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPrintEngine_PrintEnginePropertyKey,(long) QPrintEngine::PPK_FontEmbedding, "PPK_FontEmbedding");
    PyDict_SetItemString(Sbk_QPrintEngine_Type.super.ht_type.tp_dict,"PPK_FontEmbedding", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPrintEngine_PrintEnginePropertyKey->tp_dict,"PPK_FontEmbedding", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPrintEngine_PrintEnginePropertyKey,(long) QPrintEngine::PPK_SuppressSystemPrintStatus, "PPK_SuppressSystemPrintStatus");
    PyDict_SetItemString(Sbk_QPrintEngine_Type.super.ht_type.tp_dict,"PPK_SuppressSystemPrintStatus", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPrintEngine_PrintEnginePropertyKey->tp_dict,"PPK_SuppressSystemPrintStatus", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPrintEngine_PrintEnginePropertyKey,(long) QPrintEngine::PPK_Duplex, "PPK_Duplex");
    PyDict_SetItemString(Sbk_QPrintEngine_Type.super.ht_type.tp_dict,"PPK_Duplex", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPrintEngine_PrintEnginePropertyKey->tp_dict,"PPK_Duplex", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPrintEngine_PrintEnginePropertyKey,(long) QPrintEngine::PPK_PaperSources, "PPK_PaperSources");
    PyDict_SetItemString(Sbk_QPrintEngine_Type.super.ht_type.tp_dict,"PPK_PaperSources", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPrintEngine_PrintEnginePropertyKey->tp_dict,"PPK_PaperSources", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPrintEngine_PrintEnginePropertyKey,(long) QPrintEngine::PPK_CustomPaperSize, "PPK_CustomPaperSize");
    PyDict_SetItemString(Sbk_QPrintEngine_Type.super.ht_type.tp_dict,"PPK_CustomPaperSize", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPrintEngine_PrintEnginePropertyKey->tp_dict,"PPK_CustomPaperSize", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPrintEngine_PrintEnginePropertyKey,(long) QPrintEngine::PPK_PageMargins, "PPK_PageMargins");
    PyDict_SetItemString(Sbk_QPrintEngine_Type.super.ht_type.tp_dict,"PPK_PageMargins", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPrintEngine_PrintEnginePropertyKey->tp_dict,"PPK_PageMargins", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPrintEngine_PrintEnginePropertyKey,(long) QPrintEngine::PPK_CopyCount, "PPK_CopyCount");
    PyDict_SetItemString(Sbk_QPrintEngine_Type.super.ht_type.tp_dict,"PPK_CopyCount", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPrintEngine_PrintEnginePropertyKey->tp_dict,"PPK_CopyCount", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPrintEngine_PrintEnginePropertyKey,(long) QPrintEngine::PPK_SupportsMultipleCopies, "PPK_SupportsMultipleCopies");
    PyDict_SetItemString(Sbk_QPrintEngine_Type.super.ht_type.tp_dict,"PPK_SupportsMultipleCopies", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPrintEngine_PrintEnginePropertyKey->tp_dict,"PPK_SupportsMultipleCopies", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPrintEngine_PrintEnginePropertyKey,(long) QPrintEngine::PPK_PaperSize, "PPK_PaperSize");
    PyDict_SetItemString(Sbk_QPrintEngine_Type.super.ht_type.tp_dict,"PPK_PaperSize", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPrintEngine_PrintEnginePropertyKey->tp_dict,"PPK_PaperSize", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QPrintEngine_PrintEnginePropertyKey,(long) QPrintEngine::PPK_CustomBase, "PPK_CustomBase");
    PyDict_SetItemString(Sbk_QPrintEngine_Type.super.ht_type.tp_dict,"PPK_CustomBase", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QPrintEngine_PrintEnginePropertyKey->tp_dict,"PPK_CustomBase", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QPrintEngine::PrintEnginePropertyKey");
    Shiboken::TypeResolver::createValueTypeResolver<int>("QPrintEngine$ConcreteWrapper::PrintEnginePropertyKey");
    // end of enum PrintEnginePropertyKey


    Shiboken::TypeResolver::createObjectTypeResolver<QPrintEngine >("QPrintEngine*");
    Shiboken::TypeResolver::createObjectTypeResolver<QPrintEngine >("QPrintEngine$ConcreteWrapper*");
    Shiboken::TypeResolver::createObjectTypeResolver<QPrintEngine >(typeid(QPrintEngine).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QPrintEngine >(typeid(QPrintEngineWrapper).name());
    PySide::initQtMetaType<QPrintEngine* >();
}

