/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qstyleoptionframev3_wrapper.h"

// Extra includes
#include <qstyleoption.h>
#include <qwidget.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QStyleOptionFrameV3_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QStyleOptionFrameV3 >()))
        return -1;

    QStyleOptionFrameV3* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QStyleOptionFrameV3", 0, 1, &(pyargs[0])))
        return -1;

    // Overloaded function decisor
    // 0: QStyleOptionFrameV3()
    // 1: QStyleOptionFrameV3(QStyleOptionFrame)
    // 2: QStyleOptionFrameV3(QStyleOptionFrameV3)
    // 3: QStyleOptionFrameV3(int)
    if (numArgs == 0) {
        overloadId = 0; // QStyleOptionFrameV3()
    } else if (numArgs == 1 && SbkNumber_Check(pyargs[0])) {
        overloadId = 3; // QStyleOptionFrameV3(int)
    } else if (numArgs == 1 && Shiboken::Converter< ::QStyleOptionFrame >::isConvertible(pyargs[0])) {
        overloadId = 1; // QStyleOptionFrameV3(QStyleOptionFrame)
    } else if (numArgs == 1 && Shiboken::Converter< ::QStyleOptionFrameV3 >::isConvertible(pyargs[0])) {
        overloadId = 2; // QStyleOptionFrameV3(QStyleOptionFrameV3)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStyleOptionFrameV3_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QStyleOptionFrameV3()
            {

                if(!PyErr_Occurred()) {
                    // QStyleOptionFrameV3()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QStyleOptionFrameV3();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // QStyleOptionFrameV3(QStyleOptionFrame)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QStyleOptionFrame cppArg0 = Shiboken::Converter<QStyleOptionFrame >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QStyleOptionFrameV3(QStyleOptionFrame)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QStyleOptionFrameV3(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // QStyleOptionFrameV3(QStyleOptionFrameV3)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QStyleOptionFrameV3 cppArg0 = Shiboken::Converter<QStyleOptionFrameV3 >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QStyleOptionFrameV3(QStyleOptionFrameV3)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QStyleOptionFrameV3(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 3: // QStyleOptionFrameV3(int)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QStyleOptionFrameV3(int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QStyleOptionFrameV3(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QStyleOptionFrameV3 >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QStyleOptionFrameV3_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QStyleOptionFrameV3_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtGui.QStyleOptionFrame", "PySide.QtGui.QStyleOptionFrameV3", "int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QStyleOptionFrameV3", overloads);
        return -1;
}

static PyObject *Sbk_QStyleOptionFrameV3___copy__(PyObject *self)
{
        QStyleOptionFrameV3* cppSelf = 0;
        if (!Shiboken::Object::isValid(self))
            return 0;
        cppSelf = Shiboken::Converter<QStyleOptionFrameV3*>::toCpp(self);
        PyObject* pyResult = 0;
        QStyleOptionFrameV3* copy = new QStyleOptionFrameV3(*cppSelf);
        pyResult = Shiboken::Converter<QStyleOptionFrameV3*>::toPython(copy);
        Shiboken::Object::getOwnership(pyResult);

        if (PyErr_Occurred() || !pyResult) {
            Py_XDECREF(pyResult);
            return 0;
        }
        return pyResult;
}

static PyMethodDef Sbk_QStyleOptionFrameV3_methods[] = {

    {"__copy__", (PyCFunction)Sbk_QStyleOptionFrameV3___copy__, METH_NOARGS},
    {0} // Sentinel
};

static PyObject* Sbk_QStyleOptionFrameV3_get_frameShape(PyObject* self, void*)
{
    PyObject* val = Shiboken::Converter< ::QFrame::Shape >::toPython( Shiboken::Converter< QStyleOptionFrameV3* >::toCpp(self)->frameShape);
    return val;

}
static int Sbk_QStyleOptionFrameV3_set_frameShape(PyObject* self, PyObject* value, void*)
{
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'frameShape' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter< ::QFrame::Shape >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'frameShape', 'Shape' or convertible type expected");
        return -1;
    }

    Shiboken::Converter< QStyleOptionFrameV3* >::toCpp(self)->frameShape = Shiboken::Converter< ::QFrame::Shape >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QStyleOptionFrameV3_get_unused(PyObject* self, void*)
{
    PyObject* val = Shiboken::Converter< unsigned int >::toPython( Shiboken::Converter< QStyleOptionFrameV3* >::toCpp(self)->unused);
    return val;

}
static int Sbk_QStyleOptionFrameV3_set_unused(PyObject* self, PyObject* value, void*)
{
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'unused' may not be deleted");
        return -1;
    }
    if (!SbkNumber_Check(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'unused', 'uint' or convertible type expected");
        return -1;
    }

    Shiboken::Converter< QStyleOptionFrameV3* >::toCpp(self)->unused = Shiboken::Converter< unsigned int >::toCpp(value);

    return 0;
}

// Getters and Setters for QStyleOptionFrameV3
static PyGetSetDef Sbk_QStyleOptionFrameV3_getsetlist[] = {
    {const_cast<char*>("frameShape"), Sbk_QStyleOptionFrameV3_get_frameShape, Sbk_QStyleOptionFrameV3_set_frameShape},
    {const_cast<char*>("unused"), Sbk_QStyleOptionFrameV3_get_unused, Sbk_QStyleOptionFrameV3_set_unused},
    {0}  // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QStyleOptionFrameV3_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QStyleOptionFrameV3",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QStyleOptionFrameV3_methods,
    /*tp_members*/          0,
    /*tp_getset*/           Sbk_QStyleOptionFrameV3_getsetlist,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QStyleOptionFrameV3_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QStyleOptionFrameV3(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONFRAMEV3_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QStyleOptionFrameV3_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QStyleOptionFrameV3_Type);
    Sbk_QStyleOptionFrameV3_Type.super.ht_type.tp_base = SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONFRAMEV2_IDX];
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QStyleOptionFrameV3_Type, &Shiboken::callCppDestructor<QStyleOptionFrameV3 >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QStyleOptionFrameV3_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QStyleOptionFrameV3_Type, "QStyleOptionFrameV3");
    PyModule_AddObject(module, "QStyleOptionFrameV3",
        ((PyObject*)&Sbk_QStyleOptionFrameV3_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: StyleOptionVersion
    PyTypeObject* SbkPySide_QtGui_QStyleOptionFrameV3_StyleOptionVersion = Shiboken::Enum::newType("StyleOptionVersion");
    SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONFRAMEV3_STYLEOPTIONVERSION_IDX] = SbkPySide_QtGui_QStyleOptionFrameV3_StyleOptionVersion;
    if (PyType_Ready(SbkPySide_QtGui_QStyleOptionFrameV3_StyleOptionVersion) < 0)
        return;
    PyDict_SetItemString(Sbk_QStyleOptionFrameV3_Type.super.ht_type.tp_dict,
            "StyleOptionVersion",((PyObject*)SbkPySide_QtGui_QStyleOptionFrameV3_StyleOptionVersion));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyleOptionFrameV3_StyleOptionVersion,(long) QStyleOptionFrameV3::Version, "Version");
    PyDict_SetItemString(Sbk_QStyleOptionFrameV3_Type.super.ht_type.tp_dict,"Version", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyleOptionFrameV3_StyleOptionVersion->tp_dict,"Version", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QStyleOptionFrameV3::StyleOptionVersion");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::StyleOptionVersion");
    // end of enum StyleOptionVersion


    Shiboken::TypeResolver::createValueTypeResolver<QStyleOptionFrameV3 >("QStyleOptionFrameV3");
    Shiboken::TypeResolver::createObjectTypeResolver<QStyleOptionFrameV3 >("QStyleOptionFrameV3*");
    Shiboken::TypeResolver::createValueTypeResolver<QStyleOptionFrameV3 >(typeid(QStyleOptionFrameV3).name());
    PySide::initQtMetaType<QStyleOptionFrameV3 >();
}

