/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qstyleoptiongraphicsitem_wrapper.h"

// Extra includes
#include <qstyleoption.h>
#include <qtransform.h>
#include <qwidget.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QStyleOptionGraphicsItem_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QStyleOptionGraphicsItem >()))
        return -1;

    QStyleOptionGraphicsItem* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QStyleOptionGraphicsItem", 0, 1, &(pyargs[0])))
        return -1;

    // Overloaded function decisor
    // 0: QStyleOptionGraphicsItem()
    // 1: QStyleOptionGraphicsItem(QStyleOptionGraphicsItem)
    // 2: QStyleOptionGraphicsItem(int)
    if (numArgs == 0) {
        overloadId = 0; // QStyleOptionGraphicsItem()
    } else if (numArgs == 1 && SbkNumber_Check(pyargs[0])) {
        overloadId = 2; // QStyleOptionGraphicsItem(int)
    } else if (numArgs == 1 && Shiboken::Converter< ::QStyleOptionGraphicsItem >::isConvertible(pyargs[0])) {
        overloadId = 1; // QStyleOptionGraphicsItem(QStyleOptionGraphicsItem)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStyleOptionGraphicsItem_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QStyleOptionGraphicsItem()
            {

                if(!PyErr_Occurred()) {
                    // QStyleOptionGraphicsItem()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QStyleOptionGraphicsItem();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // QStyleOptionGraphicsItem(QStyleOptionGraphicsItem)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QStyleOptionGraphicsItem cppArg0 = Shiboken::Converter<QStyleOptionGraphicsItem >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QStyleOptionGraphicsItem(QStyleOptionGraphicsItem)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QStyleOptionGraphicsItem(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // QStyleOptionGraphicsItem(int)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QStyleOptionGraphicsItem(int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QStyleOptionGraphicsItem(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QStyleOptionGraphicsItem >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QStyleOptionGraphicsItem_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QStyleOptionGraphicsItem_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtGui.QStyleOptionGraphicsItem", "int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QStyleOptionGraphicsItem", overloads);
        return -1;
}

static PyObject* Sbk_QStyleOptionGraphicsItemFunc_levelOfDetailFromTransform(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: levelOfDetailFromTransform(QTransform)
    if (Shiboken::Converter< ::QTransform >::isConvertible(arg)) {
        overloadId = 0; // levelOfDetailFromTransform(QTransform)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStyleOptionGraphicsItemFunc_levelOfDetailFromTransform_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QTransform cppArg0 = Shiboken::Converter<QTransform >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // levelOfDetailFromTransform(QTransform)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qreal cppResult = QStyleOptionGraphicsItem::levelOfDetailFromTransform(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< double >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QStyleOptionGraphicsItemFunc_levelOfDetailFromTransform_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTransform", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QStyleOptionGraphicsItem.levelOfDetailFromTransform", overloads);
        return 0;
}

static PyObject *Sbk_QStyleOptionGraphicsItem___copy__(PyObject *self)
{
        QStyleOptionGraphicsItem* cppSelf = 0;
        if (!Shiboken::Object::isValid(self))
            return 0;
        cppSelf = Shiboken::Converter<QStyleOptionGraphicsItem*>::toCpp(self);
        PyObject* pyResult = 0;
        QStyleOptionGraphicsItem* copy = new QStyleOptionGraphicsItem(*cppSelf);
        pyResult = Shiboken::Converter<QStyleOptionGraphicsItem*>::toPython(copy);
        Shiboken::Object::getOwnership(pyResult);

        if (PyErr_Occurred() || !pyResult) {
            Py_XDECREF(pyResult);
            return 0;
        }
        return pyResult;
}

static PyMethodDef Sbk_QStyleOptionGraphicsItem_methods[] = {
    {"levelOfDetailFromTransform", (PyCFunction)Sbk_QStyleOptionGraphicsItemFunc_levelOfDetailFromTransform, METH_O|METH_STATIC},

    {"__copy__", (PyCFunction)Sbk_QStyleOptionGraphicsItem___copy__, METH_NOARGS},
    {0} // Sentinel
};

static PyObject* Sbk_QStyleOptionGraphicsItem_get_exposedRect(PyObject* self, void*)
{
    PyObject* val =     Shiboken::createWrapper(&Shiboken::Converter< QStyleOptionGraphicsItem* >::toCpp(self)->exposedRect);
    Shiboken::Object::releaseOwnership(val);
    return val;

}
static int Sbk_QStyleOptionGraphicsItem_set_exposedRect(PyObject* self, PyObject* value, void*)
{
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'exposedRect' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter< ::QRectF >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'exposedRect', 'QRectF' or convertible type expected");
        return -1;
    }

    Shiboken::Converter< QStyleOptionGraphicsItem* >::toCpp(self)->exposedRect = Shiboken::Converter< ::QRectF >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QStyleOptionGraphicsItem_get_matrix(PyObject* self, void*)
{
    PyObject* val =     Shiboken::createWrapper(&Shiboken::Converter< QStyleOptionGraphicsItem* >::toCpp(self)->matrix);
    Shiboken::Object::releaseOwnership(val);
    return val;

}
static int Sbk_QStyleOptionGraphicsItem_set_matrix(PyObject* self, PyObject* value, void*)
{
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'matrix' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter< ::QMatrix >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'matrix', 'QMatrix' or convertible type expected");
        return -1;
    }

    Shiboken::Converter< QStyleOptionGraphicsItem* >::toCpp(self)->matrix = Shiboken::Converter< ::QMatrix >::toCpp(value);

    return 0;
}

static PyObject* Sbk_QStyleOptionGraphicsItem_get_levelOfDetail(PyObject* self, void*)
{
    PyObject* val = Shiboken::Converter< double >::toPython( Shiboken::Converter< QStyleOptionGraphicsItem* >::toCpp(self)->levelOfDetail);
    return val;

}
static int Sbk_QStyleOptionGraphicsItem_set_levelOfDetail(PyObject* self, PyObject* value, void*)
{
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'levelOfDetail' may not be deleted");
        return -1;
    }
    if (!SbkNumber_Check(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'levelOfDetail', 'qreal' or convertible type expected");
        return -1;
    }

    Shiboken::Converter< QStyleOptionGraphicsItem* >::toCpp(self)->levelOfDetail = Shiboken::Converter< double >::toCpp(value);

    return 0;
}

// Getters and Setters for QStyleOptionGraphicsItem
static PyGetSetDef Sbk_QStyleOptionGraphicsItem_getsetlist[] = {
    {const_cast<char*>("exposedRect"), Sbk_QStyleOptionGraphicsItem_get_exposedRect, Sbk_QStyleOptionGraphicsItem_set_exposedRect},
    {const_cast<char*>("matrix"), Sbk_QStyleOptionGraphicsItem_get_matrix, Sbk_QStyleOptionGraphicsItem_set_matrix},
    {const_cast<char*>("levelOfDetail"), Sbk_QStyleOptionGraphicsItem_get_levelOfDetail, Sbk_QStyleOptionGraphicsItem_set_levelOfDetail},
    {0}  // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QStyleOptionGraphicsItem_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QStyleOptionGraphicsItem",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QStyleOptionGraphicsItem_methods,
    /*tp_members*/          0,
    /*tp_getset*/           Sbk_QStyleOptionGraphicsItem_getsetlist,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QStyleOptionGraphicsItem_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QStyleOptionGraphicsItem(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONGRAPHICSITEM_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QStyleOptionGraphicsItem_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QStyleOptionGraphicsItem_Type);
    Sbk_QStyleOptionGraphicsItem_Type.super.ht_type.tp_base = SbkPySide_QtGuiTypes[SBK_QSTYLEOPTION_IDX];
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QStyleOptionGraphicsItem_Type, &Shiboken::callCppDestructor<QStyleOptionGraphicsItem >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QStyleOptionGraphicsItem_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QStyleOptionGraphicsItem_Type, "QStyleOptionGraphicsItem");
    PyModule_AddObject(module, "QStyleOptionGraphicsItem",
        ((PyObject*)&Sbk_QStyleOptionGraphicsItem_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: StyleOptionVersion
    PyTypeObject* SbkPySide_QtGui_QStyleOptionGraphicsItem_StyleOptionVersion = Shiboken::Enum::newType("StyleOptionVersion");
    SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONGRAPHICSITEM_STYLEOPTIONVERSION_IDX] = SbkPySide_QtGui_QStyleOptionGraphicsItem_StyleOptionVersion;
    if (PyType_Ready(SbkPySide_QtGui_QStyleOptionGraphicsItem_StyleOptionVersion) < 0)
        return;
    PyDict_SetItemString(Sbk_QStyleOptionGraphicsItem_Type.super.ht_type.tp_dict,
            "StyleOptionVersion",((PyObject*)SbkPySide_QtGui_QStyleOptionGraphicsItem_StyleOptionVersion));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyleOptionGraphicsItem_StyleOptionVersion,(long) QStyleOptionGraphicsItem::Version, "Version");
    PyDict_SetItemString(Sbk_QStyleOptionGraphicsItem_Type.super.ht_type.tp_dict,"Version", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyleOptionGraphicsItem_StyleOptionVersion->tp_dict,"Version", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QStyleOptionGraphicsItem::StyleOptionVersion");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::StyleOptionVersion");
    // end of enum StyleOptionVersion

    // init enum: StyleOptionType
    PyTypeObject* SbkPySide_QtGui_QStyleOptionGraphicsItem_StyleOptionType = Shiboken::Enum::newType("StyleOptionType");
    SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONGRAPHICSITEM_STYLEOPTIONTYPE_IDX] = SbkPySide_QtGui_QStyleOptionGraphicsItem_StyleOptionType;
    if (PyType_Ready(SbkPySide_QtGui_QStyleOptionGraphicsItem_StyleOptionType) < 0)
        return;
    PyDict_SetItemString(Sbk_QStyleOptionGraphicsItem_Type.super.ht_type.tp_dict,
            "StyleOptionType",((PyObject*)SbkPySide_QtGui_QStyleOptionGraphicsItem_StyleOptionType));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyleOptionGraphicsItem_StyleOptionType,(long) QStyleOptionGraphicsItem::Type, "Type");
    PyDict_SetItemString(Sbk_QStyleOptionGraphicsItem_Type.super.ht_type.tp_dict,"Type", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyleOptionGraphicsItem_StyleOptionType->tp_dict,"Type", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QStyleOptionGraphicsItem::StyleOptionType");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::StyleOptionType");
    // end of enum StyleOptionType


    Shiboken::TypeResolver::createValueTypeResolver<QStyleOptionGraphicsItem >("QStyleOptionGraphicsItem");
    Shiboken::TypeResolver::createObjectTypeResolver<QStyleOptionGraphicsItem >("QStyleOptionGraphicsItem*");
    Shiboken::TypeResolver::createValueTypeResolver<QStyleOptionGraphicsItem >(typeid(QStyleOptionGraphicsItem).name());
    PySide::initQtMetaType<QStyleOptionGraphicsItem >();
}

