/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qstyleoptionviewitemv2_wrapper.h"

// Extra includes
#include <qstyleoption.h>
#include <qwidget.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QStyleOptionViewItemV2_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QStyleOptionViewItemV2 >()))
        return -1;

    QStyleOptionViewItemV2* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QStyleOptionViewItemV2", 0, 1, &(pyargs[0])))
        return -1;

    // Overloaded function decisor
    // 0: QStyleOptionViewItemV2()
    // 1: QStyleOptionViewItemV2(QStyleOptionViewItem)
    // 2: QStyleOptionViewItemV2(QStyleOptionViewItemV2)
    // 3: QStyleOptionViewItemV2(int)
    if (numArgs == 0) {
        overloadId = 0; // QStyleOptionViewItemV2()
    } else if (numArgs == 1 && SbkNumber_Check(pyargs[0])) {
        overloadId = 3; // QStyleOptionViewItemV2(int)
    } else if (numArgs == 1 && Shiboken::Converter< ::QStyleOptionViewItem >::isConvertible(pyargs[0])) {
        overloadId = 1; // QStyleOptionViewItemV2(QStyleOptionViewItem)
    } else if (numArgs == 1 && Shiboken::Converter< ::QStyleOptionViewItemV2 >::isConvertible(pyargs[0])) {
        overloadId = 2; // QStyleOptionViewItemV2(QStyleOptionViewItemV2)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QStyleOptionViewItemV2_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QStyleOptionViewItemV2()
            {

                if(!PyErr_Occurred()) {
                    // QStyleOptionViewItemV2()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QStyleOptionViewItemV2();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // QStyleOptionViewItemV2(QStyleOptionViewItem)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QStyleOptionViewItem cppArg0 = Shiboken::Converter<QStyleOptionViewItem >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QStyleOptionViewItemV2(QStyleOptionViewItem)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QStyleOptionViewItemV2(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // QStyleOptionViewItemV2(QStyleOptionViewItemV2)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QStyleOptionViewItemV2 cppArg0 = Shiboken::Converter<QStyleOptionViewItemV2 >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QStyleOptionViewItemV2(QStyleOptionViewItemV2)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QStyleOptionViewItemV2(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 3: // QStyleOptionViewItemV2(int)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QStyleOptionViewItemV2(int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QStyleOptionViewItemV2(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QStyleOptionViewItemV2 >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QStyleOptionViewItemV2_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QStyleOptionViewItemV2_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtGui.QStyleOptionViewItem", "PySide.QtGui.QStyleOptionViewItemV2", "int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QStyleOptionViewItemV2", overloads);
        return -1;
}

static PyObject *Sbk_QStyleOptionViewItemV2___copy__(PyObject *self)
{
        QStyleOptionViewItemV2* cppSelf = 0;
        if (!Shiboken::Object::isValid(self))
            return 0;
        cppSelf = Shiboken::Converter<QStyleOptionViewItemV2*>::toCpp(self);
        PyObject* pyResult = 0;
        QStyleOptionViewItemV2* copy = new QStyleOptionViewItemV2(*cppSelf);
        pyResult = Shiboken::Converter<QStyleOptionViewItemV2*>::toPython(copy);
        Shiboken::Object::getOwnership(pyResult);

        if (PyErr_Occurred() || !pyResult) {
            Py_XDECREF(pyResult);
            return 0;
        }
        return pyResult;
}

static PyMethodDef Sbk_QStyleOptionViewItemV2_methods[] = {

    {"__copy__", (PyCFunction)Sbk_QStyleOptionViewItemV2___copy__, METH_NOARGS},
    {0} // Sentinel
};

static PyObject* Sbk_QStyleOptionViewItemV2_get_features(PyObject* self, void*)
{
    PyObject* val =     Shiboken::createWrapper(&Shiboken::Converter< QStyleOptionViewItemV2* >::toCpp(self)->features);
    Shiboken::Object::releaseOwnership(val);
    return val;

}
static int Sbk_QStyleOptionViewItemV2_set_features(PyObject* self, PyObject* value, void*)
{
    if (value == 0) {
        PyErr_SetString(PyExc_TypeError, "'features' may not be deleted");
        return -1;
    }
    if (!Shiboken::Converter< ::QFlags<QStyleOptionViewItemV2::ViewItemFeature> >::isConvertible(value)) {
        PyErr_SetString(PyExc_TypeError, "wrong type attributed to 'features', 'ViewItemFeatures' or convertible type expected");
        return -1;
    }

    Shiboken::Converter< QStyleOptionViewItemV2* >::toCpp(self)->features = Shiboken::Converter< ::QFlags<QStyleOptionViewItemV2::ViewItemFeature> >::toCpp(value);

    return 0;
}

// Getters and Setters for QStyleOptionViewItemV2
static PyGetSetDef Sbk_QStyleOptionViewItemV2_getsetlist[] = {
    {const_cast<char*>("features"), Sbk_QStyleOptionViewItemV2_get_features, Sbk_QStyleOptionViewItemV2_set_features},
    {0}  // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QStyleOptionViewItemV2_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QStyleOptionViewItemV2",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QStyleOptionViewItemV2_methods,
    /*tp_members*/          0,
    /*tp_getset*/           Sbk_QStyleOptionViewItemV2_getsetlist,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QStyleOptionViewItemV2_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern

PyObject* SbkPySide_QtGui_QStyleOptionViewItemV2_ViewItemFeature___and__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QStyleOptionViewItemV2::ViewItemFeatures >::toPython(
        Shiboken::Converter<QStyleOptionViewItemV2::ViewItemFeatures>::toCpp(self)
        & Shiboken::Converter< QStyleOptionViewItemV2::ViewItemFeatures >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtGui_QStyleOptionViewItemV2_ViewItemFeature___or__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QStyleOptionViewItemV2::ViewItemFeatures >::toPython(
        Shiboken::Converter<QStyleOptionViewItemV2::ViewItemFeatures>::toCpp(self)
        | Shiboken::Converter< QStyleOptionViewItemV2::ViewItemFeatures >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtGui_QStyleOptionViewItemV2_ViewItemFeature___xor__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QStyleOptionViewItemV2::ViewItemFeatures >::toPython(
        Shiboken::Converter<QStyleOptionViewItemV2::ViewItemFeatures>::toCpp(self)
        ^ Shiboken::Converter< QStyleOptionViewItemV2::ViewItemFeatures >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtGui_QStyleOptionViewItemV2_ViewItemFeature___invert__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QStyleOptionViewItemV2::ViewItemFeatures >::toPython(
        ~Shiboken::Converter<QStyleOptionViewItemV2::ViewItemFeatures >::toCpp(self)
    );
}


static PyNumberMethods SbkPySide_QtGui_QStyleOptionViewItemV2_ViewItemFeature_as_number = {
    /*nb_add*/                  0,
    /*nb_subtract*/             0,
    /*nb_multiply*/             0,
    /*nb_divide*/               0,
    /*nb_remainder*/            0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             0,
    /*nb_positive*/             0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              0,
    /*nb_invert*/               (unaryfunc)SbkPySide_QtGui_QStyleOptionViewItemV2_ViewItemFeature___invert__,
    /*nb_lshift*/               0,
    /*nb_rshift*/               0,
    /*nb_and*/                  (binaryfunc)SbkPySide_QtGui_QStyleOptionViewItemV2_ViewItemFeature___and__,
    /*nb_xor*/                  (binaryfunc)SbkPySide_QtGui_QStyleOptionViewItemV2_ViewItemFeature___xor__,
    /*nb_or*/                   (binaryfunc)SbkPySide_QtGui_QStyleOptionViewItemV2_ViewItemFeature___or__,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          0,
    /*nb_inplace_subtract*/     0,
    /*nb_inplace_multiply*/     0,
    /*nb_inplace_divide*/       0,
    /*nb_inplace_remainder*/    0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       0,
    /*nb_inplace_rshift*/       0,
    /*nb_inplace_and*/          0,
    /*nb_inplace_xor*/          0,
    /*nb_inplace_or*/           0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};


// forward declaration of new function
static PyTypeObject SbkPySide_QtGui_QStyleOptionViewItemV2_ViewItemFeatures_Type = {
    PyObject_HEAD_INIT(&PyType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "ViewItemFeatures",
    /*tp_basicsize*/        0,
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        &SbkPySide_QtGui_QStyleOptionViewItemV2_ViewItemFeature_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT | Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              PyInt_Type.tp_new,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};



void init_QStyleOptionViewItemV2(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONVIEWITEMV2_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QStyleOptionViewItemV2_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QStyleOptionViewItemV2_Type);
    Sbk_QStyleOptionViewItemV2_Type.super.ht_type.tp_base = SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONVIEWITEM_IDX];
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QStyleOptionViewItemV2_Type, &Shiboken::callCppDestructor<QStyleOptionViewItemV2 >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QStyleOptionViewItemV2_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QStyleOptionViewItemV2_Type, "QStyleOptionViewItemV2");
    PyModule_AddObject(module, "QStyleOptionViewItemV2",
        ((PyObject*)&Sbk_QStyleOptionViewItemV2_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: StyleOptionVersion
    PyTypeObject* SbkPySide_QtGui_QStyleOptionViewItemV2_StyleOptionVersion = Shiboken::Enum::newType("StyleOptionVersion");
    SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONVIEWITEMV2_STYLEOPTIONVERSION_IDX] = SbkPySide_QtGui_QStyleOptionViewItemV2_StyleOptionVersion;
    if (PyType_Ready(SbkPySide_QtGui_QStyleOptionViewItemV2_StyleOptionVersion) < 0)
        return;
    PyDict_SetItemString(Sbk_QStyleOptionViewItemV2_Type.super.ht_type.tp_dict,
            "StyleOptionVersion",((PyObject*)SbkPySide_QtGui_QStyleOptionViewItemV2_StyleOptionVersion));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyleOptionViewItemV2_StyleOptionVersion,(long) QStyleOptionViewItemV2::Version, "Version");
    PyDict_SetItemString(Sbk_QStyleOptionViewItemV2_Type.super.ht_type.tp_dict,"Version", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyleOptionViewItemV2_StyleOptionVersion->tp_dict,"Version", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QStyleOptionViewItemV2::StyleOptionVersion");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::StyleOptionVersion");
    // end of enum StyleOptionVersion

    // init enum: ViewItemFeature
    PyTypeObject* SbkPySide_QtGui_QStyleOptionViewItemV2_ViewItemFeature = Shiboken::Enum::newType("ViewItemFeature");
    SbkPySide_QtGui_QStyleOptionViewItemV2_ViewItemFeature->tp_as_number = &SbkPySide_QtGui_QStyleOptionViewItemV2_ViewItemFeature_as_number;
    SbkPySide_QtGuiTypes[SBK_QSTYLEOPTIONVIEWITEMV2_VIEWITEMFEATURE_IDX] = SbkPySide_QtGui_QStyleOptionViewItemV2_ViewItemFeature;
    if (PyType_Ready(SbkPySide_QtGui_QStyleOptionViewItemV2_ViewItemFeature) < 0)
        return;
    PyDict_SetItemString(Sbk_QStyleOptionViewItemV2_Type.super.ht_type.tp_dict,
            "ViewItemFeature",((PyObject*)SbkPySide_QtGui_QStyleOptionViewItemV2_ViewItemFeature));

    // init flags class: QFlags<QStyleOptionViewItemV2::ViewItemFeature>
    SbkPySide_QtGuiTypes[SBK_QFLAGS_QSTYLEOPTIONVIEWITEMV2_VIEWITEMFEATURE__IDX] = &SbkPySide_QtGui_QStyleOptionViewItemV2_ViewItemFeatures_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QStyleOptionViewItemV2_ViewItemFeatures_Type) < 0)
        return;
    PyDict_SetItemString(Sbk_QStyleOptionViewItemV2_Type.super.ht_type.tp_dict,
            "ViewItemFeatures",((PyObject*)&SbkPySide_QtGui_QStyleOptionViewItemV2_ViewItemFeatures_Type));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyleOptionViewItemV2_ViewItemFeature,(long) QStyleOptionViewItemV2::None, "None");
    PyDict_SetItemString(Sbk_QStyleOptionViewItemV2_Type.super.ht_type.tp_dict,"None", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyleOptionViewItemV2_ViewItemFeature->tp_dict,"None", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyleOptionViewItemV2_ViewItemFeature,(long) QStyleOptionViewItemV2::WrapText, "WrapText");
    PyDict_SetItemString(Sbk_QStyleOptionViewItemV2_Type.super.ht_type.tp_dict,"WrapText", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyleOptionViewItemV2_ViewItemFeature->tp_dict,"WrapText", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyleOptionViewItemV2_ViewItemFeature,(long) QStyleOptionViewItemV2::Alternate, "Alternate");
    PyDict_SetItemString(Sbk_QStyleOptionViewItemV2_Type.super.ht_type.tp_dict,"Alternate", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyleOptionViewItemV2_ViewItemFeature->tp_dict,"Alternate", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyleOptionViewItemV2_ViewItemFeature,(long) QStyleOptionViewItemV2::HasCheckIndicator, "HasCheckIndicator");
    PyDict_SetItemString(Sbk_QStyleOptionViewItemV2_Type.super.ht_type.tp_dict,"HasCheckIndicator", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyleOptionViewItemV2_ViewItemFeature->tp_dict,"HasCheckIndicator", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyleOptionViewItemV2_ViewItemFeature,(long) QStyleOptionViewItemV2::HasDisplay, "HasDisplay");
    PyDict_SetItemString(Sbk_QStyleOptionViewItemV2_Type.super.ht_type.tp_dict,"HasDisplay", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyleOptionViewItemV2_ViewItemFeature->tp_dict,"HasDisplay", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QStyleOptionViewItemV2_ViewItemFeature,(long) QStyleOptionViewItemV2::HasDecoration, "HasDecoration");
    PyDict_SetItemString(Sbk_QStyleOptionViewItemV2_Type.super.ht_type.tp_dict,"HasDecoration", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QStyleOptionViewItemV2_ViewItemFeature->tp_dict,"HasDecoration", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QStyleOptionViewItemV2::ViewItemFeature");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::ViewItemFeature");
    // end of enum ViewItemFeature


    Shiboken::TypeResolver::createValueTypeResolver<QStyleOptionViewItemV2 >("QStyleOptionViewItemV2");
    Shiboken::TypeResolver::createObjectTypeResolver<QStyleOptionViewItemV2 >("QStyleOptionViewItemV2*");
    Shiboken::TypeResolver::createValueTypeResolver<QStyleOptionViewItemV2 >(typeid(QStyleOptionViewItemV2).name());
    PySide::initQtMetaType<QStyleOptionViewItemV2 >();
}

