/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qtextblockformat_wrapper.h"

// Extra includes
#include <QList>
#include <QMap>
#include <QVector>
#include <qbrush.h>
#include <qcolor.h>
#include <qpen.h>
#include <qtextformat.h>
#include <qtextoption.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QTextBlockFormat_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QTextBlockFormat >()))
        return -1;

    QTextBlockFormat* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QTextBlockFormat", 0, 1, &(pyargs[0])))
        return -1;

    // Overloaded function decisor
    // 0: QTextBlockFormat()
    // 1: QTextBlockFormat(QTextBlockFormat)
    // 2: QTextBlockFormat(QTextFormat)
    if (numArgs == 0) {
        overloadId = 0; // QTextBlockFormat()
    } else if (numArgs == 1 && Shiboken::Converter< ::QTextFormat >::isConvertible(pyargs[0])) {
        overloadId = 2; // QTextBlockFormat(QTextFormat)
    } else if (numArgs == 1 && Shiboken::Converter< ::QTextBlockFormat >::isConvertible(pyargs[0])) {
        overloadId = 1; // QTextBlockFormat(QTextBlockFormat)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextBlockFormat_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QTextBlockFormat()
            {

                if(!PyErr_Occurred()) {
                    // QTextBlockFormat()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QTextBlockFormat();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // QTextBlockFormat(QTextBlockFormat)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QTextBlockFormat cppArg0 = Shiboken::Converter<QTextBlockFormat >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QTextBlockFormat(QTextBlockFormat)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QTextBlockFormat(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // QTextBlockFormat(QTextFormat)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QTextFormat cppArg0 = Shiboken::Converter<QTextFormat >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QTextBlockFormat(QTextFormat)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QTextBlockFormat(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QTextBlockFormat >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QTextBlockFormat_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QTextBlockFormat_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtGui.QTextBlockFormat", "PySide.QtGui.QTextFormat", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTextBlockFormat", overloads);
        return -1;
}

static PyObject* Sbk_QTextBlockFormatFunc_alignment(PyObject* self)
{
    QTextBlockFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextBlockFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // alignment()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QFlags<Qt::AlignmentFlag> cppResult = cppSelf->alignment();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QFlags<Qt::AlignmentFlag> >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextBlockFormatFunc_bottomMargin(PyObject* self)
{
    QTextBlockFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextBlockFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // bottomMargin()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qreal cppResult = cppSelf->bottomMargin();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< double >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextBlockFormatFunc_indent(PyObject* self)
{
    QTextBlockFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextBlockFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // indent()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->indent();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextBlockFormatFunc_isValid(PyObject* self)
{
    QTextBlockFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextBlockFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isValid()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->isValid();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextBlockFormatFunc_leftMargin(PyObject* self)
{
    QTextBlockFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextBlockFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // leftMargin()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qreal cppResult = cppSelf->leftMargin();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< double >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextBlockFormatFunc_nonBreakableLines(PyObject* self)
{
    QTextBlockFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextBlockFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // nonBreakableLines()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->nonBreakableLines();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextBlockFormatFunc_pageBreakPolicy(PyObject* self)
{
    QTextBlockFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextBlockFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // pageBreakPolicy()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QFlags<QTextFormat::PageBreakFlag> cppResult = cppSelf->pageBreakPolicy();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QFlags<QTextFormat::PageBreakFlag> >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextBlockFormatFunc_rightMargin(PyObject* self)
{
    QTextBlockFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextBlockFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // rightMargin()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qreal cppResult = cppSelf->rightMargin();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< double >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextBlockFormatFunc_setAlignment(PyObject* self, PyObject* arg)
{
    QTextBlockFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextBlockFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setAlignment(QFlags<Qt::AlignmentFlag>)
    if (Shiboken::Converter< ::QFlags<Qt::AlignmentFlag> >::isConvertible(arg)) {
        overloadId = 0; // setAlignment(QFlags<Qt::AlignmentFlag>)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextBlockFormatFunc_setAlignment_TypeError;

    // Call function/method
    {
        {
            QFlags<Qt::AlignmentFlag> cppArg0 = Shiboken::Converter<QFlags<Qt::AlignmentFlag> >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setAlignment(QFlags<Qt::AlignmentFlag>)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setAlignment(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextBlockFormatFunc_setAlignment_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.Alignment", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextBlockFormat.setAlignment", overloads);
        return 0;
}

static PyObject* Sbk_QTextBlockFormatFunc_setBottomMargin(PyObject* self, PyObject* arg)
{
    QTextBlockFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextBlockFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setBottomMargin(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setBottomMargin(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextBlockFormatFunc_setBottomMargin_TypeError;

    // Call function/method
    {
        {
            qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setBottomMargin(qreal)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setBottomMargin(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextBlockFormatFunc_setBottomMargin_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextBlockFormat.setBottomMargin", overloads);
        return 0;
}

static PyObject* Sbk_QTextBlockFormatFunc_setIndent(PyObject* self, PyObject* arg)
{
    QTextBlockFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextBlockFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setIndent(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setIndent(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextBlockFormatFunc_setIndent_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setIndent(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setIndent(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextBlockFormatFunc_setIndent_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextBlockFormat.setIndent", overloads);
        return 0;
}

static PyObject* Sbk_QTextBlockFormatFunc_setLeftMargin(PyObject* self, PyObject* arg)
{
    QTextBlockFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextBlockFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setLeftMargin(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setLeftMargin(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextBlockFormatFunc_setLeftMargin_TypeError;

    // Call function/method
    {
        {
            qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setLeftMargin(qreal)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setLeftMargin(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextBlockFormatFunc_setLeftMargin_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextBlockFormat.setLeftMargin", overloads);
        return 0;
}

static PyObject* Sbk_QTextBlockFormatFunc_setNonBreakableLines(PyObject* self, PyObject* arg)
{
    QTextBlockFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextBlockFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setNonBreakableLines(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setNonBreakableLines(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextBlockFormatFunc_setNonBreakableLines_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setNonBreakableLines(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setNonBreakableLines(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextBlockFormatFunc_setNonBreakableLines_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextBlockFormat.setNonBreakableLines", overloads);
        return 0;
}

static PyObject* Sbk_QTextBlockFormatFunc_setPageBreakPolicy(PyObject* self, PyObject* arg)
{
    QTextBlockFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextBlockFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setPageBreakPolicy(QFlags<QTextFormat::PageBreakFlag>)
    if (Shiboken::Converter< ::QFlags<QTextFormat::PageBreakFlag> >::isConvertible(arg)) {
        overloadId = 0; // setPageBreakPolicy(QFlags<QTextFormat::PageBreakFlag>)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextBlockFormatFunc_setPageBreakPolicy_TypeError;

    // Call function/method
    {
        {
            QFlags<QTextFormat::PageBreakFlag> cppArg0 = Shiboken::Converter<QFlags<QTextFormat::PageBreakFlag> >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setPageBreakPolicy(QFlags<QTextFormat::PageBreakFlag>)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setPageBreakPolicy(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextBlockFormatFunc_setPageBreakPolicy_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTextFormat.PageBreakFlags", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextBlockFormat.setPageBreakPolicy", overloads);
        return 0;
}

static PyObject* Sbk_QTextBlockFormatFunc_setRightMargin(PyObject* self, PyObject* arg)
{
    QTextBlockFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextBlockFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setRightMargin(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setRightMargin(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextBlockFormatFunc_setRightMargin_TypeError;

    // Call function/method
    {
        {
            qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setRightMargin(qreal)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setRightMargin(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextBlockFormatFunc_setRightMargin_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextBlockFormat.setRightMargin", overloads);
        return 0;
}

static PyObject* Sbk_QTextBlockFormatFunc_setTabPositions(PyObject* self, PyObject* arg)
{
    QTextBlockFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextBlockFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setTabPositions(QList<QTextOption::Tab>)
    if (Shiboken::Converter< ::QList<QTextOption::Tab > >::isConvertible(arg)) {
        overloadId = 0; // setTabPositions(QList<QTextOption::Tab>)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextBlockFormatFunc_setTabPositions_TypeError;

    // Call function/method
    {
        {
            QList<QTextOption::Tab > cppArg0 = Shiboken::Converter<QList<QTextOption::Tab > >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setTabPositions(QList<QTextOption::Tab>)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setTabPositions(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextBlockFormatFunc_setTabPositions_TypeError:
        const char* overloads[] = {"list", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextBlockFormat.setTabPositions", overloads);
        return 0;
}

static PyObject* Sbk_QTextBlockFormatFunc_setTextIndent(PyObject* self, PyObject* arg)
{
    QTextBlockFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextBlockFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setTextIndent(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setTextIndent(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextBlockFormatFunc_setTextIndent_TypeError;

    // Call function/method
    {
        {
            qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setTextIndent(qreal)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setTextIndent(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextBlockFormatFunc_setTextIndent_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextBlockFormat.setTextIndent", overloads);
        return 0;
}

static PyObject* Sbk_QTextBlockFormatFunc_setTopMargin(PyObject* self, PyObject* arg)
{
    QTextBlockFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextBlockFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setTopMargin(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setTopMargin(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextBlockFormatFunc_setTopMargin_TypeError;

    // Call function/method
    {
        {
            qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setTopMargin(qreal)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setTopMargin(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextBlockFormatFunc_setTopMargin_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextBlockFormat.setTopMargin", overloads);
        return 0;
}

static PyObject* Sbk_QTextBlockFormatFunc_tabPositions(PyObject* self)
{
    QTextBlockFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextBlockFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // tabPositions()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QList<QTextOption::Tab > cppResult = cppSelf->tabPositions();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QList<QTextOption::Tab > >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextBlockFormatFunc_textIndent(PyObject* self)
{
    QTextBlockFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextBlockFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // textIndent()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qreal cppResult = cppSelf->textIndent();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< double >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextBlockFormatFunc_topMargin(PyObject* self)
{
    QTextBlockFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextBlockFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // topMargin()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qreal cppResult = cppSelf->topMargin();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< double >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject *Sbk_QTextBlockFormat___copy__(PyObject *self)
{
        QTextBlockFormat* cppSelf = 0;
        if (!Shiboken::Object::isValid(self))
            return 0;
        cppSelf = Shiboken::Converter<QTextBlockFormat*>::toCpp(self);
        PyObject* pyResult = 0;
        QTextBlockFormat* copy = new QTextBlockFormat(*cppSelf);
        pyResult = Shiboken::Converter<QTextBlockFormat*>::toPython(copy);
        Shiboken::Object::getOwnership(pyResult);

        if (PyErr_Occurred() || !pyResult) {
            Py_XDECREF(pyResult);
            return 0;
        }
        return pyResult;
}

static PyMethodDef Sbk_QTextBlockFormat_methods[] = {
    {"alignment", (PyCFunction)Sbk_QTextBlockFormatFunc_alignment, METH_NOARGS},
    {"bottomMargin", (PyCFunction)Sbk_QTextBlockFormatFunc_bottomMargin, METH_NOARGS},
    {"indent", (PyCFunction)Sbk_QTextBlockFormatFunc_indent, METH_NOARGS},
    {"isValid", (PyCFunction)Sbk_QTextBlockFormatFunc_isValid, METH_NOARGS},
    {"leftMargin", (PyCFunction)Sbk_QTextBlockFormatFunc_leftMargin, METH_NOARGS},
    {"nonBreakableLines", (PyCFunction)Sbk_QTextBlockFormatFunc_nonBreakableLines, METH_NOARGS},
    {"pageBreakPolicy", (PyCFunction)Sbk_QTextBlockFormatFunc_pageBreakPolicy, METH_NOARGS},
    {"rightMargin", (PyCFunction)Sbk_QTextBlockFormatFunc_rightMargin, METH_NOARGS},
    {"setAlignment", (PyCFunction)Sbk_QTextBlockFormatFunc_setAlignment, METH_O},
    {"setBottomMargin", (PyCFunction)Sbk_QTextBlockFormatFunc_setBottomMargin, METH_O},
    {"setIndent", (PyCFunction)Sbk_QTextBlockFormatFunc_setIndent, METH_O},
    {"setLeftMargin", (PyCFunction)Sbk_QTextBlockFormatFunc_setLeftMargin, METH_O},
    {"setNonBreakableLines", (PyCFunction)Sbk_QTextBlockFormatFunc_setNonBreakableLines, METH_O},
    {"setPageBreakPolicy", (PyCFunction)Sbk_QTextBlockFormatFunc_setPageBreakPolicy, METH_O},
    {"setRightMargin", (PyCFunction)Sbk_QTextBlockFormatFunc_setRightMargin, METH_O},
    {"setTabPositions", (PyCFunction)Sbk_QTextBlockFormatFunc_setTabPositions, METH_O},
    {"setTextIndent", (PyCFunction)Sbk_QTextBlockFormatFunc_setTextIndent, METH_O},
    {"setTopMargin", (PyCFunction)Sbk_QTextBlockFormatFunc_setTopMargin, METH_O},
    {"tabPositions", (PyCFunction)Sbk_QTextBlockFormatFunc_tabPositions, METH_NOARGS},
    {"textIndent", (PyCFunction)Sbk_QTextBlockFormatFunc_textIndent, METH_NOARGS},
    {"topMargin", (PyCFunction)Sbk_QTextBlockFormatFunc_topMargin, METH_NOARGS},

    {"__copy__", (PyCFunction)Sbk_QTextBlockFormat___copy__, METH_NOARGS},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QTextBlockFormat_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QTextBlockFormat",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QTextBlockFormat_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QTextBlockFormat_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QTextBlockFormat(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QTEXTBLOCKFORMAT_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QTextBlockFormat_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QTextBlockFormat_Type);
    Sbk_QTextBlockFormat_Type.super.ht_type.tp_base = SbkPySide_QtGuiTypes[SBK_QTEXTFORMAT_IDX];
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QTextBlockFormat_Type, &Shiboken::callCppDestructor<QTextBlockFormat >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QTextBlockFormat_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QTextBlockFormat_Type, "QTextBlockFormat");
    PyModule_AddObject(module, "QTextBlockFormat",
        ((PyObject*)&Sbk_QTextBlockFormat_Type));


    Shiboken::TypeResolver::createValueTypeResolver<QTextBlockFormat >("QTextBlockFormat");
    Shiboken::TypeResolver::createObjectTypeResolver<QTextBlockFormat >("QTextBlockFormat*");
    Shiboken::TypeResolver::createValueTypeResolver<QTextBlockFormat >(typeid(QTextBlockFormat).name());
    PySide::initQtMetaType<QTextBlockFormat >();
}

