/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qtextformat_wrapper.h"

// Extra includes
#include <QMap>
#include <QVector>
#include <qbrush.h>
#include <qcolor.h>
#include <qdatastream.h>
#include <qpen.h>
#include <qtextformat.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QTextFormat_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QTextFormat >()))
        return -1;

    QTextFormat* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QTextFormat", 0, 1, &(pyargs[0])))
        return -1;

    // Overloaded function decisor
    // 0: QTextFormat()
    // 1: QTextFormat(QTextFormat)
    // 2: QTextFormat(int)
    if (numArgs == 0) {
        overloadId = 0; // QTextFormat()
    } else if (numArgs == 1 && SbkNumber_Check(pyargs[0])) {
        overloadId = 2; // QTextFormat(int)
    } else if (numArgs == 1 && Shiboken::Converter< ::QTextFormat >::isConvertible(pyargs[0])) {
        overloadId = 1; // QTextFormat(QTextFormat)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextFormat_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QTextFormat()
            {

                if(!PyErr_Occurred()) {
                    // QTextFormat()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QTextFormat();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // QTextFormat(QTextFormat)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QTextFormat cppArg0 = Shiboken::Converter<QTextFormat >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QTextFormat(QTextFormat)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QTextFormat(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // QTextFormat(int)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QTextFormat(int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QTextFormat(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QTextFormat >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QTextFormat_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QTextFormat_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtGui.QTextFormat", "int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTextFormat", overloads);
        return -1;
}

static PyObject* Sbk_QTextFormatFunc_background(PyObject* self)
{
    QTextFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // background()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QBrush cppResult = cppSelf->background();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QBrush >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextFormatFunc_boolProperty(PyObject* self, PyObject* arg)
{
    QTextFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextFormat* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: boolProperty(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // boolProperty(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextFormatFunc_boolProperty_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // boolProperty(int)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->boolProperty(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTextFormatFunc_boolProperty_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextFormat.boolProperty", overloads);
        return 0;
}

static PyObject* Sbk_QTextFormatFunc_brushProperty(PyObject* self, PyObject* arg)
{
    QTextFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextFormat* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: brushProperty(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // brushProperty(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextFormatFunc_brushProperty_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // brushProperty(int)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QBrush cppResult = cppSelf->brushProperty(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QBrush >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTextFormatFunc_brushProperty_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextFormat.brushProperty", overloads);
        return 0;
}

static PyObject* Sbk_QTextFormatFunc_clearBackground(PyObject* self)
{
    QTextFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextFormat* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // clearBackground()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->clearBackground();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QTextFormatFunc_clearForeground(PyObject* self)
{
    QTextFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextFormat* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // clearForeground()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->clearForeground();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QTextFormatFunc_clearProperty(PyObject* self, PyObject* arg)
{
    QTextFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: clearProperty(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // clearProperty(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextFormatFunc_clearProperty_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // clearProperty(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->clearProperty(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextFormatFunc_clearProperty_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextFormat.clearProperty", overloads);
        return 0;
}

static PyObject* Sbk_QTextFormatFunc_colorProperty(PyObject* self, PyObject* arg)
{
    QTextFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextFormat* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: colorProperty(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // colorProperty(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextFormatFunc_colorProperty_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // colorProperty(int)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QColor cppResult = cppSelf->colorProperty(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QColor >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTextFormatFunc_colorProperty_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextFormat.colorProperty", overloads);
        return 0;
}

static PyObject* Sbk_QTextFormatFunc_doubleProperty(PyObject* self, PyObject* arg)
{
    QTextFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextFormat* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: doubleProperty(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // doubleProperty(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextFormatFunc_doubleProperty_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // doubleProperty(int)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qreal cppResult = cppSelf->doubleProperty(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< double >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTextFormatFunc_doubleProperty_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextFormat.doubleProperty", overloads);
        return 0;
}

static PyObject* Sbk_QTextFormatFunc_foreground(PyObject* self)
{
    QTextFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // foreground()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QBrush cppResult = cppSelf->foreground();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QBrush >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextFormatFunc_hasProperty(PyObject* self, PyObject* arg)
{
    QTextFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextFormat* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: hasProperty(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // hasProperty(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextFormatFunc_hasProperty_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // hasProperty(int)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->hasProperty(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTextFormatFunc_hasProperty_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextFormat.hasProperty", overloads);
        return 0;
}

static PyObject* Sbk_QTextFormatFunc_intProperty(PyObject* self, PyObject* arg)
{
    QTextFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextFormat* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: intProperty(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // intProperty(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextFormatFunc_intProperty_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // intProperty(int)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->intProperty(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTextFormatFunc_intProperty_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextFormat.intProperty", overloads);
        return 0;
}

static PyObject* Sbk_QTextFormatFunc_isBlockFormat(PyObject* self)
{
    QTextFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isBlockFormat()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->isBlockFormat();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextFormatFunc_isCharFormat(PyObject* self)
{
    QTextFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isCharFormat()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->isCharFormat();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextFormatFunc_isFrameFormat(PyObject* self)
{
    QTextFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isFrameFormat()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->isFrameFormat();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextFormatFunc_isImageFormat(PyObject* self)
{
    QTextFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isImageFormat()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->isImageFormat();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextFormatFunc_isListFormat(PyObject* self)
{
    QTextFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isListFormat()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->isListFormat();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextFormatFunc_isTableCellFormat(PyObject* self)
{
    QTextFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isTableCellFormat()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->isTableCellFormat();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextFormatFunc_isTableFormat(PyObject* self)
{
    QTextFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isTableFormat()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->isTableFormat();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextFormatFunc_isValid(PyObject* self)
{
    QTextFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isValid()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->isValid();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextFormatFunc_layoutDirection(PyObject* self)
{
    QTextFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // layoutDirection()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                Qt::LayoutDirection cppResult = cppSelf->layoutDirection();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::Qt::LayoutDirection >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextFormatFunc_lengthProperty(PyObject* self, PyObject* arg)
{
    QTextFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextFormat* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: lengthProperty(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // lengthProperty(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextFormatFunc_lengthProperty_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // lengthProperty(int)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QTextLength cppResult = cppSelf->lengthProperty(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QTextLength >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTextFormatFunc_lengthProperty_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextFormat.lengthProperty", overloads);
        return 0;
}

static PyObject* Sbk_QTextFormatFunc_lengthVectorProperty(PyObject* self, PyObject* arg)
{
    QTextFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextFormat* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: lengthVectorProperty(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // lengthVectorProperty(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextFormatFunc_lengthVectorProperty_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // lengthVectorProperty(int)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QVector<QTextLength > cppResult = cppSelf->lengthVectorProperty(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QVector<QTextLength > >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTextFormatFunc_lengthVectorProperty_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextFormat.lengthVectorProperty", overloads);
        return 0;
}

static PyObject* Sbk_QTextFormatFunc_merge(PyObject* self, PyObject* arg)
{
    QTextFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: merge(QTextFormat)
    if (Shiboken::Converter< ::QTextFormat >::isConvertible(arg)) {
        overloadId = 0; // merge(QTextFormat)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextFormatFunc_merge_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QTextFormat cppArg0 = Shiboken::Converter<QTextFormat >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // merge(QTextFormat)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->merge(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextFormatFunc_merge_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTextFormat", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextFormat.merge", overloads);
        return 0;
}

static PyObject* Sbk_QTextFormatFunc_objectIndex(PyObject* self)
{
    QTextFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // objectIndex()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->objectIndex();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextFormatFunc_objectType(PyObject* self)
{
    QTextFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // objectType()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->objectType();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextFormatFunc_penProperty(PyObject* self, PyObject* arg)
{
    QTextFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextFormat* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: penProperty(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // penProperty(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextFormatFunc_penProperty_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // penProperty(int)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPen cppResult = cppSelf->penProperty(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPen >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTextFormatFunc_penProperty_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextFormat.penProperty", overloads);
        return 0;
}

static PyObject* Sbk_QTextFormatFunc_properties(PyObject* self)
{
    QTextFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // properties()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QMap<int, QVariant > cppResult = cppSelf->properties();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QMap<int, QVariant > >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextFormatFunc_property(PyObject* self, PyObject* arg)
{
    QTextFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextFormat* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: property(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // property(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextFormatFunc_property_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // property(int)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QVariant cppResult = cppSelf->property(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QVariant >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTextFormatFunc_property_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextFormat.property", overloads);
        return 0;
}

static PyObject* Sbk_QTextFormatFunc_propertyCount(PyObject* self)
{
    QTextFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // propertyCount()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->propertyCount();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextFormatFunc_setBackground(PyObject* self, PyObject* arg)
{
    QTextFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setBackground(QBrush)
    if (Shiboken::Converter< ::QBrush >::isConvertible(arg)) {
        overloadId = 0; // setBackground(QBrush)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextFormatFunc_setBackground_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QBrush cppArg0 = Shiboken::Converter<QBrush >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setBackground(QBrush)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setBackground(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextFormatFunc_setBackground_TypeError:
        const char* overloads[] = {"PySide.QtGui.QBrush", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextFormat.setBackground", overloads);
        return 0;
}

static PyObject* Sbk_QTextFormatFunc_setForeground(PyObject* self, PyObject* arg)
{
    QTextFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setForeground(QBrush)
    if (Shiboken::Converter< ::QBrush >::isConvertible(arg)) {
        overloadId = 0; // setForeground(QBrush)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextFormatFunc_setForeground_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QBrush cppArg0 = Shiboken::Converter<QBrush >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setForeground(QBrush)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setForeground(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextFormatFunc_setForeground_TypeError:
        const char* overloads[] = {"PySide.QtGui.QBrush", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextFormat.setForeground", overloads);
        return 0;
}

static PyObject* Sbk_QTextFormatFunc_setLayoutDirection(PyObject* self, PyObject* arg)
{
    QTextFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setLayoutDirection(Qt::LayoutDirection)
    if (Shiboken::Converter< ::Qt::LayoutDirection >::isConvertible(arg)) {
        overloadId = 0; // setLayoutDirection(Qt::LayoutDirection)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextFormatFunc_setLayoutDirection_TypeError;

    // Call function/method
    {
        {
            Qt::LayoutDirection cppArg0 = Shiboken::Converter<Qt::LayoutDirection >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setLayoutDirection(Qt::LayoutDirection)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setLayoutDirection(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextFormatFunc_setLayoutDirection_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.LayoutDirection", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextFormat.setLayoutDirection", overloads);
        return 0;
}

static PyObject* Sbk_QTextFormatFunc_setObjectIndex(PyObject* self, PyObject* arg)
{
    QTextFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setObjectIndex(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setObjectIndex(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextFormatFunc_setObjectIndex_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setObjectIndex(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setObjectIndex(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextFormatFunc_setObjectIndex_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextFormat.setObjectIndex", overloads);
        return 0;
}

static PyObject* Sbk_QTextFormatFunc_setObjectType(PyObject* self, PyObject* arg)
{
    QTextFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setObjectType(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setObjectType(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextFormatFunc_setObjectType_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setObjectType(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setObjectType(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextFormatFunc_setObjectType_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextFormat.setObjectType", overloads);
        return 0;
}

static PyObject* Sbk_QTextFormatFunc_setProperty(PyObject* self, PyObject* args)
{
    QTextFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextFormat* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setProperty", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setProperty(int,QVariant)
    // 1: setProperty(int,QVector<QTextLength>)
    if (SbkNumber_Check(pyargs[0])) {
        if (numArgs == 2 && Shiboken::Converter< ::QVector<QTextLength > >::isConvertible(pyargs[1])) {
            overloadId = 1; // setProperty(int,QVector<QTextLength>)
        } else if (numArgs == 2 && Shiboken::Converter< QVariant >::isConvertible(pyargs[1])) {
            overloadId = 0; // setProperty(int,QVariant)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextFormatFunc_setProperty_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setProperty(int,QVariant)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                QVariant cppArg1 = Shiboken::Converter<QVariant >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // setProperty(int,QVariant)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setProperty(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // setProperty(int,QVector<QTextLength>)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                QVector<QTextLength > cppArg1 = Shiboken::Converter<QVector<QTextLength > >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // setProperty(int,QVector<QTextLength>)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setProperty(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTextFormatFunc_setProperty_TypeError:
        const char* overloads[] = {"int, QVariant", "int, list", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTextFormat.setProperty", overloads);
        return 0;
}

static PyObject* Sbk_QTextFormatFunc_stringProperty(PyObject* self, PyObject* arg)
{
    QTextFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextFormat* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: stringProperty(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // stringProperty(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextFormatFunc_stringProperty_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // stringProperty(int)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = cppSelf->stringProperty(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTextFormatFunc_stringProperty_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextFormat.stringProperty", overloads);
        return 0;
}

static PyObject* Sbk_QTextFormatFunc_toBlockFormat(PyObject* self)
{
    QTextFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // toBlockFormat()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QTextBlockFormat cppResult = cppSelf->toBlockFormat();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QTextBlockFormat >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextFormatFunc_toCharFormat(PyObject* self)
{
    QTextFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // toCharFormat()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QTextCharFormat cppResult = cppSelf->toCharFormat();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QTextCharFormat >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextFormatFunc_toFrameFormat(PyObject* self)
{
    QTextFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // toFrameFormat()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QTextFrameFormat cppResult = cppSelf->toFrameFormat();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QTextFrameFormat >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextFormatFunc_toImageFormat(PyObject* self)
{
    QTextFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // toImageFormat()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QTextImageFormat cppResult = cppSelf->toImageFormat();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QTextImageFormat >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextFormatFunc_toListFormat(PyObject* self)
{
    QTextFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // toListFormat()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QTextListFormat cppResult = cppSelf->toListFormat();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QTextListFormat >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextFormatFunc_toTableCellFormat(PyObject* self)
{
    QTextFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // toTableCellFormat()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QTextTableCellFormat cppResult = cppSelf->toTableCellFormat();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QTextTableCellFormat >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextFormatFunc_toTableFormat(PyObject* self)
{
    QTextFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // toTableFormat()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QTextTableFormat cppResult = cppSelf->toTableFormat();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QTextTableFormat >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTextFormatFunc_type(PyObject* self)
{
    QTextFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // type()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->type();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject *Sbk_QTextFormat___copy__(PyObject *self)
{
        QTextFormat* cppSelf = 0;
        if (!Shiboken::Object::isValid(self))
            return 0;
        cppSelf = Shiboken::Converter<QTextFormat*>::toCpp(self);
        PyObject* pyResult = 0;
        QTextFormat* copy = new QTextFormat(*cppSelf);
        pyResult = Shiboken::Converter<QTextFormat*>::toPython(copy);
        Shiboken::Object::getOwnership(pyResult);

        if (PyErr_Occurred() || !pyResult) {
            Py_XDECREF(pyResult);
            return 0;
        }
        return pyResult;
}

static PyMethodDef Sbk_QTextFormat_methods[] = {
    {"background", (PyCFunction)Sbk_QTextFormatFunc_background, METH_NOARGS},
    {"boolProperty", (PyCFunction)Sbk_QTextFormatFunc_boolProperty, METH_O},
    {"brushProperty", (PyCFunction)Sbk_QTextFormatFunc_brushProperty, METH_O},
    {"clearBackground", (PyCFunction)Sbk_QTextFormatFunc_clearBackground, METH_NOARGS},
    {"clearForeground", (PyCFunction)Sbk_QTextFormatFunc_clearForeground, METH_NOARGS},
    {"clearProperty", (PyCFunction)Sbk_QTextFormatFunc_clearProperty, METH_O},
    {"colorProperty", (PyCFunction)Sbk_QTextFormatFunc_colorProperty, METH_O},
    {"doubleProperty", (PyCFunction)Sbk_QTextFormatFunc_doubleProperty, METH_O},
    {"foreground", (PyCFunction)Sbk_QTextFormatFunc_foreground, METH_NOARGS},
    {"hasProperty", (PyCFunction)Sbk_QTextFormatFunc_hasProperty, METH_O},
    {"intProperty", (PyCFunction)Sbk_QTextFormatFunc_intProperty, METH_O},
    {"isBlockFormat", (PyCFunction)Sbk_QTextFormatFunc_isBlockFormat, METH_NOARGS},
    {"isCharFormat", (PyCFunction)Sbk_QTextFormatFunc_isCharFormat, METH_NOARGS},
    {"isFrameFormat", (PyCFunction)Sbk_QTextFormatFunc_isFrameFormat, METH_NOARGS},
    {"isImageFormat", (PyCFunction)Sbk_QTextFormatFunc_isImageFormat, METH_NOARGS},
    {"isListFormat", (PyCFunction)Sbk_QTextFormatFunc_isListFormat, METH_NOARGS},
    {"isTableCellFormat", (PyCFunction)Sbk_QTextFormatFunc_isTableCellFormat, METH_NOARGS},
    {"isTableFormat", (PyCFunction)Sbk_QTextFormatFunc_isTableFormat, METH_NOARGS},
    {"isValid", (PyCFunction)Sbk_QTextFormatFunc_isValid, METH_NOARGS},
    {"layoutDirection", (PyCFunction)Sbk_QTextFormatFunc_layoutDirection, METH_NOARGS},
    {"lengthProperty", (PyCFunction)Sbk_QTextFormatFunc_lengthProperty, METH_O},
    {"lengthVectorProperty", (PyCFunction)Sbk_QTextFormatFunc_lengthVectorProperty, METH_O},
    {"merge", (PyCFunction)Sbk_QTextFormatFunc_merge, METH_O},
    {"objectIndex", (PyCFunction)Sbk_QTextFormatFunc_objectIndex, METH_NOARGS},
    {"objectType", (PyCFunction)Sbk_QTextFormatFunc_objectType, METH_NOARGS},
    {"penProperty", (PyCFunction)Sbk_QTextFormatFunc_penProperty, METH_O},
    {"properties", (PyCFunction)Sbk_QTextFormatFunc_properties, METH_NOARGS},
    {"property", (PyCFunction)Sbk_QTextFormatFunc_property, METH_O},
    {"propertyCount", (PyCFunction)Sbk_QTextFormatFunc_propertyCount, METH_NOARGS},
    {"setBackground", (PyCFunction)Sbk_QTextFormatFunc_setBackground, METH_O},
    {"setForeground", (PyCFunction)Sbk_QTextFormatFunc_setForeground, METH_O},
    {"setLayoutDirection", (PyCFunction)Sbk_QTextFormatFunc_setLayoutDirection, METH_O},
    {"setObjectIndex", (PyCFunction)Sbk_QTextFormatFunc_setObjectIndex, METH_O},
    {"setObjectType", (PyCFunction)Sbk_QTextFormatFunc_setObjectType, METH_O},
    {"setProperty", (PyCFunction)Sbk_QTextFormatFunc_setProperty, METH_VARARGS},
    {"stringProperty", (PyCFunction)Sbk_QTextFormatFunc_stringProperty, METH_O},
    {"toBlockFormat", (PyCFunction)Sbk_QTextFormatFunc_toBlockFormat, METH_NOARGS},
    {"toCharFormat", (PyCFunction)Sbk_QTextFormatFunc_toCharFormat, METH_NOARGS},
    {"toFrameFormat", (PyCFunction)Sbk_QTextFormatFunc_toFrameFormat, METH_NOARGS},
    {"toImageFormat", (PyCFunction)Sbk_QTextFormatFunc_toImageFormat, METH_NOARGS},
    {"toListFormat", (PyCFunction)Sbk_QTextFormatFunc_toListFormat, METH_NOARGS},
    {"toTableCellFormat", (PyCFunction)Sbk_QTextFormatFunc_toTableCellFormat, METH_NOARGS},
    {"toTableFormat", (PyCFunction)Sbk_QTextFormatFunc_toTableFormat, METH_NOARGS},
    {"type", (PyCFunction)Sbk_QTextFormatFunc_type, METH_NOARGS},

    {"__copy__", (PyCFunction)Sbk_QTextFormat___copy__, METH_NOARGS},
    {0} // Sentinel
};

static PyObject* Sbk_QTextFormatFunc___lshift__(PyObject* self, PyObject* arg)
{
    QTextFormat* cppSelf = 0;
    bool isReverse = Shiboken::Converter< ::QTextFormat >::checkType(arg) && !Shiboken::Converter< ::QTextFormat >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextFormat* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && Shiboken::Object::checkType(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rlshift__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rlshift__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator<<(QDataStream&,QTextFormat)
    if (isReverse && Shiboken::Converter< ::QDataStream & >::isConvertible(arg)) {
        overloadId = 0; // operator<<(QDataStream&,QTextFormat)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextFormatFunc___lshift___TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QDataStream & cppArg0 = Shiboken::Converter<QDataStream & >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // operator<<(QDataStream&,QTextFormat) [reverse operator]
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDataStream & cppResult = (cppArg0) << (*cppSelf);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDataStream & >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTextFormatFunc___lshift___TypeError:
        const char* overloads[] = {"PySide.QtCore.QDataStream", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextFormat.__lshift__", overloads);
        return 0;
}

static PyObject* Sbk_QTextFormatFunc___rshift__(PyObject* self, PyObject* arg)
{
    QTextFormat* cppSelf = 0;
    bool isReverse = Shiboken::Converter< ::QTextFormat >::checkType(arg) && !Shiboken::Converter< ::QTextFormat >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTextFormat* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && Shiboken::Object::checkType(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rrshift__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rrshift__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator>>(QDataStream&,QTextFormat&)
    if (isReverse && Shiboken::Converter< ::QDataStream & >::isConvertible(arg)) {
        overloadId = 0; // operator>>(QDataStream&,QTextFormat&)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTextFormatFunc___rshift___TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QDataStream & cppArg0 = Shiboken::Converter<QDataStream & >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // operator>>(QDataStream&,QTextFormat&) [reverse operator]
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDataStream & cppResult = (cppArg0) >> (*cppSelf);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDataStream & >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTextFormatFunc___rshift___TypeError:
        const char* overloads[] = {"PySide.QtCore.QDataStream", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTextFormat.__rshift__", overloads);
        return 0;
}

// type has number operators
static PyNumberMethods Sbk_QTextFormat_as_number = {
    /*nb_add*/                  (binaryfunc)0,
    /*nb_subtract*/             (binaryfunc)0,
    /*nb_multiply*/             (binaryfunc)0,
    /*nb_divide*/               (binaryfunc)0,
    /*nb_remainder*/            (binaryfunc)0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             (unaryfunc)0,
    /*nb_positive*/             (unaryfunc)0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              0,
    /*nb_invert*/               (unaryfunc)0,
    /*nb_lshift*/               (binaryfunc)Sbk_QTextFormatFunc___lshift__,
    /*nb_rshift*/               (binaryfunc)Sbk_QTextFormatFunc___rshift__,
    /*nb_and*/                  (binaryfunc)0,
    /*nb_xor*/                  (binaryfunc)0,
    /*nb_or*/                   (binaryfunc)0,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          (binaryfunc)0,
    /*nb_inplace_subtract*/     (binaryfunc)0,
    /*nb_inplace_multiply*/     (binaryfunc)0,
    /*nb_inplace_divide*/       (binaryfunc)0,
    /*nb_inplace_remainder*/    (binaryfunc)0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       (binaryfunc)0,
    /*nb_inplace_rshift*/       (binaryfunc)0,
    /*nb_inplace_and*/          (binaryfunc)0,
    /*nb_inplace_xor*/          (binaryfunc)0,
    /*nb_inplace_or*/           (binaryfunc)0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          (binaryfunc)0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};

// Rich comparison
static PyObject* Sbk_QTextFormat_richcompare(PyObject* self, PyObject* arg, int op)
{
    PyObject* pyResult = 0;
    QTextFormat& cppSelf = *Shiboken::Converter< QTextFormat* >::toCpp(self);

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter< ::QTextFormat >::isConvertible(arg)) {
                // operator!=(const QTextFormat & rhs) const
                QTextFormat cppArg0 = Shiboken::Converter< ::QTextFormat >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf != cppArg0);
            } else goto Sbk_QTextFormat_RichComparison_TypeError;

            break;
        case Py_EQ:
            if (Shiboken::Converter< ::QTextFormat >::isConvertible(arg)) {
                // operator==(const QTextFormat & rhs) const
                QTextFormat cppArg0 = Shiboken::Converter< ::QTextFormat >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf == cppArg0);
            } else goto Sbk_QTextFormat_RichComparison_TypeError;

            break;
        default:
            goto Sbk_QTextFormat_RichComparison_TypeError;
    }

    if (pyResult && !PyErr_Occurred())
        return pyResult;
    Sbk_QTextFormat_RichComparison_TypeError:
    PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
    return 0;

}

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QTextFormat_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QTextFormat",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        &Sbk_QTextFormat_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      Sbk_QTextFormat_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QTextFormat_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QTextFormat_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern

PyObject* SbkPySide_QtGui_QTextFormat_PageBreakFlag___and__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QTextFormat::PageBreakFlags >::toPython(
        Shiboken::Converter<QTextFormat::PageBreakFlags>::toCpp(self)
        & Shiboken::Converter< QTextFormat::PageBreakFlags >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtGui_QTextFormat_PageBreakFlag___or__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QTextFormat::PageBreakFlags >::toPython(
        Shiboken::Converter<QTextFormat::PageBreakFlags>::toCpp(self)
        | Shiboken::Converter< QTextFormat::PageBreakFlags >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtGui_QTextFormat_PageBreakFlag___xor__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QTextFormat::PageBreakFlags >::toPython(
        Shiboken::Converter<QTextFormat::PageBreakFlags>::toCpp(self)
        ^ Shiboken::Converter< QTextFormat::PageBreakFlags >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtGui_QTextFormat_PageBreakFlag___invert__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QTextFormat::PageBreakFlags >::toPython(
        ~Shiboken::Converter<QTextFormat::PageBreakFlags >::toCpp(self)
    );
}


static PyNumberMethods SbkPySide_QtGui_QTextFormat_PageBreakFlag_as_number = {
    /*nb_add*/                  0,
    /*nb_subtract*/             0,
    /*nb_multiply*/             0,
    /*nb_divide*/               0,
    /*nb_remainder*/            0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             0,
    /*nb_positive*/             0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              0,
    /*nb_invert*/               (unaryfunc)SbkPySide_QtGui_QTextFormat_PageBreakFlag___invert__,
    /*nb_lshift*/               0,
    /*nb_rshift*/               0,
    /*nb_and*/                  (binaryfunc)SbkPySide_QtGui_QTextFormat_PageBreakFlag___and__,
    /*nb_xor*/                  (binaryfunc)SbkPySide_QtGui_QTextFormat_PageBreakFlag___xor__,
    /*nb_or*/                   (binaryfunc)SbkPySide_QtGui_QTextFormat_PageBreakFlag___or__,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          0,
    /*nb_inplace_subtract*/     0,
    /*nb_inplace_multiply*/     0,
    /*nb_inplace_divide*/       0,
    /*nb_inplace_remainder*/    0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       0,
    /*nb_inplace_rshift*/       0,
    /*nb_inplace_and*/          0,
    /*nb_inplace_xor*/          0,
    /*nb_inplace_or*/           0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};


// forward declaration of new function
static PyTypeObject SbkPySide_QtGui_QTextFormat_PageBreakFlags_Type = {
    PyObject_HEAD_INIT(&PyType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PageBreakFlags",
    /*tp_basicsize*/        0,
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        &SbkPySide_QtGui_QTextFormat_PageBreakFlag_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT | Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              PyInt_Type.tp_new,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};



void init_QTextFormat(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QTEXTFORMAT_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QTextFormat_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QTextFormat_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QTextFormat_Type, &Shiboken::callCppDestructor<QTextFormat >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QTextFormat_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QTextFormat_Type, "QTextFormat");
    PyModule_AddObject(module, "QTextFormat",
        ((PyObject*)&Sbk_QTextFormat_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: Property
    PyTypeObject* SbkPySide_QtGui_QTextFormat_Property = Shiboken::Enum::newType("Property");
    SbkPySide_QtGuiTypes[SBK_QTEXTFORMAT_PROPERTY_IDX] = SbkPySide_QtGui_QTextFormat_Property;
    if (PyType_Ready(SbkPySide_QtGui_QTextFormat_Property) < 0)
        return;
    PyDict_SetItemString(Sbk_QTextFormat_Type.super.ht_type.tp_dict,
            "Property",((PyObject*)SbkPySide_QtGui_QTextFormat_Property));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextFormat_Property,(long) QTextFormat::ObjectIndex, "ObjectIndex");
    PyDict_SetItemString(Sbk_QTextFormat_Type.super.ht_type.tp_dict,"ObjectIndex", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextFormat_Property->tp_dict,"ObjectIndex", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextFormat_Property,(long) QTextFormat::CssFloat, "CssFloat");
    PyDict_SetItemString(Sbk_QTextFormat_Type.super.ht_type.tp_dict,"CssFloat", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextFormat_Property->tp_dict,"CssFloat", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextFormat_Property,(long) QTextFormat::LayoutDirection, "LayoutDirection");
    PyDict_SetItemString(Sbk_QTextFormat_Type.super.ht_type.tp_dict,"LayoutDirection", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextFormat_Property->tp_dict,"LayoutDirection", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextFormat_Property,(long) QTextFormat::OutlinePen, "OutlinePen");
    PyDict_SetItemString(Sbk_QTextFormat_Type.super.ht_type.tp_dict,"OutlinePen", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextFormat_Property->tp_dict,"OutlinePen", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextFormat_Property,(long) QTextFormat::BackgroundBrush, "BackgroundBrush");
    PyDict_SetItemString(Sbk_QTextFormat_Type.super.ht_type.tp_dict,"BackgroundBrush", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextFormat_Property->tp_dict,"BackgroundBrush", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextFormat_Property,(long) QTextFormat::ForegroundBrush, "ForegroundBrush");
    PyDict_SetItemString(Sbk_QTextFormat_Type.super.ht_type.tp_dict,"ForegroundBrush", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextFormat_Property->tp_dict,"ForegroundBrush", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextFormat_Property,(long) QTextFormat::BackgroundImageUrl, "BackgroundImageUrl");
    PyDict_SetItemString(Sbk_QTextFormat_Type.super.ht_type.tp_dict,"BackgroundImageUrl", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextFormat_Property->tp_dict,"BackgroundImageUrl", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextFormat_Property,(long) QTextFormat::BlockAlignment, "BlockAlignment");
    PyDict_SetItemString(Sbk_QTextFormat_Type.super.ht_type.tp_dict,"BlockAlignment", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextFormat_Property->tp_dict,"BlockAlignment", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextFormat_Property,(long) QTextFormat::BlockTopMargin, "BlockTopMargin");
    PyDict_SetItemString(Sbk_QTextFormat_Type.super.ht_type.tp_dict,"BlockTopMargin", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextFormat_Property->tp_dict,"BlockTopMargin", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextFormat_Property,(long) QTextFormat::BlockBottomMargin, "BlockBottomMargin");
    PyDict_SetItemString(Sbk_QTextFormat_Type.super.ht_type.tp_dict,"BlockBottomMargin", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextFormat_Property->tp_dict,"BlockBottomMargin", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextFormat_Property,(long) QTextFormat::BlockLeftMargin, "BlockLeftMargin");
    PyDict_SetItemString(Sbk_QTextFormat_Type.super.ht_type.tp_dict,"BlockLeftMargin", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextFormat_Property->tp_dict,"BlockLeftMargin", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextFormat_Property,(long) QTextFormat::BlockRightMargin, "BlockRightMargin");
    PyDict_SetItemString(Sbk_QTextFormat_Type.super.ht_type.tp_dict,"BlockRightMargin", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextFormat_Property->tp_dict,"BlockRightMargin", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextFormat_Property,(long) QTextFormat::TextIndent, "TextIndent");
    PyDict_SetItemString(Sbk_QTextFormat_Type.super.ht_type.tp_dict,"TextIndent", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextFormat_Property->tp_dict,"TextIndent", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextFormat_Property,(long) QTextFormat::TabPositions, "TabPositions");
    PyDict_SetItemString(Sbk_QTextFormat_Type.super.ht_type.tp_dict,"TabPositions", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextFormat_Property->tp_dict,"TabPositions", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextFormat_Property,(long) QTextFormat::BlockIndent, "BlockIndent");
    PyDict_SetItemString(Sbk_QTextFormat_Type.super.ht_type.tp_dict,"BlockIndent", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextFormat_Property->tp_dict,"BlockIndent", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextFormat_Property,(long) QTextFormat::BlockNonBreakableLines, "BlockNonBreakableLines");
    PyDict_SetItemString(Sbk_QTextFormat_Type.super.ht_type.tp_dict,"BlockNonBreakableLines", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextFormat_Property->tp_dict,"BlockNonBreakableLines", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextFormat_Property,(long) QTextFormat::BlockTrailingHorizontalRulerWidth, "BlockTrailingHorizontalRulerWidth");
    PyDict_SetItemString(Sbk_QTextFormat_Type.super.ht_type.tp_dict,"BlockTrailingHorizontalRulerWidth", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextFormat_Property->tp_dict,"BlockTrailingHorizontalRulerWidth", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextFormat_Property,(long) QTextFormat::FirstFontProperty, "FirstFontProperty");
    PyDict_SetItemString(Sbk_QTextFormat_Type.super.ht_type.tp_dict,"FirstFontProperty", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextFormat_Property->tp_dict,"FirstFontProperty", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextFormat_Property,(long) QTextFormat::FontCapitalization, "FontCapitalization");
    PyDict_SetItemString(Sbk_QTextFormat_Type.super.ht_type.tp_dict,"FontCapitalization", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextFormat_Property->tp_dict,"FontCapitalization", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextFormat_Property,(long) QTextFormat::FontLetterSpacing, "FontLetterSpacing");
    PyDict_SetItemString(Sbk_QTextFormat_Type.super.ht_type.tp_dict,"FontLetterSpacing", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextFormat_Property->tp_dict,"FontLetterSpacing", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextFormat_Property,(long) QTextFormat::FontWordSpacing, "FontWordSpacing");
    PyDict_SetItemString(Sbk_QTextFormat_Type.super.ht_type.tp_dict,"FontWordSpacing", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextFormat_Property->tp_dict,"FontWordSpacing", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextFormat_Property,(long) QTextFormat::FontStyleHint, "FontStyleHint");
    PyDict_SetItemString(Sbk_QTextFormat_Type.super.ht_type.tp_dict,"FontStyleHint", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextFormat_Property->tp_dict,"FontStyleHint", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextFormat_Property,(long) QTextFormat::FontStyleStrategy, "FontStyleStrategy");
    PyDict_SetItemString(Sbk_QTextFormat_Type.super.ht_type.tp_dict,"FontStyleStrategy", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextFormat_Property->tp_dict,"FontStyleStrategy", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextFormat_Property,(long) QTextFormat::FontKerning, "FontKerning");
    PyDict_SetItemString(Sbk_QTextFormat_Type.super.ht_type.tp_dict,"FontKerning", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextFormat_Property->tp_dict,"FontKerning", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextFormat_Property,(long) QTextFormat::FontFamily, "FontFamily");
    PyDict_SetItemString(Sbk_QTextFormat_Type.super.ht_type.tp_dict,"FontFamily", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextFormat_Property->tp_dict,"FontFamily", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextFormat_Property,(long) QTextFormat::FontPointSize, "FontPointSize");
    PyDict_SetItemString(Sbk_QTextFormat_Type.super.ht_type.tp_dict,"FontPointSize", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextFormat_Property->tp_dict,"FontPointSize", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextFormat_Property,(long) QTextFormat::FontSizeAdjustment, "FontSizeAdjustment");
    PyDict_SetItemString(Sbk_QTextFormat_Type.super.ht_type.tp_dict,"FontSizeAdjustment", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextFormat_Property->tp_dict,"FontSizeAdjustment", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextFormat_Property,(long) QTextFormat::FontSizeIncrement, "FontSizeIncrement");
    PyDict_SetItemString(Sbk_QTextFormat_Type.super.ht_type.tp_dict,"FontSizeIncrement", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextFormat_Property->tp_dict,"FontSizeIncrement", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextFormat_Property,(long) QTextFormat::FontWeight, "FontWeight");
    PyDict_SetItemString(Sbk_QTextFormat_Type.super.ht_type.tp_dict,"FontWeight", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextFormat_Property->tp_dict,"FontWeight", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextFormat_Property,(long) QTextFormat::FontItalic, "FontItalic");
    PyDict_SetItemString(Sbk_QTextFormat_Type.super.ht_type.tp_dict,"FontItalic", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextFormat_Property->tp_dict,"FontItalic", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextFormat_Property,(long) QTextFormat::FontUnderline, "FontUnderline");
    PyDict_SetItemString(Sbk_QTextFormat_Type.super.ht_type.tp_dict,"FontUnderline", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextFormat_Property->tp_dict,"FontUnderline", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextFormat_Property,(long) QTextFormat::FontOverline, "FontOverline");
    PyDict_SetItemString(Sbk_QTextFormat_Type.super.ht_type.tp_dict,"FontOverline", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextFormat_Property->tp_dict,"FontOverline", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextFormat_Property,(long) QTextFormat::FontStrikeOut, "FontStrikeOut");
    PyDict_SetItemString(Sbk_QTextFormat_Type.super.ht_type.tp_dict,"FontStrikeOut", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextFormat_Property->tp_dict,"FontStrikeOut", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextFormat_Property,(long) QTextFormat::FontFixedPitch, "FontFixedPitch");
    PyDict_SetItemString(Sbk_QTextFormat_Type.super.ht_type.tp_dict,"FontFixedPitch", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextFormat_Property->tp_dict,"FontFixedPitch", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextFormat_Property,(long) QTextFormat::FontPixelSize, "FontPixelSize");
    PyDict_SetItemString(Sbk_QTextFormat_Type.super.ht_type.tp_dict,"FontPixelSize", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextFormat_Property->tp_dict,"FontPixelSize", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextFormat_Property,(long) QTextFormat::LastFontProperty, "LastFontProperty");
    PyDict_SetItemString(Sbk_QTextFormat_Type.super.ht_type.tp_dict,"LastFontProperty", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextFormat_Property->tp_dict,"LastFontProperty", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextFormat_Property,(long) QTextFormat::TextUnderlineColor, "TextUnderlineColor");
    PyDict_SetItemString(Sbk_QTextFormat_Type.super.ht_type.tp_dict,"TextUnderlineColor", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextFormat_Property->tp_dict,"TextUnderlineColor", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextFormat_Property,(long) QTextFormat::TextVerticalAlignment, "TextVerticalAlignment");
    PyDict_SetItemString(Sbk_QTextFormat_Type.super.ht_type.tp_dict,"TextVerticalAlignment", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextFormat_Property->tp_dict,"TextVerticalAlignment", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextFormat_Property,(long) QTextFormat::TextOutline, "TextOutline");
    PyDict_SetItemString(Sbk_QTextFormat_Type.super.ht_type.tp_dict,"TextOutline", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextFormat_Property->tp_dict,"TextOutline", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextFormat_Property,(long) QTextFormat::TextUnderlineStyle, "TextUnderlineStyle");
    PyDict_SetItemString(Sbk_QTextFormat_Type.super.ht_type.tp_dict,"TextUnderlineStyle", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextFormat_Property->tp_dict,"TextUnderlineStyle", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextFormat_Property,(long) QTextFormat::TextToolTip, "TextToolTip");
    PyDict_SetItemString(Sbk_QTextFormat_Type.super.ht_type.tp_dict,"TextToolTip", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextFormat_Property->tp_dict,"TextToolTip", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextFormat_Property,(long) QTextFormat::IsAnchor, "IsAnchor");
    PyDict_SetItemString(Sbk_QTextFormat_Type.super.ht_type.tp_dict,"IsAnchor", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextFormat_Property->tp_dict,"IsAnchor", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextFormat_Property,(long) QTextFormat::AnchorHref, "AnchorHref");
    PyDict_SetItemString(Sbk_QTextFormat_Type.super.ht_type.tp_dict,"AnchorHref", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextFormat_Property->tp_dict,"AnchorHref", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextFormat_Property,(long) QTextFormat::AnchorName, "AnchorName");
    PyDict_SetItemString(Sbk_QTextFormat_Type.super.ht_type.tp_dict,"AnchorName", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextFormat_Property->tp_dict,"AnchorName", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextFormat_Property,(long) QTextFormat::ObjectType, "ObjectType");
    PyDict_SetItemString(Sbk_QTextFormat_Type.super.ht_type.tp_dict,"ObjectType", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextFormat_Property->tp_dict,"ObjectType", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextFormat_Property,(long) QTextFormat::ListStyle, "ListStyle");
    PyDict_SetItemString(Sbk_QTextFormat_Type.super.ht_type.tp_dict,"ListStyle", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextFormat_Property->tp_dict,"ListStyle", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextFormat_Property,(long) QTextFormat::ListIndent, "ListIndent");
    PyDict_SetItemString(Sbk_QTextFormat_Type.super.ht_type.tp_dict,"ListIndent", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextFormat_Property->tp_dict,"ListIndent", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextFormat_Property,(long) QTextFormat::FrameBorder, "FrameBorder");
    PyDict_SetItemString(Sbk_QTextFormat_Type.super.ht_type.tp_dict,"FrameBorder", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextFormat_Property->tp_dict,"FrameBorder", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextFormat_Property,(long) QTextFormat::FrameMargin, "FrameMargin");
    PyDict_SetItemString(Sbk_QTextFormat_Type.super.ht_type.tp_dict,"FrameMargin", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextFormat_Property->tp_dict,"FrameMargin", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextFormat_Property,(long) QTextFormat::FramePadding, "FramePadding");
    PyDict_SetItemString(Sbk_QTextFormat_Type.super.ht_type.tp_dict,"FramePadding", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextFormat_Property->tp_dict,"FramePadding", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextFormat_Property,(long) QTextFormat::FrameWidth, "FrameWidth");
    PyDict_SetItemString(Sbk_QTextFormat_Type.super.ht_type.tp_dict,"FrameWidth", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextFormat_Property->tp_dict,"FrameWidth", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextFormat_Property,(long) QTextFormat::FrameHeight, "FrameHeight");
    PyDict_SetItemString(Sbk_QTextFormat_Type.super.ht_type.tp_dict,"FrameHeight", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextFormat_Property->tp_dict,"FrameHeight", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextFormat_Property,(long) QTextFormat::FrameTopMargin, "FrameTopMargin");
    PyDict_SetItemString(Sbk_QTextFormat_Type.super.ht_type.tp_dict,"FrameTopMargin", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextFormat_Property->tp_dict,"FrameTopMargin", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextFormat_Property,(long) QTextFormat::FrameBottomMargin, "FrameBottomMargin");
    PyDict_SetItemString(Sbk_QTextFormat_Type.super.ht_type.tp_dict,"FrameBottomMargin", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextFormat_Property->tp_dict,"FrameBottomMargin", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextFormat_Property,(long) QTextFormat::FrameLeftMargin, "FrameLeftMargin");
    PyDict_SetItemString(Sbk_QTextFormat_Type.super.ht_type.tp_dict,"FrameLeftMargin", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextFormat_Property->tp_dict,"FrameLeftMargin", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextFormat_Property,(long) QTextFormat::FrameRightMargin, "FrameRightMargin");
    PyDict_SetItemString(Sbk_QTextFormat_Type.super.ht_type.tp_dict,"FrameRightMargin", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextFormat_Property->tp_dict,"FrameRightMargin", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextFormat_Property,(long) QTextFormat::FrameBorderBrush, "FrameBorderBrush");
    PyDict_SetItemString(Sbk_QTextFormat_Type.super.ht_type.tp_dict,"FrameBorderBrush", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextFormat_Property->tp_dict,"FrameBorderBrush", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextFormat_Property,(long) QTextFormat::FrameBorderStyle, "FrameBorderStyle");
    PyDict_SetItemString(Sbk_QTextFormat_Type.super.ht_type.tp_dict,"FrameBorderStyle", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextFormat_Property->tp_dict,"FrameBorderStyle", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextFormat_Property,(long) QTextFormat::TableColumns, "TableColumns");
    PyDict_SetItemString(Sbk_QTextFormat_Type.super.ht_type.tp_dict,"TableColumns", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextFormat_Property->tp_dict,"TableColumns", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextFormat_Property,(long) QTextFormat::TableColumnWidthConstraints, "TableColumnWidthConstraints");
    PyDict_SetItemString(Sbk_QTextFormat_Type.super.ht_type.tp_dict,"TableColumnWidthConstraints", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextFormat_Property->tp_dict,"TableColumnWidthConstraints", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextFormat_Property,(long) QTextFormat::TableCellSpacing, "TableCellSpacing");
    PyDict_SetItemString(Sbk_QTextFormat_Type.super.ht_type.tp_dict,"TableCellSpacing", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextFormat_Property->tp_dict,"TableCellSpacing", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextFormat_Property,(long) QTextFormat::TableCellPadding, "TableCellPadding");
    PyDict_SetItemString(Sbk_QTextFormat_Type.super.ht_type.tp_dict,"TableCellPadding", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextFormat_Property->tp_dict,"TableCellPadding", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextFormat_Property,(long) QTextFormat::TableHeaderRowCount, "TableHeaderRowCount");
    PyDict_SetItemString(Sbk_QTextFormat_Type.super.ht_type.tp_dict,"TableHeaderRowCount", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextFormat_Property->tp_dict,"TableHeaderRowCount", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextFormat_Property,(long) QTextFormat::TableCellRowSpan, "TableCellRowSpan");
    PyDict_SetItemString(Sbk_QTextFormat_Type.super.ht_type.tp_dict,"TableCellRowSpan", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextFormat_Property->tp_dict,"TableCellRowSpan", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextFormat_Property,(long) QTextFormat::TableCellColumnSpan, "TableCellColumnSpan");
    PyDict_SetItemString(Sbk_QTextFormat_Type.super.ht_type.tp_dict,"TableCellColumnSpan", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextFormat_Property->tp_dict,"TableCellColumnSpan", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextFormat_Property,(long) QTextFormat::TableCellTopPadding, "TableCellTopPadding");
    PyDict_SetItemString(Sbk_QTextFormat_Type.super.ht_type.tp_dict,"TableCellTopPadding", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextFormat_Property->tp_dict,"TableCellTopPadding", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextFormat_Property,(long) QTextFormat::TableCellBottomPadding, "TableCellBottomPadding");
    PyDict_SetItemString(Sbk_QTextFormat_Type.super.ht_type.tp_dict,"TableCellBottomPadding", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextFormat_Property->tp_dict,"TableCellBottomPadding", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextFormat_Property,(long) QTextFormat::TableCellLeftPadding, "TableCellLeftPadding");
    PyDict_SetItemString(Sbk_QTextFormat_Type.super.ht_type.tp_dict,"TableCellLeftPadding", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextFormat_Property->tp_dict,"TableCellLeftPadding", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextFormat_Property,(long) QTextFormat::TableCellRightPadding, "TableCellRightPadding");
    PyDict_SetItemString(Sbk_QTextFormat_Type.super.ht_type.tp_dict,"TableCellRightPadding", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextFormat_Property->tp_dict,"TableCellRightPadding", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextFormat_Property,(long) QTextFormat::ImageName, "ImageName");
    PyDict_SetItemString(Sbk_QTextFormat_Type.super.ht_type.tp_dict,"ImageName", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextFormat_Property->tp_dict,"ImageName", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextFormat_Property,(long) QTextFormat::ImageWidth, "ImageWidth");
    PyDict_SetItemString(Sbk_QTextFormat_Type.super.ht_type.tp_dict,"ImageWidth", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextFormat_Property->tp_dict,"ImageWidth", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextFormat_Property,(long) QTextFormat::ImageHeight, "ImageHeight");
    PyDict_SetItemString(Sbk_QTextFormat_Type.super.ht_type.tp_dict,"ImageHeight", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextFormat_Property->tp_dict,"ImageHeight", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextFormat_Property,(long) QTextFormat::FullWidthSelection, "FullWidthSelection");
    PyDict_SetItemString(Sbk_QTextFormat_Type.super.ht_type.tp_dict,"FullWidthSelection", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextFormat_Property->tp_dict,"FullWidthSelection", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextFormat_Property,(long) QTextFormat::PageBreakPolicy, "PageBreakPolicy");
    PyDict_SetItemString(Sbk_QTextFormat_Type.super.ht_type.tp_dict,"PageBreakPolicy", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextFormat_Property->tp_dict,"PageBreakPolicy", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextFormat_Property,(long) QTextFormat::UserProperty, "UserProperty");
    PyDict_SetItemString(Sbk_QTextFormat_Type.super.ht_type.tp_dict,"UserProperty", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextFormat_Property->tp_dict,"UserProperty", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QTextFormat::Property");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::Property");
    // end of enum Property

    // init enum: FormatType
    PyTypeObject* SbkPySide_QtGui_QTextFormat_FormatType = Shiboken::Enum::newType("FormatType");
    SbkPySide_QtGuiTypes[SBK_QTEXTFORMAT_FORMATTYPE_IDX] = SbkPySide_QtGui_QTextFormat_FormatType;
    if (PyType_Ready(SbkPySide_QtGui_QTextFormat_FormatType) < 0)
        return;
    PyDict_SetItemString(Sbk_QTextFormat_Type.super.ht_type.tp_dict,
            "FormatType",((PyObject*)SbkPySide_QtGui_QTextFormat_FormatType));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextFormat_FormatType,(long) QTextFormat::InvalidFormat, "InvalidFormat");
    PyDict_SetItemString(Sbk_QTextFormat_Type.super.ht_type.tp_dict,"InvalidFormat", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextFormat_FormatType->tp_dict,"InvalidFormat", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextFormat_FormatType,(long) QTextFormat::BlockFormat, "BlockFormat");
    PyDict_SetItemString(Sbk_QTextFormat_Type.super.ht_type.tp_dict,"BlockFormat", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextFormat_FormatType->tp_dict,"BlockFormat", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextFormat_FormatType,(long) QTextFormat::CharFormat, "CharFormat");
    PyDict_SetItemString(Sbk_QTextFormat_Type.super.ht_type.tp_dict,"CharFormat", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextFormat_FormatType->tp_dict,"CharFormat", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextFormat_FormatType,(long) QTextFormat::ListFormat, "ListFormat");
    PyDict_SetItemString(Sbk_QTextFormat_Type.super.ht_type.tp_dict,"ListFormat", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextFormat_FormatType->tp_dict,"ListFormat", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextFormat_FormatType,(long) QTextFormat::TableFormat, "TableFormat");
    PyDict_SetItemString(Sbk_QTextFormat_Type.super.ht_type.tp_dict,"TableFormat", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextFormat_FormatType->tp_dict,"TableFormat", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextFormat_FormatType,(long) QTextFormat::FrameFormat, "FrameFormat");
    PyDict_SetItemString(Sbk_QTextFormat_Type.super.ht_type.tp_dict,"FrameFormat", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextFormat_FormatType->tp_dict,"FrameFormat", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextFormat_FormatType,(long) QTextFormat::UserFormat, "UserFormat");
    PyDict_SetItemString(Sbk_QTextFormat_Type.super.ht_type.tp_dict,"UserFormat", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextFormat_FormatType->tp_dict,"UserFormat", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QTextFormat::FormatType");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::FormatType");
    // end of enum FormatType

    // init enum: ObjectTypes
    PyTypeObject* SbkPySide_QtGui_QTextFormat_ObjectTypes = Shiboken::Enum::newType("ObjectTypes");
    SbkPySide_QtGuiTypes[SBK_QTEXTFORMAT_OBJECTTYPES_IDX] = SbkPySide_QtGui_QTextFormat_ObjectTypes;
    if (PyType_Ready(SbkPySide_QtGui_QTextFormat_ObjectTypes) < 0)
        return;
    PyDict_SetItemString(Sbk_QTextFormat_Type.super.ht_type.tp_dict,
            "ObjectTypes",((PyObject*)SbkPySide_QtGui_QTextFormat_ObjectTypes));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextFormat_ObjectTypes,(long) QTextFormat::NoObject, "NoObject");
    PyDict_SetItemString(Sbk_QTextFormat_Type.super.ht_type.tp_dict,"NoObject", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextFormat_ObjectTypes->tp_dict,"NoObject", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextFormat_ObjectTypes,(long) QTextFormat::ImageObject, "ImageObject");
    PyDict_SetItemString(Sbk_QTextFormat_Type.super.ht_type.tp_dict,"ImageObject", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextFormat_ObjectTypes->tp_dict,"ImageObject", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextFormat_ObjectTypes,(long) QTextFormat::TableObject, "TableObject");
    PyDict_SetItemString(Sbk_QTextFormat_Type.super.ht_type.tp_dict,"TableObject", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextFormat_ObjectTypes->tp_dict,"TableObject", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextFormat_ObjectTypes,(long) QTextFormat::TableCellObject, "TableCellObject");
    PyDict_SetItemString(Sbk_QTextFormat_Type.super.ht_type.tp_dict,"TableCellObject", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextFormat_ObjectTypes->tp_dict,"TableCellObject", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextFormat_ObjectTypes,(long) QTextFormat::UserObject, "UserObject");
    PyDict_SetItemString(Sbk_QTextFormat_Type.super.ht_type.tp_dict,"UserObject", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextFormat_ObjectTypes->tp_dict,"UserObject", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QTextFormat::ObjectTypes");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::ObjectTypes");
    // end of enum ObjectTypes

    // init enum: PageBreakFlag
    PyTypeObject* SbkPySide_QtGui_QTextFormat_PageBreakFlag = Shiboken::Enum::newType("PageBreakFlag");
    SbkPySide_QtGui_QTextFormat_PageBreakFlag->tp_as_number = &SbkPySide_QtGui_QTextFormat_PageBreakFlag_as_number;
    SbkPySide_QtGuiTypes[SBK_QTEXTFORMAT_PAGEBREAKFLAG_IDX] = SbkPySide_QtGui_QTextFormat_PageBreakFlag;
    if (PyType_Ready(SbkPySide_QtGui_QTextFormat_PageBreakFlag) < 0)
        return;
    PyDict_SetItemString(Sbk_QTextFormat_Type.super.ht_type.tp_dict,
            "PageBreakFlag",((PyObject*)SbkPySide_QtGui_QTextFormat_PageBreakFlag));

    // init flags class: QFlags<QTextFormat::PageBreakFlag>
    SbkPySide_QtGuiTypes[SBK_QFLAGS_QTEXTFORMAT_PAGEBREAKFLAG__IDX] = &SbkPySide_QtGui_QTextFormat_PageBreakFlags_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtGui_QTextFormat_PageBreakFlags_Type) < 0)
        return;
    PyDict_SetItemString(Sbk_QTextFormat_Type.super.ht_type.tp_dict,
            "PageBreakFlags",((PyObject*)&SbkPySide_QtGui_QTextFormat_PageBreakFlags_Type));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextFormat_PageBreakFlag,(long) QTextFormat::PageBreak_Auto, "PageBreak_Auto");
    PyDict_SetItemString(Sbk_QTextFormat_Type.super.ht_type.tp_dict,"PageBreak_Auto", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextFormat_PageBreakFlag->tp_dict,"PageBreak_Auto", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextFormat_PageBreakFlag,(long) QTextFormat::PageBreak_AlwaysBefore, "PageBreak_AlwaysBefore");
    PyDict_SetItemString(Sbk_QTextFormat_Type.super.ht_type.tp_dict,"PageBreak_AlwaysBefore", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextFormat_PageBreakFlag->tp_dict,"PageBreak_AlwaysBefore", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QTextFormat_PageBreakFlag,(long) QTextFormat::PageBreak_AlwaysAfter, "PageBreak_AlwaysAfter");
    PyDict_SetItemString(Sbk_QTextFormat_Type.super.ht_type.tp_dict,"PageBreak_AlwaysAfter", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QTextFormat_PageBreakFlag->tp_dict,"PageBreak_AlwaysAfter", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QTextFormat::PageBreakFlag");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::PageBreakFlag");
    // end of enum PageBreakFlag


    Shiboken::TypeResolver::createValueTypeResolver<QTextFormat >("QTextFormat");
    Shiboken::TypeResolver::createObjectTypeResolver<QTextFormat >("QTextFormat*");
    Shiboken::TypeResolver::createValueTypeResolver<QTextFormat >(typeid(QTextFormat).name());
    PySide::initQtMetaType<QTextFormat >();
}

