/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtgui_python.h"

#include "qvector4d_wrapper.h"

// Extra includes
#include <QMatrix4x4>
#include <qdatastream.h>
#include <qpoint.h>
#include <qvector2d.h>
#include <qvector3d.h>
#include <qvector4d.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QVector4D_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QVector4D >()))
        return -1;

    QVector4D* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QVector4D", 0, 4, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return -1;

    // Overloaded function decisor
    // 0: QVector4D()
    // 1: QVector4D(QPoint)
    // 2: QVector4D(QPointF)
    // 3: QVector4D(QVector2D)
    // 4: QVector4D(QVector2D,qreal,qreal)
    // 5: QVector4D(QVector3D)
    // 6: QVector4D(QVector3D,qreal)
    // 7: QVector4D(QVector4D)
    // 8: QVector4D(qreal,qreal,qreal,qreal)
    if (numArgs == 0) {
        overloadId = 0; // QVector4D()
    } else if (numArgs == 4 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
        overloadId = 8; // QVector4D(qreal,qreal,qreal,qreal)
    } else if (Shiboken::Converter< ::QVector2D >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 3; // QVector4D(QVector2D)
        } else if (numArgs == 3 && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
            overloadId = 4; // QVector4D(QVector2D,qreal,qreal)
        }
    } else if (Shiboken::Converter< ::QVector3D >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 5; // QVector4D(QVector3D)
        } else if (numArgs == 2 && SbkNumber_Check(pyargs[1])) {
            overloadId = 6; // QVector4D(QVector3D,qreal)
        }
    } else if (numArgs == 1 && Shiboken::Converter< ::QVector4D >::isConvertible(pyargs[0])) {
        overloadId = 7; // QVector4D(QVector4D)
    } else if (numArgs == 1 && Shiboken::Converter< ::QPoint >::isConvertible(pyargs[0])) {
        overloadId = 1; // QVector4D(QPoint)
    } else if (numArgs == 1 && Shiboken::Converter< ::QPointF >::isConvertible(pyargs[0])) {
        overloadId = 2; // QVector4D(QPointF)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QVector4D_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QVector4D()
            {

                if(!PyErr_Occurred()) {
                    // QVector4D()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QVector4D();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // QVector4D(QPoint)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QPoint cppArg0 = Shiboken::Converter<QPoint >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QVector4D(QPoint)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QVector4D(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // QVector4D(QPointF)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QPointF cppArg0 = Shiboken::Converter<QPointF >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QVector4D(QPointF)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QVector4D(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 3: // QVector4D(QVector2D)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QVector2D cppArg0 = Shiboken::Converter<QVector2D >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QVector4D(QVector2D)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QVector4D(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 4: // QVector4D(QVector2D,qreal,qreal)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QVector2D cppArg0 = Shiboken::Converter<QVector2D >::toCpp(pyargs[0]);
                qreal cppArg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
                qreal cppArg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                    // QVector4D(QVector2D,qreal,qreal)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QVector4D(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 5: // QVector4D(QVector3D)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QVector3D cppArg0 = Shiboken::Converter<QVector3D >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QVector4D(QVector3D)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QVector4D(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 6: // QVector4D(QVector3D,qreal)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QVector3D cppArg0 = Shiboken::Converter<QVector3D >::toCpp(pyargs[0]);
                qreal cppArg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // QVector4D(QVector3D,qreal)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QVector4D(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 7: // QVector4D(QVector4D)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QVector4D cppArg0 = Shiboken::Converter<QVector4D >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QVector4D(QVector4D)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QVector4D(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 8: // QVector4D(qreal,qreal,qreal,qreal)
            {
                qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(pyargs[0]);
                qreal cppArg1 = Shiboken::Converter<qreal >::toCpp(pyargs[1]);
                qreal cppArg2 = Shiboken::Converter<qreal >::toCpp(pyargs[2]);
                qreal cppArg3 = Shiboken::Converter<qreal >::toCpp(pyargs[3]);

                if(!PyErr_Occurred()) {
                    // QVector4D(qreal,qreal,qreal,qreal)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QVector4D(cppArg0, cppArg1, cppArg2, cppArg3);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QVector4D >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QVector4D_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QVector4D_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtCore.QPoint", "PySide.QtCore.QPointF", "PySide.QtGui.QVector2D", "PySide.QtGui.QVector2D, float, float", "PySide.QtGui.QVector3D", "PySide.QtGui.QVector3D, float", "PySide.QtGui.QVector4D", "float, float, float, float", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QVector4D", overloads);
        return -1;
}

static PyObject* Sbk_QVector4DFunc___reduce__(PyObject* self)
{
    QVector4D* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QVector4D* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // __reduce__()
                // Begin code injection
                
                // TEMPLATE - reduce_code - START
                pyResult = Py_BuildValue("(N(dddd))", PyObject_Type(self), cppSelf->x(), cppSelf->y(), cppSelf->z(), cppSelf->w());
                // TEMPLATE - reduce_code - END
                
                // End of code injection


            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QVector4DFunc_dotProduct(PyObject* self, PyObject* args)
{
    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "dotProduct", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: dotProduct(QVector4D,QVector4D)
    if (numArgs == 2 && Shiboken::Converter< ::QVector4D >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QVector4D >::isConvertible(pyargs[1])) {
        overloadId = 0; // dotProduct(QVector4D,QVector4D)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QVector4DFunc_dotProduct_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QVector4D cppArg0 = Shiboken::Converter<QVector4D >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QVector4D cppArg1 = Shiboken::Converter<QVector4D >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // dotProduct(QVector4D,QVector4D)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qreal cppResult = QVector4D::dotProduct(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< double >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QVector4DFunc_dotProduct_TypeError:
        const char* overloads[] = {"PySide.QtGui.QVector4D, PySide.QtGui.QVector4D", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QVector4D.dotProduct", overloads);
        return 0;
}

static PyObject* Sbk_QVector4DFunc_isNull(PyObject* self)
{
    QVector4D* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QVector4D* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isNull()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->isNull();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QVector4DFunc_length(PyObject* self)
{
    QVector4D* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QVector4D* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // length()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qreal cppResult = cppSelf->length();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< double >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QVector4DFunc_lengthSquared(PyObject* self)
{
    QVector4D* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QVector4D* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // lengthSquared()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qreal cppResult = cppSelf->lengthSquared();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< double >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QVector4DFunc_normalize(PyObject* self)
{
    QVector4D* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QVector4D* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // normalize()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->normalize();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QVector4DFunc_normalized(PyObject* self)
{
    QVector4D* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QVector4D* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // normalized()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QVector4D cppResult = cppSelf->normalized();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QVector4D >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QVector4DFunc_setW(PyObject* self, PyObject* arg)
{
    QVector4D* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QVector4D* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setW(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setW(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QVector4DFunc_setW_TypeError;

    // Call function/method
    {
        {
            qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setW(qreal)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setW(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QVector4DFunc_setW_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QVector4D.setW", overloads);
        return 0;
}

static PyObject* Sbk_QVector4DFunc_setX(PyObject* self, PyObject* arg)
{
    QVector4D* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QVector4D* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setX(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setX(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QVector4DFunc_setX_TypeError;

    // Call function/method
    {
        {
            qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setX(qreal)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setX(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QVector4DFunc_setX_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QVector4D.setX", overloads);
        return 0;
}

static PyObject* Sbk_QVector4DFunc_setY(PyObject* self, PyObject* arg)
{
    QVector4D* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QVector4D* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setY(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setY(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QVector4DFunc_setY_TypeError;

    // Call function/method
    {
        {
            qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setY(qreal)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setY(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QVector4DFunc_setY_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QVector4D.setY", overloads);
        return 0;
}

static PyObject* Sbk_QVector4DFunc_setZ(PyObject* self, PyObject* arg)
{
    QVector4D* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QVector4D* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setZ(qreal)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setZ(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QVector4DFunc_setZ_TypeError;

    // Call function/method
    {
        {
            qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setZ(qreal)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setZ(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QVector4DFunc_setZ_TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QVector4D.setZ", overloads);
        return 0;
}

static PyObject* Sbk_QVector4DFunc_toPoint(PyObject* self)
{
    QVector4D* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QVector4D* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // toPoint()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPoint cppResult = cppSelf->toPoint();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPoint >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QVector4DFunc_toPointF(PyObject* self)
{
    QVector4D* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QVector4D* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // toPointF()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPointF cppResult = cppSelf->toPointF();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPointF >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QVector4DFunc_toVector2D(PyObject* self)
{
    QVector4D* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QVector4D* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // toVector2D()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QVector2D cppResult = cppSelf->toVector2D();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QVector2D >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QVector4DFunc_toVector2DAffine(PyObject* self)
{
    QVector4D* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QVector4D* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // toVector2DAffine()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QVector2D cppResult = cppSelf->toVector2DAffine();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QVector2D >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QVector4DFunc_toVector3D(PyObject* self)
{
    QVector4D* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QVector4D* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // toVector3D()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QVector3D cppResult = cppSelf->toVector3D();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QVector3D >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QVector4DFunc_toVector3DAffine(PyObject* self)
{
    QVector4D* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QVector4D* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // toVector3DAffine()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QVector3D cppResult = cppSelf->toVector3DAffine();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QVector3D >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QVector4DFunc_w(PyObject* self)
{
    QVector4D* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QVector4D* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // w()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qreal cppResult = cppSelf->w();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< double >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QVector4DFunc_x(PyObject* self)
{
    QVector4D* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QVector4D* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // x()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qreal cppResult = cppSelf->x();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< double >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QVector4DFunc_y(PyObject* self)
{
    QVector4D* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QVector4D* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // y()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qreal cppResult = cppSelf->y();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< double >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QVector4DFunc_z(PyObject* self)
{
    QVector4D* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QVector4D* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // z()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qreal cppResult = cppSelf->z();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< double >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject *Sbk_QVector4D___copy__(PyObject *self)
{
        QVector4D* cppSelf = 0;
        if (!Shiboken::Object::isValid(self))
            return 0;
        cppSelf = Shiboken::Converter<QVector4D*>::toCpp(self);
        PyObject* pyResult = 0;
        QVector4D* copy = new QVector4D(*cppSelf);
        pyResult = Shiboken::Converter<QVector4D*>::toPython(copy);
        Shiboken::Object::getOwnership(pyResult);

        if (PyErr_Occurred() || !pyResult) {
            Py_XDECREF(pyResult);
            return 0;
        }
        return pyResult;
}

static PyMethodDef Sbk_QVector4D_methods[] = {
    {"__reduce__", (PyCFunction)Sbk_QVector4DFunc___reduce__, METH_NOARGS},
    {"dotProduct", (PyCFunction)Sbk_QVector4DFunc_dotProduct, METH_VARARGS|METH_STATIC},
    {"isNull", (PyCFunction)Sbk_QVector4DFunc_isNull, METH_NOARGS},
    {"length", (PyCFunction)Sbk_QVector4DFunc_length, METH_NOARGS},
    {"lengthSquared", (PyCFunction)Sbk_QVector4DFunc_lengthSquared, METH_NOARGS},
    {"normalize", (PyCFunction)Sbk_QVector4DFunc_normalize, METH_NOARGS},
    {"normalized", (PyCFunction)Sbk_QVector4DFunc_normalized, METH_NOARGS},
    {"setW", (PyCFunction)Sbk_QVector4DFunc_setW, METH_O},
    {"setX", (PyCFunction)Sbk_QVector4DFunc_setX, METH_O},
    {"setY", (PyCFunction)Sbk_QVector4DFunc_setY, METH_O},
    {"setZ", (PyCFunction)Sbk_QVector4DFunc_setZ, METH_O},
    {"toPoint", (PyCFunction)Sbk_QVector4DFunc_toPoint, METH_NOARGS},
    {"toPointF", (PyCFunction)Sbk_QVector4DFunc_toPointF, METH_NOARGS},
    {"toVector2D", (PyCFunction)Sbk_QVector4DFunc_toVector2D, METH_NOARGS},
    {"toVector2DAffine", (PyCFunction)Sbk_QVector4DFunc_toVector2DAffine, METH_NOARGS},
    {"toVector3D", (PyCFunction)Sbk_QVector4DFunc_toVector3D, METH_NOARGS},
    {"toVector3DAffine", (PyCFunction)Sbk_QVector4DFunc_toVector3DAffine, METH_NOARGS},
    {"w", (PyCFunction)Sbk_QVector4DFunc_w, METH_NOARGS},
    {"x", (PyCFunction)Sbk_QVector4DFunc_x, METH_NOARGS},
    {"y", (PyCFunction)Sbk_QVector4DFunc_y, METH_NOARGS},
    {"z", (PyCFunction)Sbk_QVector4DFunc_z, METH_NOARGS},

    {"__copy__", (PyCFunction)Sbk_QVector4D___copy__, METH_NOARGS},
    {0} // Sentinel
};

static PyObject* Sbk_QVector4DFunc___mul__(PyObject* self, PyObject* arg)
{
    QVector4D* cppSelf = 0;
    bool isReverse = Shiboken::Converter< ::QVector4D >::checkType(arg) && !Shiboken::Converter< ::QVector4D >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QVector4D* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && Shiboken::Object::checkType(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rmul__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rmul__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator*(QVector4D,QMatrix4x4)
    // 1: operator*(QMatrix4x4,QVector4D)
    // 2: operator*(QVector4D,QVector4D)
    // 3: operator*(qreal,QVector4D)
    // 4: operator*(QVector4D,qreal)
    if (!isReverse && SbkNumber_Check(arg)) {
        overloadId = 4; // operator*(QVector4D,qreal)
    } else if (isReverse && SbkNumber_Check(arg)) {
        overloadId = 3; // operator*(qreal,QVector4D)
    } else if (!isReverse && Shiboken::Converter< ::QVector4D >::isConvertible(arg)) {
        overloadId = 2; // operator*(QVector4D,QVector4D)
    } else if (isReverse && Shiboken::Converter< ::QMatrix4x4 >::isConvertible(arg)) {
        overloadId = 1; // operator*(QMatrix4x4,QVector4D)
    } else if (!isReverse && Shiboken::Converter< ::QMatrix4x4 >::isConvertible(arg)) {
        overloadId = 0; // operator*(QVector4D,QMatrix4x4)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QVector4DFunc___mul___TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // operator*(QVector4D,QMatrix4x4)
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QMatrix4x4 cppArg0 = Shiboken::Converter<QMatrix4x4 >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // operator*(QVector4D,QMatrix4x4)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QVector4D cppResult = (*cppSelf) * (cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QVector4D >::toPython(cppResult);
                }
                break;
            }
            case 1: // operator*(QMatrix4x4,QVector4D)
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QMatrix4x4 cppArg0 = Shiboken::Converter<QMatrix4x4 >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // operator*(QMatrix4x4,QVector4D) [reverse operator]
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QVector4D cppResult = (cppArg0) * (*cppSelf);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QVector4D >::toPython(cppResult);
                }
                break;
            }
            case 2: // operator*(QVector4D,QVector4D)
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QVector4D cppArg0 = Shiboken::Converter<QVector4D >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // operator*(QVector4D,QVector4D)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    const QVector4D cppResult = (*cppSelf) * (cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QVector4D >::toPython(cppResult);
                }
                break;
            }
            case 3: // operator*(qreal,QVector4D)
            {
                qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // operator*(qreal,QVector4D) [reverse operator]
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    const QVector4D cppResult = cppArg0 * (*cppSelf);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QVector4D >::toPython(cppResult);
                }
                break;
            }
            case 4: // operator*(QVector4D,qreal)
            {
                qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // operator*(QVector4D,qreal)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    const QVector4D cppResult = (*cppSelf) * cppArg0;
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QVector4D >::toPython(cppResult);
                }
                break;
            }
        }
    }


    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QVector4DFunc___mul___TypeError:
        const char* overloads[] = {"PySide.QtGui.QMatrix4x4", "PySide.QtGui.QMatrix4x4", "PySide.QtGui.QVector4D", "float", "float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QVector4D.__mul__", overloads);
        return 0;
}

static PyObject* Sbk_QVector4DFunc___imul__(PyObject* self, PyObject* arg)
{
    QVector4D* cppSelf = 0;
    bool isReverse = Shiboken::Converter< ::QVector4D >::checkType(arg) && !Shiboken::Converter< ::QVector4D >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QVector4D* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: operator*=(QVector4D)
    // 1: operator*=(qreal)
    if (!isReverse && SbkNumber_Check(arg)) {
        overloadId = 1; // operator*=(qreal)
    } else if (!isReverse && Shiboken::Converter< ::QVector4D >::isConvertible(arg)) {
        overloadId = 0; // operator*=(QVector4D)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QVector4DFunc___imul___TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // operator*=(QVector4D)
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QVector4D cppArg0 = Shiboken::Converter<QVector4D >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // operator*=(QVector4D)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    (*cppSelf) *= (cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // operator*=(qreal)
            {
                qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // operator*=(qreal)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    (*cppSelf) *= cppArg0;
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_INCREF(self);
    return self;

    Sbk_QVector4DFunc___imul___TypeError:
        const char* overloads[] = {"PySide.QtGui.QVector4D", "float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QVector4D.__imul__", overloads);
        return 0;
}

static PyObject* Sbk_QVector4DFunc___add__(PyObject* self, PyObject* arg)
{
    QVector4D* cppSelf = 0;
    bool isReverse = Shiboken::Converter< ::QVector4D >::checkType(arg) && !Shiboken::Converter< ::QVector4D >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QVector4D* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && Shiboken::Object::checkType(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__radd__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__radd__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator+(QVector4D,QVector4D)
    if (!isReverse && Shiboken::Converter< ::QVector4D >::isConvertible(arg)) {
        overloadId = 0; // operator+(QVector4D,QVector4D)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QVector4DFunc___add___TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QVector4D cppArg0 = Shiboken::Converter<QVector4D >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // operator+(QVector4D,QVector4D)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                const QVector4D cppResult = (*cppSelf) + (cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QVector4D >::toPython(cppResult);
            }
        }
    }


    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QVector4DFunc___add___TypeError:
        const char* overloads[] = {"PySide.QtGui.QVector4D", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QVector4D.__add__", overloads);
        return 0;
}

static PyObject* Sbk_QVector4DFunc___iadd__(PyObject* self, PyObject* arg)
{
    QVector4D* cppSelf = 0;
    bool isReverse = Shiboken::Converter< ::QVector4D >::checkType(arg) && !Shiboken::Converter< ::QVector4D >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QVector4D* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: operator+=(QVector4D)
    if (!isReverse && Shiboken::Converter< ::QVector4D >::isConvertible(arg)) {
        overloadId = 0; // operator+=(QVector4D)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QVector4DFunc___iadd___TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QVector4D cppArg0 = Shiboken::Converter<QVector4D >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // operator+=(QVector4D)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (*cppSelf) += (cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_INCREF(self);
    return self;

    Sbk_QVector4DFunc___iadd___TypeError:
        const char* overloads[] = {"PySide.QtGui.QVector4D", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QVector4D.__iadd__", overloads);
        return 0;
}

static PyObject* Sbk_QVector4DFunc___neg__(PyObject* self)
{
    QVector4D* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QVector4D* >::toCpp(self);

    PyObject* pyResult = 0;

    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // operator-(QVector4D)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                const QVector4D cppResult = - (*cppSelf);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QVector4D >::toPython(cppResult);
            }
        }
    }


    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QVector4DFunc___sub__(PyObject* self, PyObject* arg)
{
    QVector4D* cppSelf = 0;
    bool isReverse = Shiboken::Converter< ::QVector4D >::checkType(arg) && !Shiboken::Converter< ::QVector4D >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QVector4D* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && Shiboken::Object::checkType(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rsub__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rsub__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator-(QVector4D,QVector4D)
    if (!isReverse && Shiboken::Converter< ::QVector4D >::isConvertible(arg)) {
        overloadId = 0; // operator-(QVector4D,QVector4D)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QVector4DFunc___sub___TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QVector4D cppArg0 = Shiboken::Converter<QVector4D >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // operator-(QVector4D,QVector4D)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                const QVector4D cppResult = (*cppSelf) - (cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QVector4D >::toPython(cppResult);
            }
        }
    }


    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QVector4DFunc___sub___TypeError:
        const char* overloads[] = {"PySide.QtGui.QVector4D", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QVector4D.__sub__", overloads);
        return 0;
}

static PyObject* Sbk_QVector4DFunc___isub__(PyObject* self, PyObject* arg)
{
    QVector4D* cppSelf = 0;
    bool isReverse = Shiboken::Converter< ::QVector4D >::checkType(arg) && !Shiboken::Converter< ::QVector4D >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QVector4D* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: operator-=(QVector4D)
    if (!isReverse && Shiboken::Converter< ::QVector4D >::isConvertible(arg)) {
        overloadId = 0; // operator-=(QVector4D)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QVector4DFunc___isub___TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QVector4D cppArg0 = Shiboken::Converter<QVector4D >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // operator-=(QVector4D)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (*cppSelf) -= (cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_INCREF(self);
    return self;

    Sbk_QVector4DFunc___isub___TypeError:
        const char* overloads[] = {"PySide.QtGui.QVector4D", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QVector4D.__isub__", overloads);
        return 0;
}

static PyObject* Sbk_QVector4DFunc___div__(PyObject* self, PyObject* arg)
{
    QVector4D* cppSelf = 0;
    bool isReverse = Shiboken::Converter< ::QVector4D >::checkType(arg) && !Shiboken::Converter< ::QVector4D >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QVector4D* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && Shiboken::Object::checkType(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rdiv__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rdiv__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator/(QVector4D,qreal)
    if (!isReverse && SbkNumber_Check(arg)) {
        overloadId = 0; // operator/(QVector4D,qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QVector4DFunc___div___TypeError;

    // Call function/method
    {
        {
            qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // operator/(QVector4D,qreal)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                const QVector4D cppResult = (*cppSelf) / cppArg0;
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QVector4D >::toPython(cppResult);
            }
        }
    }


    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QVector4DFunc___div___TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QVector4D.__div__", overloads);
        return 0;
}

static PyObject* Sbk_QVector4DFunc___idiv__(PyObject* self, PyObject* arg)
{
    QVector4D* cppSelf = 0;
    bool isReverse = Shiboken::Converter< ::QVector4D >::checkType(arg) && !Shiboken::Converter< ::QVector4D >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QVector4D* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: operator/=(qreal)
    if (!isReverse && SbkNumber_Check(arg)) {
        overloadId = 0; // operator/=(qreal)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QVector4DFunc___idiv___TypeError;

    // Call function/method
    {
        {
            qreal cppArg0 = Shiboken::Converter<qreal >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // operator/=(qreal)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (*cppSelf) /= cppArg0;
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_INCREF(self);
    return self;

    Sbk_QVector4DFunc___idiv___TypeError:
        const char* overloads[] = {"float", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QVector4D.__idiv__", overloads);
        return 0;
}

static PyObject* Sbk_QVector4DFunc___lshift__(PyObject* self, PyObject* arg)
{
    QVector4D* cppSelf = 0;
    bool isReverse = Shiboken::Converter< ::QVector4D >::checkType(arg) && !Shiboken::Converter< ::QVector4D >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QVector4D* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && Shiboken::Object::checkType(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rlshift__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rlshift__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator<<(QDataStream&,QVector4D)
    if (isReverse && Shiboken::Converter< ::QDataStream & >::isConvertible(arg)) {
        overloadId = 0; // operator<<(QDataStream&,QVector4D)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QVector4DFunc___lshift___TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QDataStream & cppArg0 = Shiboken::Converter<QDataStream & >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // operator<<(QDataStream&,QVector4D) [reverse operator]
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDataStream & cppResult = (cppArg0) << (*cppSelf);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDataStream & >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QVector4DFunc___lshift___TypeError:
        const char* overloads[] = {"PySide.QtCore.QDataStream", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QVector4D.__lshift__", overloads);
        return 0;
}

static PyObject* Sbk_QVector4DFunc___rshift__(PyObject* self, PyObject* arg)
{
    QVector4D* cppSelf = 0;
    bool isReverse = Shiboken::Converter< ::QVector4D >::checkType(arg) && !Shiboken::Converter< ::QVector4D >::checkType(self);
    if (isReverse)
        std::swap(self, arg);

    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QVector4D* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    if (!isReverse
        && Shiboken::Object::checkType(arg)
        && !PyObject_TypeCheck(arg, self->ob_type)
        && PyObject_HasAttrString(arg, const_cast<char*>("__rrshift__"))) {
        PyObject* revOpMethod = PyObject_GetAttrString(arg, const_cast<char*>("__rrshift__"));
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, const_cast<char*>("O"), self);
            if (PyErr_Occurred() && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = 0;
            }
        }
        Py_XDECREF(revOpMethod);

    }
    // Do not enter here if other object has implemented a reverse operator.
    if (!pyResult) {

    // Overloaded function decisor
    // 0: operator>>(QDataStream&,QVector4D&)
    if (isReverse && Shiboken::Converter< ::QDataStream & >::isConvertible(arg)) {
        overloadId = 0; // operator>>(QDataStream&,QVector4D&)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QVector4DFunc___rshift___TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QDataStream & cppArg0 = Shiboken::Converter<QDataStream & >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // operator>>(QDataStream&,QVector4D&) [reverse operator]
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDataStream & cppResult = (cppArg0) >> (*cppSelf);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDataStream & >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    } // End of "if (!pyResult)"


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QVector4DFunc___rshift___TypeError:
        const char* overloads[] = {"PySide.QtCore.QDataStream", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QVector4D.__rshift__", overloads);
        return 0;
}

// type has number operators
static PyNumberMethods Sbk_QVector4D_as_number = {
    /*nb_add*/                  (binaryfunc)Sbk_QVector4DFunc___add__,
    /*nb_subtract*/             (binaryfunc)Sbk_QVector4DFunc___sub__,
    /*nb_multiply*/             (binaryfunc)Sbk_QVector4DFunc___mul__,
    /*nb_divide*/               (binaryfunc)Sbk_QVector4DFunc___div__,
    /*nb_remainder*/            (binaryfunc)0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             (unaryfunc)Sbk_QVector4DFunc___neg__,
    /*nb_positive*/             (unaryfunc)0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              0,
    /*nb_invert*/               (unaryfunc)0,
    /*nb_lshift*/               (binaryfunc)Sbk_QVector4DFunc___lshift__,
    /*nb_rshift*/               (binaryfunc)Sbk_QVector4DFunc___rshift__,
    /*nb_and*/                  (binaryfunc)0,
    /*nb_xor*/                  (binaryfunc)0,
    /*nb_or*/                   (binaryfunc)0,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          (binaryfunc)Sbk_QVector4DFunc___iadd__,
    /*nb_inplace_subtract*/     (binaryfunc)Sbk_QVector4DFunc___isub__,
    /*nb_inplace_multiply*/     (binaryfunc)Sbk_QVector4DFunc___imul__,
    /*nb_inplace_divide*/       (binaryfunc)Sbk_QVector4DFunc___idiv__,
    /*nb_inplace_remainder*/    (binaryfunc)0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       (binaryfunc)0,
    /*nb_inplace_rshift*/       (binaryfunc)0,
    /*nb_inplace_and*/          (binaryfunc)0,
    /*nb_inplace_xor*/          (binaryfunc)0,
    /*nb_inplace_or*/           (binaryfunc)0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          (binaryfunc)Sbk_QVector4DFunc___div__,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};

// Rich comparison
static PyObject* Sbk_QVector4D_richcompare(PyObject* self, PyObject* arg, int op)
{
    PyObject* pyResult = 0;
    QVector4D& cppSelf = *Shiboken::Converter< QVector4D* >::toCpp(self);

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter< ::QVector4D >::isConvertible(arg)) {
                // operator!=(const QVector4D & v2)
                QVector4D cppArg0 = Shiboken::Converter< ::QVector4D >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf != cppArg0);
            } else goto Sbk_QVector4D_RichComparison_TypeError;

            break;
        case Py_EQ:
            if (Shiboken::Converter< ::QVector4D >::isConvertible(arg)) {
                // operator==(const QVector4D & v2)
                QVector4D cppArg0 = Shiboken::Converter< ::QVector4D >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf == cppArg0);
            } else goto Sbk_QVector4D_RichComparison_TypeError;

            break;
        default:
            goto Sbk_QVector4D_RichComparison_TypeError;
    }

    if (pyResult && !PyErr_Occurred())
        return pyResult;
    Sbk_QVector4D_RichComparison_TypeError:
    PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
    return 0;

}

} // extern "C"

extern "C"
{
static PyObject* Sbk_QVector4D__repr__(PyObject* pyObj)
{
    QBuffer buffer;
    buffer.open(QBuffer::ReadWrite);
    QDebug dbg(&buffer);
    dbg << Shiboken::Converter< ::QVector4D >::toCpp(pyObj);
    buffer.close();
    return PyString_FromFormat("<PySide.QtGui.%s at %p>", buffer.data().constData(), pyObj);
}
} // extern C

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QVector4D_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QVector4D",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Sbk_QVector4D__repr__,
    /*tp_as_number*/        &Sbk_QVector4D_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      Sbk_QVector4D_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QVector4D_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QVector4D_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QVector4D(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QVECTOR4D_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QVector4D_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QVector4D_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QVector4D_Type, &Shiboken::callCppDestructor<QVector4D >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QVector4D_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QVector4D_Type, "QVector4D");
    PyModule_AddObject(module, "QVector4D",
        ((PyObject*)&Sbk_QVector4D_Type));


    Shiboken::TypeResolver::createValueTypeResolver<QVector4D >("QVector4D");
    Shiboken::TypeResolver::createObjectTypeResolver<QVector4D >("QVector4D*");
    Shiboken::TypeResolver::createValueTypeResolver<QVector4D >(typeid(QVector4D).name());
    PySide::initQtMetaType<QVector4D >();
}

