/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include "pyside_qtmultimedia_python.h"

#include "qabstractvideosurface_wrapper.h"

// Extra includes
#include <QList>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qthread.h>
#include <qvideoframe.h>
#include <qvideosurfaceformat.h>


// Native ---------------------------------------------------------

QAbstractVideoSurfaceWrapper::QAbstractVideoSurfaceWrapper(QObject * parent) : QAbstractVideoSurface(parent) {
    // ... middle
}

void QAbstractVideoSurfaceWrapper::childEvent(QChildEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "childEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::childEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QChildEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QAbstractVideoSurfaceWrapper::connectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "connectNotify"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QAbstractVideoSurfaceWrapper::customEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "customEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::customEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QAbstractVideoSurfaceWrapper::disconnectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

bool QAbstractVideoSurfaceWrapper::event(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "event"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::event(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractVideoSurface.event", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
    return cppResult;
}

bool QAbstractVideoSurfaceWrapper::eventFilter(QObject * arg__1, QEvent * arg__2)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "eventFilter"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::eventFilter(arg__1, arg__2);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QObject * >::toPython(arg__1),
        Shiboken::Converter< ::QEvent * >::toPython(arg__2)
    ));
    bool invalidadeArg2 = PyTuple_GET_ITEM(pyargs, 1)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractVideoSurface.eventFilter", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    if (invalidadeArg2)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 1));
    return cppResult;
}

bool QAbstractVideoSurfaceWrapper::isFormatSupported(const QVideoSurfaceFormat & format) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "isFormatSupported"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractVideoSurface::isFormatSupported(format);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QVideoSurfaceFormat >::toPython(format)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractVideoSurface.isFormatSupported", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    return cppResult;
}

QVideoSurfaceFormat QAbstractVideoSurfaceWrapper::nearestFormat(const QVideoSurfaceFormat & format) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "nearestFormat"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractVideoSurface::nearestFormat(format);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QVideoSurfaceFormat >::toPython(format)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QVideoSurfaceFormat();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QVideoSurfaceFormat >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractVideoSurface.nearestFormat", Shiboken::SbkType<QVideoSurfaceFormat >()->tp_name, pyResult->ob_type->tp_name);
        return QVideoSurfaceFormat();
    }
    QVideoSurfaceFormat cppResult(Shiboken::Converter< ::QVideoSurfaceFormat >::toCpp(pyResult));
    return cppResult;
}

bool QAbstractVideoSurfaceWrapper::present(const QVideoFrame & frame)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "present"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QAbstractVideoSurface.present()' not implemented.");
        return bool(0);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QVideoFrame >::toPython(frame)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractVideoSurface.present", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    return cppResult;
}

bool QAbstractVideoSurfaceWrapper::start(const QVideoSurfaceFormat & format)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "start"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractVideoSurface::start(format);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QVideoSurfaceFormat >::toPython(format)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractVideoSurface.start", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    return cppResult;
}

void QAbstractVideoSurfaceWrapper::stop()
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "stop"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractVideoSurface::stop();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

QList<QVideoFrame::PixelFormat > QAbstractVideoSurfaceWrapper::supportedPixelFormats(QAbstractVideoBuffer::HandleType handleType) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "supportedPixelFormats"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QAbstractVideoSurface.supportedPixelFormats()' not implemented.");
        return QList<QVideoFrame::PixelFormat >();
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QAbstractVideoBuffer::HandleType >::toPython(handleType)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QList<QVideoFrame::PixelFormat >();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QList<QVideoFrame::PixelFormat > >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QAbstractVideoSurface.supportedPixelFormats", "list", pyResult->ob_type->tp_name);
        return QList<QVideoFrame::PixelFormat >();
    }
    QList<QVideoFrame::PixelFormat > cppResult(Shiboken::Converter< ::QList<QVideoFrame::PixelFormat > >::toCpp(pyResult));
    return cppResult;
}

void QAbstractVideoSurfaceWrapper::timerEvent(QTimerEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "timerEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::timerEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QTimerEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

const QMetaObject* QAbstractVideoSurfaceWrapper::metaObject() const
{
    SbkObject* pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    return reinterpret_cast<QMetaObject*>(Shiboken::Object::getTypeUserData(pySelf));
}

int QAbstractVideoSurfaceWrapper::qt_metacall(QMetaObject::Call call, int id, void** args)
{
    int result = QAbstractVideoSurface::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

QAbstractVideoSurfaceWrapper::~QAbstractVideoSurfaceWrapper()
{
    SbkObject* wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QAbstractVideoSurface_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QAbstractVideoSurface >()))
        return -1;

    QAbstractVideoSurfaceWrapper* cptr = 0;
    int overloadId = -1;
    const char* argNames[] = {"parent"};
    const QMetaObject* metaObject;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);
    SbkObjectType* type = reinterpret_cast<SbkObjectType*>(self->ob_type);
    SbkObjectType* myType = reinterpret_cast<SbkObjectType*>(SbkPySide_QtMultimediaTypes[SBK_QABSTRACTVIDEOSURFACE_IDX]);
    if (type == myType) {
        PyErr_SetString(PyExc_NotImplementedError,
            "'QAbstractVideoSurface' represents a C++ abstract class and cannot be instantiated");
        return -1;
    }



    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_ParseTuple(args, "|O:QAbstractVideoSurface", &(pyargs[0])))
        return -1;

    // Overloaded function decisor
    // 0: QAbstractVideoSurface(QObject*)
    if (numArgs == 0) {
        overloadId = 0; // QAbstractVideoSurface(QObject*)
    } else if (Shiboken::Converter< ::QObject * >::isConvertible(pyargs[0])) {
        overloadId = 0; // QAbstractVideoSurface(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QAbstractVideoSurface_Init_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "parent");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "parent";
                    else if (Shiboken::Converter< ::QObject * >::isConvertible(value))
                        pyargs[0] = value;
else
                        goto Sbk_QAbstractVideoSurface_Init_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtMultimedia.QAbstractVideoSurface(): got multiple values for keyword argument '%s'", errorArgName);
                    return -1;
                }
            }
            if (!Shiboken::Object::isValid(pyargs[0]))
                return -1;
            QObject * cppArg0 = pyargs[0] ? Shiboken::Converter<QObject * >::toCpp(pyargs[0]) : 0;

            if(!PyErr_Occurred()) {
                // QAbstractVideoSurface(QObject*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new QAbstractVideoSurfaceWrapper(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                Shiboken::Object::setParent(pyargs[0], self);
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QAbstractVideoSurface >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QAbstractVideoSurface_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    metaObject = cptr->metaObject(); // <- init python qt properties
    if (kwds && !PySide::fillQtProperties(self, metaObject, kwds, argNames, 1))
        return -1;


    return 1;

    Sbk_QAbstractVideoSurface_Init_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtMultimedia.QAbstractVideoSurface", overloads);
        return -1;
}

static PyObject* Sbk_QAbstractVideoSurfaceFunc_error(PyObject* self)
{
    QAbstractVideoSurface* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QAbstractVideoSurface* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // error()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QAbstractVideoSurface::Error cppResult = cppSelf->error();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QAbstractVideoSurface::Error >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QAbstractVideoSurfaceFunc_isActive(PyObject* self)
{
    QAbstractVideoSurface* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QAbstractVideoSurface* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isActive()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->isActive();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QAbstractVideoSurfaceFunc_isFormatSupported(PyObject* self, PyObject* arg)
{
    QAbstractVideoSurface* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QAbstractVideoSurface* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: isFormatSupported(QVideoSurfaceFormat)const
    if (Shiboken::Converter< ::QVideoSurfaceFormat >::isConvertible(arg)) {
        overloadId = 0; // isFormatSupported(QVideoSurfaceFormat)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QAbstractVideoSurfaceFunc_isFormatSupported_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QVideoSurfaceFormat cppArg0 = Shiboken::Converter<QVideoSurfaceFormat >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // isFormatSupported(QVideoSurfaceFormat)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QAbstractVideoSurface::isFormatSupported(cppArg0):cppSelf->isFormatSupported(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QAbstractVideoSurfaceFunc_isFormatSupported_TypeError:
        const char* overloads[] = {"PySide.QtMultimedia.QVideoSurfaceFormat", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtMultimedia.QAbstractVideoSurface.isFormatSupported", overloads);
        return 0;
}

static PyObject* Sbk_QAbstractVideoSurfaceFunc_nearestFormat(PyObject* self, PyObject* arg)
{
    QAbstractVideoSurface* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QAbstractVideoSurface* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: nearestFormat(QVideoSurfaceFormat)const
    if (Shiboken::Converter< ::QVideoSurfaceFormat >::isConvertible(arg)) {
        overloadId = 0; // nearestFormat(QVideoSurfaceFormat)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QAbstractVideoSurfaceFunc_nearestFormat_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QVideoSurfaceFormat cppArg0 = Shiboken::Converter<QVideoSurfaceFormat >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // nearestFormat(QVideoSurfaceFormat)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QVideoSurfaceFormat cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QAbstractVideoSurface::nearestFormat(cppArg0):cppSelf->nearestFormat(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QVideoSurfaceFormat >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QAbstractVideoSurfaceFunc_nearestFormat_TypeError:
        const char* overloads[] = {"PySide.QtMultimedia.QVideoSurfaceFormat", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtMultimedia.QAbstractVideoSurface.nearestFormat", overloads);
        return 0;
}

static PyObject* Sbk_QAbstractVideoSurfaceFunc_present(PyObject* self, PyObject* arg)
{
    QAbstractVideoSurface* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QAbstractVideoSurface* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: present(QVideoFrame)
    if (Shiboken::Converter< ::QVideoFrame >::isConvertible(arg)) {
        overloadId = 0; // present(QVideoFrame)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QAbstractVideoSurfaceFunc_present_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            const QVideoFrame & cppArg0 = Shiboken::Converter<const QVideoFrame & >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // present(QVideoFrame)
                if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self))) {
                    PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QAbstractVideoSurface.present()' not implemented.");
                    return 0;
                }
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->present(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QAbstractVideoSurfaceFunc_present_TypeError:
        const char* overloads[] = {"PySide.QtMultimedia.QVideoFrame", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtMultimedia.QAbstractVideoSurface.present", overloads);
        return 0;
}

static PyObject* Sbk_QAbstractVideoSurfaceFunc_setError(PyObject* self, PyObject* arg)
{
    QAbstractVideoSurface* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QAbstractVideoSurface* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setError(QAbstractVideoSurface::Error)
    if (Shiboken::Converter< ::QAbstractVideoSurface::Error >::isConvertible(arg)) {
        overloadId = 0; // setError(QAbstractVideoSurface::Error)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QAbstractVideoSurfaceFunc_setError_TypeError;

    // Call function/method
    {
        {
            QAbstractVideoSurface::Error cppArg0 = Shiboken::Converter<QAbstractVideoSurface::Error >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setError(QAbstractVideoSurface::Error)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setError(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QAbstractVideoSurfaceFunc_setError_TypeError:
        const char* overloads[] = {"PySide.QtMultimedia.QAbstractVideoSurface.Error", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtMultimedia.QAbstractVideoSurface.setError", overloads);
        return 0;
}

static PyObject* Sbk_QAbstractVideoSurfaceFunc_start(PyObject* self, PyObject* arg)
{
    QAbstractVideoSurface* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QAbstractVideoSurface* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: start(QVideoSurfaceFormat)
    if (Shiboken::Converter< ::QVideoSurfaceFormat >::isConvertible(arg)) {
        overloadId = 0; // start(QVideoSurfaceFormat)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QAbstractVideoSurfaceFunc_start_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QVideoSurfaceFormat cppArg0 = Shiboken::Converter<QVideoSurfaceFormat >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // start(QVideoSurfaceFormat)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QAbstractVideoSurface::start(cppArg0):cppSelf->start(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QAbstractVideoSurfaceFunc_start_TypeError:
        const char* overloads[] = {"PySide.QtMultimedia.QVideoSurfaceFormat", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtMultimedia.QAbstractVideoSurface.start", overloads);
        return 0;
}

static PyObject* Sbk_QAbstractVideoSurfaceFunc_stop(PyObject* self)
{
    QAbstractVideoSurface* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QAbstractVideoSurface* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // stop()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QAbstractVideoSurface::stop():cppSelf->stop());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QAbstractVideoSurfaceFunc_supportedPixelFormats(PyObject* self, PyObject* args, PyObject* kwds)
{
    QAbstractVideoSurface* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QAbstractVideoSurface* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtMultimedia.QAbstractVideoSurface.supportedPixelFormats(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:supportedPixelFormats", &(pyargs[0])))
        return 0;


    // Overloaded function decisor
    // 0: supportedPixelFormats(QAbstractVideoBuffer::HandleType)const
    if (numArgs == 0) {
        overloadId = 0; // supportedPixelFormats(QAbstractVideoBuffer::HandleType)const
    } else if (Shiboken::Converter< ::QAbstractVideoBuffer::HandleType >::isConvertible(pyargs[0])) {
        overloadId = 0; // supportedPixelFormats(QAbstractVideoBuffer::HandleType)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QAbstractVideoSurfaceFunc_supportedPixelFormats_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "handleType");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "handleType";
                    else if (Shiboken::Converter< ::QAbstractVideoBuffer::HandleType >::isConvertible(value))
                        pyargs[0] = value;
else
                        goto Sbk_QAbstractVideoSurfaceFunc_supportedPixelFormats_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtMultimedia.QAbstractVideoSurface.supportedPixelFormats(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QAbstractVideoBuffer::HandleType cppArg0 = pyargs[0] ? Shiboken::Converter<QAbstractVideoBuffer::HandleType >::toCpp(pyargs[0]) : QAbstractVideoBuffer::NoHandle;

            if(!PyErr_Occurred()) {
                // supportedPixelFormats(QAbstractVideoBuffer::HandleType)const
                if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self))) {
                    PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QAbstractVideoSurface.supportedPixelFormats()' not implemented.");
                    return 0;
                }
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QList<QVideoFrame::PixelFormat > cppResult = cppSelf->supportedPixelFormats(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QList<QVideoFrame::PixelFormat > >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QAbstractVideoSurfaceFunc_supportedPixelFormats_TypeError:
        const char* overloads[] = {"PySide.QtMultimedia.QAbstractVideoBuffer.HandleType = QAbstractVideoBuffer.NoHandle", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtMultimedia.QAbstractVideoSurface.supportedPixelFormats", overloads);
        return 0;
}

static PyObject* Sbk_QAbstractVideoSurfaceFunc_surfaceFormat(PyObject* self)
{
    QAbstractVideoSurface* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QAbstractVideoSurface* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // surfaceFormat()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QVideoSurfaceFormat cppResult = cppSelf->surfaceFormat();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QVideoSurfaceFormat >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef Sbk_QAbstractVideoSurface_methods[] = {
    {"error", (PyCFunction)Sbk_QAbstractVideoSurfaceFunc_error, METH_NOARGS},
    {"isActive", (PyCFunction)Sbk_QAbstractVideoSurfaceFunc_isActive, METH_NOARGS},
    {"isFormatSupported", (PyCFunction)Sbk_QAbstractVideoSurfaceFunc_isFormatSupported, METH_O},
    {"nearestFormat", (PyCFunction)Sbk_QAbstractVideoSurfaceFunc_nearestFormat, METH_O},
    {"present", (PyCFunction)Sbk_QAbstractVideoSurfaceFunc_present, METH_O},
    {"setError", (PyCFunction)Sbk_QAbstractVideoSurfaceFunc_setError, METH_O},
    {"start", (PyCFunction)Sbk_QAbstractVideoSurfaceFunc_start, METH_O},
    {"stop", (PyCFunction)Sbk_QAbstractVideoSurfaceFunc_stop, METH_NOARGS},
    {"supportedPixelFormats", (PyCFunction)Sbk_QAbstractVideoSurfaceFunc_supportedPixelFormats, METH_VARARGS|METH_KEYWORDS},
    {"surfaceFormat", (PyCFunction)Sbk_QAbstractVideoSurfaceFunc_surfaceFormat, METH_NOARGS},

    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QAbstractVideoSurface_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtMultimedia.QAbstractVideoSurface",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QAbstractVideoSurface_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QAbstractVideoSurface_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern

static SbkObjectType* Sbk_QAbstractVideoSurface_typeDiscovery(void* cptr, SbkObjectType* instanceType)
{
    if (instanceType == reinterpret_cast<SbkObjectType*>(Shiboken::SbkType<QObject >()) && dynamic_cast<QAbstractVideoSurface*>(reinterpret_cast<QObject*>(cptr)))
        return &Sbk_QAbstractVideoSurface_Type;
    return 0;
}


void init_QAbstractVideoSurface(PyObject* module)
{
    SbkPySide_QtMultimediaTypes[SBK_QABSTRACTVIDEOSURFACE_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QAbstractVideoSurface_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QAbstractVideoSurface_Type);
    Shiboken::ObjectType::setSubTypeInitHook(&Sbk_QAbstractVideoSurface_Type, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(&Sbk_QAbstractVideoSurface_Type, &QAbstractVideoSurface::staticMetaObject);    Sbk_QAbstractVideoSurface_Type.super.ht_type.tp_base = SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX];
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QAbstractVideoSurface_Type, &Shiboken::callCppDestructor<QAbstractVideoSurface >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QAbstractVideoSurface_Type) < 0)
        return;

    // Fill type discovery information
    Shiboken::ObjectType::setTypeDiscoveryFunction(&Sbk_QAbstractVideoSurface_Type, &Sbk_QAbstractVideoSurface_typeDiscovery);
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkObjectType*>(SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX]), &Sbk_QAbstractVideoSurface_Type);

    Shiboken::ObjectType::setOriginalName(&Sbk_QAbstractVideoSurface_Type, "QAbstractVideoSurface*");
    PyModule_AddObject(module, "QAbstractVideoSurface",
        ((PyObject*)&Sbk_QAbstractVideoSurface_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: Error
    PyTypeObject* SbkPySide_QtMultimedia_QAbstractVideoSurface_Error = Shiboken::Enum::newType("Error");
    SbkPySide_QtMultimediaTypes[SBK_QABSTRACTVIDEOSURFACE_ERROR_IDX] = SbkPySide_QtMultimedia_QAbstractVideoSurface_Error;
    if (PyType_Ready(SbkPySide_QtMultimedia_QAbstractVideoSurface_Error) < 0)
        return;
    PyDict_SetItemString(Sbk_QAbstractVideoSurface_Type.super.ht_type.tp_dict,
            "Error",((PyObject*)SbkPySide_QtMultimedia_QAbstractVideoSurface_Error));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtMultimedia_QAbstractVideoSurface_Error,(long) QAbstractVideoSurface::NoError, "NoError");
    PyDict_SetItemString(Sbk_QAbstractVideoSurface_Type.super.ht_type.tp_dict,"NoError", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtMultimedia_QAbstractVideoSurface_Error->tp_dict,"NoError", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtMultimedia_QAbstractVideoSurface_Error,(long) QAbstractVideoSurface::UnsupportedFormatError, "UnsupportedFormatError");
    PyDict_SetItemString(Sbk_QAbstractVideoSurface_Type.super.ht_type.tp_dict,"UnsupportedFormatError", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtMultimedia_QAbstractVideoSurface_Error->tp_dict,"UnsupportedFormatError", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtMultimedia_QAbstractVideoSurface_Error,(long) QAbstractVideoSurface::IncorrectFormatError, "IncorrectFormatError");
    PyDict_SetItemString(Sbk_QAbstractVideoSurface_Type.super.ht_type.tp_dict,"IncorrectFormatError", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtMultimedia_QAbstractVideoSurface_Error->tp_dict,"IncorrectFormatError", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtMultimedia_QAbstractVideoSurface_Error,(long) QAbstractVideoSurface::StoppedError, "StoppedError");
    PyDict_SetItemString(Sbk_QAbstractVideoSurface_Type.super.ht_type.tp_dict,"StoppedError", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtMultimedia_QAbstractVideoSurface_Error->tp_dict,"StoppedError", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtMultimedia_QAbstractVideoSurface_Error,(long) QAbstractVideoSurface::ResourceError, "ResourceError");
    PyDict_SetItemString(Sbk_QAbstractVideoSurface_Type.super.ht_type.tp_dict,"ResourceError", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtMultimedia_QAbstractVideoSurface_Error->tp_dict,"ResourceError", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QAbstractVideoSurface::Error");
    Shiboken::TypeResolver::createValueTypeResolver<int>("QAbstractVideoSurface$ConcreteWrapper::Error");
    // end of enum Error

    // Initialize signals
    PySideSignal* signal_item;

    signal_item = PySide::Signal::newObject("activeChanged", "bool", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QAbstractVideoSurface_Type, "activeChanged", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("supportedFormatsChanged", "void", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QAbstractVideoSurface_Type, "supportedFormatsChanged", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("surfaceFormatChanged", "QVideoSurfaceFormat", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QAbstractVideoSurface_Type, "surfaceFormatChanged", signal_item);
    Py_DECREF((PyObject*) signal_item);


    Shiboken::TypeResolver::createObjectTypeResolver<QAbstractVideoSurface >("QAbstractVideoSurface*");
    Shiboken::TypeResolver::createObjectTypeResolver<QAbstractVideoSurface >("QAbstractVideoSurface$ConcreteWrapper*");
    Shiboken::TypeResolver::createObjectTypeResolver<QAbstractVideoSurface >(typeid(QAbstractVideoSurface).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QAbstractVideoSurface >(typeid(QAbstractVideoSurfaceWrapper).name());
    PySide::initQtMetaType<QAbstractVideoSurface* >();
}

