/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtnetwork_python.h"

#include "qhttprequestheader_wrapper.h"

// Extra includes
#include <QList>
#include <QPair>
#include <QStringList>
#include <qhttp.h>


// Native ---------------------------------------------------------

QHttpRequestHeaderWrapper::QHttpRequestHeaderWrapper() : QHttpRequestHeader() {
    // ... middle
}

QHttpRequestHeaderWrapper::QHttpRequestHeaderWrapper(const QString & method, const QString & path, int majorVer, int minorVer) : QHttpRequestHeader(method, path, majorVer, minorVer) {
    // ... middle
}

QHttpRequestHeaderWrapper::QHttpRequestHeaderWrapper(const QString & str) : QHttpRequestHeader(str) {
    // ... middle
}

int QHttpRequestHeaderWrapper::majorVersion() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "majorVersion"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QHttpRequestHeader::majorVersion();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QHttpRequestHeader.majorVersion", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter< int >::toCpp(pyResult));
    return cppResult;
}

int QHttpRequestHeaderWrapper::minorVersion() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "minorVersion"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QHttpRequestHeader::minorVersion();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QHttpRequestHeader.minorVersion", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter< int >::toCpp(pyResult));
    return cppResult;
}

bool QHttpRequestHeaderWrapper::parseLine(const QString & line, int number)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "parseLine"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QHttpRequestHeader::parseLine(line, number);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(Ni)",
        Shiboken::Converter< QString >::toPython(line),
        number
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QHttpRequestHeader.parseLine", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    return cppResult;
}

QString QHttpRequestHeaderWrapper::toString() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "toString"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QHttpRequestHeader::toString();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QString();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< QString >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QHttpRequestHeader.toString", "QString", pyResult->ob_type->tp_name);
        return QString();
    }
    QString cppResult(Shiboken::Converter< QString >::toCpp(pyResult));
    return cppResult;
}

QHttpRequestHeaderWrapper::~QHttpRequestHeaderWrapper()
{
    SbkObject* wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QHttpRequestHeader_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QHttpRequestHeader >()))
        return -1;

    QHttpRequestHeaderWrapper* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);

    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 4) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtNetwork.QHttpRequestHeader(): too many arguments");
        return -1;
    }

    if (!PyArg_ParseTuple(args, "|OOOO:QHttpRequestHeader", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return -1;

    // Overloaded function decisor
    // 0: QHttpRequestHeader()
    // 1: QHttpRequestHeader(QHttpRequestHeader)
    // 2: QHttpRequestHeader(QString,QString,int,int)
    // 3: QHttpRequestHeader(QString)
    if (numArgs == 0) {
        overloadId = 0; // QHttpRequestHeader()
    } else if (Shiboken::Converter< QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 3; // QHttpRequestHeader(QString)
        } else if (Shiboken::Converter< QString >::isConvertible(pyargs[1])) {
            if (numArgs == 2) {
                overloadId = 2; // QHttpRequestHeader(QString,QString,int,int)
            } else if (SbkNumber_Check(pyargs[2])) {
                if (numArgs == 3) {
                    overloadId = 2; // QHttpRequestHeader(QString,QString,int,int)
                } else if (SbkNumber_Check(pyargs[3])) {
                    overloadId = 2; // QHttpRequestHeader(QString,QString,int,int)
                }
            }
        }
    } else if (numArgs == 1 && Shiboken::Converter< ::QHttpRequestHeader >::isConvertible(pyargs[0])) {
        overloadId = 1; // QHttpRequestHeader(QHttpRequestHeader)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QHttpRequestHeader_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QHttpRequestHeader()
            {

                if(!PyErr_Occurred()) {
                    // QHttpRequestHeader()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QHttpRequestHeaderWrapper();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // QHttpRequestHeader(QHttpRequestHeader)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QHttpRequestHeader cppArg0 = Shiboken::Converter<QHttpRequestHeader >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QHttpRequestHeader(QHttpRequestHeader)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QHttpRequestHeaderWrapper(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // QHttpRequestHeader(QString,QString,int,int)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "majorVer");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "majorVer";
                        else if (SbkNumber_Check(value))
                            pyargs[2] = value;
else
                            goto Sbk_QHttpRequestHeader_Init_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "minorVer");
                    if (value) {
                        if (pyargs[3])
                            errorArgName = "minorVer";
                        else if (SbkNumber_Check(value))
                            pyargs[3] = value;
else
                            goto Sbk_QHttpRequestHeader_Init_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QHttpRequestHeader(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
                QString cppArg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);
                int cppArg2 = pyargs[2] ? Shiboken::Converter<int >::toCpp(pyargs[2]) : 1;
                int cppArg3 = pyargs[3] ? Shiboken::Converter<int >::toCpp(pyargs[3]) : 1;

                if(!PyErr_Occurred()) {
                    // QHttpRequestHeader(QString,QString,int,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QHttpRequestHeaderWrapper(cppArg0, cppArg1, cppArg2, cppArg3);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 3: // QHttpRequestHeader(QString)
            {
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QHttpRequestHeader(QString)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QHttpRequestHeaderWrapper(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QHttpRequestHeader >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QHttpRequestHeader_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QHttpRequestHeader_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtNetwork.QHttpRequestHeader", "QString, QString, int = 1, int = 1", "QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtNetwork.QHttpRequestHeader", overloads);
        return -1;
}

static PyObject* Sbk_QHttpRequestHeaderFunc_majorVersion(PyObject* self)
{
    QHttpRequestHeader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHttpRequestHeader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // majorVersion()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QHttpRequestHeader::majorVersion():cppSelf->majorVersion());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QHttpRequestHeaderFunc_method(PyObject* self)
{
    QHttpRequestHeader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHttpRequestHeader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // method()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = cppSelf->method();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QHttpRequestHeaderFunc_minorVersion(PyObject* self)
{
    QHttpRequestHeader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHttpRequestHeader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // minorVersion()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QHttpRequestHeader::minorVersion():cppSelf->minorVersion());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QHttpRequestHeaderFunc_parseLine(PyObject* self, PyObject* args)
{
    QHttpRequestHeader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHttpRequestHeader* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "parseLine", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: parseLine(QString,int)
    if (numArgs == 2 && Shiboken::Converter< QString >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // parseLine(QString,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QHttpRequestHeaderFunc_parseLine_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // parseLine(QString,int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QHttpRequestHeader::parseLine(cppArg0, cppArg1):cppSelf->parseLine(cppArg0, cppArg1));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QHttpRequestHeaderFunc_parseLine_TypeError:
        const char* overloads[] = {"QString, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtNetwork.QHttpRequestHeader.parseLine", overloads);
        return 0;
}

static PyObject* Sbk_QHttpRequestHeaderFunc_path(PyObject* self)
{
    QHttpRequestHeader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHttpRequestHeader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // path()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = cppSelf->path();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QHttpRequestHeaderFunc_setRequest(PyObject* self, PyObject* args, PyObject* kwds)
{
    QHttpRequestHeader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHttpRequestHeader* >::toCpp(self);

    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 4) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtNetwork.QHttpRequestHeader.setRequest(): too many arguments");
        return 0;
    } else if (numArgs < 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtNetwork.QHttpRequestHeader.setRequest(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OOOO:setRequest", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: setRequest(QString,QString,int,int)
    if (numArgs >= 2 && Shiboken::Converter< QString >::isConvertible(pyargs[0]) && Shiboken::Converter< QString >::isConvertible(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 0; // setRequest(QString,QString,int,int)
        } else if (SbkNumber_Check(pyargs[2])) {
            if (numArgs == 3) {
                overloadId = 0; // setRequest(QString,QString,int,int)
            } else if (SbkNumber_Check(pyargs[3])) {
                overloadId = 0; // setRequest(QString,QString,int,int)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QHttpRequestHeaderFunc_setRequest_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "majorVer");
                if (value) {
                    if (pyargs[2])
                        errorArgName = "majorVer";
                    else if (SbkNumber_Check(value))
                        pyargs[2] = value;
else
                        goto Sbk_QHttpRequestHeaderFunc_setRequest_TypeError;
                }
                value = PyDict_GetItemString(kwds, "minorVer");
                if (value) {
                    if (pyargs[3])
                        errorArgName = "minorVer";
                    else if (SbkNumber_Check(value))
                        pyargs[3] = value;
else
                        goto Sbk_QHttpRequestHeaderFunc_setRequest_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QHttpRequestHeader.setRequest(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QString cppArg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);
            int cppArg2 = pyargs[2] ? Shiboken::Converter<int >::toCpp(pyargs[2]) : 1;
            int cppArg3 = pyargs[3] ? Shiboken::Converter<int >::toCpp(pyargs[3]) : 1;

            if(!PyErr_Occurred()) {
                // setRequest(QString,QString,int,int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setRequest(cppArg0, cppArg1, cppArg2, cppArg3);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QHttpRequestHeaderFunc_setRequest_TypeError:
        const char* overloads[] = {"QString, QString, int = 1, int = 1", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtNetwork.QHttpRequestHeader.setRequest", overloads);
        return 0;
}

static PyObject* Sbk_QHttpRequestHeaderFunc_toString(PyObject* self)
{
    QHttpRequestHeader* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHttpRequestHeader* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // toString()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QHttpRequestHeader::toString():cppSelf->toString());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject *Sbk_QHttpRequestHeader___copy__(PyObject *self)
{
        QHttpRequestHeader* cppSelf = 0;
        if (!Shiboken::Object::isValid(self))
            return 0;
        cppSelf = Shiboken::Converter<QHttpRequestHeader*>::toCpp(self);
        PyObject* pyResult = 0;
        QHttpRequestHeader* copy = new QHttpRequestHeader(*cppSelf);
        pyResult = Shiboken::Converter<QHttpRequestHeader*>::toPython(copy);
        Shiboken::Object::getOwnership(pyResult);

        if (PyErr_Occurred() || !pyResult) {
            Py_XDECREF(pyResult);
            return 0;
        }
        return pyResult;
}

static PyMethodDef Sbk_QHttpRequestHeader_methods[] = {
    {"majorVersion", (PyCFunction)Sbk_QHttpRequestHeaderFunc_majorVersion, METH_NOARGS},
    {"method", (PyCFunction)Sbk_QHttpRequestHeaderFunc_method, METH_NOARGS},
    {"minorVersion", (PyCFunction)Sbk_QHttpRequestHeaderFunc_minorVersion, METH_NOARGS},
    {"parseLine", (PyCFunction)Sbk_QHttpRequestHeaderFunc_parseLine, METH_VARARGS},
    {"path", (PyCFunction)Sbk_QHttpRequestHeaderFunc_path, METH_NOARGS},
    {"setRequest", (PyCFunction)Sbk_QHttpRequestHeaderFunc_setRequest, METH_VARARGS|METH_KEYWORDS},
    {"toString", (PyCFunction)Sbk_QHttpRequestHeaderFunc_toString, METH_NOARGS},

    {"__copy__", (PyCFunction)Sbk_QHttpRequestHeader___copy__, METH_NOARGS},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QHttpRequestHeader_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtNetwork.QHttpRequestHeader",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QHttpRequestHeader_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QHttpRequestHeader_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern

static SbkObjectType* Sbk_QHttpRequestHeader_typeDiscovery(void* cptr, SbkObjectType* instanceType)
{
    if (instanceType == reinterpret_cast<SbkObjectType*>(Shiboken::SbkType<QHttpHeader >()) && dynamic_cast<QHttpRequestHeader*>(reinterpret_cast<QHttpHeader*>(cptr)))
        return &Sbk_QHttpRequestHeader_Type;
    return 0;
}


void init_QHttpRequestHeader(PyObject* module)
{
    SbkPySide_QtNetworkTypes[SBK_QHTTPREQUESTHEADER_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QHttpRequestHeader_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QHttpRequestHeader_Type);
    Sbk_QHttpRequestHeader_Type.super.ht_type.tp_base = SbkPySide_QtNetworkTypes[SBK_QHTTPHEADER_IDX];
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QHttpRequestHeader_Type, &Shiboken::callCppDestructor<QHttpRequestHeaderWrapper >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QHttpRequestHeader_Type) < 0)
        return;

    // Fill type discovery information
    Shiboken::ObjectType::setTypeDiscoveryFunction(&Sbk_QHttpRequestHeader_Type, &Sbk_QHttpRequestHeader_typeDiscovery);
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkObjectType*>(SbkPySide_QtNetworkTypes[SBK_QHTTPHEADER_IDX]), &Sbk_QHttpRequestHeader_Type);

    Shiboken::ObjectType::setOriginalName(&Sbk_QHttpRequestHeader_Type, "QHttpRequestHeader");
    PyModule_AddObject(module, "QHttpRequestHeader",
        ((PyObject*)&Sbk_QHttpRequestHeader_Type));


    Shiboken::TypeResolver::createValueTypeResolver<QHttpRequestHeader >("QHttpRequestHeader");
    Shiboken::TypeResolver::createObjectTypeResolver<QHttpRequestHeader >("QHttpRequestHeader*");
    Shiboken::TypeResolver::createValueTypeResolver<QHttpRequestHeader >(typeid(QHttpRequestHeader).name());
    Shiboken::TypeResolver::createValueTypeResolver<QHttpRequestHeader >(typeid(QHttpRequestHeaderWrapper).name());
    PySide::initQtMetaType<QHttpRequestHeader >();
}

