/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include "pyside_qtnetwork_python.h"

#include "qnetworkdiskcache_wrapper.h"

// Extra includes
#include <QList>
#include <qabstractnetworkcache.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qiodevice.h>
#include <qnetworkdiskcache.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qthread.h>
#include <qurl.h>


// Native ---------------------------------------------------------

QNetworkDiskCacheWrapper::QNetworkDiskCacheWrapper(QObject * parent) : QNetworkDiskCache(parent) {
    // ... middle
}

qint64 QNetworkDiskCacheWrapper::cacheSize() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "cacheSize"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QNetworkDiskCache::cacheSize();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return qint64(0);
    }
    // Check return type
    bool typeIsValid = PyLong_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QNetworkDiskCache.cacheSize", "qint64", pyResult->ob_type->tp_name);
        return qint64(0);
    }
    qint64 cppResult(Shiboken::Converter< long long >::toCpp(pyResult));
    return cppResult;
}

void QNetworkDiskCacheWrapper::childEvent(QChildEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "childEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::childEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QChildEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QNetworkDiskCacheWrapper::clear()
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "clear"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QNetworkDiskCache::clear();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QNetworkDiskCacheWrapper::connectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "connectNotify"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QNetworkDiskCacheWrapper::customEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "customEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::customEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

QIODevice * QNetworkDiskCacheWrapper::data(const QUrl & url)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "data"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QNetworkDiskCache::data(url);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QUrl >::toPython(url)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return 0;
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QIODevice * >::isConvertible(pyResult);
    typeIsValid = typeIsValid || (pyResult == Py_None);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QNetworkDiskCache.data", Shiboken::SbkType<QIODevice >()->tp_name, pyResult->ob_type->tp_name);
        return 0;
    }
    QIODevice * cppResult(Shiboken::Converter< ::QIODevice * >::toCpp(pyResult));
    return cppResult;
}

void QNetworkDiskCacheWrapper::disconnectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

bool QNetworkDiskCacheWrapper::event(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "event"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::event(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QNetworkDiskCache.event", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
    return cppResult;
}

bool QNetworkDiskCacheWrapper::eventFilter(QObject * arg__1, QEvent * arg__2)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "eventFilter"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::eventFilter(arg__1, arg__2);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QObject * >::toPython(arg__1),
        Shiboken::Converter< ::QEvent * >::toPython(arg__2)
    ));
    bool invalidadeArg2 = PyTuple_GET_ITEM(pyargs, 1)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QNetworkDiskCache.eventFilter", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    if (invalidadeArg2)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 1));
    return cppResult;
}

qint64 QNetworkDiskCacheWrapper::expire()
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "expire"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QNetworkDiskCache::expire();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return qint64(0);
    }
    // Check return type
    bool typeIsValid = PyLong_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QNetworkDiskCache.expire", "qint64", pyResult->ob_type->tp_name);
        return qint64(0);
    }
    qint64 cppResult(Shiboken::Converter< long long >::toCpp(pyResult));
    return cppResult;
}

void QNetworkDiskCacheWrapper::insert(QIODevice * device)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "insert"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QNetworkDiskCache::insert(device);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QIODevice * >::toPython(device)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

QNetworkCacheMetaData QNetworkDiskCacheWrapper::metaData(const QUrl & url)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "metaData"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QNetworkDiskCache::metaData(url);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QUrl >::toPython(url)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QNetworkCacheMetaData();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QNetworkCacheMetaData >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QNetworkDiskCache.metaData", Shiboken::SbkType<QNetworkCacheMetaData >()->tp_name, pyResult->ob_type->tp_name);
        return QNetworkCacheMetaData();
    }
    QNetworkCacheMetaData cppResult(Shiboken::Converter< ::QNetworkCacheMetaData >::toCpp(pyResult));
    return cppResult;
}

QIODevice * QNetworkDiskCacheWrapper::prepare(const QNetworkCacheMetaData & metaData)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "prepare"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QNetworkDiskCache::prepare(metaData);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QNetworkCacheMetaData >::toPython(metaData)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return 0;
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QIODevice * >::isConvertible(pyResult);
    typeIsValid = typeIsValid || (pyResult == Py_None);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QNetworkDiskCache.prepare", Shiboken::SbkType<QIODevice >()->tp_name, pyResult->ob_type->tp_name);
        return 0;
    }
    QIODevice * cppResult(Shiboken::Converter< ::QIODevice * >::toCpp(pyResult));
    return cppResult;
}

bool QNetworkDiskCacheWrapper::remove(const QUrl & url)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "remove"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QNetworkDiskCache::remove(url);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QUrl >::toPython(url)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QNetworkDiskCache.remove", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    return cppResult;
}

void QNetworkDiskCacheWrapper::timerEvent(QTimerEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "timerEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::timerEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QTimerEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QNetworkDiskCacheWrapper::updateMetaData(const QNetworkCacheMetaData & metaData)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "updateMetaData"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QNetworkDiskCache::updateMetaData(metaData);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QNetworkCacheMetaData >::toPython(metaData)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

const QMetaObject* QNetworkDiskCacheWrapper::metaObject() const
{
    SbkObject* pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    return reinterpret_cast<QMetaObject*>(Shiboken::Object::getTypeUserData(pySelf));
}

int QNetworkDiskCacheWrapper::qt_metacall(QMetaObject::Call call, int id, void** args)
{
    int result = QNetworkDiskCache::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

QNetworkDiskCacheWrapper::~QNetworkDiskCacheWrapper()
{
    SbkObject* wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QNetworkDiskCache_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QNetworkDiskCache >()))
        return -1;

    QNetworkDiskCacheWrapper* cptr = 0;
    int overloadId = -1;
    const char* argNames[] = {"parent"};
    const QMetaObject* metaObject;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_ParseTuple(args, "|O:QNetworkDiskCache", &(pyargs[0])))
        return -1;

    // Overloaded function decisor
    // 0: QNetworkDiskCache(QObject*)
    if (numArgs == 0) {
        overloadId = 0; // QNetworkDiskCache(QObject*)
    } else if (Shiboken::Converter< ::QObject * >::isConvertible(pyargs[0])) {
        overloadId = 0; // QNetworkDiskCache(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QNetworkDiskCache_Init_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "parent");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "parent";
                    else if (Shiboken::Converter< ::QObject * >::isConvertible(value))
                        pyargs[0] = value;
else
                        goto Sbk_QNetworkDiskCache_Init_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QNetworkDiskCache(): got multiple values for keyword argument '%s'", errorArgName);
                    return -1;
                }
            }
            if (!Shiboken::Object::isValid(pyargs[0]))
                return -1;
            QObject * cppArg0 = pyargs[0] ? Shiboken::Converter<QObject * >::toCpp(pyargs[0]) : 0;

            if(!PyErr_Occurred()) {
                // QNetworkDiskCache(QObject*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new QNetworkDiskCacheWrapper(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                Shiboken::Object::setParent(pyargs[0], self);
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QNetworkDiskCache >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QNetworkDiskCache_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    metaObject = cptr->metaObject(); // <- init python qt properties
    if (kwds && !PySide::fillQtProperties(self, metaObject, kwds, argNames, 1))
        return -1;


    return 1;

    Sbk_QNetworkDiskCache_Init_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtNetwork.QNetworkDiskCache", overloads);
        return -1;
}

static PyObject* Sbk_QNetworkDiskCacheFunc_cacheDirectory(PyObject* self)
{
    QNetworkDiskCache* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QNetworkDiskCache* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // cacheDirectory()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = cppSelf->cacheDirectory();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QNetworkDiskCacheFunc_cacheSize(PyObject* self)
{
    QNetworkDiskCache* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QNetworkDiskCache* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // cacheSize()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qint64 cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QNetworkDiskCache::cacheSize():cppSelf->cacheSize());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< long long >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QNetworkDiskCacheFunc_clear(PyObject* self)
{
    QNetworkDiskCache* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QNetworkDiskCache* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // clear()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QNetworkDiskCache::clear():cppSelf->clear());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QNetworkDiskCacheFunc_data(PyObject* self, PyObject* arg)
{
    QNetworkDiskCache* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QNetworkDiskCache* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: data(QUrl)
    if (Shiboken::Converter< ::QUrl >::isConvertible(arg)) {
        overloadId = 0; // data(QUrl)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QNetworkDiskCacheFunc_data_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QUrl cppArg0 = Shiboken::Converter<QUrl >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // data(QUrl)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QIODevice * cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QNetworkDiskCache::data(cppArg0):cppSelf->data(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QIODevice * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QNetworkDiskCacheFunc_data_TypeError:
        const char* overloads[] = {"PySide.QtCore.QUrl", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QNetworkDiskCache.data", overloads);
        return 0;
}

static PyObject* Sbk_QNetworkDiskCacheFunc_expire(PyObject* self)
{
    QNetworkDiskCache* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QNetworkDiskCache* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // expire()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qint64 cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QNetworkDiskCache::expire():cppSelf->expire());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< long long >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QNetworkDiskCacheFunc_fileMetaData(PyObject* self, PyObject* arg)
{
    QNetworkDiskCache* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QNetworkDiskCache* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: fileMetaData(QString)const
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // fileMetaData(QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QNetworkDiskCacheFunc_fileMetaData_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // fileMetaData(QString)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QNetworkCacheMetaData cppResult = cppSelf->fileMetaData(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QNetworkCacheMetaData >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QNetworkDiskCacheFunc_fileMetaData_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QNetworkDiskCache.fileMetaData", overloads);
        return 0;
}

static PyObject* Sbk_QNetworkDiskCacheFunc_insert(PyObject* self, PyObject* arg)
{
    QNetworkDiskCache* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QNetworkDiskCache* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: insert(QIODevice*)
    if (Shiboken::Converter< ::QIODevice * >::isConvertible(arg)) {
        overloadId = 0; // insert(QIODevice*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QNetworkDiskCacheFunc_insert_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QIODevice * cppArg0 = Shiboken::Converter<QIODevice * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // insert(QIODevice*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QNetworkDiskCache::insert(cppArg0):cppSelf->insert(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QNetworkDiskCacheFunc_insert_TypeError:
        const char* overloads[] = {"PySide.QtCore.QIODevice", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QNetworkDiskCache.insert", overloads);
        return 0;
}

static PyObject* Sbk_QNetworkDiskCacheFunc_maximumCacheSize(PyObject* self)
{
    QNetworkDiskCache* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QNetworkDiskCache* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // maximumCacheSize()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qint64 cppResult = cppSelf->maximumCacheSize();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< long long >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QNetworkDiskCacheFunc_metaData(PyObject* self, PyObject* arg)
{
    QNetworkDiskCache* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QNetworkDiskCache* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: metaData(QUrl)
    if (Shiboken::Converter< ::QUrl >::isConvertible(arg)) {
        overloadId = 0; // metaData(QUrl)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QNetworkDiskCacheFunc_metaData_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QUrl cppArg0 = Shiboken::Converter<QUrl >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // metaData(QUrl)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QNetworkCacheMetaData cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QNetworkDiskCache::metaData(cppArg0):cppSelf->metaData(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QNetworkCacheMetaData >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QNetworkDiskCacheFunc_metaData_TypeError:
        const char* overloads[] = {"PySide.QtCore.QUrl", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QNetworkDiskCache.metaData", overloads);
        return 0;
}

static PyObject* Sbk_QNetworkDiskCacheFunc_prepare(PyObject* self, PyObject* arg)
{
    QNetworkDiskCache* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QNetworkDiskCache* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: prepare(QNetworkCacheMetaData)
    if (Shiboken::Converter< ::QNetworkCacheMetaData >::isConvertible(arg)) {
        overloadId = 0; // prepare(QNetworkCacheMetaData)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QNetworkDiskCacheFunc_prepare_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QNetworkCacheMetaData cppArg0 = Shiboken::Converter<QNetworkCacheMetaData >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // prepare(QNetworkCacheMetaData)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QIODevice * cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QNetworkDiskCache::prepare(cppArg0):cppSelf->prepare(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QIODevice * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QNetworkDiskCacheFunc_prepare_TypeError:
        const char* overloads[] = {"PySide.QtNetwork.QNetworkCacheMetaData", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QNetworkDiskCache.prepare", overloads);
        return 0;
}

static PyObject* Sbk_QNetworkDiskCacheFunc_remove(PyObject* self, PyObject* arg)
{
    QNetworkDiskCache* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QNetworkDiskCache* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: remove(QUrl)
    if (Shiboken::Converter< ::QUrl >::isConvertible(arg)) {
        overloadId = 0; // remove(QUrl)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QNetworkDiskCacheFunc_remove_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QUrl cppArg0 = Shiboken::Converter<QUrl >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // remove(QUrl)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QNetworkDiskCache::remove(cppArg0):cppSelf->remove(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QNetworkDiskCacheFunc_remove_TypeError:
        const char* overloads[] = {"PySide.QtCore.QUrl", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QNetworkDiskCache.remove", overloads);
        return 0;
}

static PyObject* Sbk_QNetworkDiskCacheFunc_setCacheDirectory(PyObject* self, PyObject* arg)
{
    QNetworkDiskCache* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QNetworkDiskCache* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setCacheDirectory(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // setCacheDirectory(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QNetworkDiskCacheFunc_setCacheDirectory_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setCacheDirectory(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setCacheDirectory(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QNetworkDiskCacheFunc_setCacheDirectory_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QNetworkDiskCache.setCacheDirectory", overloads);
        return 0;
}

static PyObject* Sbk_QNetworkDiskCacheFunc_setMaximumCacheSize(PyObject* self, PyObject* arg)
{
    QNetworkDiskCache* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QNetworkDiskCache* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setMaximumCacheSize(qint64)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setMaximumCacheSize(qint64)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QNetworkDiskCacheFunc_setMaximumCacheSize_TypeError;

    // Call function/method
    {
        {
            qint64 cppArg0 = Shiboken::Converter<qint64 >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setMaximumCacheSize(qint64)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setMaximumCacheSize(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QNetworkDiskCacheFunc_setMaximumCacheSize_TypeError:
        const char* overloads[] = {"long long", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QNetworkDiskCache.setMaximumCacheSize", overloads);
        return 0;
}

static PyObject* Sbk_QNetworkDiskCacheFunc_updateMetaData(PyObject* self, PyObject* arg)
{
    QNetworkDiskCache* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QNetworkDiskCache* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: updateMetaData(QNetworkCacheMetaData)
    if (Shiboken::Converter< ::QNetworkCacheMetaData >::isConvertible(arg)) {
        overloadId = 0; // updateMetaData(QNetworkCacheMetaData)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QNetworkDiskCacheFunc_updateMetaData_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QNetworkCacheMetaData cppArg0 = Shiboken::Converter<QNetworkCacheMetaData >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // updateMetaData(QNetworkCacheMetaData)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QNetworkDiskCache::updateMetaData(cppArg0):cppSelf->updateMetaData(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QNetworkDiskCacheFunc_updateMetaData_TypeError:
        const char* overloads[] = {"PySide.QtNetwork.QNetworkCacheMetaData", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QNetworkDiskCache.updateMetaData", overloads);
        return 0;
}

static PyMethodDef Sbk_QNetworkDiskCache_methods[] = {
    {"cacheDirectory", (PyCFunction)Sbk_QNetworkDiskCacheFunc_cacheDirectory, METH_NOARGS},
    {"cacheSize", (PyCFunction)Sbk_QNetworkDiskCacheFunc_cacheSize, METH_NOARGS},
    {"clear", (PyCFunction)Sbk_QNetworkDiskCacheFunc_clear, METH_NOARGS},
    {"data", (PyCFunction)Sbk_QNetworkDiskCacheFunc_data, METH_O},
    {"expire", (PyCFunction)Sbk_QNetworkDiskCacheFunc_expire, METH_NOARGS},
    {"fileMetaData", (PyCFunction)Sbk_QNetworkDiskCacheFunc_fileMetaData, METH_O},
    {"insert", (PyCFunction)Sbk_QNetworkDiskCacheFunc_insert, METH_O},
    {"maximumCacheSize", (PyCFunction)Sbk_QNetworkDiskCacheFunc_maximumCacheSize, METH_NOARGS},
    {"metaData", (PyCFunction)Sbk_QNetworkDiskCacheFunc_metaData, METH_O},
    {"prepare", (PyCFunction)Sbk_QNetworkDiskCacheFunc_prepare, METH_O},
    {"remove", (PyCFunction)Sbk_QNetworkDiskCacheFunc_remove, METH_O},
    {"setCacheDirectory", (PyCFunction)Sbk_QNetworkDiskCacheFunc_setCacheDirectory, METH_O},
    {"setMaximumCacheSize", (PyCFunction)Sbk_QNetworkDiskCacheFunc_setMaximumCacheSize, METH_O},
    {"updateMetaData", (PyCFunction)Sbk_QNetworkDiskCacheFunc_updateMetaData, METH_O},

    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QNetworkDiskCache_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtNetwork.QNetworkDiskCache",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QNetworkDiskCache_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QNetworkDiskCache_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern

static SbkObjectType* Sbk_QNetworkDiskCache_typeDiscovery(void* cptr, SbkObjectType* instanceType)
{
    if (instanceType == reinterpret_cast<SbkObjectType*>(Shiboken::SbkType<QObject >()) && dynamic_cast<QNetworkDiskCache*>(reinterpret_cast<QObject*>(cptr)))
        return &Sbk_QNetworkDiskCache_Type;
    return 0;
}


void init_QNetworkDiskCache(PyObject* module)
{
    SbkPySide_QtNetworkTypes[SBK_QNETWORKDISKCACHE_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QNetworkDiskCache_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QNetworkDiskCache_Type);
    Shiboken::ObjectType::setSubTypeInitHook(&Sbk_QNetworkDiskCache_Type, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(&Sbk_QNetworkDiskCache_Type, &QNetworkDiskCache::staticMetaObject);    Sbk_QNetworkDiskCache_Type.super.ht_type.tp_base = SbkPySide_QtNetworkTypes[SBK_QABSTRACTNETWORKCACHE_IDX];
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QNetworkDiskCache_Type, &Shiboken::callCppDestructor<QNetworkDiskCache >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QNetworkDiskCache_Type) < 0)
        return;

    // Fill type discovery information
    Shiboken::ObjectType::setTypeDiscoveryFunction(&Sbk_QNetworkDiskCache_Type, &Sbk_QNetworkDiskCache_typeDiscovery);
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkObjectType*>(SbkPySide_QtNetworkTypes[SBK_QABSTRACTNETWORKCACHE_IDX]), &Sbk_QNetworkDiskCache_Type);

    Shiboken::ObjectType::setOriginalName(&Sbk_QNetworkDiskCache_Type, "QNetworkDiskCache*");
    PyModule_AddObject(module, "QNetworkDiskCache",
        ((PyObject*)&Sbk_QNetworkDiskCache_Type));


    Shiboken::TypeResolver::createObjectTypeResolver<QNetworkDiskCache >("QNetworkDiskCache*");
    Shiboken::TypeResolver::createObjectTypeResolver<QNetworkDiskCache >(typeid(QNetworkDiskCache).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QNetworkDiskCache >(typeid(QNetworkDiskCacheWrapper).name());
    PySide::initQtMetaType<QNetworkDiskCache* >();
}

