/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtnetwork_python.h"

#include "qnetworkinterface_wrapper.h"

// Extra includes
#include <QList>
#include <qhostaddress.h>
#include <qnetworkinterface.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QNetworkInterface_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QNetworkInterface >()))
        return -1;

    QNetworkInterface* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QNetworkInterface", 0, 1, &(pyargs[0])))
        return -1;

    // Overloaded function decisor
    // 0: QNetworkInterface()
    // 1: QNetworkInterface(QNetworkInterface)
    if (numArgs == 0) {
        overloadId = 0; // QNetworkInterface()
    } else if (numArgs == 1 && Shiboken::Converter< ::QNetworkInterface >::isConvertible(pyargs[0])) {
        overloadId = 1; // QNetworkInterface(QNetworkInterface)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QNetworkInterface_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QNetworkInterface()
            {

                if(!PyErr_Occurred()) {
                    // QNetworkInterface()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QNetworkInterface();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // QNetworkInterface(QNetworkInterface)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QNetworkInterface cppArg0 = Shiboken::Converter<QNetworkInterface >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QNetworkInterface(QNetworkInterface)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QNetworkInterface(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QNetworkInterface >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QNetworkInterface_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QNetworkInterface_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtNetwork.QNetworkInterface", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtNetwork.QNetworkInterface", overloads);
        return -1;
}

static PyObject* Sbk_QNetworkInterfaceFunc_addressEntries(PyObject* self)
{
    QNetworkInterface* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QNetworkInterface* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // addressEntries()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QList<QNetworkAddressEntry > cppResult = cppSelf->addressEntries();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QList<QNetworkAddressEntry > >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QNetworkInterfaceFunc_allAddresses(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // allAddresses()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QList<QHostAddress > cppResult = QNetworkInterface::allAddresses();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QList<QHostAddress > >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QNetworkInterfaceFunc_allInterfaces(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // allInterfaces()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QList<QNetworkInterface > cppResult = QNetworkInterface::allInterfaces();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QList<QNetworkInterface > >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QNetworkInterfaceFunc_flags(PyObject* self)
{
    QNetworkInterface* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QNetworkInterface* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // flags()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QFlags<QNetworkInterface::InterfaceFlag> cppResult = cppSelf->flags();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QFlags<QNetworkInterface::InterfaceFlag> >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QNetworkInterfaceFunc_hardwareAddress(PyObject* self)
{
    QNetworkInterface* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QNetworkInterface* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // hardwareAddress()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = cppSelf->hardwareAddress();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QNetworkInterfaceFunc_humanReadableName(PyObject* self)
{
    QNetworkInterface* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QNetworkInterface* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // humanReadableName()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = cppSelf->humanReadableName();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QNetworkInterfaceFunc_index(PyObject* self)
{
    QNetworkInterface* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QNetworkInterface* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // index()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->index();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QNetworkInterfaceFunc_interfaceFromIndex(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: interfaceFromIndex(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // interfaceFromIndex(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QNetworkInterfaceFunc_interfaceFromIndex_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // interfaceFromIndex(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QNetworkInterface cppResult = QNetworkInterface::interfaceFromIndex(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QNetworkInterface >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QNetworkInterfaceFunc_interfaceFromIndex_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QNetworkInterface.interfaceFromIndex", overloads);
        return 0;
}

static PyObject* Sbk_QNetworkInterfaceFunc_interfaceFromName(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: interfaceFromName(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // interfaceFromName(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QNetworkInterfaceFunc_interfaceFromName_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // interfaceFromName(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QNetworkInterface cppResult = QNetworkInterface::interfaceFromName(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QNetworkInterface >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QNetworkInterfaceFunc_interfaceFromName_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtNetwork.QNetworkInterface.interfaceFromName", overloads);
        return 0;
}

static PyObject* Sbk_QNetworkInterfaceFunc_isValid(PyObject* self)
{
    QNetworkInterface* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QNetworkInterface* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isValid()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->isValid();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QNetworkInterfaceFunc_name(PyObject* self)
{
    QNetworkInterface* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QNetworkInterface* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // name()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = cppSelf->name();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject *Sbk_QNetworkInterface___copy__(PyObject *self)
{
        QNetworkInterface* cppSelf = 0;
        if (!Shiboken::Object::isValid(self))
            return 0;
        cppSelf = Shiboken::Converter<QNetworkInterface*>::toCpp(self);
        PyObject* pyResult = 0;
        QNetworkInterface* copy = new QNetworkInterface(*cppSelf);
        pyResult = Shiboken::Converter<QNetworkInterface*>::toPython(copy);
        Shiboken::Object::getOwnership(pyResult);

        if (PyErr_Occurred() || !pyResult) {
            Py_XDECREF(pyResult);
            return 0;
        }
        return pyResult;
}

static PyMethodDef Sbk_QNetworkInterface_methods[] = {
    {"addressEntries", (PyCFunction)Sbk_QNetworkInterfaceFunc_addressEntries, METH_NOARGS},
    {"allAddresses", (PyCFunction)Sbk_QNetworkInterfaceFunc_allAddresses, METH_NOARGS|METH_STATIC},
    {"allInterfaces", (PyCFunction)Sbk_QNetworkInterfaceFunc_allInterfaces, METH_NOARGS|METH_STATIC},
    {"flags", (PyCFunction)Sbk_QNetworkInterfaceFunc_flags, METH_NOARGS},
    {"hardwareAddress", (PyCFunction)Sbk_QNetworkInterfaceFunc_hardwareAddress, METH_NOARGS},
    {"humanReadableName", (PyCFunction)Sbk_QNetworkInterfaceFunc_humanReadableName, METH_NOARGS},
    {"index", (PyCFunction)Sbk_QNetworkInterfaceFunc_index, METH_NOARGS},
    {"interfaceFromIndex", (PyCFunction)Sbk_QNetworkInterfaceFunc_interfaceFromIndex, METH_O|METH_STATIC},
    {"interfaceFromName", (PyCFunction)Sbk_QNetworkInterfaceFunc_interfaceFromName, METH_O|METH_STATIC},
    {"isValid", (PyCFunction)Sbk_QNetworkInterfaceFunc_isValid, METH_NOARGS},
    {"name", (PyCFunction)Sbk_QNetworkInterfaceFunc_name, METH_NOARGS},

    {"__copy__", (PyCFunction)Sbk_QNetworkInterface___copy__, METH_NOARGS},
    {0} // Sentinel
};

} // extern "C"

extern "C"
{
static PyObject* Sbk_QNetworkInterface__repr__(PyObject* pyObj)
{
    QBuffer buffer;
    buffer.open(QBuffer::ReadWrite);
    QDebug dbg(&buffer);
    dbg << Shiboken::Converter< ::QNetworkInterface >::toCpp(pyObj);
    buffer.close();
    return PyString_FromFormat("<PySide.QtNetwork.%s at %p>", buffer.data().constData(), pyObj);
}
} // extern C

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QNetworkInterface_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtNetwork.QNetworkInterface",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Sbk_QNetworkInterface__repr__,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QNetworkInterface_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QNetworkInterface_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern

PyObject* SbkPySide_QtNetwork_QNetworkInterface_InterfaceFlag___and__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QNetworkInterface::InterfaceFlags >::toPython(
        Shiboken::Converter<QNetworkInterface::InterfaceFlags>::toCpp(self)
        & Shiboken::Converter< QNetworkInterface::InterfaceFlags >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtNetwork_QNetworkInterface_InterfaceFlag___or__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QNetworkInterface::InterfaceFlags >::toPython(
        Shiboken::Converter<QNetworkInterface::InterfaceFlags>::toCpp(self)
        | Shiboken::Converter< QNetworkInterface::InterfaceFlags >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtNetwork_QNetworkInterface_InterfaceFlag___xor__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QNetworkInterface::InterfaceFlags >::toPython(
        Shiboken::Converter<QNetworkInterface::InterfaceFlags>::toCpp(self)
        ^ Shiboken::Converter< QNetworkInterface::InterfaceFlags >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtNetwork_QNetworkInterface_InterfaceFlag___invert__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QNetworkInterface::InterfaceFlags >::toPython(
        ~Shiboken::Converter<QNetworkInterface::InterfaceFlags >::toCpp(self)
    );
}


static PyNumberMethods SbkPySide_QtNetwork_QNetworkInterface_InterfaceFlag_as_number = {
    /*nb_add*/                  0,
    /*nb_subtract*/             0,
    /*nb_multiply*/             0,
    /*nb_divide*/               0,
    /*nb_remainder*/            0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             0,
    /*nb_positive*/             0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              0,
    /*nb_invert*/               (unaryfunc)SbkPySide_QtNetwork_QNetworkInterface_InterfaceFlag___invert__,
    /*nb_lshift*/               0,
    /*nb_rshift*/               0,
    /*nb_and*/                  (binaryfunc)SbkPySide_QtNetwork_QNetworkInterface_InterfaceFlag___and__,
    /*nb_xor*/                  (binaryfunc)SbkPySide_QtNetwork_QNetworkInterface_InterfaceFlag___xor__,
    /*nb_or*/                   (binaryfunc)SbkPySide_QtNetwork_QNetworkInterface_InterfaceFlag___or__,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          0,
    /*nb_inplace_subtract*/     0,
    /*nb_inplace_multiply*/     0,
    /*nb_inplace_divide*/       0,
    /*nb_inplace_remainder*/    0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       0,
    /*nb_inplace_rshift*/       0,
    /*nb_inplace_and*/          0,
    /*nb_inplace_xor*/          0,
    /*nb_inplace_or*/           0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};


// forward declaration of new function
static PyTypeObject SbkPySide_QtNetwork_QNetworkInterface_InterfaceFlags_Type = {
    PyObject_HEAD_INIT(&PyType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "InterfaceFlags",
    /*tp_basicsize*/        0,
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        &SbkPySide_QtNetwork_QNetworkInterface_InterfaceFlag_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT | Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              PyInt_Type.tp_new,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};



void init_QNetworkInterface(PyObject* module)
{
    SbkPySide_QtNetworkTypes[SBK_QNETWORKINTERFACE_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QNetworkInterface_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QNetworkInterface_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QNetworkInterface_Type, &Shiboken::callCppDestructor<QNetworkInterface >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QNetworkInterface_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QNetworkInterface_Type, "QNetworkInterface");
    PyModule_AddObject(module, "QNetworkInterface",
        ((PyObject*)&Sbk_QNetworkInterface_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: InterfaceFlag
    PyTypeObject* SbkPySide_QtNetwork_QNetworkInterface_InterfaceFlag = Shiboken::Enum::newType("InterfaceFlag");
    SbkPySide_QtNetwork_QNetworkInterface_InterfaceFlag->tp_as_number = &SbkPySide_QtNetwork_QNetworkInterface_InterfaceFlag_as_number;
    SbkPySide_QtNetworkTypes[SBK_QNETWORKINTERFACE_INTERFACEFLAG_IDX] = SbkPySide_QtNetwork_QNetworkInterface_InterfaceFlag;
    if (PyType_Ready(SbkPySide_QtNetwork_QNetworkInterface_InterfaceFlag) < 0)
        return;
    PyDict_SetItemString(Sbk_QNetworkInterface_Type.super.ht_type.tp_dict,
            "InterfaceFlag",((PyObject*)SbkPySide_QtNetwork_QNetworkInterface_InterfaceFlag));

    // init flags class: QFlags<QNetworkInterface::InterfaceFlag>
    SbkPySide_QtNetworkTypes[SBK_QFLAGS_QNETWORKINTERFACE_INTERFACEFLAG__IDX] = &SbkPySide_QtNetwork_QNetworkInterface_InterfaceFlags_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtNetwork_QNetworkInterface_InterfaceFlags_Type) < 0)
        return;
    PyDict_SetItemString(Sbk_QNetworkInterface_Type.super.ht_type.tp_dict,
            "InterfaceFlags",((PyObject*)&SbkPySide_QtNetwork_QNetworkInterface_InterfaceFlags_Type));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QNetworkInterface_InterfaceFlag,(long) QNetworkInterface::IsUp, "IsUp");
    PyDict_SetItemString(Sbk_QNetworkInterface_Type.super.ht_type.tp_dict,"IsUp", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QNetworkInterface_InterfaceFlag->tp_dict,"IsUp", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QNetworkInterface_InterfaceFlag,(long) QNetworkInterface::IsRunning, "IsRunning");
    PyDict_SetItemString(Sbk_QNetworkInterface_Type.super.ht_type.tp_dict,"IsRunning", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QNetworkInterface_InterfaceFlag->tp_dict,"IsRunning", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QNetworkInterface_InterfaceFlag,(long) QNetworkInterface::CanBroadcast, "CanBroadcast");
    PyDict_SetItemString(Sbk_QNetworkInterface_Type.super.ht_type.tp_dict,"CanBroadcast", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QNetworkInterface_InterfaceFlag->tp_dict,"CanBroadcast", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QNetworkInterface_InterfaceFlag,(long) QNetworkInterface::IsLoopBack, "IsLoopBack");
    PyDict_SetItemString(Sbk_QNetworkInterface_Type.super.ht_type.tp_dict,"IsLoopBack", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QNetworkInterface_InterfaceFlag->tp_dict,"IsLoopBack", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QNetworkInterface_InterfaceFlag,(long) QNetworkInterface::IsPointToPoint, "IsPointToPoint");
    PyDict_SetItemString(Sbk_QNetworkInterface_Type.super.ht_type.tp_dict,"IsPointToPoint", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QNetworkInterface_InterfaceFlag->tp_dict,"IsPointToPoint", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtNetwork_QNetworkInterface_InterfaceFlag,(long) QNetworkInterface::CanMulticast, "CanMulticast");
    PyDict_SetItemString(Sbk_QNetworkInterface_Type.super.ht_type.tp_dict,"CanMulticast", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtNetwork_QNetworkInterface_InterfaceFlag->tp_dict,"CanMulticast", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QNetworkInterface::InterfaceFlag");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::InterfaceFlag");
    // end of enum InterfaceFlag


    Shiboken::TypeResolver::createValueTypeResolver<QNetworkInterface >("QNetworkInterface");
    Shiboken::TypeResolver::createObjectTypeResolver<QNetworkInterface >("QNetworkInterface*");
    Shiboken::TypeResolver::createValueTypeResolver<QNetworkInterface >(typeid(QNetworkInterface).name());
    PySide::initQtMetaType<QNetworkInterface >();
}

