/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtnetwork_python.h"

#include "qsslkey_wrapper.h"

// Extra includes
#include <qbytearray.h>
#include <qiodevice.h>
#include <qsslkey.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QSslKey_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QSslKey >()))
        return -1;

    QSslKey* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);

    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);

    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 5) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtNetwork.QSslKey(): too many arguments");
        return -1;
    }

    if (!PyArg_ParseTuple(args, "|OOOOO:QSslKey", &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3]), &(pyargs[4])))
        return -1;

    // Overloaded function decisor
    // 0: QSslKey()
    // 1: QSslKey(QIODevice*,QSsl::KeyAlgorithm,QSsl::EncodingFormat,QSsl::KeyType,QByteArray)
    // 2: QSslKey(QByteArray,QSsl::KeyAlgorithm,QSsl::EncodingFormat,QSsl::KeyType,QByteArray)
    // 3: QSslKey(QSslKey)
    if (numArgs == 0) {
        overloadId = 0; // QSslKey()
    } else if (numArgs == 1 && Shiboken::Converter< ::QSslKey >::isConvertible(pyargs[0])) {
        overloadId = 3; // QSslKey(QSslKey)
    } else if (numArgs >= 2 && Shiboken::Converter< ::QByteArray >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QSsl::KeyAlgorithm >::isConvertible(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 2; // QSslKey(QByteArray,QSsl::KeyAlgorithm,QSsl::EncodingFormat,QSsl::KeyType,QByteArray)
        } else if (Shiboken::Converter< ::QSsl::EncodingFormat >::isConvertible(pyargs[2])) {
            if (numArgs == 3) {
                overloadId = 2; // QSslKey(QByteArray,QSsl::KeyAlgorithm,QSsl::EncodingFormat,QSsl::KeyType,QByteArray)
            } else if (Shiboken::Converter< ::QSsl::KeyType >::isConvertible(pyargs[3])) {
                if (numArgs == 4) {
                    overloadId = 2; // QSslKey(QByteArray,QSsl::KeyAlgorithm,QSsl::EncodingFormat,QSsl::KeyType,QByteArray)
                } else if (Shiboken::Converter< ::QByteArray >::isConvertible(pyargs[4])) {
                    overloadId = 2; // QSslKey(QByteArray,QSsl::KeyAlgorithm,QSsl::EncodingFormat,QSsl::KeyType,QByteArray)
                }
            }
        }
    } else if (numArgs >= 2 && Shiboken::Converter< ::QIODevice * >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QSsl::KeyAlgorithm >::isConvertible(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 1; // QSslKey(QIODevice*,QSsl::KeyAlgorithm,QSsl::EncodingFormat,QSsl::KeyType,QByteArray)
        } else if (Shiboken::Converter< ::QSsl::EncodingFormat >::isConvertible(pyargs[2])) {
            if (numArgs == 3) {
                overloadId = 1; // QSslKey(QIODevice*,QSsl::KeyAlgorithm,QSsl::EncodingFormat,QSsl::KeyType,QByteArray)
            } else if (Shiboken::Converter< ::QSsl::KeyType >::isConvertible(pyargs[3])) {
                if (numArgs == 4) {
                    overloadId = 1; // QSslKey(QIODevice*,QSsl::KeyAlgorithm,QSsl::EncodingFormat,QSsl::KeyType,QByteArray)
                } else if (Shiboken::Converter< ::QByteArray >::isConvertible(pyargs[4])) {
                    overloadId = 1; // QSslKey(QIODevice*,QSsl::KeyAlgorithm,QSsl::EncodingFormat,QSsl::KeyType,QByteArray)
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSslKey_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QSslKey()
            {

                if(!PyErr_Occurred()) {
                    // QSslKey()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QSslKey();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // QSslKey(QIODevice*,QSsl::KeyAlgorithm,QSsl::EncodingFormat,QSsl::KeyType,QByteArray)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "format");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "format";
                        else if (Shiboken::Converter< ::QSsl::EncodingFormat >::isConvertible(value))
                            pyargs[2] = value;
else
                            goto Sbk_QSslKey_Init_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "type");
                    if (value) {
                        if (pyargs[3])
                            errorArgName = "type";
                        else if (Shiboken::Converter< ::QSsl::KeyType >::isConvertible(value))
                            pyargs[3] = value;
else
                            goto Sbk_QSslKey_Init_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "passPhrase");
                    if (value) {
                        if (pyargs[4])
                            errorArgName = "passPhrase";
                        else if (Shiboken::Converter< ::QByteArray >::isConvertible(value))
                            pyargs[4] = value;
else
                            goto Sbk_QSslKey_Init_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QSslKey(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QIODevice * cppArg0 = Shiboken::Converter<QIODevice * >::toCpp(pyargs[0]);
                QSsl::KeyAlgorithm cppArg1 = Shiboken::Converter<QSsl::KeyAlgorithm >::toCpp(pyargs[1]);
                QSsl::EncodingFormat cppArg2 = pyargs[2] ? Shiboken::Converter<QSsl::EncodingFormat >::toCpp(pyargs[2]) : QSsl::Pem;
                QSsl::KeyType cppArg3 = pyargs[3] ? Shiboken::Converter<QSsl::KeyType >::toCpp(pyargs[3]) : QSsl::PrivateKey;
                if (!Shiboken::Object::isValid(pyargs[4]))
                    return -1;
                QByteArray cppArg4_tmp = QByteArray();
                QByteArray cppArg4 = pyargs[4] ? Shiboken::Converter<QByteArray >::toCpp(pyargs[4]) : cppArg4_tmp;

                if(!PyErr_Occurred()) {
                    // QSslKey(QIODevice*,QSsl::KeyAlgorithm,QSsl::EncodingFormat,QSsl::KeyType,QByteArray)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QSslKey(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 2: // QSslKey(QByteArray,QSsl::KeyAlgorithm,QSsl::EncodingFormat,QSsl::KeyType,QByteArray)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "format");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "format";
                        else if (Shiboken::Converter< ::QSsl::EncodingFormat >::isConvertible(value))
                            pyargs[2] = value;
else
                            goto Sbk_QSslKey_Init_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "type");
                    if (value) {
                        if (pyargs[3])
                            errorArgName = "type";
                        else if (Shiboken::Converter< ::QSsl::KeyType >::isConvertible(value))
                            pyargs[3] = value;
else
                            goto Sbk_QSslKey_Init_TypeError;
                    }
                    value = PyDict_GetItemString(kwds, "passPhrase");
                    if (value) {
                        if (pyargs[4])
                            errorArgName = "passPhrase";
                        else if (Shiboken::Converter< ::QByteArray >::isConvertible(value))
                            pyargs[4] = value;
else
                            goto Sbk_QSslKey_Init_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QSslKey(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QByteArray cppArg0 = Shiboken::Converter<QByteArray >::toCpp(pyargs[0]);
                QSsl::KeyAlgorithm cppArg1 = Shiboken::Converter<QSsl::KeyAlgorithm >::toCpp(pyargs[1]);
                QSsl::EncodingFormat cppArg2 = pyargs[2] ? Shiboken::Converter<QSsl::EncodingFormat >::toCpp(pyargs[2]) : QSsl::Pem;
                QSsl::KeyType cppArg3 = pyargs[3] ? Shiboken::Converter<QSsl::KeyType >::toCpp(pyargs[3]) : QSsl::PrivateKey;
                if (!Shiboken::Object::isValid(pyargs[4]))
                    return -1;
                QByteArray cppArg4_tmp = QByteArray();
                QByteArray cppArg4 = pyargs[4] ? Shiboken::Converter<QByteArray >::toCpp(pyargs[4]) : cppArg4_tmp;

                if(!PyErr_Occurred()) {
                    // QSslKey(QByteArray,QSsl::KeyAlgorithm,QSsl::EncodingFormat,QSsl::KeyType,QByteArray)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QSslKey(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 3: // QSslKey(QSslKey)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QSslKey cppArg0 = Shiboken::Converter<QSslKey >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QSslKey(QSslKey)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QSslKey(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QSslKey >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QSslKey_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QSslKey_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtCore.QIODevice, PySide.QtNetwork.QSsl.KeyAlgorithm, PySide.QtNetwork.QSsl.EncodingFormat = QSsl.Pem, PySide.QtNetwork.QSsl.KeyType = QSsl.PrivateKey, PySide.QtCore.QByteArray = QByteArray()", "PySide.QtCore.QByteArray, PySide.QtNetwork.QSsl.KeyAlgorithm, PySide.QtNetwork.QSsl.EncodingFormat = QSsl.Pem, PySide.QtNetwork.QSsl.KeyType = QSsl.PrivateKey, PySide.QtCore.QByteArray = QByteArray()", "PySide.QtNetwork.QSslKey", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtNetwork.QSslKey", overloads);
        return -1;
}

static PyObject* Sbk_QSslKeyFunc_algorithm(PyObject* self)
{
    QSslKey* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSslKey* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // algorithm()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QSsl::KeyAlgorithm cppResult = cppSelf->algorithm();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QSsl::KeyAlgorithm >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QSslKeyFunc_clear(PyObject* self)
{
    QSslKey* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSslKey* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // clear()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->clear();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QSslKeyFunc_handle(PyObject* self)
{
    QSslKey* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSslKey* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // handle()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                Qt::HANDLE cppResult = cppSelf->handle();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< Qt::HANDLE >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QSslKeyFunc_isNull(PyObject* self)
{
    QSslKey* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSslKey* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isNull()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->isNull();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QSslKeyFunc_length(PyObject* self)
{
    QSslKey* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSslKey* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // length()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->length();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QSslKeyFunc_toDer(PyObject* self, PyObject* args, PyObject* kwds)
{
    QSslKey* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSslKey* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtNetwork.QSslKey.toDer(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:toDer", &(pyargs[0])))
        return 0;


    // Overloaded function decisor
    // 0: toDer(QByteArray)const
    if (numArgs == 0) {
        overloadId = 0; // toDer(QByteArray)const
    } else if (Shiboken::Converter< ::QByteArray >::isConvertible(pyargs[0])) {
        overloadId = 0; // toDer(QByteArray)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSslKeyFunc_toDer_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "passPhrase");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "passPhrase";
                    else if (Shiboken::Converter< ::QByteArray >::isConvertible(value))
                        pyargs[0] = value;
else
                        goto Sbk_QSslKeyFunc_toDer_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QSslKey.toDer(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QByteArray cppArg0_tmp = QByteArray();
            QByteArray cppArg0 = pyargs[0] ? Shiboken::Converter<QByteArray >::toCpp(pyargs[0]) : cppArg0_tmp;

            if(!PyErr_Occurred()) {
                // toDer(QByteArray)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QByteArray cppResult = cppSelf->toDer(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QByteArray >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QSslKeyFunc_toDer_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray = QByteArray()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtNetwork.QSslKey.toDer", overloads);
        return 0;
}

static PyObject* Sbk_QSslKeyFunc_toPem(PyObject* self, PyObject* args, PyObject* kwds)
{
    QSslKey* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSslKey* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtNetwork.QSslKey.toPem(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:toPem", &(pyargs[0])))
        return 0;


    // Overloaded function decisor
    // 0: toPem(QByteArray)const
    if (numArgs == 0) {
        overloadId = 0; // toPem(QByteArray)const
    } else if (Shiboken::Converter< ::QByteArray >::isConvertible(pyargs[0])) {
        overloadId = 0; // toPem(QByteArray)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QSslKeyFunc_toPem_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "passPhrase");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "passPhrase";
                    else if (Shiboken::Converter< ::QByteArray >::isConvertible(value))
                        pyargs[0] = value;
else
                        goto Sbk_QSslKeyFunc_toPem_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtNetwork.QSslKey.toPem(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QByteArray cppArg0_tmp = QByteArray();
            QByteArray cppArg0 = pyargs[0] ? Shiboken::Converter<QByteArray >::toCpp(pyargs[0]) : cppArg0_tmp;

            if(!PyErr_Occurred()) {
                // toPem(QByteArray)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QByteArray cppResult = cppSelf->toPem(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QByteArray >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QSslKeyFunc_toPem_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray = QByteArray()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtNetwork.QSslKey.toPem", overloads);
        return 0;
}

static PyObject* Sbk_QSslKeyFunc_type(PyObject* self)
{
    QSslKey* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QSslKey* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // type()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QSsl::KeyType cppResult = cppSelf->type();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QSsl::KeyType >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject *Sbk_QSslKey___copy__(PyObject *self)
{
        QSslKey* cppSelf = 0;
        if (!Shiboken::Object::isValid(self))
            return 0;
        cppSelf = Shiboken::Converter<QSslKey*>::toCpp(self);
        PyObject* pyResult = 0;
        QSslKey* copy = new QSslKey(*cppSelf);
        pyResult = Shiboken::Converter<QSslKey*>::toPython(copy);
        Shiboken::Object::getOwnership(pyResult);

        if (PyErr_Occurred() || !pyResult) {
            Py_XDECREF(pyResult);
            return 0;
        }
        return pyResult;
}

static PyMethodDef Sbk_QSslKey_methods[] = {
    {"algorithm", (PyCFunction)Sbk_QSslKeyFunc_algorithm, METH_NOARGS},
    {"clear", (PyCFunction)Sbk_QSslKeyFunc_clear, METH_NOARGS},
    {"handle", (PyCFunction)Sbk_QSslKeyFunc_handle, METH_NOARGS},
    {"isNull", (PyCFunction)Sbk_QSslKeyFunc_isNull, METH_NOARGS},
    {"length", (PyCFunction)Sbk_QSslKeyFunc_length, METH_NOARGS},
    {"toDer", (PyCFunction)Sbk_QSslKeyFunc_toDer, METH_VARARGS|METH_KEYWORDS},
    {"toPem", (PyCFunction)Sbk_QSslKeyFunc_toPem, METH_VARARGS|METH_KEYWORDS},
    {"type", (PyCFunction)Sbk_QSslKeyFunc_type, METH_NOARGS},

    {"__copy__", (PyCFunction)Sbk_QSslKey___copy__, METH_NOARGS},
    {0} // Sentinel
};

// Rich comparison
static PyObject* Sbk_QSslKey_richcompare(PyObject* self, PyObject* arg, int op)
{
    PyObject* pyResult = 0;
    QSslKey& cppSelf = *Shiboken::Converter< QSslKey* >::toCpp(self);

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter< ::QSslKey >::isConvertible(arg)) {
                // operator!=(const QSslKey & key) const
                QSslKey cppArg0 = Shiboken::Converter< ::QSslKey >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf != cppArg0);
            } else goto Sbk_QSslKey_RichComparison_TypeError;

            break;
        case Py_EQ:
            if (Shiboken::Converter< ::QSslKey >::isConvertible(arg)) {
                // operator==(const QSslKey & key) const
                QSslKey cppArg0 = Shiboken::Converter< ::QSslKey >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf == cppArg0);
            } else goto Sbk_QSslKey_RichComparison_TypeError;

            break;
        default:
            goto Sbk_QSslKey_RichComparison_TypeError;
    }

    if (pyResult && !PyErr_Occurred())
        return pyResult;
    Sbk_QSslKey_RichComparison_TypeError:
    PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
    return 0;

}

} // extern "C"

extern "C"
{
static PyObject* Sbk_QSslKey__repr__(PyObject* pyObj)
{
    QBuffer buffer;
    buffer.open(QBuffer::ReadWrite);
    QDebug dbg(&buffer);
    dbg << Shiboken::Converter< ::QSslKey >::toCpp(pyObj);
    buffer.close();
    return PyString_FromFormat("<PySide.QtNetwork.%s at %p>", buffer.data().constData(), pyObj);
}
} // extern C

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QSslKey_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtNetwork.QSslKey",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             Sbk_QSslKey__repr__,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      Sbk_QSslKey_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QSslKey_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QSslKey_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QSslKey(PyObject* module)
{
    SbkPySide_QtNetworkTypes[SBK_QSSLKEY_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QSslKey_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QSslKey_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QSslKey_Type, &Shiboken::callCppDestructor<QSslKey >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QSslKey_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QSslKey_Type, "QSslKey");
    PyModule_AddObject(module, "QSslKey",
        ((PyObject*)&Sbk_QSslKey_Type));


    Shiboken::TypeResolver::createValueTypeResolver<QSslKey >("QSslKey");
    Shiboken::TypeResolver::createObjectTypeResolver<QSslKey >("QSslKey*");
    Shiboken::TypeResolver::createValueTypeResolver<QSslKey >(typeid(QSslKey).name());
    PySide::initQtMetaType<QSslKey >();
}

