/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtopengl_python.h"

#include "qglframebufferobjectformat_wrapper.h"

// Extra includes
#include <qglframebufferobject.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QGLFramebufferObjectFormat_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QGLFramebufferObjectFormat >()))
        return -1;

    QGLFramebufferObjectFormat* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QGLFramebufferObjectFormat", 0, 1, &(pyargs[0])))
        return -1;

    // Overloaded function decisor
    // 0: QGLFramebufferObjectFormat()
    // 1: QGLFramebufferObjectFormat(QGLFramebufferObjectFormat)
    if (numArgs == 0) {
        overloadId = 0; // QGLFramebufferObjectFormat()
    } else if (numArgs == 1 && Shiboken::Converter< ::QGLFramebufferObjectFormat >::isConvertible(pyargs[0])) {
        overloadId = 1; // QGLFramebufferObjectFormat(QGLFramebufferObjectFormat)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLFramebufferObjectFormat_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QGLFramebufferObjectFormat()
            {

                if(!PyErr_Occurred()) {
                    // QGLFramebufferObjectFormat()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QGLFramebufferObjectFormat();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // QGLFramebufferObjectFormat(QGLFramebufferObjectFormat)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QGLFramebufferObjectFormat cppArg0 = Shiboken::Converter<QGLFramebufferObjectFormat >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QGLFramebufferObjectFormat(QGLFramebufferObjectFormat)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QGLFramebufferObjectFormat(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QGLFramebufferObjectFormat >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QGLFramebufferObjectFormat_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QGLFramebufferObjectFormat_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtOpenGL.QGLFramebufferObjectFormat", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtOpenGL.QGLFramebufferObjectFormat", overloads);
        return -1;
}

static PyObject* Sbk_QGLFramebufferObjectFormatFunc_attachment(PyObject* self)
{
    QGLFramebufferObjectFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLFramebufferObjectFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // attachment()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QGLFramebufferObject::Attachment cppResult = cppSelf->attachment();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QGLFramebufferObject::Attachment >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGLFramebufferObjectFormatFunc_internalTextureFormat(PyObject* self)
{
    QGLFramebufferObjectFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLFramebufferObjectFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // internalTextureFormat()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                unsigned int cppResult = cppSelf->internalTextureFormat();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< unsigned int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGLFramebufferObjectFormatFunc_samples(PyObject* self)
{
    QGLFramebufferObjectFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLFramebufferObjectFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // samples()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->samples();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QGLFramebufferObjectFormatFunc_setAttachment(PyObject* self, PyObject* arg)
{
    QGLFramebufferObjectFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLFramebufferObjectFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setAttachment(QGLFramebufferObject::Attachment)
    if (Shiboken::Converter< ::QGLFramebufferObject::Attachment >::isConvertible(arg)) {
        overloadId = 0; // setAttachment(QGLFramebufferObject::Attachment)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLFramebufferObjectFormatFunc_setAttachment_TypeError;

    // Call function/method
    {
        {
            QGLFramebufferObject::Attachment cppArg0 = Shiboken::Converter<QGLFramebufferObject::Attachment >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setAttachment(QGLFramebufferObject::Attachment)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setAttachment(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGLFramebufferObjectFormatFunc_setAttachment_TypeError:
        const char* overloads[] = {"PySide.QtOpenGL.QGLFramebufferObject.Attachment", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtOpenGL.QGLFramebufferObjectFormat.setAttachment", overloads);
        return 0;
}

static PyObject* Sbk_QGLFramebufferObjectFormatFunc_setInternalTextureFormat(PyObject* self, PyObject* arg)
{
    QGLFramebufferObjectFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLFramebufferObjectFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setInternalTextureFormat(uint)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setInternalTextureFormat(uint)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLFramebufferObjectFormatFunc_setInternalTextureFormat_TypeError;

    // Call function/method
    {
        {
            unsigned int cppArg0 = Shiboken::Converter<unsigned int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setInternalTextureFormat(uint)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setInternalTextureFormat(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGLFramebufferObjectFormatFunc_setInternalTextureFormat_TypeError:
        const char* overloads[] = {"unsigned int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtOpenGL.QGLFramebufferObjectFormat.setInternalTextureFormat", overloads);
        return 0;
}

static PyObject* Sbk_QGLFramebufferObjectFormatFunc_setSamples(PyObject* self, PyObject* arg)
{
    QGLFramebufferObjectFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLFramebufferObjectFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setSamples(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setSamples(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLFramebufferObjectFormatFunc_setSamples_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setSamples(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setSamples(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGLFramebufferObjectFormatFunc_setSamples_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtOpenGL.QGLFramebufferObjectFormat.setSamples", overloads);
        return 0;
}

static PyObject* Sbk_QGLFramebufferObjectFormatFunc_setTextureTarget(PyObject* self, PyObject* arg)
{
    QGLFramebufferObjectFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLFramebufferObjectFormat* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setTextureTarget(uint)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setTextureTarget(uint)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QGLFramebufferObjectFormatFunc_setTextureTarget_TypeError;

    // Call function/method
    {
        {
            unsigned int cppArg0 = Shiboken::Converter<unsigned int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setTextureTarget(uint)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setTextureTarget(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QGLFramebufferObjectFormatFunc_setTextureTarget_TypeError:
        const char* overloads[] = {"unsigned int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtOpenGL.QGLFramebufferObjectFormat.setTextureTarget", overloads);
        return 0;
}

static PyObject* Sbk_QGLFramebufferObjectFormatFunc_textureTarget(PyObject* self)
{
    QGLFramebufferObjectFormat* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QGLFramebufferObjectFormat* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // textureTarget()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                unsigned int cppResult = cppSelf->textureTarget();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< unsigned int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject *Sbk_QGLFramebufferObjectFormat___copy__(PyObject *self)
{
        QGLFramebufferObjectFormat* cppSelf = 0;
        if (!Shiboken::Object::isValid(self))
            return 0;
        cppSelf = Shiboken::Converter<QGLFramebufferObjectFormat*>::toCpp(self);
        PyObject* pyResult = 0;
        QGLFramebufferObjectFormat* copy = new QGLFramebufferObjectFormat(*cppSelf);
        pyResult = Shiboken::Converter<QGLFramebufferObjectFormat*>::toPython(copy);
        Shiboken::Object::getOwnership(pyResult);

        if (PyErr_Occurred() || !pyResult) {
            Py_XDECREF(pyResult);
            return 0;
        }
        return pyResult;
}

static PyMethodDef Sbk_QGLFramebufferObjectFormat_methods[] = {
    {"attachment", (PyCFunction)Sbk_QGLFramebufferObjectFormatFunc_attachment, METH_NOARGS},
    {"internalTextureFormat", (PyCFunction)Sbk_QGLFramebufferObjectFormatFunc_internalTextureFormat, METH_NOARGS},
    {"samples", (PyCFunction)Sbk_QGLFramebufferObjectFormatFunc_samples, METH_NOARGS},
    {"setAttachment", (PyCFunction)Sbk_QGLFramebufferObjectFormatFunc_setAttachment, METH_O},
    {"setInternalTextureFormat", (PyCFunction)Sbk_QGLFramebufferObjectFormatFunc_setInternalTextureFormat, METH_O},
    {"setSamples", (PyCFunction)Sbk_QGLFramebufferObjectFormatFunc_setSamples, METH_O},
    {"setTextureTarget", (PyCFunction)Sbk_QGLFramebufferObjectFormatFunc_setTextureTarget, METH_O},
    {"textureTarget", (PyCFunction)Sbk_QGLFramebufferObjectFormatFunc_textureTarget, METH_NOARGS},

    {"__copy__", (PyCFunction)Sbk_QGLFramebufferObjectFormat___copy__, METH_NOARGS},
    {0} // Sentinel
};

// Rich comparison
static PyObject* Sbk_QGLFramebufferObjectFormat_richcompare(PyObject* self, PyObject* arg, int op)
{
    PyObject* pyResult = 0;
    QGLFramebufferObjectFormat& cppSelf = *Shiboken::Converter< QGLFramebufferObjectFormat* >::toCpp(self);

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter< ::QGLFramebufferObjectFormat >::isConvertible(arg)) {
                // operator!=(const QGLFramebufferObjectFormat & other) const
                QGLFramebufferObjectFormat cppArg0 = Shiboken::Converter< ::QGLFramebufferObjectFormat >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf != cppArg0);
            } else goto Sbk_QGLFramebufferObjectFormat_RichComparison_TypeError;

            break;
        case Py_EQ:
            if (Shiboken::Converter< ::QGLFramebufferObjectFormat >::isConvertible(arg)) {
                // operator==(const QGLFramebufferObjectFormat & other) const
                QGLFramebufferObjectFormat cppArg0 = Shiboken::Converter< ::QGLFramebufferObjectFormat >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf == cppArg0);
            } else goto Sbk_QGLFramebufferObjectFormat_RichComparison_TypeError;

            break;
        default:
            goto Sbk_QGLFramebufferObjectFormat_RichComparison_TypeError;
    }

    if (pyResult && !PyErr_Occurred())
        return pyResult;
    Sbk_QGLFramebufferObjectFormat_RichComparison_TypeError:
    PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
    return 0;

}

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QGLFramebufferObjectFormat_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtOpenGL.QGLFramebufferObjectFormat",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      Sbk_QGLFramebufferObjectFormat_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QGLFramebufferObjectFormat_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QGLFramebufferObjectFormat_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QGLFramebufferObjectFormat(PyObject* module)
{
    SbkPySide_QtOpenGLTypes[SBK_QGLFRAMEBUFFEROBJECTFORMAT_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QGLFramebufferObjectFormat_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QGLFramebufferObjectFormat_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QGLFramebufferObjectFormat_Type, &Shiboken::callCppDestructor<QGLFramebufferObjectFormat >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QGLFramebufferObjectFormat_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QGLFramebufferObjectFormat_Type, "QGLFramebufferObjectFormat");
    PyModule_AddObject(module, "QGLFramebufferObjectFormat",
        ((PyObject*)&Sbk_QGLFramebufferObjectFormat_Type));


    Shiboken::TypeResolver::createValueTypeResolver<QGLFramebufferObjectFormat >("QGLFramebufferObjectFormat");
    Shiboken::TypeResolver::createObjectTypeResolver<QGLFramebufferObjectFormat >("QGLFramebufferObjectFormat*");
    Shiboken::TypeResolver::createValueTypeResolver<QGLFramebufferObjectFormat >(typeid(QGLFramebufferObjectFormat).name());
    PySide::initQtMetaType<QGLFramebufferObjectFormat >();
}

