/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include "pyside_qtwebkit_python.h"

#include "qwebpage_wrapper.h"

// Extra includes
#include <QList>
#include <QStringList>
#include <qaction.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qevent.h>
#include <qmenu.h>
#include <qnetworkaccessmanager.h>
#include <qnetworkreply.h>
#include <qnetworkrequest.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpalette.h>
#include <qpoint.h>
#include <qrect.h>
#include <qsize.h>
#include <qthread.h>
#include <qundostack.h>
#include <qurl.h>
#include <qwebframe.h>
#include <qwebhistory.h>
#include <qwebpage.h>
#include <qwebpluginfactory.h>
#include <qwebsettings.h>
#include <qwidget.h>


// Native ---------------------------------------------------------

QWebPageWrapper::QWebPageWrapper(QObject * parent) : QWebPage(parent) {
    // ... middle
}

bool QWebPageWrapper::acceptNavigationRequest(QWebFrame * frame, const QNetworkRequest & request, QWebPage::NavigationType type)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "acceptNavigationRequest"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWebPage::acceptNavigationRequest(frame, request, type);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NNN)",
        Shiboken::Converter< ::QWebFrame * >::toPython(frame),
        Shiboken::Converter< ::QNetworkRequest >::toPython(request),
        Shiboken::Converter< ::QWebPage::NavigationType >::toPython(type)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QWebPage.acceptNavigationRequest", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    return cppResult;
}

void QWebPageWrapper::childEvent(QChildEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "childEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::childEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QChildEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

QString QWebPageWrapper::chooseFile(QWebFrame * originatingFrame, const QString & oldFile)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "chooseFile"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWebPage::chooseFile(originatingFrame, oldFile);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QWebFrame * >::toPython(originatingFrame),
        Shiboken::Converter< QString >::toPython(oldFile)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QString();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< QString >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QWebPage.chooseFile", "QString", pyResult->ob_type->tp_name);
        return QString();
    }
    QString cppResult(Shiboken::Converter< QString >::toCpp(pyResult));
    return cppResult;
}

void QWebPageWrapper::connectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "connectNotify"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

QObject * QWebPageWrapper::createPlugin(const QString & classid, const QUrl & url, const QStringList & paramNames, const QStringList & paramValues)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "createPlugin"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWebPage::createPlugin(classid, url, paramNames, paramValues);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NNNN)",
        Shiboken::Converter< QString >::toPython(classid),
        Shiboken::Converter< ::QUrl >::toPython(url),
        Shiboken::Converter< ::QStringList >::toPython(paramNames),
        Shiboken::Converter< ::QStringList >::toPython(paramValues)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return 0;
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QObject * >::isConvertible(pyResult);
    typeIsValid = typeIsValid || (pyResult == Py_None);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QWebPage.createPlugin", Shiboken::SbkType<QObject >()->tp_name, pyResult->ob_type->tp_name);
        return 0;
    }
    QObject * cppResult(Shiboken::Converter< ::QObject * >::toCpp(pyResult));
    return cppResult;
}

QWebPage * QWebPageWrapper::createWindow(QWebPage::WebWindowType type)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "createWindow"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWebPage::createWindow(type);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QWebPage::WebWindowType >::toPython(type)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return 0;
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QWebPage * >::isConvertible(pyResult);
    typeIsValid = typeIsValid || (pyResult == Py_None);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QWebPage.createWindow", Shiboken::SbkType<QWebPage >()->tp_name, pyResult->ob_type->tp_name);
        return 0;
    }
    QWebPage * cppResult(Shiboken::Converter< ::QWebPage * >::toCpp(pyResult));
    return cppResult;
}

void QWebPageWrapper::customEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "customEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::customEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QWebPageWrapper::disconnectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

bool QWebPageWrapper::event(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "event"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWebPage::event(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QWebPage.event", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
    return cppResult;
}

bool QWebPageWrapper::eventFilter(QObject * arg__1, QEvent * arg__2)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "eventFilter"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::eventFilter(arg__1, arg__2);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QObject * >::toPython(arg__1),
        Shiboken::Converter< ::QEvent * >::toPython(arg__2)
    ));
    bool invalidadeArg2 = PyTuple_GET_ITEM(pyargs, 1)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QWebPage.eventFilter", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    if (invalidadeArg2)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 1));
    return cppResult;
}

void QWebPageWrapper::javaScriptAlert(QWebFrame * originatingFrame, const QString & msg)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "javaScriptAlert"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWebPage::javaScriptAlert(originatingFrame, msg);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QWebFrame * >::toPython(originatingFrame),
        Shiboken::Converter< QString >::toPython(msg)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

bool QWebPageWrapper::javaScriptConfirm(QWebFrame * originatingFrame, const QString & msg)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "javaScriptConfirm"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWebPage::javaScriptConfirm(originatingFrame, msg);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QWebFrame * >::toPython(originatingFrame),
        Shiboken::Converter< QString >::toPython(msg)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QWebPage.javaScriptConfirm", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    return cppResult;
}

void QWebPageWrapper::javaScriptConsoleMessage(const QString & message, int lineNumber, const QString & sourceID)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "javaScriptConsoleMessage"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWebPage::javaScriptConsoleMessage(message, lineNumber, sourceID);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NiN)",
        Shiboken::Converter< QString >::toPython(message),
        lineNumber,
        Shiboken::Converter< QString >::toPython(sourceID)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

bool QWebPageWrapper::javaScriptPrompt(QWebFrame * originatingFrame, const QString & msg, const QString & defaultValue, QString * result)
{

    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "javaScriptPrompt"));
    if (py_override.isNull()) {

        gil.release();
        return this->::QWebPage::javaScriptPrompt(originatingFrame, msg, defaultValue, result);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NNN)",
        Shiboken::Converter< ::QWebFrame * >::toPython(originatingFrame),
        Shiboken::Converter< QString >::toPython(msg),
        Shiboken::Converter< QString >::toPython(defaultValue)
    ));


    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));

    return cppResult;
}

bool QWebPageWrapper::supportsExtension(QWebPage::Extension extension) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "supportsExtension"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWebPage::supportsExtension(extension);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QWebPage::Extension >::toPython(extension)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QWebPage.supportsExtension", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    return cppResult;
}

void QWebPageWrapper::timerEvent(QTimerEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "timerEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::timerEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QTimerEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QWebPageWrapper::triggerAction(QWebPage::WebAction action, bool checked)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "triggerAction"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWebPage::triggerAction(action, checked);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QWebPage::WebAction >::toPython(action),
        Shiboken::Converter< bool >::toPython(checked)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

QString QWebPageWrapper::userAgentForUrl(const QUrl & url) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "userAgentForUrl"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWebPage::userAgentForUrl(url);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QUrl >::toPython(url)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QString();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< QString >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QWebPage.userAgentForUrl", "QString", pyResult->ob_type->tp_name);
        return QString();
    }
    QString cppResult(Shiboken::Converter< QString >::toCpp(pyResult));
    return cppResult;
}

const QMetaObject* QWebPageWrapper::metaObject() const
{
    SbkObject* pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    return reinterpret_cast<QMetaObject*>(Shiboken::Object::getTypeUserData(pySelf));
}

int QWebPageWrapper::qt_metacall(QMetaObject::Call call, int id, void** args)
{
    int result = QWebPage::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

QWebPageWrapper::~QWebPageWrapper()
{
    SbkObject* wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QWebPage_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QWebPage >()))
        return -1;

    QWebPageWrapper* cptr = 0;
    int overloadId = -1;
    const char* argNames[] = {"parent"};
    const QMetaObject* metaObject;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_ParseTuple(args, "|O:QWebPage", &(pyargs[0])))
        return -1;

    // Overloaded function decisor
    // 0: QWebPage(QObject*)
    if (numArgs == 0) {
        overloadId = 0; // QWebPage(QObject*)
    } else if (Shiboken::Converter< ::QObject * >::isConvertible(pyargs[0])) {
        overloadId = 0; // QWebPage(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebPage_Init_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "parent");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "parent";
                    else if (Shiboken::Converter< ::QObject * >::isConvertible(value))
                        pyargs[0] = value;
else
                        goto Sbk_QWebPage_Init_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtWebKit.QWebPage(): got multiple values for keyword argument '%s'", errorArgName);
                    return -1;
                }
            }
            if (!Shiboken::Object::isValid(pyargs[0]))
                return -1;
            QObject * cppArg0 = pyargs[0] ? Shiboken::Converter<QObject * >::toCpp(pyargs[0]) : 0;

            if(!PyErr_Occurred()) {
                // QWebPage(QObject*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new QWebPageWrapper(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                Shiboken::Object::setParent(pyargs[0], self);
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QWebPage >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QWebPage_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    metaObject = cptr->metaObject(); // <- init python qt properties
    if (kwds && !PySide::fillQtProperties(self, metaObject, kwds, argNames, 1))
        return -1;


    return 1;

    Sbk_QWebPage_Init_TypeError:
        const char* overloads[] = {"PySide.QtCore.QObject = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtWebKit.QWebPage", overloads);
        return -1;
}

static PyObject* Sbk_QWebPageFunc_acceptNavigationRequest(PyObject* self, PyObject* args)
{
    QWebPage* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebPage* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "acceptNavigationRequest", 3, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: acceptNavigationRequest(QWebFrame*,QNetworkRequest,QWebPage::NavigationType)
    if (numArgs == 3 && Shiboken::Converter< ::QWebFrame * >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QNetworkRequest >::isConvertible(pyargs[1]) && Shiboken::Converter< ::QWebPage::NavigationType >::isConvertible(pyargs[2])) {
        overloadId = 0; // acceptNavigationRequest(QWebFrame*,QNetworkRequest,QWebPage::NavigationType)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebPageFunc_acceptNavigationRequest_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QWebFrame * cppArg0 = Shiboken::Converter<QWebFrame * >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QNetworkRequest cppArg1 = Shiboken::Converter<QNetworkRequest >::toCpp(pyargs[1]);
            QWebPage::NavigationType cppArg2 = Shiboken::Converter<QWebPage::NavigationType >::toCpp(pyargs[2]);

            if(!PyErr_Occurred()) {
                // acceptNavigationRequest(QWebFrame*,QNetworkRequest,QWebPage::NavigationType)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QWebPage::acceptNavigationRequest(cppArg0, cppArg1, cppArg2):cppSelf->acceptNavigationRequest(cppArg0, cppArg1, cppArg2));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QWebPageFunc_acceptNavigationRequest_TypeError:
        const char* overloads[] = {"PySide.QtWebKit.QWebFrame, PySide.QtNetwork.QNetworkRequest, PySide.QtWebKit.QWebPage.NavigationType", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtWebKit.QWebPage.acceptNavigationRequest", overloads);
        return 0;
}

static PyObject* Sbk_QWebPageFunc_action(PyObject* self, PyObject* arg)
{
    QWebPage* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebPage* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: action(QWebPage::WebAction)const
    if (Shiboken::Converter< ::QWebPage::WebAction >::isConvertible(arg)) {
        overloadId = 0; // action(QWebPage::WebAction)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebPageFunc_action_TypeError;

    // Call function/method
    {
        {
            QWebPage::WebAction cppArg0 = Shiboken::Converter<QWebPage::WebAction >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // action(QWebPage::WebAction)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QAction * cppResult = cppSelf->action(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QAction * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QWebPageFunc_action_TypeError:
        const char* overloads[] = {"PySide.QtWebKit.QWebPage.WebAction", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebPage.action", overloads);
        return 0;
}

static PyObject* Sbk_QWebPageFunc_bytesReceived(PyObject* self)
{
    QWebPage* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebPage* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // bytesReceived()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                quint64 cppResult = cppSelf->bytesReceived();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< unsigned long long >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWebPageFunc_chooseFile(PyObject* self, PyObject* args)
{
    QWebPage* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebPage* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "chooseFile", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: chooseFile(QWebFrame*,QString)
    if (numArgs == 2 && Shiboken::Converter< ::QWebFrame * >::isConvertible(pyargs[0]) && Shiboken::Converter< QString >::isConvertible(pyargs[1])) {
        overloadId = 0; // chooseFile(QWebFrame*,QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebPageFunc_chooseFile_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QWebFrame * cppArg0 = Shiboken::Converter<QWebFrame * >::toCpp(pyargs[0]);
            QString cppArg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // chooseFile(QWebFrame*,QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QWebPage::chooseFile(cppArg0, cppArg1):cppSelf->chooseFile(cppArg0, cppArg1));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QWebPageFunc_chooseFile_TypeError:
        const char* overloads[] = {"PySide.QtWebKit.QWebFrame, QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtWebKit.QWebPage.chooseFile", overloads);
        return 0;
}

static PyObject* Sbk_QWebPageFunc_createPlugin(PyObject* self, PyObject* args)
{
    QWebPage* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebPage* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "createPlugin", 4, 4, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: createPlugin(QString,QUrl,QStringList,QStringList)
    if (numArgs == 4 && Shiboken::Converter< QString >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QUrl >::isConvertible(pyargs[1]) && Shiboken::Converter< ::QStringList >::isConvertible(pyargs[2]) && Shiboken::Converter< ::QStringList >::isConvertible(pyargs[3])) {
        overloadId = 0; // createPlugin(QString,QUrl,QStringList,QStringList)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebPageFunc_createPlugin_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QUrl cppArg1 = Shiboken::Converter<QUrl >::toCpp(pyargs[1]);
            QStringList cppArg2 = Shiboken::Converter<QStringList >::toCpp(pyargs[2]);
            QStringList cppArg3 = Shiboken::Converter<QStringList >::toCpp(pyargs[3]);

            if(!PyErr_Occurred()) {
                // createPlugin(QString,QUrl,QStringList,QStringList)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QObject * cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QWebPage::createPlugin(cppArg0, cppArg1, cppArg2, cppArg3):cppSelf->createPlugin(cppArg0, cppArg1, cppArg2, cppArg3));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QObject * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QWebPageFunc_createPlugin_TypeError:
        const char* overloads[] = {"QString, PySide.QtCore.QUrl, list, list", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtWebKit.QWebPage.createPlugin", overloads);
        return 0;
}

static PyObject* Sbk_QWebPageFunc_createStandardContextMenu(PyObject* self)
{
    QWebPage* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebPage* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // createStandardContextMenu()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QMenu * cppResult = cppSelf->createStandardContextMenu();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QMenu * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWebPageFunc_createWindow(PyObject* self, PyObject* arg)
{
    QWebPage* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebPage* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: createWindow(QWebPage::WebWindowType)
    if (Shiboken::Converter< ::QWebPage::WebWindowType >::isConvertible(arg)) {
        overloadId = 0; // createWindow(QWebPage::WebWindowType)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebPageFunc_createWindow_TypeError;

    // Call function/method
    {
        {
            QWebPage::WebWindowType cppArg0 = Shiboken::Converter<QWebPage::WebWindowType >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // createWindow(QWebPage::WebWindowType)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QWebPage * cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QWebPage::createWindow(cppArg0):cppSelf->createWindow(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QWebPage * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QWebPageFunc_createWindow_TypeError:
        const char* overloads[] = {"PySide.QtWebKit.QWebPage.WebWindowType", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebPage.createWindow", overloads);
        return 0;
}

static PyObject* Sbk_QWebPageFunc_currentFrame(PyObject* self)
{
    QWebPage* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebPage* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // currentFrame()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QWebFrame * cppResult = cppSelf->currentFrame();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QWebFrame * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWebPageFunc_event(PyObject* self, PyObject* arg)
{
    QWebPage* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebPage* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: event(QEvent*)
    if (Shiboken::Converter< ::QEvent * >::isConvertible(arg)) {
        overloadId = 0; // event(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebPageFunc_event_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QEvent * cppArg0 = Shiboken::Converter<QEvent * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // event(QEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QWebPage::event(cppArg0):cppSelf->event(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QWebPageFunc_event_TypeError:
        const char* overloads[] = {"PySide.QtCore.QEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebPage.event", overloads);
        return 0;
}

static PyObject* Sbk_QWebPageFunc_findText(PyObject* self, PyObject* args, PyObject* kwds)
{
    QWebPage* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebPage* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtWebKit.QWebPage.findText(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtWebKit.QWebPage.findText(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:findText", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: findText(QString,QFlags<QWebPage::FindFlag>)
    if (Shiboken::Converter< QString >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // findText(QString,QFlags<QWebPage::FindFlag>)
        } else if (Shiboken::Converter< ::QFlags<QWebPage::FindFlag> >::isConvertible(pyargs[1])) {
            overloadId = 0; // findText(QString,QFlags<QWebPage::FindFlag>)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebPageFunc_findText_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "options");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "options";
                    else if (Shiboken::Converter< ::QFlags<QWebPage::FindFlag> >::isConvertible(value))
                        pyargs[1] = value;
else
                        goto Sbk_QWebPageFunc_findText_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtWebKit.QWebPage.findText(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QFlags<QWebPage::FindFlag> cppArg1 = pyargs[1] ? Shiboken::Converter<QFlags<QWebPage::FindFlag> >::toCpp(pyargs[1]) : QFlags<QWebPage::FindFlag>(0);

            if(!PyErr_Occurred()) {
                // findText(QString,QFlags<QWebPage::FindFlag>)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->findText(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QWebPageFunc_findText_TypeError:
        const char* overloads[] = {"QString, PySide.QtWebKit.QWebPage.FindFlags = 0", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtWebKit.QWebPage.findText", overloads);
        return 0;
}

static PyObject* Sbk_QWebPageFunc_focusNextPrevChild(PyObject* self, PyObject* arg)
{
    QWebPage* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebPage* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: focusNextPrevChild(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // focusNextPrevChild(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebPageFunc_focusNextPrevChild_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // focusNextPrevChild(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->focusNextPrevChild(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QWebPageFunc_focusNextPrevChild_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebPage.focusNextPrevChild", overloads);
        return 0;
}

static PyObject* Sbk_QWebPageFunc_forwardUnsupportedContent(PyObject* self)
{
    QWebPage* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebPage* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // forwardUnsupportedContent()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->forwardUnsupportedContent();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWebPageFunc_frameAt(PyObject* self, PyObject* arg)
{
    QWebPage* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebPage* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: frameAt(QPoint)const
    if (Shiboken::Converter< ::QPoint >::isConvertible(arg)) {
        overloadId = 0; // frameAt(QPoint)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebPageFunc_frameAt_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QPoint cppArg0 = Shiboken::Converter<QPoint >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // frameAt(QPoint)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QWebFrame * cppResult = cppSelf->frameAt(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QWebFrame * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QWebPageFunc_frameAt_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebPage.frameAt", overloads);
        return 0;
}

static PyObject* Sbk_QWebPageFunc_history(PyObject* self)
{
    QWebPage* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebPage* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // history()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QWebHistory * cppResult = cppSelf->history();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QWebHistory * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWebPageFunc_inputMethodQuery(PyObject* self, PyObject* arg)
{
    QWebPage* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebPage* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: inputMethodQuery(Qt::InputMethodQuery)const
    if (Shiboken::Converter< ::Qt::InputMethodQuery >::isConvertible(arg)) {
        overloadId = 0; // inputMethodQuery(Qt::InputMethodQuery)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebPageFunc_inputMethodQuery_TypeError;

    // Call function/method
    {
        {
            Qt::InputMethodQuery cppArg0 = Shiboken::Converter<Qt::InputMethodQuery >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // inputMethodQuery(Qt::InputMethodQuery)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QVariant cppResult = cppSelf->inputMethodQuery(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QVariant >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QWebPageFunc_inputMethodQuery_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.InputMethodQuery", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebPage.inputMethodQuery", overloads);
        return 0;
}

static PyObject* Sbk_QWebPageFunc_isContentEditable(PyObject* self)
{
    QWebPage* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebPage* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isContentEditable()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->isContentEditable();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWebPageFunc_isModified(PyObject* self)
{
    QWebPage* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebPage* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isModified()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->isModified();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWebPageFunc_javaScriptAlert(PyObject* self, PyObject* args)
{
    QWebPage* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebPage* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "javaScriptAlert", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: javaScriptAlert(QWebFrame*,QString)
    if (numArgs == 2 && Shiboken::Converter< ::QWebFrame * >::isConvertible(pyargs[0]) && Shiboken::Converter< QString >::isConvertible(pyargs[1])) {
        overloadId = 0; // javaScriptAlert(QWebFrame*,QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebPageFunc_javaScriptAlert_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QWebFrame * cppArg0 = Shiboken::Converter<QWebFrame * >::toCpp(pyargs[0]);
            QString cppArg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // javaScriptAlert(QWebFrame*,QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QWebPage::javaScriptAlert(cppArg0, cppArg1):cppSelf->javaScriptAlert(cppArg0, cppArg1));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWebPageFunc_javaScriptAlert_TypeError:
        const char* overloads[] = {"PySide.QtWebKit.QWebFrame, QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtWebKit.QWebPage.javaScriptAlert", overloads);
        return 0;
}

static PyObject* Sbk_QWebPageFunc_javaScriptConfirm(PyObject* self, PyObject* args)
{
    QWebPage* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebPage* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "javaScriptConfirm", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: javaScriptConfirm(QWebFrame*,QString)
    if (numArgs == 2 && Shiboken::Converter< ::QWebFrame * >::isConvertible(pyargs[0]) && Shiboken::Converter< QString >::isConvertible(pyargs[1])) {
        overloadId = 0; // javaScriptConfirm(QWebFrame*,QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebPageFunc_javaScriptConfirm_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QWebFrame * cppArg0 = Shiboken::Converter<QWebFrame * >::toCpp(pyargs[0]);
            QString cppArg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // javaScriptConfirm(QWebFrame*,QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QWebPage::javaScriptConfirm(cppArg0, cppArg1):cppSelf->javaScriptConfirm(cppArg0, cppArg1));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QWebPageFunc_javaScriptConfirm_TypeError:
        const char* overloads[] = {"PySide.QtWebKit.QWebFrame, QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtWebKit.QWebPage.javaScriptConfirm", overloads);
        return 0;
}

static PyObject* Sbk_QWebPageFunc_javaScriptConsoleMessage(PyObject* self, PyObject* args)
{
    QWebPage* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebPage* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "javaScriptConsoleMessage", 3, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: javaScriptConsoleMessage(QString,int,QString)
    if (numArgs == 3 && Shiboken::Converter< QString >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1]) && Shiboken::Converter< QString >::isConvertible(pyargs[2])) {
        overloadId = 0; // javaScriptConsoleMessage(QString,int,QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebPageFunc_javaScriptConsoleMessage_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
            QString cppArg2 = Shiboken::Converter<QString >::toCpp(pyargs[2]);

            if(!PyErr_Occurred()) {
                // javaScriptConsoleMessage(QString,int,QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QWebPage::javaScriptConsoleMessage(cppArg0, cppArg1, cppArg2):cppSelf->javaScriptConsoleMessage(cppArg0, cppArg1, cppArg2));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWebPageFunc_javaScriptConsoleMessage_TypeError:
        const char* overloads[] = {"QString, int, QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtWebKit.QWebPage.javaScriptConsoleMessage", overloads);
        return 0;
}

static PyObject* Sbk_QWebPageFunc_javaScriptPrompt(PyObject* self, PyObject* args)
{
    QWebPage* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebPage* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "javaScriptPrompt", 3, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: javaScriptPrompt(QWebFrame*,QString,QString,QString*)
    if (numArgs == 3 && Shiboken::Converter< ::QWebFrame * >::isConvertible(pyargs[0]) && Shiboken::Converter< QString >::isConvertible(pyargs[1]) && Shiboken::Converter< QString >::isConvertible(pyargs[2])) {
        overloadId = 0; // javaScriptPrompt(QWebFrame*,QString,QString,QString*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebPageFunc_javaScriptPrompt_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QWebFrame * cppArg0 = Shiboken::Converter<QWebFrame * >::toCpp(pyargs[0]);
            QString cppArg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);
            QString cppArg2 = Shiboken::Converter<QString >::toCpp(pyargs[2]);

            if(!PyErr_Occurred()) {
                // javaScriptPrompt(QWebFrame*,QString,QString,QString*)


                // Begin code injection
                
                QString str;
                bool retval_ = cppSelf->javaScriptPrompt(cppArg0, cppArg1, cppArg2, &str);
                pyResult = Shiboken::makeTuple(retval_, str);
                
                // End of code injection
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QWebPageFunc_javaScriptPrompt_TypeError:
        const char* overloads[] = {"PySide.QtWebKit.QWebFrame, QString, QString, QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtWebKit.QWebPage.javaScriptPrompt", overloads);
        return 0;
}

static PyObject* Sbk_QWebPageFunc_linkDelegationPolicy(PyObject* self)
{
    QWebPage* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebPage* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // linkDelegationPolicy()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QWebPage::LinkDelegationPolicy cppResult = cppSelf->linkDelegationPolicy();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QWebPage::LinkDelegationPolicy >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWebPageFunc_mainFrame(PyObject* self)
{
    QWebPage* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebPage* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // mainFrame()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QWebFrame * cppResult = cppSelf->mainFrame();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QWebFrame * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWebPageFunc_networkAccessManager(PyObject* self)
{
    QWebPage* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebPage* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // networkAccessManager()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QNetworkAccessManager * cppResult = cppSelf->networkAccessManager();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QNetworkAccessManager * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWebPageFunc_palette(PyObject* self)
{
    QWebPage* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebPage* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // palette()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPalette cppResult = cppSelf->palette();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPalette >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWebPageFunc_pluginFactory(PyObject* self)
{
    QWebPage* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebPage* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // pluginFactory()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QWebPluginFactory * cppResult = cppSelf->pluginFactory();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QWebPluginFactory * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWebPageFunc_preferredContentsSize(PyObject* self)
{
    QWebPage* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebPage* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // preferredContentsSize()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QSize cppResult = cppSelf->preferredContentsSize();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QSize >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWebPageFunc_selectedText(PyObject* self)
{
    QWebPage* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebPage* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // selectedText()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = cppSelf->selectedText();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWebPageFunc_setContentEditable(PyObject* self, PyObject* arg)
{
    QWebPage* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebPage* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setContentEditable(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setContentEditable(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebPageFunc_setContentEditable_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setContentEditable(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setContentEditable(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWebPageFunc_setContentEditable_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebPage.setContentEditable", overloads);
        return 0;
}

static PyObject* Sbk_QWebPageFunc_setForwardUnsupportedContent(PyObject* self, PyObject* arg)
{
    QWebPage* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebPage* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setForwardUnsupportedContent(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setForwardUnsupportedContent(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebPageFunc_setForwardUnsupportedContent_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setForwardUnsupportedContent(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setForwardUnsupportedContent(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWebPageFunc_setForwardUnsupportedContent_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebPage.setForwardUnsupportedContent", overloads);
        return 0;
}

static PyObject* Sbk_QWebPageFunc_setLinkDelegationPolicy(PyObject* self, PyObject* arg)
{
    QWebPage* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebPage* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setLinkDelegationPolicy(QWebPage::LinkDelegationPolicy)
    if (Shiboken::Converter< ::QWebPage::LinkDelegationPolicy >::isConvertible(arg)) {
        overloadId = 0; // setLinkDelegationPolicy(QWebPage::LinkDelegationPolicy)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebPageFunc_setLinkDelegationPolicy_TypeError;

    // Call function/method
    {
        {
            QWebPage::LinkDelegationPolicy cppArg0 = Shiboken::Converter<QWebPage::LinkDelegationPolicy >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setLinkDelegationPolicy(QWebPage::LinkDelegationPolicy)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setLinkDelegationPolicy(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWebPageFunc_setLinkDelegationPolicy_TypeError:
        const char* overloads[] = {"PySide.QtWebKit.QWebPage.LinkDelegationPolicy", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebPage.setLinkDelegationPolicy", overloads);
        return 0;
}

static PyObject* Sbk_QWebPageFunc_setNetworkAccessManager(PyObject* self, PyObject* arg)
{
    QWebPage* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebPage* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setNetworkAccessManager(QNetworkAccessManager*)
    if (Shiboken::Converter< ::QNetworkAccessManager * >::isConvertible(arg)) {
        overloadId = 0; // setNetworkAccessManager(QNetworkAccessManager*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebPageFunc_setNetworkAccessManager_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QNetworkAccessManager * cppArg0 = Shiboken::Converter<QNetworkAccessManager * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setNetworkAccessManager(QNetworkAccessManager*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setNetworkAccessManager(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWebPageFunc_setNetworkAccessManager_TypeError:
        const char* overloads[] = {"PySide.QtNetwork.QNetworkAccessManager", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebPage.setNetworkAccessManager", overloads);
        return 0;
}

static PyObject* Sbk_QWebPageFunc_setPalette(PyObject* self, PyObject* arg)
{
    QWebPage* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebPage* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setPalette(QPalette)
    if (Shiboken::Converter< ::QPalette >::isConvertible(arg)) {
        overloadId = 0; // setPalette(QPalette)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebPageFunc_setPalette_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QPalette cppArg0 = Shiboken::Converter<QPalette >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setPalette(QPalette)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setPalette(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWebPageFunc_setPalette_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPalette", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebPage.setPalette", overloads);
        return 0;
}

static PyObject* Sbk_QWebPageFunc_setPluginFactory(PyObject* self, PyObject* arg)
{
    QWebPage* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebPage* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setPluginFactory(QWebPluginFactory*)
    if (Shiboken::Converter< ::QWebPluginFactory * >::isConvertible(arg)) {
        overloadId = 0; // setPluginFactory(QWebPluginFactory*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebPageFunc_setPluginFactory_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QWebPluginFactory * cppArg0 = Shiboken::Converter<QWebPluginFactory * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setPluginFactory(QWebPluginFactory*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setPluginFactory(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWebPageFunc_setPluginFactory_TypeError:
        const char* overloads[] = {"PySide.QtWebKit.QWebPluginFactory", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebPage.setPluginFactory", overloads);
        return 0;
}

static PyObject* Sbk_QWebPageFunc_setPreferredContentsSize(PyObject* self, PyObject* arg)
{
    QWebPage* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebPage* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setPreferredContentsSize(QSize)const
    if (Shiboken::Converter< ::QSize >::isConvertible(arg)) {
        overloadId = 0; // setPreferredContentsSize(QSize)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebPageFunc_setPreferredContentsSize_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QSize cppArg0 = Shiboken::Converter<QSize >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setPreferredContentsSize(QSize)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setPreferredContentsSize(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWebPageFunc_setPreferredContentsSize_TypeError:
        const char* overloads[] = {"PySide.QtCore.QSize", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebPage.setPreferredContentsSize", overloads);
        return 0;
}

static PyObject* Sbk_QWebPageFunc_setView(PyObject* self, PyObject* arg)
{
    QWebPage* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebPage* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setView(QWidget*)
    if (Shiboken::Converter< ::QWidget * >::isConvertible(arg)) {
        overloadId = 0; // setView(QWidget*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebPageFunc_setView_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QWidget * cppArg0 = Shiboken::Converter<QWidget * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setView(QWidget*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setView(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWebPageFunc_setView_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWidget", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebPage.setView", overloads);
        return 0;
}

static PyObject* Sbk_QWebPageFunc_setViewportSize(PyObject* self, PyObject* arg)
{
    QWebPage* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebPage* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setViewportSize(QSize)const
    if (Shiboken::Converter< ::QSize >::isConvertible(arg)) {
        overloadId = 0; // setViewportSize(QSize)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebPageFunc_setViewportSize_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QSize cppArg0 = Shiboken::Converter<QSize >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setViewportSize(QSize)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setViewportSize(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWebPageFunc_setViewportSize_TypeError:
        const char* overloads[] = {"PySide.QtCore.QSize", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebPage.setViewportSize", overloads);
        return 0;
}

static PyObject* Sbk_QWebPageFunc_settings(PyObject* self)
{
    QWebPage* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebPage* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // settings()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QWebSettings * cppResult = cppSelf->settings();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QWebSettings * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWebPageFunc_shouldInterruptJavaScript(PyObject* self)
{
    QWebPage* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebPage* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // shouldInterruptJavaScript()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->shouldInterruptJavaScript();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWebPageFunc_supportsExtension(PyObject* self, PyObject* arg)
{
    QWebPage* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebPage* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: supportsExtension(QWebPage::Extension)const
    if (Shiboken::Converter< ::QWebPage::Extension >::isConvertible(arg)) {
        overloadId = 0; // supportsExtension(QWebPage::Extension)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebPageFunc_supportsExtension_TypeError;

    // Call function/method
    {
        {
            QWebPage::Extension cppArg0 = Shiboken::Converter<QWebPage::Extension >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // supportsExtension(QWebPage::Extension)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QWebPage::supportsExtension(cppArg0):cppSelf->supportsExtension(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QWebPageFunc_supportsExtension_TypeError:
        const char* overloads[] = {"PySide.QtWebKit.QWebPage.Extension", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebPage.supportsExtension", overloads);
        return 0;
}

static PyObject* Sbk_QWebPageFunc_swallowContextMenuEvent(PyObject* self, PyObject* arg)
{
    QWebPage* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebPage* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: swallowContextMenuEvent(QContextMenuEvent*)
    if (Shiboken::Converter< ::QContextMenuEvent * >::isConvertible(arg)) {
        overloadId = 0; // swallowContextMenuEvent(QContextMenuEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebPageFunc_swallowContextMenuEvent_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QContextMenuEvent * cppArg0 = Shiboken::Converter<QContextMenuEvent * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // swallowContextMenuEvent(QContextMenuEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->swallowContextMenuEvent(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QWebPageFunc_swallowContextMenuEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QContextMenuEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebPage.swallowContextMenuEvent", overloads);
        return 0;
}

static PyObject* Sbk_QWebPageFunc_totalBytes(PyObject* self)
{
    QWebPage* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebPage* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // totalBytes()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                quint64 cppResult = cppSelf->totalBytes();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< unsigned long long >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWebPageFunc_triggerAction(PyObject* self, PyObject* args, PyObject* kwds)
{
    QWebPage* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebPage* >::toCpp(self);

    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtWebKit.QWebPage.triggerAction(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtWebKit.QWebPage.triggerAction(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:triggerAction", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: triggerAction(QWebPage::WebAction,bool)
    if (Shiboken::Converter< ::QWebPage::WebAction >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // triggerAction(QWebPage::WebAction,bool)
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 0; // triggerAction(QWebPage::WebAction,bool)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebPageFunc_triggerAction_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "checked");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "checked";
                    else if (SbkNumber_Check(value))
                        pyargs[1] = value;
else
                        goto Sbk_QWebPageFunc_triggerAction_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtWebKit.QWebPage.triggerAction(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QWebPage::WebAction cppArg0 = Shiboken::Converter<QWebPage::WebAction >::toCpp(pyargs[0]);
            bool cppArg1 = pyargs[1] ? Shiboken::Converter<bool >::toCpp(pyargs[1]) : false;

            if(!PyErr_Occurred()) {
                // triggerAction(QWebPage::WebAction,bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QWebPage::triggerAction(cppArg0, cppArg1):cppSelf->triggerAction(cppArg0, cppArg1));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWebPageFunc_triggerAction_TypeError:
        const char* overloads[] = {"PySide.QtWebKit.QWebPage.WebAction, bool = false", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtWebKit.QWebPage.triggerAction", overloads);
        return 0;
}

static PyObject* Sbk_QWebPageFunc_undoStack(PyObject* self)
{
    QWebPage* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebPage* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // undoStack()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QUndoStack * cppResult = cppSelf->undoStack();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QUndoStack * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWebPageFunc_updatePositionDependentActions(PyObject* self, PyObject* arg)
{
    QWebPage* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebPage* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: updatePositionDependentActions(QPoint)
    if (Shiboken::Converter< ::QPoint >::isConvertible(arg)) {
        overloadId = 0; // updatePositionDependentActions(QPoint)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebPageFunc_updatePositionDependentActions_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QPoint cppArg0 = Shiboken::Converter<QPoint >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // updatePositionDependentActions(QPoint)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->updatePositionDependentActions(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWebPageFunc_updatePositionDependentActions_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebPage.updatePositionDependentActions", overloads);
        return 0;
}

static PyObject* Sbk_QWebPageFunc_userAgentForUrl(PyObject* self, PyObject* arg)
{
    QWebPage* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebPage* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: userAgentForUrl(QUrl)const
    if (Shiboken::Converter< ::QUrl >::isConvertible(arg)) {
        overloadId = 0; // userAgentForUrl(QUrl)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebPageFunc_userAgentForUrl_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QUrl cppArg0 = Shiboken::Converter<QUrl >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // userAgentForUrl(QUrl)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QWebPage::userAgentForUrl(cppArg0):cppSelf->userAgentForUrl(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QWebPageFunc_userAgentForUrl_TypeError:
        const char* overloads[] = {"PySide.QtCore.QUrl", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebPage.userAgentForUrl", overloads);
        return 0;
}

static PyObject* Sbk_QWebPageFunc_view(PyObject* self)
{
    QWebPage* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebPage* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // view()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QWidget * cppResult = cppSelf->view();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QWidget * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWebPageFunc_viewportSize(PyObject* self)
{
    QWebPage* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebPage* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // viewportSize()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QSize cppResult = cppSelf->viewportSize();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QSize >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef Sbk_QWebPage_methods[] = {
    {"acceptNavigationRequest", (PyCFunction)Sbk_QWebPageFunc_acceptNavigationRequest, METH_VARARGS},
    {"action", (PyCFunction)Sbk_QWebPageFunc_action, METH_O},
    {"bytesReceived", (PyCFunction)Sbk_QWebPageFunc_bytesReceived, METH_NOARGS},
    {"chooseFile", (PyCFunction)Sbk_QWebPageFunc_chooseFile, METH_VARARGS},
    {"createPlugin", (PyCFunction)Sbk_QWebPageFunc_createPlugin, METH_VARARGS},
    {"createStandardContextMenu", (PyCFunction)Sbk_QWebPageFunc_createStandardContextMenu, METH_NOARGS},
    {"createWindow", (PyCFunction)Sbk_QWebPageFunc_createWindow, METH_O},
    {"currentFrame", (PyCFunction)Sbk_QWebPageFunc_currentFrame, METH_NOARGS},
    {"event", (PyCFunction)Sbk_QWebPageFunc_event, METH_O},
    {"findText", (PyCFunction)Sbk_QWebPageFunc_findText, METH_VARARGS|METH_KEYWORDS},
    {"focusNextPrevChild", (PyCFunction)Sbk_QWebPageFunc_focusNextPrevChild, METH_O},
    {"forwardUnsupportedContent", (PyCFunction)Sbk_QWebPageFunc_forwardUnsupportedContent, METH_NOARGS},
    {"frameAt", (PyCFunction)Sbk_QWebPageFunc_frameAt, METH_O},
    {"history", (PyCFunction)Sbk_QWebPageFunc_history, METH_NOARGS},
    {"inputMethodQuery", (PyCFunction)Sbk_QWebPageFunc_inputMethodQuery, METH_O},
    {"isContentEditable", (PyCFunction)Sbk_QWebPageFunc_isContentEditable, METH_NOARGS},
    {"isModified", (PyCFunction)Sbk_QWebPageFunc_isModified, METH_NOARGS},
    {"javaScriptAlert", (PyCFunction)Sbk_QWebPageFunc_javaScriptAlert, METH_VARARGS},
    {"javaScriptConfirm", (PyCFunction)Sbk_QWebPageFunc_javaScriptConfirm, METH_VARARGS},
    {"javaScriptConsoleMessage", (PyCFunction)Sbk_QWebPageFunc_javaScriptConsoleMessage, METH_VARARGS},
    {"javaScriptPrompt", (PyCFunction)Sbk_QWebPageFunc_javaScriptPrompt, METH_VARARGS},
    {"linkDelegationPolicy", (PyCFunction)Sbk_QWebPageFunc_linkDelegationPolicy, METH_NOARGS},
    {"mainFrame", (PyCFunction)Sbk_QWebPageFunc_mainFrame, METH_NOARGS},
    {"networkAccessManager", (PyCFunction)Sbk_QWebPageFunc_networkAccessManager, METH_NOARGS},
    {"palette", (PyCFunction)Sbk_QWebPageFunc_palette, METH_NOARGS},
    {"pluginFactory", (PyCFunction)Sbk_QWebPageFunc_pluginFactory, METH_NOARGS},
    {"preferredContentsSize", (PyCFunction)Sbk_QWebPageFunc_preferredContentsSize, METH_NOARGS},
    {"selectedText", (PyCFunction)Sbk_QWebPageFunc_selectedText, METH_NOARGS},
    {"setContentEditable", (PyCFunction)Sbk_QWebPageFunc_setContentEditable, METH_O},
    {"setForwardUnsupportedContent", (PyCFunction)Sbk_QWebPageFunc_setForwardUnsupportedContent, METH_O},
    {"setLinkDelegationPolicy", (PyCFunction)Sbk_QWebPageFunc_setLinkDelegationPolicy, METH_O},
    {"setNetworkAccessManager", (PyCFunction)Sbk_QWebPageFunc_setNetworkAccessManager, METH_O},
    {"setPalette", (PyCFunction)Sbk_QWebPageFunc_setPalette, METH_O},
    {"setPluginFactory", (PyCFunction)Sbk_QWebPageFunc_setPluginFactory, METH_O},
    {"setPreferredContentsSize", (PyCFunction)Sbk_QWebPageFunc_setPreferredContentsSize, METH_O},
    {"setView", (PyCFunction)Sbk_QWebPageFunc_setView, METH_O},
    {"setViewportSize", (PyCFunction)Sbk_QWebPageFunc_setViewportSize, METH_O},
    {"settings", (PyCFunction)Sbk_QWebPageFunc_settings, METH_NOARGS},
    {"shouldInterruptJavaScript", (PyCFunction)Sbk_QWebPageFunc_shouldInterruptJavaScript, METH_NOARGS},
    {"supportsExtension", (PyCFunction)Sbk_QWebPageFunc_supportsExtension, METH_O},
    {"swallowContextMenuEvent", (PyCFunction)Sbk_QWebPageFunc_swallowContextMenuEvent, METH_O},
    {"totalBytes", (PyCFunction)Sbk_QWebPageFunc_totalBytes, METH_NOARGS},
    {"triggerAction", (PyCFunction)Sbk_QWebPageFunc_triggerAction, METH_VARARGS|METH_KEYWORDS},
    {"undoStack", (PyCFunction)Sbk_QWebPageFunc_undoStack, METH_NOARGS},
    {"updatePositionDependentActions", (PyCFunction)Sbk_QWebPageFunc_updatePositionDependentActions, METH_O},
    {"userAgentForUrl", (PyCFunction)Sbk_QWebPageFunc_userAgentForUrl, METH_O},
    {"view", (PyCFunction)Sbk_QWebPageFunc_view, METH_NOARGS},
    {"viewportSize", (PyCFunction)Sbk_QWebPageFunc_viewportSize, METH_NOARGS},

    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QWebPage_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtWebKit.QWebPage",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QWebPage_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QWebPage_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern

static SbkObjectType* Sbk_QWebPage_typeDiscovery(void* cptr, SbkObjectType* instanceType)
{
    if (instanceType == reinterpret_cast<SbkObjectType*>(Shiboken::SbkType<QObject >()) && dynamic_cast<QWebPage*>(reinterpret_cast<QObject*>(cptr)))
        return &Sbk_QWebPage_Type;
    return 0;
}

PyObject* SbkPySide_QtWebKit_QWebPage_FindFlag___and__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QWebPage::FindFlags >::toPython(
        Shiboken::Converter<QWebPage::FindFlags>::toCpp(self)
        & Shiboken::Converter< QWebPage::FindFlags >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtWebKit_QWebPage_FindFlag___or__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QWebPage::FindFlags >::toPython(
        Shiboken::Converter<QWebPage::FindFlags>::toCpp(self)
        | Shiboken::Converter< QWebPage::FindFlags >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtWebKit_QWebPage_FindFlag___xor__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QWebPage::FindFlags >::toPython(
        Shiboken::Converter<QWebPage::FindFlags>::toCpp(self)
        ^ Shiboken::Converter< QWebPage::FindFlags >::toCpp(arg)
    );
}

PyObject* SbkPySide_QtWebKit_QWebPage_FindFlag___invert__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< QWebPage::FindFlags >::toPython(
        ~Shiboken::Converter<QWebPage::FindFlags >::toCpp(self)
    );
}


static PyNumberMethods SbkPySide_QtWebKit_QWebPage_FindFlag_as_number = {
    /*nb_add*/                  0,
    /*nb_subtract*/             0,
    /*nb_multiply*/             0,
    /*nb_divide*/               0,
    /*nb_remainder*/            0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             0,
    /*nb_positive*/             0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              0,
    /*nb_invert*/               (unaryfunc)SbkPySide_QtWebKit_QWebPage_FindFlag___invert__,
    /*nb_lshift*/               0,
    /*nb_rshift*/               0,
    /*nb_and*/                  (binaryfunc)SbkPySide_QtWebKit_QWebPage_FindFlag___and__,
    /*nb_xor*/                  (binaryfunc)SbkPySide_QtWebKit_QWebPage_FindFlag___xor__,
    /*nb_or*/                   (binaryfunc)SbkPySide_QtWebKit_QWebPage_FindFlag___or__,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          0,
    /*nb_inplace_subtract*/     0,
    /*nb_inplace_multiply*/     0,
    /*nb_inplace_divide*/       0,
    /*nb_inplace_remainder*/    0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       0,
    /*nb_inplace_rshift*/       0,
    /*nb_inplace_and*/          0,
    /*nb_inplace_xor*/          0,
    /*nb_inplace_or*/           0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};


// forward declaration of new function
static PyTypeObject SbkPySide_QtWebKit_QWebPage_FindFlags_Type = {
    PyObject_HEAD_INIT(&PyType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "FindFlags",
    /*tp_basicsize*/        0,
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        &SbkPySide_QtWebKit_QWebPage_FindFlag_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT | Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              PyInt_Type.tp_new,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};



void init_QWebPage(PyObject* module)
{
    SbkPySide_QtWebKitTypes[SBK_QWEBPAGE_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QWebPage_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QWebPage_Type);
    Shiboken::ObjectType::setSubTypeInitHook(&Sbk_QWebPage_Type, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(&Sbk_QWebPage_Type, &QWebPage::staticMetaObject);    Sbk_QWebPage_Type.super.ht_type.tp_base = SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX];
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QWebPage_Type, &Shiboken::callCppDestructor<QWebPage >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QWebPage_Type) < 0)
        return;

    // Fill type discovery information
    Shiboken::ObjectType::setTypeDiscoveryFunction(&Sbk_QWebPage_Type, &Sbk_QWebPage_typeDiscovery);
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkObjectType*>(SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX]), &Sbk_QWebPage_Type);

    Shiboken::ObjectType::setOriginalName(&Sbk_QWebPage_Type, "QWebPage*");
    PyModule_AddObject(module, "QWebPage",
        ((PyObject*)&Sbk_QWebPage_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: ErrorDomain
    PyTypeObject* SbkPySide_QtWebKit_QWebPage_ErrorDomain = Shiboken::Enum::newType("ErrorDomain");
    SbkPySide_QtWebKitTypes[SBK_QWEBPAGE_ERRORDOMAIN_IDX] = SbkPySide_QtWebKit_QWebPage_ErrorDomain;
    if (PyType_Ready(SbkPySide_QtWebKit_QWebPage_ErrorDomain) < 0)
        return;
    PyDict_SetItemString(Sbk_QWebPage_Type.super.ht_type.tp_dict,
            "ErrorDomain",((PyObject*)SbkPySide_QtWebKit_QWebPage_ErrorDomain));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebPage_ErrorDomain,(long) QWebPage::QtNetwork, "QtNetwork");
    PyDict_SetItemString(Sbk_QWebPage_Type.super.ht_type.tp_dict,"QtNetwork", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebPage_ErrorDomain->tp_dict,"QtNetwork", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebPage_ErrorDomain,(long) QWebPage::Http, "Http");
    PyDict_SetItemString(Sbk_QWebPage_Type.super.ht_type.tp_dict,"Http", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebPage_ErrorDomain->tp_dict,"Http", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebPage_ErrorDomain,(long) QWebPage::WebKit, "WebKit");
    PyDict_SetItemString(Sbk_QWebPage_Type.super.ht_type.tp_dict,"WebKit", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebPage_ErrorDomain->tp_dict,"WebKit", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QWebPage::ErrorDomain");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::ErrorDomain");
    // end of enum ErrorDomain

    // init enum: NavigationType
    PyTypeObject* SbkPySide_QtWebKit_QWebPage_NavigationType = Shiboken::Enum::newType("NavigationType");
    SbkPySide_QtWebKitTypes[SBK_QWEBPAGE_NAVIGATIONTYPE_IDX] = SbkPySide_QtWebKit_QWebPage_NavigationType;
    if (PyType_Ready(SbkPySide_QtWebKit_QWebPage_NavigationType) < 0)
        return;
    PyDict_SetItemString(Sbk_QWebPage_Type.super.ht_type.tp_dict,
            "NavigationType",((PyObject*)SbkPySide_QtWebKit_QWebPage_NavigationType));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebPage_NavigationType,(long) QWebPage::NavigationTypeLinkClicked, "NavigationTypeLinkClicked");
    PyDict_SetItemString(Sbk_QWebPage_Type.super.ht_type.tp_dict,"NavigationTypeLinkClicked", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebPage_NavigationType->tp_dict,"NavigationTypeLinkClicked", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebPage_NavigationType,(long) QWebPage::NavigationTypeFormSubmitted, "NavigationTypeFormSubmitted");
    PyDict_SetItemString(Sbk_QWebPage_Type.super.ht_type.tp_dict,"NavigationTypeFormSubmitted", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebPage_NavigationType->tp_dict,"NavigationTypeFormSubmitted", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebPage_NavigationType,(long) QWebPage::NavigationTypeBackOrForward, "NavigationTypeBackOrForward");
    PyDict_SetItemString(Sbk_QWebPage_Type.super.ht_type.tp_dict,"NavigationTypeBackOrForward", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebPage_NavigationType->tp_dict,"NavigationTypeBackOrForward", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebPage_NavigationType,(long) QWebPage::NavigationTypeReload, "NavigationTypeReload");
    PyDict_SetItemString(Sbk_QWebPage_Type.super.ht_type.tp_dict,"NavigationTypeReload", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebPage_NavigationType->tp_dict,"NavigationTypeReload", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebPage_NavigationType,(long) QWebPage::NavigationTypeFormResubmitted, "NavigationTypeFormResubmitted");
    PyDict_SetItemString(Sbk_QWebPage_Type.super.ht_type.tp_dict,"NavigationTypeFormResubmitted", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebPage_NavigationType->tp_dict,"NavigationTypeFormResubmitted", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebPage_NavigationType,(long) QWebPage::NavigationTypeOther, "NavigationTypeOther");
    PyDict_SetItemString(Sbk_QWebPage_Type.super.ht_type.tp_dict,"NavigationTypeOther", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebPage_NavigationType->tp_dict,"NavigationTypeOther", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QWebPage::NavigationType");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::NavigationType");
    // end of enum NavigationType

    // init enum: WebAction
    PyTypeObject* SbkPySide_QtWebKit_QWebPage_WebAction = Shiboken::Enum::newType("WebAction");
    SbkPySide_QtWebKitTypes[SBK_QWEBPAGE_WEBACTION_IDX] = SbkPySide_QtWebKit_QWebPage_WebAction;
    if (PyType_Ready(SbkPySide_QtWebKit_QWebPage_WebAction) < 0)
        return;
    PyDict_SetItemString(Sbk_QWebPage_Type.super.ht_type.tp_dict,
            "WebAction",((PyObject*)SbkPySide_QtWebKit_QWebPage_WebAction));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebPage_WebAction,(long) QWebPage::NoWebAction, "NoWebAction");
    PyDict_SetItemString(Sbk_QWebPage_Type.super.ht_type.tp_dict,"NoWebAction", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebPage_WebAction->tp_dict,"NoWebAction", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebPage_WebAction,(long) QWebPage::OpenLink, "OpenLink");
    PyDict_SetItemString(Sbk_QWebPage_Type.super.ht_type.tp_dict,"OpenLink", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebPage_WebAction->tp_dict,"OpenLink", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebPage_WebAction,(long) QWebPage::OpenLinkInNewWindow, "OpenLinkInNewWindow");
    PyDict_SetItemString(Sbk_QWebPage_Type.super.ht_type.tp_dict,"OpenLinkInNewWindow", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebPage_WebAction->tp_dict,"OpenLinkInNewWindow", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebPage_WebAction,(long) QWebPage::OpenFrameInNewWindow, "OpenFrameInNewWindow");
    PyDict_SetItemString(Sbk_QWebPage_Type.super.ht_type.tp_dict,"OpenFrameInNewWindow", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebPage_WebAction->tp_dict,"OpenFrameInNewWindow", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebPage_WebAction,(long) QWebPage::DownloadLinkToDisk, "DownloadLinkToDisk");
    PyDict_SetItemString(Sbk_QWebPage_Type.super.ht_type.tp_dict,"DownloadLinkToDisk", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebPage_WebAction->tp_dict,"DownloadLinkToDisk", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebPage_WebAction,(long) QWebPage::CopyLinkToClipboard, "CopyLinkToClipboard");
    PyDict_SetItemString(Sbk_QWebPage_Type.super.ht_type.tp_dict,"CopyLinkToClipboard", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebPage_WebAction->tp_dict,"CopyLinkToClipboard", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebPage_WebAction,(long) QWebPage::OpenImageInNewWindow, "OpenImageInNewWindow");
    PyDict_SetItemString(Sbk_QWebPage_Type.super.ht_type.tp_dict,"OpenImageInNewWindow", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebPage_WebAction->tp_dict,"OpenImageInNewWindow", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebPage_WebAction,(long) QWebPage::DownloadImageToDisk, "DownloadImageToDisk");
    PyDict_SetItemString(Sbk_QWebPage_Type.super.ht_type.tp_dict,"DownloadImageToDisk", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebPage_WebAction->tp_dict,"DownloadImageToDisk", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebPage_WebAction,(long) QWebPage::CopyImageToClipboard, "CopyImageToClipboard");
    PyDict_SetItemString(Sbk_QWebPage_Type.super.ht_type.tp_dict,"CopyImageToClipboard", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebPage_WebAction->tp_dict,"CopyImageToClipboard", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebPage_WebAction,(long) QWebPage::Back, "Back");
    PyDict_SetItemString(Sbk_QWebPage_Type.super.ht_type.tp_dict,"Back", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebPage_WebAction->tp_dict,"Back", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebPage_WebAction,(long) QWebPage::Forward, "Forward");
    PyDict_SetItemString(Sbk_QWebPage_Type.super.ht_type.tp_dict,"Forward", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebPage_WebAction->tp_dict,"Forward", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebPage_WebAction,(long) QWebPage::Stop, "Stop");
    PyDict_SetItemString(Sbk_QWebPage_Type.super.ht_type.tp_dict,"Stop", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebPage_WebAction->tp_dict,"Stop", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebPage_WebAction,(long) QWebPage::Reload, "Reload");
    PyDict_SetItemString(Sbk_QWebPage_Type.super.ht_type.tp_dict,"Reload", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebPage_WebAction->tp_dict,"Reload", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebPage_WebAction,(long) QWebPage::Cut, "Cut");
    PyDict_SetItemString(Sbk_QWebPage_Type.super.ht_type.tp_dict,"Cut", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebPage_WebAction->tp_dict,"Cut", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebPage_WebAction,(long) QWebPage::Copy, "Copy");
    PyDict_SetItemString(Sbk_QWebPage_Type.super.ht_type.tp_dict,"Copy", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebPage_WebAction->tp_dict,"Copy", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebPage_WebAction,(long) QWebPage::Paste, "Paste");
    PyDict_SetItemString(Sbk_QWebPage_Type.super.ht_type.tp_dict,"Paste", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebPage_WebAction->tp_dict,"Paste", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebPage_WebAction,(long) QWebPage::Undo, "Undo");
    PyDict_SetItemString(Sbk_QWebPage_Type.super.ht_type.tp_dict,"Undo", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebPage_WebAction->tp_dict,"Undo", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebPage_WebAction,(long) QWebPage::Redo, "Redo");
    PyDict_SetItemString(Sbk_QWebPage_Type.super.ht_type.tp_dict,"Redo", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebPage_WebAction->tp_dict,"Redo", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebPage_WebAction,(long) QWebPage::MoveToNextChar, "MoveToNextChar");
    PyDict_SetItemString(Sbk_QWebPage_Type.super.ht_type.tp_dict,"MoveToNextChar", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebPage_WebAction->tp_dict,"MoveToNextChar", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebPage_WebAction,(long) QWebPage::MoveToPreviousChar, "MoveToPreviousChar");
    PyDict_SetItemString(Sbk_QWebPage_Type.super.ht_type.tp_dict,"MoveToPreviousChar", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebPage_WebAction->tp_dict,"MoveToPreviousChar", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebPage_WebAction,(long) QWebPage::MoveToNextWord, "MoveToNextWord");
    PyDict_SetItemString(Sbk_QWebPage_Type.super.ht_type.tp_dict,"MoveToNextWord", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebPage_WebAction->tp_dict,"MoveToNextWord", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebPage_WebAction,(long) QWebPage::MoveToPreviousWord, "MoveToPreviousWord");
    PyDict_SetItemString(Sbk_QWebPage_Type.super.ht_type.tp_dict,"MoveToPreviousWord", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebPage_WebAction->tp_dict,"MoveToPreviousWord", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebPage_WebAction,(long) QWebPage::MoveToNextLine, "MoveToNextLine");
    PyDict_SetItemString(Sbk_QWebPage_Type.super.ht_type.tp_dict,"MoveToNextLine", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebPage_WebAction->tp_dict,"MoveToNextLine", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebPage_WebAction,(long) QWebPage::MoveToPreviousLine, "MoveToPreviousLine");
    PyDict_SetItemString(Sbk_QWebPage_Type.super.ht_type.tp_dict,"MoveToPreviousLine", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebPage_WebAction->tp_dict,"MoveToPreviousLine", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebPage_WebAction,(long) QWebPage::MoveToStartOfLine, "MoveToStartOfLine");
    PyDict_SetItemString(Sbk_QWebPage_Type.super.ht_type.tp_dict,"MoveToStartOfLine", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebPage_WebAction->tp_dict,"MoveToStartOfLine", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebPage_WebAction,(long) QWebPage::MoveToEndOfLine, "MoveToEndOfLine");
    PyDict_SetItemString(Sbk_QWebPage_Type.super.ht_type.tp_dict,"MoveToEndOfLine", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebPage_WebAction->tp_dict,"MoveToEndOfLine", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebPage_WebAction,(long) QWebPage::MoveToStartOfBlock, "MoveToStartOfBlock");
    PyDict_SetItemString(Sbk_QWebPage_Type.super.ht_type.tp_dict,"MoveToStartOfBlock", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebPage_WebAction->tp_dict,"MoveToStartOfBlock", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebPage_WebAction,(long) QWebPage::MoveToEndOfBlock, "MoveToEndOfBlock");
    PyDict_SetItemString(Sbk_QWebPage_Type.super.ht_type.tp_dict,"MoveToEndOfBlock", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebPage_WebAction->tp_dict,"MoveToEndOfBlock", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebPage_WebAction,(long) QWebPage::MoveToStartOfDocument, "MoveToStartOfDocument");
    PyDict_SetItemString(Sbk_QWebPage_Type.super.ht_type.tp_dict,"MoveToStartOfDocument", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebPage_WebAction->tp_dict,"MoveToStartOfDocument", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebPage_WebAction,(long) QWebPage::MoveToEndOfDocument, "MoveToEndOfDocument");
    PyDict_SetItemString(Sbk_QWebPage_Type.super.ht_type.tp_dict,"MoveToEndOfDocument", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebPage_WebAction->tp_dict,"MoveToEndOfDocument", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebPage_WebAction,(long) QWebPage::SelectNextChar, "SelectNextChar");
    PyDict_SetItemString(Sbk_QWebPage_Type.super.ht_type.tp_dict,"SelectNextChar", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebPage_WebAction->tp_dict,"SelectNextChar", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebPage_WebAction,(long) QWebPage::SelectPreviousChar, "SelectPreviousChar");
    PyDict_SetItemString(Sbk_QWebPage_Type.super.ht_type.tp_dict,"SelectPreviousChar", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebPage_WebAction->tp_dict,"SelectPreviousChar", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebPage_WebAction,(long) QWebPage::SelectNextWord, "SelectNextWord");
    PyDict_SetItemString(Sbk_QWebPage_Type.super.ht_type.tp_dict,"SelectNextWord", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebPage_WebAction->tp_dict,"SelectNextWord", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebPage_WebAction,(long) QWebPage::SelectPreviousWord, "SelectPreviousWord");
    PyDict_SetItemString(Sbk_QWebPage_Type.super.ht_type.tp_dict,"SelectPreviousWord", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebPage_WebAction->tp_dict,"SelectPreviousWord", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebPage_WebAction,(long) QWebPage::SelectNextLine, "SelectNextLine");
    PyDict_SetItemString(Sbk_QWebPage_Type.super.ht_type.tp_dict,"SelectNextLine", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebPage_WebAction->tp_dict,"SelectNextLine", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebPage_WebAction,(long) QWebPage::SelectPreviousLine, "SelectPreviousLine");
    PyDict_SetItemString(Sbk_QWebPage_Type.super.ht_type.tp_dict,"SelectPreviousLine", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebPage_WebAction->tp_dict,"SelectPreviousLine", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebPage_WebAction,(long) QWebPage::SelectStartOfLine, "SelectStartOfLine");
    PyDict_SetItemString(Sbk_QWebPage_Type.super.ht_type.tp_dict,"SelectStartOfLine", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebPage_WebAction->tp_dict,"SelectStartOfLine", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebPage_WebAction,(long) QWebPage::SelectEndOfLine, "SelectEndOfLine");
    PyDict_SetItemString(Sbk_QWebPage_Type.super.ht_type.tp_dict,"SelectEndOfLine", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebPage_WebAction->tp_dict,"SelectEndOfLine", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebPage_WebAction,(long) QWebPage::SelectStartOfBlock, "SelectStartOfBlock");
    PyDict_SetItemString(Sbk_QWebPage_Type.super.ht_type.tp_dict,"SelectStartOfBlock", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebPage_WebAction->tp_dict,"SelectStartOfBlock", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebPage_WebAction,(long) QWebPage::SelectEndOfBlock, "SelectEndOfBlock");
    PyDict_SetItemString(Sbk_QWebPage_Type.super.ht_type.tp_dict,"SelectEndOfBlock", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebPage_WebAction->tp_dict,"SelectEndOfBlock", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebPage_WebAction,(long) QWebPage::SelectStartOfDocument, "SelectStartOfDocument");
    PyDict_SetItemString(Sbk_QWebPage_Type.super.ht_type.tp_dict,"SelectStartOfDocument", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebPage_WebAction->tp_dict,"SelectStartOfDocument", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebPage_WebAction,(long) QWebPage::SelectEndOfDocument, "SelectEndOfDocument");
    PyDict_SetItemString(Sbk_QWebPage_Type.super.ht_type.tp_dict,"SelectEndOfDocument", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebPage_WebAction->tp_dict,"SelectEndOfDocument", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebPage_WebAction,(long) QWebPage::DeleteStartOfWord, "DeleteStartOfWord");
    PyDict_SetItemString(Sbk_QWebPage_Type.super.ht_type.tp_dict,"DeleteStartOfWord", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebPage_WebAction->tp_dict,"DeleteStartOfWord", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebPage_WebAction,(long) QWebPage::DeleteEndOfWord, "DeleteEndOfWord");
    PyDict_SetItemString(Sbk_QWebPage_Type.super.ht_type.tp_dict,"DeleteEndOfWord", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebPage_WebAction->tp_dict,"DeleteEndOfWord", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebPage_WebAction,(long) QWebPage::SetTextDirectionDefault, "SetTextDirectionDefault");
    PyDict_SetItemString(Sbk_QWebPage_Type.super.ht_type.tp_dict,"SetTextDirectionDefault", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebPage_WebAction->tp_dict,"SetTextDirectionDefault", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebPage_WebAction,(long) QWebPage::SetTextDirectionLeftToRight, "SetTextDirectionLeftToRight");
    PyDict_SetItemString(Sbk_QWebPage_Type.super.ht_type.tp_dict,"SetTextDirectionLeftToRight", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebPage_WebAction->tp_dict,"SetTextDirectionLeftToRight", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebPage_WebAction,(long) QWebPage::SetTextDirectionRightToLeft, "SetTextDirectionRightToLeft");
    PyDict_SetItemString(Sbk_QWebPage_Type.super.ht_type.tp_dict,"SetTextDirectionRightToLeft", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebPage_WebAction->tp_dict,"SetTextDirectionRightToLeft", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebPage_WebAction,(long) QWebPage::ToggleBold, "ToggleBold");
    PyDict_SetItemString(Sbk_QWebPage_Type.super.ht_type.tp_dict,"ToggleBold", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebPage_WebAction->tp_dict,"ToggleBold", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebPage_WebAction,(long) QWebPage::ToggleItalic, "ToggleItalic");
    PyDict_SetItemString(Sbk_QWebPage_Type.super.ht_type.tp_dict,"ToggleItalic", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebPage_WebAction->tp_dict,"ToggleItalic", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebPage_WebAction,(long) QWebPage::ToggleUnderline, "ToggleUnderline");
    PyDict_SetItemString(Sbk_QWebPage_Type.super.ht_type.tp_dict,"ToggleUnderline", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebPage_WebAction->tp_dict,"ToggleUnderline", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebPage_WebAction,(long) QWebPage::InspectElement, "InspectElement");
    PyDict_SetItemString(Sbk_QWebPage_Type.super.ht_type.tp_dict,"InspectElement", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebPage_WebAction->tp_dict,"InspectElement", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebPage_WebAction,(long) QWebPage::InsertParagraphSeparator, "InsertParagraphSeparator");
    PyDict_SetItemString(Sbk_QWebPage_Type.super.ht_type.tp_dict,"InsertParagraphSeparator", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebPage_WebAction->tp_dict,"InsertParagraphSeparator", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebPage_WebAction,(long) QWebPage::InsertLineSeparator, "InsertLineSeparator");
    PyDict_SetItemString(Sbk_QWebPage_Type.super.ht_type.tp_dict,"InsertLineSeparator", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebPage_WebAction->tp_dict,"InsertLineSeparator", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebPage_WebAction,(long) QWebPage::SelectAll, "SelectAll");
    PyDict_SetItemString(Sbk_QWebPage_Type.super.ht_type.tp_dict,"SelectAll", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebPage_WebAction->tp_dict,"SelectAll", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebPage_WebAction,(long) QWebPage::ReloadAndBypassCache, "ReloadAndBypassCache");
    PyDict_SetItemString(Sbk_QWebPage_Type.super.ht_type.tp_dict,"ReloadAndBypassCache", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebPage_WebAction->tp_dict,"ReloadAndBypassCache", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebPage_WebAction,(long) QWebPage::PasteAndMatchStyle, "PasteAndMatchStyle");
    PyDict_SetItemString(Sbk_QWebPage_Type.super.ht_type.tp_dict,"PasteAndMatchStyle", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebPage_WebAction->tp_dict,"PasteAndMatchStyle", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebPage_WebAction,(long) QWebPage::RemoveFormat, "RemoveFormat");
    PyDict_SetItemString(Sbk_QWebPage_Type.super.ht_type.tp_dict,"RemoveFormat", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebPage_WebAction->tp_dict,"RemoveFormat", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebPage_WebAction,(long) QWebPage::ToggleStrikethrough, "ToggleStrikethrough");
    PyDict_SetItemString(Sbk_QWebPage_Type.super.ht_type.tp_dict,"ToggleStrikethrough", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebPage_WebAction->tp_dict,"ToggleStrikethrough", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebPage_WebAction,(long) QWebPage::ToggleSubscript, "ToggleSubscript");
    PyDict_SetItemString(Sbk_QWebPage_Type.super.ht_type.tp_dict,"ToggleSubscript", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebPage_WebAction->tp_dict,"ToggleSubscript", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebPage_WebAction,(long) QWebPage::ToggleSuperscript, "ToggleSuperscript");
    PyDict_SetItemString(Sbk_QWebPage_Type.super.ht_type.tp_dict,"ToggleSuperscript", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebPage_WebAction->tp_dict,"ToggleSuperscript", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebPage_WebAction,(long) QWebPage::InsertUnorderedList, "InsertUnorderedList");
    PyDict_SetItemString(Sbk_QWebPage_Type.super.ht_type.tp_dict,"InsertUnorderedList", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebPage_WebAction->tp_dict,"InsertUnorderedList", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebPage_WebAction,(long) QWebPage::InsertOrderedList, "InsertOrderedList");
    PyDict_SetItemString(Sbk_QWebPage_Type.super.ht_type.tp_dict,"InsertOrderedList", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebPage_WebAction->tp_dict,"InsertOrderedList", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebPage_WebAction,(long) QWebPage::Indent, "Indent");
    PyDict_SetItemString(Sbk_QWebPage_Type.super.ht_type.tp_dict,"Indent", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebPage_WebAction->tp_dict,"Indent", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebPage_WebAction,(long) QWebPage::Outdent, "Outdent");
    PyDict_SetItemString(Sbk_QWebPage_Type.super.ht_type.tp_dict,"Outdent", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebPage_WebAction->tp_dict,"Outdent", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebPage_WebAction,(long) QWebPage::AlignCenter, "AlignCenter");
    PyDict_SetItemString(Sbk_QWebPage_Type.super.ht_type.tp_dict,"AlignCenter", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebPage_WebAction->tp_dict,"AlignCenter", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebPage_WebAction,(long) QWebPage::AlignJustified, "AlignJustified");
    PyDict_SetItemString(Sbk_QWebPage_Type.super.ht_type.tp_dict,"AlignJustified", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebPage_WebAction->tp_dict,"AlignJustified", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebPage_WebAction,(long) QWebPage::AlignLeft, "AlignLeft");
    PyDict_SetItemString(Sbk_QWebPage_Type.super.ht_type.tp_dict,"AlignLeft", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebPage_WebAction->tp_dict,"AlignLeft", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebPage_WebAction,(long) QWebPage::AlignRight, "AlignRight");
    PyDict_SetItemString(Sbk_QWebPage_Type.super.ht_type.tp_dict,"AlignRight", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebPage_WebAction->tp_dict,"AlignRight", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebPage_WebAction,(long) QWebPage::StopScheduledPageRefresh, "StopScheduledPageRefresh");
    PyDict_SetItemString(Sbk_QWebPage_Type.super.ht_type.tp_dict,"StopScheduledPageRefresh", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebPage_WebAction->tp_dict,"StopScheduledPageRefresh", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebPage_WebAction,(long) QWebPage::WebActionCount, "WebActionCount");
    PyDict_SetItemString(Sbk_QWebPage_Type.super.ht_type.tp_dict,"WebActionCount", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebPage_WebAction->tp_dict,"WebActionCount", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QWebPage::WebAction");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::WebAction");
    // end of enum WebAction

    // init enum: WebWindowType
    PyTypeObject* SbkPySide_QtWebKit_QWebPage_WebWindowType = Shiboken::Enum::newType("WebWindowType");
    SbkPySide_QtWebKitTypes[SBK_QWEBPAGE_WEBWINDOWTYPE_IDX] = SbkPySide_QtWebKit_QWebPage_WebWindowType;
    if (PyType_Ready(SbkPySide_QtWebKit_QWebPage_WebWindowType) < 0)
        return;
    PyDict_SetItemString(Sbk_QWebPage_Type.super.ht_type.tp_dict,
            "WebWindowType",((PyObject*)SbkPySide_QtWebKit_QWebPage_WebWindowType));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebPage_WebWindowType,(long) QWebPage::WebBrowserWindow, "WebBrowserWindow");
    PyDict_SetItemString(Sbk_QWebPage_Type.super.ht_type.tp_dict,"WebBrowserWindow", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebPage_WebWindowType->tp_dict,"WebBrowserWindow", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebPage_WebWindowType,(long) QWebPage::WebModalDialog, "WebModalDialog");
    PyDict_SetItemString(Sbk_QWebPage_Type.super.ht_type.tp_dict,"WebModalDialog", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebPage_WebWindowType->tp_dict,"WebModalDialog", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QWebPage::WebWindowType");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::WebWindowType");
    // end of enum WebWindowType

    // init enum: FindFlag
    PyTypeObject* SbkPySide_QtWebKit_QWebPage_FindFlag = Shiboken::Enum::newType("FindFlag");
    SbkPySide_QtWebKit_QWebPage_FindFlag->tp_as_number = &SbkPySide_QtWebKit_QWebPage_FindFlag_as_number;
    SbkPySide_QtWebKitTypes[SBK_QWEBPAGE_FINDFLAG_IDX] = SbkPySide_QtWebKit_QWebPage_FindFlag;
    if (PyType_Ready(SbkPySide_QtWebKit_QWebPage_FindFlag) < 0)
        return;
    PyDict_SetItemString(Sbk_QWebPage_Type.super.ht_type.tp_dict,
            "FindFlag",((PyObject*)SbkPySide_QtWebKit_QWebPage_FindFlag));

    // init flags class: QFlags<QWebPage::FindFlag>
    SbkPySide_QtWebKitTypes[SBK_QFLAGS_QWEBPAGE_FINDFLAG__IDX] = &SbkPySide_QtWebKit_QWebPage_FindFlags_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_QtWebKit_QWebPage_FindFlags_Type) < 0)
        return;
    PyDict_SetItemString(Sbk_QWebPage_Type.super.ht_type.tp_dict,
            "FindFlags",((PyObject*)&SbkPySide_QtWebKit_QWebPage_FindFlags_Type));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebPage_FindFlag,(long) QWebPage::FindBackward, "FindBackward");
    PyDict_SetItemString(Sbk_QWebPage_Type.super.ht_type.tp_dict,"FindBackward", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebPage_FindFlag->tp_dict,"FindBackward", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebPage_FindFlag,(long) QWebPage::FindCaseSensitively, "FindCaseSensitively");
    PyDict_SetItemString(Sbk_QWebPage_Type.super.ht_type.tp_dict,"FindCaseSensitively", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebPage_FindFlag->tp_dict,"FindCaseSensitively", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebPage_FindFlag,(long) QWebPage::FindWrapsAroundDocument, "FindWrapsAroundDocument");
    PyDict_SetItemString(Sbk_QWebPage_Type.super.ht_type.tp_dict,"FindWrapsAroundDocument", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebPage_FindFlag->tp_dict,"FindWrapsAroundDocument", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebPage_FindFlag,(long) QWebPage::HighlightAllOccurrences, "HighlightAllOccurrences");
    PyDict_SetItemString(Sbk_QWebPage_Type.super.ht_type.tp_dict,"HighlightAllOccurrences", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebPage_FindFlag->tp_dict,"HighlightAllOccurrences", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QWebPage::FindFlag");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::FindFlag");
    // end of enum FindFlag

    // init enum: Extension
    PyTypeObject* SbkPySide_QtWebKit_QWebPage_Extension = Shiboken::Enum::newType("Extension");
    SbkPySide_QtWebKitTypes[SBK_QWEBPAGE_EXTENSION_IDX] = SbkPySide_QtWebKit_QWebPage_Extension;
    if (PyType_Ready(SbkPySide_QtWebKit_QWebPage_Extension) < 0)
        return;
    PyDict_SetItemString(Sbk_QWebPage_Type.super.ht_type.tp_dict,
            "Extension",((PyObject*)SbkPySide_QtWebKit_QWebPage_Extension));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebPage_Extension,(long) QWebPage::ChooseMultipleFilesExtension, "ChooseMultipleFilesExtension");
    PyDict_SetItemString(Sbk_QWebPage_Type.super.ht_type.tp_dict,"ChooseMultipleFilesExtension", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebPage_Extension->tp_dict,"ChooseMultipleFilesExtension", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebPage_Extension,(long) QWebPage::ErrorPageExtension, "ErrorPageExtension");
    PyDict_SetItemString(Sbk_QWebPage_Type.super.ht_type.tp_dict,"ErrorPageExtension", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebPage_Extension->tp_dict,"ErrorPageExtension", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QWebPage::Extension");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::Extension");
    // end of enum Extension

    // init enum: LinkDelegationPolicy
    PyTypeObject* SbkPySide_QtWebKit_QWebPage_LinkDelegationPolicy = Shiboken::Enum::newType("LinkDelegationPolicy");
    SbkPySide_QtWebKitTypes[SBK_QWEBPAGE_LINKDELEGATIONPOLICY_IDX] = SbkPySide_QtWebKit_QWebPage_LinkDelegationPolicy;
    if (PyType_Ready(SbkPySide_QtWebKit_QWebPage_LinkDelegationPolicy) < 0)
        return;
    PyDict_SetItemString(Sbk_QWebPage_Type.super.ht_type.tp_dict,
            "LinkDelegationPolicy",((PyObject*)SbkPySide_QtWebKit_QWebPage_LinkDelegationPolicy));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebPage_LinkDelegationPolicy,(long) QWebPage::DontDelegateLinks, "DontDelegateLinks");
    PyDict_SetItemString(Sbk_QWebPage_Type.super.ht_type.tp_dict,"DontDelegateLinks", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebPage_LinkDelegationPolicy->tp_dict,"DontDelegateLinks", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebPage_LinkDelegationPolicy,(long) QWebPage::DelegateExternalLinks, "DelegateExternalLinks");
    PyDict_SetItemString(Sbk_QWebPage_Type.super.ht_type.tp_dict,"DelegateExternalLinks", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebPage_LinkDelegationPolicy->tp_dict,"DelegateExternalLinks", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebPage_LinkDelegationPolicy,(long) QWebPage::DelegateAllLinks, "DelegateAllLinks");
    PyDict_SetItemString(Sbk_QWebPage_Type.super.ht_type.tp_dict,"DelegateAllLinks", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebPage_LinkDelegationPolicy->tp_dict,"DelegateAllLinks", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QWebPage::LinkDelegationPolicy");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::LinkDelegationPolicy");
    // end of enum LinkDelegationPolicy

    // Initialize signals
    PySideSignal* signal_item;

    signal_item = PySide::Signal::newObject("microFocusChanged", "void", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QWebPage_Type, "microFocusChanged", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("loadFinished", "bool", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QWebPage_Type, "loadFinished", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("printRequested", "QWebFrame*", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QWebPage_Type, "printRequested", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("loadProgress", "int", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QWebPage_Type, "loadProgress", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("statusBarMessage", "QString", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QWebPage_Type, "statusBarMessage", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("statusBarVisibilityChangeRequested", "bool", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QWebPage_Type, "statusBarVisibilityChangeRequested", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("menuBarVisibilityChangeRequested", "bool", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QWebPage_Type, "menuBarVisibilityChangeRequested", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("linkClicked", "QUrl", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QWebPage_Type, "linkClicked", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("linkHovered", "QString,QString,QString", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QWebPage_Type, "linkHovered", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("saveFrameStateRequested", "QWebFrame*,QWebHistoryItem*", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QWebPage_Type, "saveFrameStateRequested", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("selectionChanged", "void", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QWebPage_Type, "selectionChanged", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("loadStarted", "void", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QWebPage_Type, "loadStarted", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("windowCloseRequested", "void", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QWebPage_Type, "windowCloseRequested", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("toolBarVisibilityChangeRequested", "bool", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QWebPage_Type, "toolBarVisibilityChangeRequested", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("unsupportedContent", "QNetworkReply*", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QWebPage_Type, "unsupportedContent", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("repaintRequested", "QRect", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QWebPage_Type, "repaintRequested", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("scrollRequested", "int,int,QRect", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QWebPage_Type, "scrollRequested", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("contentsChanged", "void", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QWebPage_Type, "contentsChanged", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("frameCreated", "QWebFrame*", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QWebPage_Type, "frameCreated", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("geometryChangeRequested", "QRect", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QWebPage_Type, "geometryChangeRequested", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("downloadRequested", "QNetworkRequest", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QWebPage_Type, "downloadRequested", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("databaseQuotaExceeded", "QWebFrame*,QString", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QWebPage_Type, "databaseQuotaExceeded", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("restoreFrameStateRequested", "QWebFrame*", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QWebPage_Type, "restoreFrameStateRequested", signal_item);
    Py_DECREF((PyObject*) signal_item);


    Shiboken::TypeResolver::createObjectTypeResolver<QWebPage >("QWebPage*");
    Shiboken::TypeResolver::createObjectTypeResolver<QWebPage >(typeid(QWebPage).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QWebPage >(typeid(QWebPageWrapper).name());
    PySide::initQtMetaType<QWebPage* >();
}

