/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtwebkit_python.h"

#include "qwebsettings_wrapper.h"

// Extra includes
#include <qicon.h>
#include <qpixmap.h>
#include <qurl.h>
#include <qwebsettings.h>



// Target ---------------------------------------------------------

extern "C" {
static PyObject* Sbk_QWebSettingsFunc_clearIconDatabase(PyObject* self)
{

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // clearIconDatabase()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QWebSettings::clearIconDatabase();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QWebSettingsFunc_clearMemoryCaches(PyObject* self)
{

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // clearMemoryCaches()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QWebSettings::clearMemoryCaches();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QWebSettingsFunc_defaultTextEncoding(PyObject* self)
{
    QWebSettings* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebSettings* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // defaultTextEncoding()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = cppSelf->defaultTextEncoding();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWebSettingsFunc_enablePersistentStorage(PyObject* self, PyObject* args, PyObject* kwds)
{
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtWebKit.QWebSettings.enablePersistentStorage(): too many arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|O:enablePersistentStorage", &(pyargs[0])))
        return 0;


    // Overloaded function decisor
    // 0: enablePersistentStorage(QString)
    if (numArgs == 0) {
        overloadId = 0; // enablePersistentStorage(QString)
    } else if (Shiboken::Converter< QString >::isConvertible(pyargs[0])) {
        overloadId = 0; // enablePersistentStorage(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebSettingsFunc_enablePersistentStorage_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "path");
                if (value) {
                    if (pyargs[0])
                        errorArgName = "path";
                    else if (Shiboken::Converter< QString >::isConvertible(value))
                        pyargs[0] = value;
else
                        goto Sbk_QWebSettingsFunc_enablePersistentStorage_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtWebKit.QWebSettings.enablePersistentStorage(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QString cppArg0 = pyargs[0] ? Shiboken::Converter<QString >::toCpp(pyargs[0]) : QString();

            if(!PyErr_Occurred()) {
                // enablePersistentStorage(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QWebSettings::enablePersistentStorage(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWebSettingsFunc_enablePersistentStorage_TypeError:
        const char* overloads[] = {"QString = QString()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtWebKit.QWebSettings.enablePersistentStorage", overloads);
        return 0;
}

static PyObject* Sbk_QWebSettingsFunc_fontFamily(PyObject* self, PyObject* arg)
{
    QWebSettings* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebSettings* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: fontFamily(QWebSettings::FontFamily)const
    if (Shiboken::Converter< ::QWebSettings::FontFamily >::isConvertible(arg)) {
        overloadId = 0; // fontFamily(QWebSettings::FontFamily)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebSettingsFunc_fontFamily_TypeError;

    // Call function/method
    {
        {
            QWebSettings::FontFamily cppArg0 = Shiboken::Converter<QWebSettings::FontFamily >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // fontFamily(QWebSettings::FontFamily)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = cppSelf->fontFamily(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QWebSettingsFunc_fontFamily_TypeError:
        const char* overloads[] = {"PySide.QtWebKit.QWebSettings.FontFamily", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebSettings.fontFamily", overloads);
        return 0;
}

static PyObject* Sbk_QWebSettingsFunc_fontSize(PyObject* self, PyObject* arg)
{
    QWebSettings* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebSettings* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: fontSize(QWebSettings::FontSize)const
    if (Shiboken::Converter< ::QWebSettings::FontSize >::isConvertible(arg)) {
        overloadId = 0; // fontSize(QWebSettings::FontSize)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebSettingsFunc_fontSize_TypeError;

    // Call function/method
    {
        {
            QWebSettings::FontSize cppArg0 = Shiboken::Converter<QWebSettings::FontSize >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // fontSize(QWebSettings::FontSize)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->fontSize(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QWebSettingsFunc_fontSize_TypeError:
        const char* overloads[] = {"PySide.QtWebKit.QWebSettings.FontSize", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebSettings.fontSize", overloads);
        return 0;
}

static PyObject* Sbk_QWebSettingsFunc_globalSettings(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // globalSettings()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QWebSettings * cppResult = QWebSettings::globalSettings();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QWebSettings * >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWebSettingsFunc_iconDatabasePath(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // iconDatabasePath()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = QWebSettings::iconDatabasePath();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWebSettingsFunc_iconForUrl(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: iconForUrl(QUrl)
    if (Shiboken::Converter< ::QUrl >::isConvertible(arg)) {
        overloadId = 0; // iconForUrl(QUrl)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebSettingsFunc_iconForUrl_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QUrl cppArg0 = Shiboken::Converter<QUrl >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // iconForUrl(QUrl)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QIcon cppResult = QWebSettings::iconForUrl(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QIcon >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QWebSettingsFunc_iconForUrl_TypeError:
        const char* overloads[] = {"PySide.QtCore.QUrl", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebSettings.iconForUrl", overloads);
        return 0;
}

static PyObject* Sbk_QWebSettingsFunc_localStoragePath(PyObject* self)
{
    QWebSettings* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebSettings* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // localStoragePath()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = cppSelf->localStoragePath();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWebSettingsFunc_maximumPagesInCache(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // maximumPagesInCache()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = QWebSettings::maximumPagesInCache();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWebSettingsFunc_offlineStorageDefaultQuota(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // offlineStorageDefaultQuota()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qint64 cppResult = QWebSettings::offlineStorageDefaultQuota();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< long long >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWebSettingsFunc_offlineStoragePath(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // offlineStoragePath()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = QWebSettings::offlineStoragePath();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWebSettingsFunc_offlineWebApplicationCachePath(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // offlineWebApplicationCachePath()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = QWebSettings::offlineWebApplicationCachePath();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWebSettingsFunc_offlineWebApplicationCacheQuota(PyObject* self)
{
    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // offlineWebApplicationCacheQuota()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qint64 cppResult = QWebSettings::offlineWebApplicationCacheQuota();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< long long >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWebSettingsFunc_resetAttribute(PyObject* self, PyObject* arg)
{
    QWebSettings* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebSettings* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: resetAttribute(QWebSettings::WebAttribute)
    if (Shiboken::Converter< ::QWebSettings::WebAttribute >::isConvertible(arg)) {
        overloadId = 0; // resetAttribute(QWebSettings::WebAttribute)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebSettingsFunc_resetAttribute_TypeError;

    // Call function/method
    {
        {
            QWebSettings::WebAttribute cppArg0 = Shiboken::Converter<QWebSettings::WebAttribute >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // resetAttribute(QWebSettings::WebAttribute)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->resetAttribute(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWebSettingsFunc_resetAttribute_TypeError:
        const char* overloads[] = {"PySide.QtWebKit.QWebSettings.WebAttribute", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebSettings.resetAttribute", overloads);
        return 0;
}

static PyObject* Sbk_QWebSettingsFunc_resetFontFamily(PyObject* self, PyObject* arg)
{
    QWebSettings* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebSettings* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: resetFontFamily(QWebSettings::FontFamily)
    if (Shiboken::Converter< ::QWebSettings::FontFamily >::isConvertible(arg)) {
        overloadId = 0; // resetFontFamily(QWebSettings::FontFamily)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebSettingsFunc_resetFontFamily_TypeError;

    // Call function/method
    {
        {
            QWebSettings::FontFamily cppArg0 = Shiboken::Converter<QWebSettings::FontFamily >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // resetFontFamily(QWebSettings::FontFamily)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->resetFontFamily(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWebSettingsFunc_resetFontFamily_TypeError:
        const char* overloads[] = {"PySide.QtWebKit.QWebSettings.FontFamily", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebSettings.resetFontFamily", overloads);
        return 0;
}

static PyObject* Sbk_QWebSettingsFunc_resetFontSize(PyObject* self, PyObject* arg)
{
    QWebSettings* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebSettings* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: resetFontSize(QWebSettings::FontSize)
    if (Shiboken::Converter< ::QWebSettings::FontSize >::isConvertible(arg)) {
        overloadId = 0; // resetFontSize(QWebSettings::FontSize)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebSettingsFunc_resetFontSize_TypeError;

    // Call function/method
    {
        {
            QWebSettings::FontSize cppArg0 = Shiboken::Converter<QWebSettings::FontSize >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // resetFontSize(QWebSettings::FontSize)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->resetFontSize(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWebSettingsFunc_resetFontSize_TypeError:
        const char* overloads[] = {"PySide.QtWebKit.QWebSettings.FontSize", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebSettings.resetFontSize", overloads);
        return 0;
}

static PyObject* Sbk_QWebSettingsFunc_setAttribute(PyObject* self, PyObject* args)
{
    QWebSettings* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebSettings* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setAttribute", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setAttribute(QWebSettings::WebAttribute,bool)
    if (numArgs == 2 && Shiboken::Converter< ::QWebSettings::WebAttribute >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // setAttribute(QWebSettings::WebAttribute,bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebSettingsFunc_setAttribute_TypeError;

    // Call function/method
    {
        {
            QWebSettings::WebAttribute cppArg0 = Shiboken::Converter<QWebSettings::WebAttribute >::toCpp(pyargs[0]);
            bool cppArg1 = Shiboken::Converter<bool >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // setAttribute(QWebSettings::WebAttribute,bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setAttribute(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWebSettingsFunc_setAttribute_TypeError:
        const char* overloads[] = {"PySide.QtWebKit.QWebSettings.WebAttribute, bool", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtWebKit.QWebSettings.setAttribute", overloads);
        return 0;
}

static PyObject* Sbk_QWebSettingsFunc_setDefaultTextEncoding(PyObject* self, PyObject* arg)
{
    QWebSettings* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebSettings* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDefaultTextEncoding(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // setDefaultTextEncoding(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebSettingsFunc_setDefaultTextEncoding_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setDefaultTextEncoding(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setDefaultTextEncoding(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWebSettingsFunc_setDefaultTextEncoding_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebSettings.setDefaultTextEncoding", overloads);
        return 0;
}

static PyObject* Sbk_QWebSettingsFunc_setFontFamily(PyObject* self, PyObject* args)
{
    QWebSettings* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebSettings* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setFontFamily", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setFontFamily(QWebSettings::FontFamily,QString)
    if (numArgs == 2 && Shiboken::Converter< ::QWebSettings::FontFamily >::isConvertible(pyargs[0]) && Shiboken::Converter< QString >::isConvertible(pyargs[1])) {
        overloadId = 0; // setFontFamily(QWebSettings::FontFamily,QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebSettingsFunc_setFontFamily_TypeError;

    // Call function/method
    {
        {
            QWebSettings::FontFamily cppArg0 = Shiboken::Converter<QWebSettings::FontFamily >::toCpp(pyargs[0]);
            QString cppArg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // setFontFamily(QWebSettings::FontFamily,QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setFontFamily(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWebSettingsFunc_setFontFamily_TypeError:
        const char* overloads[] = {"PySide.QtWebKit.QWebSettings.FontFamily, QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtWebKit.QWebSettings.setFontFamily", overloads);
        return 0;
}

static PyObject* Sbk_QWebSettingsFunc_setFontSize(PyObject* self, PyObject* args)
{
    QWebSettings* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebSettings* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setFontSize", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setFontSize(QWebSettings::FontSize,int)
    if (numArgs == 2 && Shiboken::Converter< ::QWebSettings::FontSize >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // setFontSize(QWebSettings::FontSize,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebSettingsFunc_setFontSize_TypeError;

    // Call function/method
    {
        {
            QWebSettings::FontSize cppArg0 = Shiboken::Converter<QWebSettings::FontSize >::toCpp(pyargs[0]);
            int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // setFontSize(QWebSettings::FontSize,int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setFontSize(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWebSettingsFunc_setFontSize_TypeError:
        const char* overloads[] = {"PySide.QtWebKit.QWebSettings.FontSize, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtWebKit.QWebSettings.setFontSize", overloads);
        return 0;
}

static PyObject* Sbk_QWebSettingsFunc_setIconDatabasePath(PyObject* self, PyObject* arg)
{
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setIconDatabasePath(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // setIconDatabasePath(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebSettingsFunc_setIconDatabasePath_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setIconDatabasePath(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QWebSettings::setIconDatabasePath(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWebSettingsFunc_setIconDatabasePath_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebSettings.setIconDatabasePath", overloads);
        return 0;
}

static PyObject* Sbk_QWebSettingsFunc_setLocalStoragePath(PyObject* self, PyObject* arg)
{
    QWebSettings* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebSettings* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setLocalStoragePath(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // setLocalStoragePath(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebSettingsFunc_setLocalStoragePath_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setLocalStoragePath(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setLocalStoragePath(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWebSettingsFunc_setLocalStoragePath_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebSettings.setLocalStoragePath", overloads);
        return 0;
}

static PyObject* Sbk_QWebSettingsFunc_setMaximumPagesInCache(PyObject* self, PyObject* arg)
{
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setMaximumPagesInCache(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setMaximumPagesInCache(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebSettingsFunc_setMaximumPagesInCache_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setMaximumPagesInCache(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QWebSettings::setMaximumPagesInCache(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWebSettingsFunc_setMaximumPagesInCache_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebSettings.setMaximumPagesInCache", overloads);
        return 0;
}

static PyObject* Sbk_QWebSettingsFunc_setObjectCacheCapacities(PyObject* self, PyObject* args)
{
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setObjectCacheCapacities", 3, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: setObjectCacheCapacities(int,int,int)
    if (numArgs == 3 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
        overloadId = 0; // setObjectCacheCapacities(int,int,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebSettingsFunc_setObjectCacheCapacities_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
            int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

            if(!PyErr_Occurred()) {
                // setObjectCacheCapacities(int,int,int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QWebSettings::setObjectCacheCapacities(cppArg0, cppArg1, cppArg2);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWebSettingsFunc_setObjectCacheCapacities_TypeError:
        const char* overloads[] = {"int, int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtWebKit.QWebSettings.setObjectCacheCapacities", overloads);
        return 0;
}

static PyObject* Sbk_QWebSettingsFunc_setOfflineStorageDefaultQuota(PyObject* self, PyObject* arg)
{
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setOfflineStorageDefaultQuota(qint64)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setOfflineStorageDefaultQuota(qint64)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebSettingsFunc_setOfflineStorageDefaultQuota_TypeError;

    // Call function/method
    {
        {
            qint64 cppArg0 = Shiboken::Converter<qint64 >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setOfflineStorageDefaultQuota(qint64)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QWebSettings::setOfflineStorageDefaultQuota(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWebSettingsFunc_setOfflineStorageDefaultQuota_TypeError:
        const char* overloads[] = {"long long", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebSettings.setOfflineStorageDefaultQuota", overloads);
        return 0;
}

static PyObject* Sbk_QWebSettingsFunc_setOfflineStoragePath(PyObject* self, PyObject* arg)
{
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setOfflineStoragePath(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // setOfflineStoragePath(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebSettingsFunc_setOfflineStoragePath_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setOfflineStoragePath(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QWebSettings::setOfflineStoragePath(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWebSettingsFunc_setOfflineStoragePath_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebSettings.setOfflineStoragePath", overloads);
        return 0;
}

static PyObject* Sbk_QWebSettingsFunc_setOfflineWebApplicationCachePath(PyObject* self, PyObject* arg)
{
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setOfflineWebApplicationCachePath(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // setOfflineWebApplicationCachePath(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebSettingsFunc_setOfflineWebApplicationCachePath_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setOfflineWebApplicationCachePath(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QWebSettings::setOfflineWebApplicationCachePath(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWebSettingsFunc_setOfflineWebApplicationCachePath_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebSettings.setOfflineWebApplicationCachePath", overloads);
        return 0;
}

static PyObject* Sbk_QWebSettingsFunc_setOfflineWebApplicationCacheQuota(PyObject* self, PyObject* arg)
{
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setOfflineWebApplicationCacheQuota(qint64)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setOfflineWebApplicationCacheQuota(qint64)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebSettingsFunc_setOfflineWebApplicationCacheQuota_TypeError;

    // Call function/method
    {
        {
            qint64 cppArg0 = Shiboken::Converter<qint64 >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setOfflineWebApplicationCacheQuota(qint64)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QWebSettings::setOfflineWebApplicationCacheQuota(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWebSettingsFunc_setOfflineWebApplicationCacheQuota_TypeError:
        const char* overloads[] = {"long long", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebSettings.setOfflineWebApplicationCacheQuota", overloads);
        return 0;
}

static PyObject* Sbk_QWebSettingsFunc_setUserStyleSheetUrl(PyObject* self, PyObject* arg)
{
    QWebSettings* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebSettings* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setUserStyleSheetUrl(QUrl)
    if (Shiboken::Converter< ::QUrl >::isConvertible(arg)) {
        overloadId = 0; // setUserStyleSheetUrl(QUrl)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebSettingsFunc_setUserStyleSheetUrl_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QUrl cppArg0 = Shiboken::Converter<QUrl >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setUserStyleSheetUrl(QUrl)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setUserStyleSheetUrl(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWebSettingsFunc_setUserStyleSheetUrl_TypeError:
        const char* overloads[] = {"PySide.QtCore.QUrl", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebSettings.setUserStyleSheetUrl", overloads);
        return 0;
}

static PyObject* Sbk_QWebSettingsFunc_setWebGraphic(PyObject* self, PyObject* args)
{
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setWebGraphic", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setWebGraphic(QWebSettings::WebGraphic,QPixmap)
    if (numArgs == 2 && Shiboken::Converter< ::QWebSettings::WebGraphic >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QPixmap >::isConvertible(pyargs[1])) {
        overloadId = 0; // setWebGraphic(QWebSettings::WebGraphic,QPixmap)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebSettingsFunc_setWebGraphic_TypeError;

    // Call function/method
    {
        {
            QWebSettings::WebGraphic cppArg0 = Shiboken::Converter<QWebSettings::WebGraphic >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QPixmap cppArg1 = Shiboken::Converter<QPixmap >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // setWebGraphic(QWebSettings::WebGraphic,QPixmap)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QWebSettings::setWebGraphic(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QWebSettingsFunc_setWebGraphic_TypeError:
        const char* overloads[] = {"PySide.QtWebKit.QWebSettings.WebGraphic, PySide.QtGui.QPixmap", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtWebKit.QWebSettings.setWebGraphic", overloads);
        return 0;
}

static PyObject* Sbk_QWebSettingsFunc_testAttribute(PyObject* self, PyObject* arg)
{
    QWebSettings* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebSettings* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: testAttribute(QWebSettings::WebAttribute)const
    if (Shiboken::Converter< ::QWebSettings::WebAttribute >::isConvertible(arg)) {
        overloadId = 0; // testAttribute(QWebSettings::WebAttribute)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebSettingsFunc_testAttribute_TypeError;

    // Call function/method
    {
        {
            QWebSettings::WebAttribute cppArg0 = Shiboken::Converter<QWebSettings::WebAttribute >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // testAttribute(QWebSettings::WebAttribute)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->testAttribute(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QWebSettingsFunc_testAttribute_TypeError:
        const char* overloads[] = {"PySide.QtWebKit.QWebSettings.WebAttribute", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebSettings.testAttribute", overloads);
        return 0;
}

static PyObject* Sbk_QWebSettingsFunc_userStyleSheetUrl(PyObject* self)
{
    QWebSettings* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QWebSettings* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // userStyleSheetUrl()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QUrl cppResult = cppSelf->userStyleSheetUrl();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QUrl >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QWebSettingsFunc_webGraphic(PyObject* self, PyObject* arg)
{
    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: webGraphic(QWebSettings::WebGraphic)
    if (Shiboken::Converter< ::QWebSettings::WebGraphic >::isConvertible(arg)) {
        overloadId = 0; // webGraphic(QWebSettings::WebGraphic)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QWebSettingsFunc_webGraphic_TypeError;

    // Call function/method
    {
        {
            QWebSettings::WebGraphic cppArg0 = Shiboken::Converter<QWebSettings::WebGraphic >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // webGraphic(QWebSettings::WebGraphic)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QPixmap cppResult = QWebSettings::webGraphic(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QPixmap >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QWebSettingsFunc_webGraphic_TypeError:
        const char* overloads[] = {"PySide.QtWebKit.QWebSettings.WebGraphic", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtWebKit.QWebSettings.webGraphic", overloads);
        return 0;
}

static PyMethodDef Sbk_QWebSettings_methods[] = {
    {"clearIconDatabase", (PyCFunction)Sbk_QWebSettingsFunc_clearIconDatabase, METH_NOARGS|METH_STATIC},
    {"clearMemoryCaches", (PyCFunction)Sbk_QWebSettingsFunc_clearMemoryCaches, METH_NOARGS|METH_STATIC},
    {"defaultTextEncoding", (PyCFunction)Sbk_QWebSettingsFunc_defaultTextEncoding, METH_NOARGS},
    {"enablePersistentStorage", (PyCFunction)Sbk_QWebSettingsFunc_enablePersistentStorage, METH_VARARGS|METH_KEYWORDS|METH_STATIC},
    {"fontFamily", (PyCFunction)Sbk_QWebSettingsFunc_fontFamily, METH_O},
    {"fontSize", (PyCFunction)Sbk_QWebSettingsFunc_fontSize, METH_O},
    {"globalSettings", (PyCFunction)Sbk_QWebSettingsFunc_globalSettings, METH_NOARGS|METH_STATIC},
    {"iconDatabasePath", (PyCFunction)Sbk_QWebSettingsFunc_iconDatabasePath, METH_NOARGS|METH_STATIC},
    {"iconForUrl", (PyCFunction)Sbk_QWebSettingsFunc_iconForUrl, METH_O|METH_STATIC},
    {"localStoragePath", (PyCFunction)Sbk_QWebSettingsFunc_localStoragePath, METH_NOARGS},
    {"maximumPagesInCache", (PyCFunction)Sbk_QWebSettingsFunc_maximumPagesInCache, METH_NOARGS|METH_STATIC},
    {"offlineStorageDefaultQuota", (PyCFunction)Sbk_QWebSettingsFunc_offlineStorageDefaultQuota, METH_NOARGS|METH_STATIC},
    {"offlineStoragePath", (PyCFunction)Sbk_QWebSettingsFunc_offlineStoragePath, METH_NOARGS|METH_STATIC},
    {"offlineWebApplicationCachePath", (PyCFunction)Sbk_QWebSettingsFunc_offlineWebApplicationCachePath, METH_NOARGS|METH_STATIC},
    {"offlineWebApplicationCacheQuota", (PyCFunction)Sbk_QWebSettingsFunc_offlineWebApplicationCacheQuota, METH_NOARGS|METH_STATIC},
    {"resetAttribute", (PyCFunction)Sbk_QWebSettingsFunc_resetAttribute, METH_O},
    {"resetFontFamily", (PyCFunction)Sbk_QWebSettingsFunc_resetFontFamily, METH_O},
    {"resetFontSize", (PyCFunction)Sbk_QWebSettingsFunc_resetFontSize, METH_O},
    {"setAttribute", (PyCFunction)Sbk_QWebSettingsFunc_setAttribute, METH_VARARGS},
    {"setDefaultTextEncoding", (PyCFunction)Sbk_QWebSettingsFunc_setDefaultTextEncoding, METH_O},
    {"setFontFamily", (PyCFunction)Sbk_QWebSettingsFunc_setFontFamily, METH_VARARGS},
    {"setFontSize", (PyCFunction)Sbk_QWebSettingsFunc_setFontSize, METH_VARARGS},
    {"setIconDatabasePath", (PyCFunction)Sbk_QWebSettingsFunc_setIconDatabasePath, METH_O|METH_STATIC},
    {"setLocalStoragePath", (PyCFunction)Sbk_QWebSettingsFunc_setLocalStoragePath, METH_O},
    {"setMaximumPagesInCache", (PyCFunction)Sbk_QWebSettingsFunc_setMaximumPagesInCache, METH_O|METH_STATIC},
    {"setObjectCacheCapacities", (PyCFunction)Sbk_QWebSettingsFunc_setObjectCacheCapacities, METH_VARARGS|METH_STATIC},
    {"setOfflineStorageDefaultQuota", (PyCFunction)Sbk_QWebSettingsFunc_setOfflineStorageDefaultQuota, METH_O|METH_STATIC},
    {"setOfflineStoragePath", (PyCFunction)Sbk_QWebSettingsFunc_setOfflineStoragePath, METH_O|METH_STATIC},
    {"setOfflineWebApplicationCachePath", (PyCFunction)Sbk_QWebSettingsFunc_setOfflineWebApplicationCachePath, METH_O|METH_STATIC},
    {"setOfflineWebApplicationCacheQuota", (PyCFunction)Sbk_QWebSettingsFunc_setOfflineWebApplicationCacheQuota, METH_O|METH_STATIC},
    {"setUserStyleSheetUrl", (PyCFunction)Sbk_QWebSettingsFunc_setUserStyleSheetUrl, METH_O},
    {"setWebGraphic", (PyCFunction)Sbk_QWebSettingsFunc_setWebGraphic, METH_VARARGS|METH_STATIC},
    {"testAttribute", (PyCFunction)Sbk_QWebSettingsFunc_testAttribute, METH_O},
    {"userStyleSheetUrl", (PyCFunction)Sbk_QWebSettingsFunc_userStyleSheetUrl, METH_NOARGS},
    {"webGraphic", (PyCFunction)Sbk_QWebSettingsFunc_webGraphic, METH_O|METH_STATIC},

    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QWebSettings_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtWebKit.QWebSettings",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          SbkDeallocWrapperWithPrivateDtor,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QWebSettings_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              0,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QWebSettings(PyObject* module)
{
    SbkPySide_QtWebKitTypes[SBK_QWEBSETTINGS_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QWebSettings_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QWebSettings_Type);
    if (PyType_Ready((PyTypeObject*)&Sbk_QWebSettings_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QWebSettings_Type, "QWebSettings*");
    PyModule_AddObject(module, "QWebSettings",
        ((PyObject*)&Sbk_QWebSettings_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: FontSize
    PyTypeObject* SbkPySide_QtWebKit_QWebSettings_FontSize = Shiboken::Enum::newType("FontSize");
    SbkPySide_QtWebKitTypes[SBK_QWEBSETTINGS_FONTSIZE_IDX] = SbkPySide_QtWebKit_QWebSettings_FontSize;
    if (PyType_Ready(SbkPySide_QtWebKit_QWebSettings_FontSize) < 0)
        return;
    PyDict_SetItemString(Sbk_QWebSettings_Type.super.ht_type.tp_dict,
            "FontSize",((PyObject*)SbkPySide_QtWebKit_QWebSettings_FontSize));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebSettings_FontSize,(long) QWebSettings::MinimumFontSize, "MinimumFontSize");
    PyDict_SetItemString(Sbk_QWebSettings_Type.super.ht_type.tp_dict,"MinimumFontSize", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebSettings_FontSize->tp_dict,"MinimumFontSize", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebSettings_FontSize,(long) QWebSettings::MinimumLogicalFontSize, "MinimumLogicalFontSize");
    PyDict_SetItemString(Sbk_QWebSettings_Type.super.ht_type.tp_dict,"MinimumLogicalFontSize", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebSettings_FontSize->tp_dict,"MinimumLogicalFontSize", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebSettings_FontSize,(long) QWebSettings::DefaultFontSize, "DefaultFontSize");
    PyDict_SetItemString(Sbk_QWebSettings_Type.super.ht_type.tp_dict,"DefaultFontSize", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebSettings_FontSize->tp_dict,"DefaultFontSize", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebSettings_FontSize,(long) QWebSettings::DefaultFixedFontSize, "DefaultFixedFontSize");
    PyDict_SetItemString(Sbk_QWebSettings_Type.super.ht_type.tp_dict,"DefaultFixedFontSize", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebSettings_FontSize->tp_dict,"DefaultFixedFontSize", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QWebSettings::FontSize");
    Shiboken::TypeResolver::createValueTypeResolver<int>("QWebSettings$ConcreteWrapper::FontSize");
    // end of enum FontSize

    // init enum: WebGraphic
    PyTypeObject* SbkPySide_QtWebKit_QWebSettings_WebGraphic = Shiboken::Enum::newType("WebGraphic");
    SbkPySide_QtWebKitTypes[SBK_QWEBSETTINGS_WEBGRAPHIC_IDX] = SbkPySide_QtWebKit_QWebSettings_WebGraphic;
    if (PyType_Ready(SbkPySide_QtWebKit_QWebSettings_WebGraphic) < 0)
        return;
    PyDict_SetItemString(Sbk_QWebSettings_Type.super.ht_type.tp_dict,
            "WebGraphic",((PyObject*)SbkPySide_QtWebKit_QWebSettings_WebGraphic));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebSettings_WebGraphic,(long) QWebSettings::MissingImageGraphic, "MissingImageGraphic");
    PyDict_SetItemString(Sbk_QWebSettings_Type.super.ht_type.tp_dict,"MissingImageGraphic", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebSettings_WebGraphic->tp_dict,"MissingImageGraphic", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebSettings_WebGraphic,(long) QWebSettings::MissingPluginGraphic, "MissingPluginGraphic");
    PyDict_SetItemString(Sbk_QWebSettings_Type.super.ht_type.tp_dict,"MissingPluginGraphic", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebSettings_WebGraphic->tp_dict,"MissingPluginGraphic", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebSettings_WebGraphic,(long) QWebSettings::DefaultFrameIconGraphic, "DefaultFrameIconGraphic");
    PyDict_SetItemString(Sbk_QWebSettings_Type.super.ht_type.tp_dict,"DefaultFrameIconGraphic", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebSettings_WebGraphic->tp_dict,"DefaultFrameIconGraphic", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebSettings_WebGraphic,(long) QWebSettings::TextAreaSizeGripCornerGraphic, "TextAreaSizeGripCornerGraphic");
    PyDict_SetItemString(Sbk_QWebSettings_Type.super.ht_type.tp_dict,"TextAreaSizeGripCornerGraphic", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebSettings_WebGraphic->tp_dict,"TextAreaSizeGripCornerGraphic", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebSettings_WebGraphic,(long) QWebSettings::DeleteButtonGraphic, "DeleteButtonGraphic");
    PyDict_SetItemString(Sbk_QWebSettings_Type.super.ht_type.tp_dict,"DeleteButtonGraphic", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebSettings_WebGraphic->tp_dict,"DeleteButtonGraphic", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QWebSettings::WebGraphic");
    Shiboken::TypeResolver::createValueTypeResolver<int>("QWebSettings$ConcreteWrapper::WebGraphic");
    // end of enum WebGraphic

    // init enum: FontFamily
    PyTypeObject* SbkPySide_QtWebKit_QWebSettings_FontFamily = Shiboken::Enum::newType("FontFamily");
    SbkPySide_QtWebKitTypes[SBK_QWEBSETTINGS_FONTFAMILY_IDX] = SbkPySide_QtWebKit_QWebSettings_FontFamily;
    if (PyType_Ready(SbkPySide_QtWebKit_QWebSettings_FontFamily) < 0)
        return;
    PyDict_SetItemString(Sbk_QWebSettings_Type.super.ht_type.tp_dict,
            "FontFamily",((PyObject*)SbkPySide_QtWebKit_QWebSettings_FontFamily));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebSettings_FontFamily,(long) QWebSettings::StandardFont, "StandardFont");
    PyDict_SetItemString(Sbk_QWebSettings_Type.super.ht_type.tp_dict,"StandardFont", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebSettings_FontFamily->tp_dict,"StandardFont", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebSettings_FontFamily,(long) QWebSettings::FixedFont, "FixedFont");
    PyDict_SetItemString(Sbk_QWebSettings_Type.super.ht_type.tp_dict,"FixedFont", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebSettings_FontFamily->tp_dict,"FixedFont", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebSettings_FontFamily,(long) QWebSettings::SerifFont, "SerifFont");
    PyDict_SetItemString(Sbk_QWebSettings_Type.super.ht_type.tp_dict,"SerifFont", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebSettings_FontFamily->tp_dict,"SerifFont", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebSettings_FontFamily,(long) QWebSettings::SansSerifFont, "SansSerifFont");
    PyDict_SetItemString(Sbk_QWebSettings_Type.super.ht_type.tp_dict,"SansSerifFont", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebSettings_FontFamily->tp_dict,"SansSerifFont", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebSettings_FontFamily,(long) QWebSettings::CursiveFont, "CursiveFont");
    PyDict_SetItemString(Sbk_QWebSettings_Type.super.ht_type.tp_dict,"CursiveFont", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebSettings_FontFamily->tp_dict,"CursiveFont", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebSettings_FontFamily,(long) QWebSettings::FantasyFont, "FantasyFont");
    PyDict_SetItemString(Sbk_QWebSettings_Type.super.ht_type.tp_dict,"FantasyFont", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebSettings_FontFamily->tp_dict,"FantasyFont", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QWebSettings::FontFamily");
    Shiboken::TypeResolver::createValueTypeResolver<int>("QWebSettings$ConcreteWrapper::FontFamily");
    // end of enum FontFamily

    // init enum: WebAttribute
    PyTypeObject* SbkPySide_QtWebKit_QWebSettings_WebAttribute = Shiboken::Enum::newType("WebAttribute");
    SbkPySide_QtWebKitTypes[SBK_QWEBSETTINGS_WEBATTRIBUTE_IDX] = SbkPySide_QtWebKit_QWebSettings_WebAttribute;
    if (PyType_Ready(SbkPySide_QtWebKit_QWebSettings_WebAttribute) < 0)
        return;
    PyDict_SetItemString(Sbk_QWebSettings_Type.super.ht_type.tp_dict,
            "WebAttribute",((PyObject*)SbkPySide_QtWebKit_QWebSettings_WebAttribute));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebSettings_WebAttribute,(long) QWebSettings::AutoLoadImages, "AutoLoadImages");
    PyDict_SetItemString(Sbk_QWebSettings_Type.super.ht_type.tp_dict,"AutoLoadImages", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebSettings_WebAttribute->tp_dict,"AutoLoadImages", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebSettings_WebAttribute,(long) QWebSettings::JavascriptEnabled, "JavascriptEnabled");
    PyDict_SetItemString(Sbk_QWebSettings_Type.super.ht_type.tp_dict,"JavascriptEnabled", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebSettings_WebAttribute->tp_dict,"JavascriptEnabled", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebSettings_WebAttribute,(long) QWebSettings::JavaEnabled, "JavaEnabled");
    PyDict_SetItemString(Sbk_QWebSettings_Type.super.ht_type.tp_dict,"JavaEnabled", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebSettings_WebAttribute->tp_dict,"JavaEnabled", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebSettings_WebAttribute,(long) QWebSettings::PluginsEnabled, "PluginsEnabled");
    PyDict_SetItemString(Sbk_QWebSettings_Type.super.ht_type.tp_dict,"PluginsEnabled", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebSettings_WebAttribute->tp_dict,"PluginsEnabled", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebSettings_WebAttribute,(long) QWebSettings::PrivateBrowsingEnabled, "PrivateBrowsingEnabled");
    PyDict_SetItemString(Sbk_QWebSettings_Type.super.ht_type.tp_dict,"PrivateBrowsingEnabled", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebSettings_WebAttribute->tp_dict,"PrivateBrowsingEnabled", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebSettings_WebAttribute,(long) QWebSettings::JavascriptCanOpenWindows, "JavascriptCanOpenWindows");
    PyDict_SetItemString(Sbk_QWebSettings_Type.super.ht_type.tp_dict,"JavascriptCanOpenWindows", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebSettings_WebAttribute->tp_dict,"JavascriptCanOpenWindows", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebSettings_WebAttribute,(long) QWebSettings::JavascriptCanAccessClipboard, "JavascriptCanAccessClipboard");
    PyDict_SetItemString(Sbk_QWebSettings_Type.super.ht_type.tp_dict,"JavascriptCanAccessClipboard", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebSettings_WebAttribute->tp_dict,"JavascriptCanAccessClipboard", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebSettings_WebAttribute,(long) QWebSettings::DeveloperExtrasEnabled, "DeveloperExtrasEnabled");
    PyDict_SetItemString(Sbk_QWebSettings_Type.super.ht_type.tp_dict,"DeveloperExtrasEnabled", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebSettings_WebAttribute->tp_dict,"DeveloperExtrasEnabled", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebSettings_WebAttribute,(long) QWebSettings::LinksIncludedInFocusChain, "LinksIncludedInFocusChain");
    PyDict_SetItemString(Sbk_QWebSettings_Type.super.ht_type.tp_dict,"LinksIncludedInFocusChain", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebSettings_WebAttribute->tp_dict,"LinksIncludedInFocusChain", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebSettings_WebAttribute,(long) QWebSettings::ZoomTextOnly, "ZoomTextOnly");
    PyDict_SetItemString(Sbk_QWebSettings_Type.super.ht_type.tp_dict,"ZoomTextOnly", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebSettings_WebAttribute->tp_dict,"ZoomTextOnly", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebSettings_WebAttribute,(long) QWebSettings::PrintElementBackgrounds, "PrintElementBackgrounds");
    PyDict_SetItemString(Sbk_QWebSettings_Type.super.ht_type.tp_dict,"PrintElementBackgrounds", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebSettings_WebAttribute->tp_dict,"PrintElementBackgrounds", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebSettings_WebAttribute,(long) QWebSettings::OfflineStorageDatabaseEnabled, "OfflineStorageDatabaseEnabled");
    PyDict_SetItemString(Sbk_QWebSettings_Type.super.ht_type.tp_dict,"OfflineStorageDatabaseEnabled", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebSettings_WebAttribute->tp_dict,"OfflineStorageDatabaseEnabled", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebSettings_WebAttribute,(long) QWebSettings::OfflineWebApplicationCacheEnabled, "OfflineWebApplicationCacheEnabled");
    PyDict_SetItemString(Sbk_QWebSettings_Type.super.ht_type.tp_dict,"OfflineWebApplicationCacheEnabled", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebSettings_WebAttribute->tp_dict,"OfflineWebApplicationCacheEnabled", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebSettings_WebAttribute,(long) QWebSettings::LocalStorageEnabled, "LocalStorageEnabled");
    PyDict_SetItemString(Sbk_QWebSettings_Type.super.ht_type.tp_dict,"LocalStorageEnabled", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebSettings_WebAttribute->tp_dict,"LocalStorageEnabled", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebSettings_WebAttribute,(long) QWebSettings::LocalStorageDatabaseEnabled, "LocalStorageDatabaseEnabled");
    PyDict_SetItemString(Sbk_QWebSettings_Type.super.ht_type.tp_dict,"LocalStorageDatabaseEnabled", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebSettings_WebAttribute->tp_dict,"LocalStorageDatabaseEnabled", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebSettings_WebAttribute,(long) QWebSettings::LocalContentCanAccessRemoteUrls, "LocalContentCanAccessRemoteUrls");
    PyDict_SetItemString(Sbk_QWebSettings_Type.super.ht_type.tp_dict,"LocalContentCanAccessRemoteUrls", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebSettings_WebAttribute->tp_dict,"LocalContentCanAccessRemoteUrls", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebSettings_WebAttribute,(long) QWebSettings::DnsPrefetchEnabled, "DnsPrefetchEnabled");
    PyDict_SetItemString(Sbk_QWebSettings_Type.super.ht_type.tp_dict,"DnsPrefetchEnabled", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebSettings_WebAttribute->tp_dict,"DnsPrefetchEnabled", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebSettings_WebAttribute,(long) QWebSettings::XSSAuditingEnabled, "XSSAuditingEnabled");
    PyDict_SetItemString(Sbk_QWebSettings_Type.super.ht_type.tp_dict,"XSSAuditingEnabled", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebSettings_WebAttribute->tp_dict,"XSSAuditingEnabled", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebSettings_WebAttribute,(long) QWebSettings::AcceleratedCompositingEnabled, "AcceleratedCompositingEnabled");
    PyDict_SetItemString(Sbk_QWebSettings_Type.super.ht_type.tp_dict,"AcceleratedCompositingEnabled", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebSettings_WebAttribute->tp_dict,"AcceleratedCompositingEnabled", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebSettings_WebAttribute,(long) QWebSettings::SpatialNavigationEnabled, "SpatialNavigationEnabled");
    PyDict_SetItemString(Sbk_QWebSettings_Type.super.ht_type.tp_dict,"SpatialNavigationEnabled", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebSettings_WebAttribute->tp_dict,"SpatialNavigationEnabled", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebSettings_WebAttribute,(long) QWebSettings::LocalContentCanAccessFileUrls, "LocalContentCanAccessFileUrls");
    PyDict_SetItemString(Sbk_QWebSettings_Type.super.ht_type.tp_dict,"LocalContentCanAccessFileUrls", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebSettings_WebAttribute->tp_dict,"LocalContentCanAccessFileUrls", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebSettings_WebAttribute,(long) QWebSettings::TiledBackingStoreEnabled, "TiledBackingStoreEnabled");
    PyDict_SetItemString(Sbk_QWebSettings_Type.super.ht_type.tp_dict,"TiledBackingStoreEnabled", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebSettings_WebAttribute->tp_dict,"TiledBackingStoreEnabled", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebSettings_WebAttribute,(long) QWebSettings::FrameFlatteningEnabled, "FrameFlatteningEnabled");
    PyDict_SetItemString(Sbk_QWebSettings_Type.super.ht_type.tp_dict,"FrameFlatteningEnabled", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebSettings_WebAttribute->tp_dict,"FrameFlatteningEnabled", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtWebKit_QWebSettings_WebAttribute,(long) QWebSettings::SiteSpecificQuirksEnabled, "SiteSpecificQuirksEnabled");
    PyDict_SetItemString(Sbk_QWebSettings_Type.super.ht_type.tp_dict,"SiteSpecificQuirksEnabled", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtWebKit_QWebSettings_WebAttribute->tp_dict,"SiteSpecificQuirksEnabled", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QWebSettings::WebAttribute");
    Shiboken::TypeResolver::createValueTypeResolver<int>("QWebSettings$ConcreteWrapper::WebAttribute");
    // end of enum WebAttribute


    Shiboken::TypeResolver::createObjectTypeResolver<QWebSettings >("QWebSettings*");
    Shiboken::TypeResolver::createObjectTypeResolver<QWebSettings >("QWebSettings$ConcreteWrapper*");
    Shiboken::TypeResolver::createObjectTypeResolver<QWebSettings >(typeid(QWebSettings).name());
    PySide::initQtMetaType<QWebSettings* >();
}

