/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtxml_python.h"

#include "qdomcharacterdata_wrapper.h"

// Extra includes
#include <qdom.h>
#include <qtextstream.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QDomCharacterData_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QDomCharacterData >()))
        return -1;

    QDomCharacterData* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QDomCharacterData", 0, 1, &(pyargs[0])))
        return -1;

    // Overloaded function decisor
    // 0: QDomCharacterData()
    // 1: QDomCharacterData(QDomCharacterData)
    if (numArgs == 0) {
        overloadId = 0; // QDomCharacterData()
    } else if (numArgs == 1 && Shiboken::Converter< ::QDomCharacterData >::isConvertible(pyargs[0])) {
        overloadId = 1; // QDomCharacterData(QDomCharacterData)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDomCharacterData_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QDomCharacterData()
            {

                if(!PyErr_Occurred()) {
                    // QDomCharacterData()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QDomCharacterData();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // QDomCharacterData(QDomCharacterData)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QDomCharacterData cppArg0 = Shiboken::Converter<QDomCharacterData >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QDomCharacterData(QDomCharacterData)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QDomCharacterData(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QDomCharacterData >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QDomCharacterData_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QDomCharacterData_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtXml.QDomCharacterData", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtXml.QDomCharacterData", overloads);
        return -1;
}

static PyObject* Sbk_QDomCharacterDataFunc_appendData(PyObject* self, PyObject* arg)
{
    QDomCharacterData* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDomCharacterData* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: appendData(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // appendData(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDomCharacterDataFunc_appendData_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // appendData(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->appendData(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QDomCharacterDataFunc_appendData_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXml.QDomCharacterData.appendData", overloads);
        return 0;
}

static PyObject* Sbk_QDomCharacterDataFunc_data(PyObject* self)
{
    QDomCharacterData* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDomCharacterData* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // data()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = cppSelf->data();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDomCharacterDataFunc_deleteData(PyObject* self, PyObject* args)
{
    QDomCharacterData* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDomCharacterData* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "deleteData", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: deleteData(ulong,ulong)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // deleteData(ulong,ulong)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDomCharacterDataFunc_deleteData_TypeError;

    // Call function/method
    {
        {
            unsigned long cppArg0 = Shiboken::Converter<unsigned long >::toCpp(pyargs[0]);
            unsigned long cppArg1 = Shiboken::Converter<unsigned long >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // deleteData(ulong,ulong)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->deleteData(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QDomCharacterDataFunc_deleteData_TypeError:
        const char* overloads[] = {"unsigned long, unsigned long", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtXml.QDomCharacterData.deleteData", overloads);
        return 0;
}

static PyObject* Sbk_QDomCharacterDataFunc_insertData(PyObject* self, PyObject* args)
{
    QDomCharacterData* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDomCharacterData* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "insertData", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: insertData(ulong,QString)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && Shiboken::Converter< QString >::isConvertible(pyargs[1])) {
        overloadId = 0; // insertData(ulong,QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDomCharacterDataFunc_insertData_TypeError;

    // Call function/method
    {
        {
            unsigned long cppArg0 = Shiboken::Converter<unsigned long >::toCpp(pyargs[0]);
            QString cppArg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // insertData(ulong,QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->insertData(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QDomCharacterDataFunc_insertData_TypeError:
        const char* overloads[] = {"unsigned long, QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtXml.QDomCharacterData.insertData", overloads);
        return 0;
}

static PyObject* Sbk_QDomCharacterDataFunc_length(PyObject* self)
{
    QDomCharacterData* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDomCharacterData* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // length()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                uint cppResult = cppSelf->length();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< unsigned int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDomCharacterDataFunc_replaceData(PyObject* self, PyObject* args)
{
    QDomCharacterData* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDomCharacterData* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "replaceData", 3, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: replaceData(ulong,ulong,QString)
    if (numArgs == 3 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && Shiboken::Converter< QString >::isConvertible(pyargs[2])) {
        overloadId = 0; // replaceData(ulong,ulong,QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDomCharacterDataFunc_replaceData_TypeError;

    // Call function/method
    {
        {
            unsigned long cppArg0 = Shiboken::Converter<unsigned long >::toCpp(pyargs[0]);
            unsigned long cppArg1 = Shiboken::Converter<unsigned long >::toCpp(pyargs[1]);
            QString cppArg2 = Shiboken::Converter<QString >::toCpp(pyargs[2]);

            if(!PyErr_Occurred()) {
                // replaceData(ulong,ulong,QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->replaceData(cppArg0, cppArg1, cppArg2);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QDomCharacterDataFunc_replaceData_TypeError:
        const char* overloads[] = {"unsigned long, unsigned long, QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtXml.QDomCharacterData.replaceData", overloads);
        return 0;
}

static PyObject* Sbk_QDomCharacterDataFunc_setData(PyObject* self, PyObject* arg)
{
    QDomCharacterData* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDomCharacterData* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setData(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // setData(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDomCharacterDataFunc_setData_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setData(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setData(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QDomCharacterDataFunc_setData_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXml.QDomCharacterData.setData", overloads);
        return 0;
}

static PyObject* Sbk_QDomCharacterDataFunc_substringData(PyObject* self, PyObject* args)
{
    QDomCharacterData* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDomCharacterData* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "substringData", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: substringData(ulong,ulong)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // substringData(ulong,ulong)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDomCharacterDataFunc_substringData_TypeError;

    // Call function/method
    {
        {
            unsigned long cppArg0 = Shiboken::Converter<unsigned long >::toCpp(pyargs[0]);
            unsigned long cppArg1 = Shiboken::Converter<unsigned long >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // substringData(ulong,ulong)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = cppSelf->substringData(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QDomCharacterDataFunc_substringData_TypeError:
        const char* overloads[] = {"unsigned long, unsigned long", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtXml.QDomCharacterData.substringData", overloads);
        return 0;
}

static PyObject *Sbk_QDomCharacterData___copy__(PyObject *self)
{
        QDomCharacterData* cppSelf = 0;
        if (!Shiboken::Object::isValid(self))
            return 0;
        cppSelf = Shiboken::Converter<QDomCharacterData*>::toCpp(self);
        PyObject* pyResult = 0;
        QDomCharacterData* copy = new QDomCharacterData(*cppSelf);
        pyResult = Shiboken::Converter<QDomCharacterData*>::toPython(copy);
        Shiboken::Object::getOwnership(pyResult);

        if (PyErr_Occurred() || !pyResult) {
            Py_XDECREF(pyResult);
            return 0;
        }
        return pyResult;
}

static PyMethodDef Sbk_QDomCharacterData_methods[] = {
    {"appendData", (PyCFunction)Sbk_QDomCharacterDataFunc_appendData, METH_O},
    {"data", (PyCFunction)Sbk_QDomCharacterDataFunc_data, METH_NOARGS},
    {"deleteData", (PyCFunction)Sbk_QDomCharacterDataFunc_deleteData, METH_VARARGS},
    {"insertData", (PyCFunction)Sbk_QDomCharacterDataFunc_insertData, METH_VARARGS},
    {"length", (PyCFunction)Sbk_QDomCharacterDataFunc_length, METH_NOARGS},
    {"replaceData", (PyCFunction)Sbk_QDomCharacterDataFunc_replaceData, METH_VARARGS},
    {"setData", (PyCFunction)Sbk_QDomCharacterDataFunc_setData, METH_O},
    {"substringData", (PyCFunction)Sbk_QDomCharacterDataFunc_substringData, METH_VARARGS},

    {"__copy__", (PyCFunction)Sbk_QDomCharacterData___copy__, METH_NOARGS},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QDomCharacterData_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtXml.QDomCharacterData",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QDomCharacterData_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QDomCharacterData_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QDomCharacterData(PyObject* module)
{
    SbkPySide_QtXmlTypes[SBK_QDOMCHARACTERDATA_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QDomCharacterData_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QDomCharacterData_Type);
    Sbk_QDomCharacterData_Type.super.ht_type.tp_base = SbkPySide_QtXmlTypes[SBK_QDOMNODE_IDX];
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QDomCharacterData_Type, &Shiboken::callCppDestructor<QDomCharacterData >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QDomCharacterData_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QDomCharacterData_Type, "QDomCharacterData");
    PyModule_AddObject(module, "QDomCharacterData",
        ((PyObject*)&Sbk_QDomCharacterData_Type));


    Shiboken::TypeResolver::createValueTypeResolver<QDomCharacterData >("QDomCharacterData");
    Shiboken::TypeResolver::createObjectTypeResolver<QDomCharacterData >("QDomCharacterData*");
    Shiboken::TypeResolver::createValueTypeResolver<QDomCharacterData >(typeid(QDomCharacterData).name());
    PySide::initQtMetaType<QDomCharacterData >();
}

