/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtxml_python.h"

#include "qdomentityreference_wrapper.h"

// Extra includes
#include <qdom.h>
#include <qtextstream.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QDomEntityReference_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QDomEntityReference >()))
        return -1;

    QDomEntityReference* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QDomEntityReference", 0, 1, &(pyargs[0])))
        return -1;

    // Overloaded function decisor
    // 0: QDomEntityReference()
    // 1: QDomEntityReference(QDomEntityReference)
    if (numArgs == 0) {
        overloadId = 0; // QDomEntityReference()
    } else if (numArgs == 1 && Shiboken::Converter< ::QDomEntityReference >::isConvertible(pyargs[0])) {
        overloadId = 1; // QDomEntityReference(QDomEntityReference)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDomEntityReference_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QDomEntityReference()
            {

                if(!PyErr_Occurred()) {
                    // QDomEntityReference()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QDomEntityReference();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // QDomEntityReference(QDomEntityReference)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QDomEntityReference cppArg0 = Shiboken::Converter<QDomEntityReference >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QDomEntityReference(QDomEntityReference)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QDomEntityReference(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QDomEntityReference >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QDomEntityReference_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QDomEntityReference_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtXml.QDomEntityReference", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtXml.QDomEntityReference", overloads);
        return -1;
}

static PyObject *Sbk_QDomEntityReference___copy__(PyObject *self)
{
        QDomEntityReference* cppSelf = 0;
        if (!Shiboken::Object::isValid(self))
            return 0;
        cppSelf = Shiboken::Converter<QDomEntityReference*>::toCpp(self);
        PyObject* pyResult = 0;
        QDomEntityReference* copy = new QDomEntityReference(*cppSelf);
        pyResult = Shiboken::Converter<QDomEntityReference*>::toPython(copy);
        Shiboken::Object::getOwnership(pyResult);

        if (PyErr_Occurred() || !pyResult) {
            Py_XDECREF(pyResult);
            return 0;
        }
        return pyResult;
}

static PyMethodDef Sbk_QDomEntityReference_methods[] = {

    {"__copy__", (PyCFunction)Sbk_QDomEntityReference___copy__, METH_NOARGS},
    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QDomEntityReference_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtXml.QDomEntityReference",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QDomEntityReference_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QDomEntityReference_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QDomEntityReference(PyObject* module)
{
    SbkPySide_QtXmlTypes[SBK_QDOMENTITYREFERENCE_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QDomEntityReference_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QDomEntityReference_Type);
    Sbk_QDomEntityReference_Type.super.ht_type.tp_base = SbkPySide_QtXmlTypes[SBK_QDOMNODE_IDX];
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QDomEntityReference_Type, &Shiboken::callCppDestructor<QDomEntityReference >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QDomEntityReference_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QDomEntityReference_Type, "QDomEntityReference");
    PyModule_AddObject(module, "QDomEntityReference",
        ((PyObject*)&Sbk_QDomEntityReference_Type));


    Shiboken::TypeResolver::createValueTypeResolver<QDomEntityReference >("QDomEntityReference");
    Shiboken::TypeResolver::createObjectTypeResolver<QDomEntityReference >("QDomEntityReference*");
    Shiboken::TypeResolver::createValueTypeResolver<QDomEntityReference >(typeid(QDomEntityReference).name());
    PySide::initQtMetaType<QDomEntityReference >();
}

