/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtxml_python.h"

#include "qdomnamednodemap_wrapper.h"

// Extra includes
#include <qdom.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QDomNamedNodeMap_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QDomNamedNodeMap >()))
        return -1;

    QDomNamedNodeMap* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QDomNamedNodeMap", 0, 1, &(pyargs[0])))
        return -1;

    // Overloaded function decisor
    // 0: QDomNamedNodeMap()
    // 1: QDomNamedNodeMap(QDomNamedNodeMap)
    if (numArgs == 0) {
        overloadId = 0; // QDomNamedNodeMap()
    } else if (numArgs == 1 && Shiboken::Converter< ::QDomNamedNodeMap >::isConvertible(pyargs[0])) {
        overloadId = 1; // QDomNamedNodeMap(QDomNamedNodeMap)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDomNamedNodeMap_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QDomNamedNodeMap()
            {

                if(!PyErr_Occurred()) {
                    // QDomNamedNodeMap()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QDomNamedNodeMap();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // QDomNamedNodeMap(QDomNamedNodeMap)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QDomNamedNodeMap cppArg0 = Shiboken::Converter<QDomNamedNodeMap >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QDomNamedNodeMap(QDomNamedNodeMap)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QDomNamedNodeMap(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QDomNamedNodeMap >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QDomNamedNodeMap_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QDomNamedNodeMap_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtXml.QDomNamedNodeMap", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtXml.QDomNamedNodeMap", overloads);
        return -1;
}

static PyObject* Sbk_QDomNamedNodeMapFunc_contains(PyObject* self, PyObject* arg)
{
    QDomNamedNodeMap* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDomNamedNodeMap* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: contains(QString)const
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // contains(QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDomNamedNodeMapFunc_contains_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // contains(QString)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->contains(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QDomNamedNodeMapFunc_contains_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXml.QDomNamedNodeMap.contains", overloads);
        return 0;
}

static PyObject* Sbk_QDomNamedNodeMapFunc_count(PyObject* self)
{
    QDomNamedNodeMap* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDomNamedNodeMap* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // count()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->count();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDomNamedNodeMapFunc_isEmpty(PyObject* self)
{
    QDomNamedNodeMap* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDomNamedNodeMap* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isEmpty()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->isEmpty();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDomNamedNodeMapFunc_item(PyObject* self, PyObject* arg)
{
    QDomNamedNodeMap* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDomNamedNodeMap* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: item(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // item(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDomNamedNodeMapFunc_item_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // item(int)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDomNode cppResult = cppSelf->item(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDomNode >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QDomNamedNodeMapFunc_item_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXml.QDomNamedNodeMap.item", overloads);
        return 0;
}

static PyObject* Sbk_QDomNamedNodeMapFunc_length(PyObject* self)
{
    QDomNamedNodeMap* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDomNamedNodeMap* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // length()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                uint cppResult = cppSelf->length();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< unsigned int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QDomNamedNodeMapFunc_namedItem(PyObject* self, PyObject* arg)
{
    QDomNamedNodeMap* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDomNamedNodeMap* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: namedItem(QString)const
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // namedItem(QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDomNamedNodeMapFunc_namedItem_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // namedItem(QString)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDomNode cppResult = cppSelf->namedItem(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDomNode >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QDomNamedNodeMapFunc_namedItem_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXml.QDomNamedNodeMap.namedItem", overloads);
        return 0;
}

static PyObject* Sbk_QDomNamedNodeMapFunc_namedItemNS(PyObject* self, PyObject* args)
{
    QDomNamedNodeMap* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDomNamedNodeMap* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "namedItemNS", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: namedItemNS(QString,QString)const
    if (numArgs == 2 && Shiboken::Converter< QString >::isConvertible(pyargs[0]) && Shiboken::Converter< QString >::isConvertible(pyargs[1])) {
        overloadId = 0; // namedItemNS(QString,QString)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDomNamedNodeMapFunc_namedItemNS_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QString cppArg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // namedItemNS(QString,QString)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDomNode cppResult = cppSelf->namedItemNS(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDomNode >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QDomNamedNodeMapFunc_namedItemNS_TypeError:
        const char* overloads[] = {"QString, QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtXml.QDomNamedNodeMap.namedItemNS", overloads);
        return 0;
}

static PyObject* Sbk_QDomNamedNodeMapFunc_removeNamedItem(PyObject* self, PyObject* arg)
{
    QDomNamedNodeMap* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDomNamedNodeMap* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: removeNamedItem(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // removeNamedItem(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDomNamedNodeMapFunc_removeNamedItem_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // removeNamedItem(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDomNode cppResult = cppSelf->removeNamedItem(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDomNode >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QDomNamedNodeMapFunc_removeNamedItem_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXml.QDomNamedNodeMap.removeNamedItem", overloads);
        return 0;
}

static PyObject* Sbk_QDomNamedNodeMapFunc_removeNamedItemNS(PyObject* self, PyObject* args)
{
    QDomNamedNodeMap* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDomNamedNodeMap* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "removeNamedItemNS", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: removeNamedItemNS(QString,QString)
    if (numArgs == 2 && Shiboken::Converter< QString >::isConvertible(pyargs[0]) && Shiboken::Converter< QString >::isConvertible(pyargs[1])) {
        overloadId = 0; // removeNamedItemNS(QString,QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDomNamedNodeMapFunc_removeNamedItemNS_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QString cppArg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // removeNamedItemNS(QString,QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDomNode cppResult = cppSelf->removeNamedItemNS(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDomNode >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QDomNamedNodeMapFunc_removeNamedItemNS_TypeError:
        const char* overloads[] = {"QString, QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtXml.QDomNamedNodeMap.removeNamedItemNS", overloads);
        return 0;
}

static PyObject* Sbk_QDomNamedNodeMapFunc_setNamedItem(PyObject* self, PyObject* arg)
{
    QDomNamedNodeMap* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDomNamedNodeMap* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setNamedItem(QDomNode)
    if (Shiboken::Converter< ::QDomNode >::isConvertible(arg)) {
        overloadId = 0; // setNamedItem(QDomNode)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDomNamedNodeMapFunc_setNamedItem_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QDomNode cppArg0 = Shiboken::Converter<QDomNode >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setNamedItem(QDomNode)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDomNode cppResult = cppSelf->setNamedItem(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDomNode >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QDomNamedNodeMapFunc_setNamedItem_TypeError:
        const char* overloads[] = {"PySide.QtXml.QDomNode", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXml.QDomNamedNodeMap.setNamedItem", overloads);
        return 0;
}

static PyObject* Sbk_QDomNamedNodeMapFunc_setNamedItemNS(PyObject* self, PyObject* arg)
{
    QDomNamedNodeMap* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDomNamedNodeMap* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: setNamedItemNS(QDomNode)
    if (Shiboken::Converter< ::QDomNode >::isConvertible(arg)) {
        overloadId = 0; // setNamedItemNS(QDomNode)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QDomNamedNodeMapFunc_setNamedItemNS_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QDomNode cppArg0 = Shiboken::Converter<QDomNode >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setNamedItemNS(QDomNode)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QDomNode cppResult = cppSelf->setNamedItemNS(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QDomNode >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QDomNamedNodeMapFunc_setNamedItemNS_TypeError:
        const char* overloads[] = {"PySide.QtXml.QDomNode", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXml.QDomNamedNodeMap.setNamedItemNS", overloads);
        return 0;
}

static PyObject* Sbk_QDomNamedNodeMapFunc_size(PyObject* self)
{
    QDomNamedNodeMap* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QDomNamedNodeMap* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // size()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->size();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject *Sbk_QDomNamedNodeMap___copy__(PyObject *self)
{
        QDomNamedNodeMap* cppSelf = 0;
        if (!Shiboken::Object::isValid(self))
            return 0;
        cppSelf = Shiboken::Converter<QDomNamedNodeMap*>::toCpp(self);
        PyObject* pyResult = 0;
        QDomNamedNodeMap* copy = new QDomNamedNodeMap(*cppSelf);
        pyResult = Shiboken::Converter<QDomNamedNodeMap*>::toPython(copy);
        Shiboken::Object::getOwnership(pyResult);

        if (PyErr_Occurred() || !pyResult) {
            Py_XDECREF(pyResult);
            return 0;
        }
        return pyResult;
}

static PyMethodDef Sbk_QDomNamedNodeMap_methods[] = {
    {"contains", (PyCFunction)Sbk_QDomNamedNodeMapFunc_contains, METH_O},
    {"count", (PyCFunction)Sbk_QDomNamedNodeMapFunc_count, METH_NOARGS},
    {"isEmpty", (PyCFunction)Sbk_QDomNamedNodeMapFunc_isEmpty, METH_NOARGS},
    {"item", (PyCFunction)Sbk_QDomNamedNodeMapFunc_item, METH_O},
    {"length", (PyCFunction)Sbk_QDomNamedNodeMapFunc_length, METH_NOARGS},
    {"namedItem", (PyCFunction)Sbk_QDomNamedNodeMapFunc_namedItem, METH_O},
    {"namedItemNS", (PyCFunction)Sbk_QDomNamedNodeMapFunc_namedItemNS, METH_VARARGS},
    {"removeNamedItem", (PyCFunction)Sbk_QDomNamedNodeMapFunc_removeNamedItem, METH_O},
    {"removeNamedItemNS", (PyCFunction)Sbk_QDomNamedNodeMapFunc_removeNamedItemNS, METH_VARARGS},
    {"setNamedItem", (PyCFunction)Sbk_QDomNamedNodeMapFunc_setNamedItem, METH_O},
    {"setNamedItemNS", (PyCFunction)Sbk_QDomNamedNodeMapFunc_setNamedItemNS, METH_O},
    {"size", (PyCFunction)Sbk_QDomNamedNodeMapFunc_size, METH_NOARGS},

    {"__copy__", (PyCFunction)Sbk_QDomNamedNodeMap___copy__, METH_NOARGS},
    {0} // Sentinel
};

// Rich comparison
static PyObject* Sbk_QDomNamedNodeMap_richcompare(PyObject* self, PyObject* arg, int op)
{
    PyObject* pyResult = 0;
    QDomNamedNodeMap& cppSelf = *Shiboken::Converter< QDomNamedNodeMap* >::toCpp(self);

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter< ::QDomNamedNodeMap >::isConvertible(arg)) {
                // operator!=(const QDomNamedNodeMap & arg__1) const
                QDomNamedNodeMap cppArg0 = Shiboken::Converter< ::QDomNamedNodeMap >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf != cppArg0);
            } else goto Sbk_QDomNamedNodeMap_RichComparison_TypeError;

            break;
        case Py_EQ:
            if (Shiboken::Converter< ::QDomNamedNodeMap >::isConvertible(arg)) {
                // operator==(const QDomNamedNodeMap & arg__1) const
                QDomNamedNodeMap cppArg0 = Shiboken::Converter< ::QDomNamedNodeMap >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf == cppArg0);
            } else goto Sbk_QDomNamedNodeMap_RichComparison_TypeError;

            break;
        default:
            goto Sbk_QDomNamedNodeMap_RichComparison_TypeError;
    }

    if (pyResult && !PyErr_Occurred())
        return pyResult;
    Sbk_QDomNamedNodeMap_RichComparison_TypeError:
    PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
    return 0;

}

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QDomNamedNodeMap_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtXml.QDomNamedNodeMap",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      Sbk_QDomNamedNodeMap_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QDomNamedNodeMap_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QDomNamedNodeMap_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QDomNamedNodeMap(PyObject* module)
{
    SbkPySide_QtXmlTypes[SBK_QDOMNAMEDNODEMAP_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QDomNamedNodeMap_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QDomNamedNodeMap_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QDomNamedNodeMap_Type, &Shiboken::callCppDestructor<QDomNamedNodeMap >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QDomNamedNodeMap_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QDomNamedNodeMap_Type, "QDomNamedNodeMap");
    PyModule_AddObject(module, "QDomNamedNodeMap",
        ((PyObject*)&Sbk_QDomNamedNodeMap_Type));


    Shiboken::TypeResolver::createValueTypeResolver<QDomNamedNodeMap >("QDomNamedNodeMap");
    Shiboken::TypeResolver::createObjectTypeResolver<QDomNamedNodeMap >("QDomNamedNodeMap*");
    Shiboken::TypeResolver::createValueTypeResolver<QDomNamedNodeMap >(typeid(QDomNamedNodeMap).name());
    PySide::initQtMetaType<QDomNamedNodeMap >();
}

