/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtxml_python.h"

#include "qxmldtdhandler_wrapper.h"

// Extra includes


// Native ---------------------------------------------------------

QXmlDTDHandlerWrapper::QXmlDTDHandlerWrapper() : QXmlDTDHandler() {
    // ... middle
}

QString QXmlDTDHandlerWrapper::errorString() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "errorString"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QXmlDTDHandler.errorString()' not implemented.");
        return QString();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QString();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< QString >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QXmlDTDHandler.errorString", "QString", pyResult->ob_type->tp_name);
        return QString();
    }
    QString cppResult(Shiboken::Converter< QString >::toCpp(pyResult));
    return cppResult;
}

bool QXmlDTDHandlerWrapper::notationDecl(const QString & name, const QString & publicId, const QString & systemId)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "notationDecl"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QXmlDTDHandler.notationDecl()' not implemented.");
        return bool(0);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NNN)",
        Shiboken::Converter< QString >::toPython(name),
        Shiboken::Converter< QString >::toPython(publicId),
        Shiboken::Converter< QString >::toPython(systemId)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QXmlDTDHandler.notationDecl", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    return cppResult;
}

bool QXmlDTDHandlerWrapper::unparsedEntityDecl(const QString & name, const QString & publicId, const QString & systemId, const QString & notationName)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "unparsedEntityDecl"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QXmlDTDHandler.unparsedEntityDecl()' not implemented.");
        return bool(0);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NNNN)",
        Shiboken::Converter< QString >::toPython(name),
        Shiboken::Converter< QString >::toPython(publicId),
        Shiboken::Converter< QString >::toPython(systemId),
        Shiboken::Converter< QString >::toPython(notationName)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QXmlDTDHandler.unparsedEntityDecl", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    return cppResult;
}

QXmlDTDHandlerWrapper::~QXmlDTDHandlerWrapper()
{
    SbkObject* wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QXmlDTDHandler_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QXmlDTDHandler >()))
        return -1;

    QXmlDTDHandlerWrapper* cptr = 0;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);
    SbkObjectType* type = reinterpret_cast<SbkObjectType*>(self->ob_type);
    SbkObjectType* myType = reinterpret_cast<SbkObjectType*>(SbkPySide_QtXmlTypes[SBK_QXMLDTDHANDLER_IDX]);
    if (type == myType) {
        PyErr_SetString(PyExc_NotImplementedError,
            "'QXmlDTDHandler' represents a C++ abstract class and cannot be instantiated");
        return -1;
    }


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // QXmlDTDHandler()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new QXmlDTDHandlerWrapper();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QXmlDTDHandler >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject* Sbk_QXmlDTDHandlerFunc_errorString(PyObject* self)
{
    QXmlDTDHandler* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlDTDHandler* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // errorString()const
                if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self))) {
                    PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QXmlDTDHandler.errorString()' not implemented.");
                    return 0;
                }
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = cppSelf->errorString();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QXmlDTDHandlerFunc_notationDecl(PyObject* self, PyObject* args)
{
    QXmlDTDHandler* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlDTDHandler* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "notationDecl", 3, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: notationDecl(QString,QString,QString)
    if (numArgs == 3 && Shiboken::Converter< QString >::isConvertible(pyargs[0]) && Shiboken::Converter< QString >::isConvertible(pyargs[1]) && Shiboken::Converter< QString >::isConvertible(pyargs[2])) {
        overloadId = 0; // notationDecl(QString,QString,QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QXmlDTDHandlerFunc_notationDecl_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QString cppArg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);
            QString cppArg2 = Shiboken::Converter<QString >::toCpp(pyargs[2]);

            if(!PyErr_Occurred()) {
                // notationDecl(QString,QString,QString)
                if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self))) {
                    PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QXmlDTDHandler.notationDecl()' not implemented.");
                    return 0;
                }
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->notationDecl(cppArg0, cppArg1, cppArg2);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QXmlDTDHandlerFunc_notationDecl_TypeError:
        const char* overloads[] = {"QString, QString, QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtXml.QXmlDTDHandler.notationDecl", overloads);
        return 0;
}

static PyObject* Sbk_QXmlDTDHandlerFunc_unparsedEntityDecl(PyObject* self, PyObject* args)
{
    QXmlDTDHandler* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlDTDHandler* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "unparsedEntityDecl", 4, 4, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: unparsedEntityDecl(QString,QString,QString,QString)
    if (numArgs == 4 && Shiboken::Converter< QString >::isConvertible(pyargs[0]) && Shiboken::Converter< QString >::isConvertible(pyargs[1]) && Shiboken::Converter< QString >::isConvertible(pyargs[2]) && Shiboken::Converter< QString >::isConvertible(pyargs[3])) {
        overloadId = 0; // unparsedEntityDecl(QString,QString,QString,QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QXmlDTDHandlerFunc_unparsedEntityDecl_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QString cppArg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);
            QString cppArg2 = Shiboken::Converter<QString >::toCpp(pyargs[2]);
            QString cppArg3 = Shiboken::Converter<QString >::toCpp(pyargs[3]);

            if(!PyErr_Occurred()) {
                // unparsedEntityDecl(QString,QString,QString,QString)
                if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self))) {
                    PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'QXmlDTDHandler.unparsedEntityDecl()' not implemented.");
                    return 0;
                }
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->unparsedEntityDecl(cppArg0, cppArg1, cppArg2, cppArg3);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QXmlDTDHandlerFunc_unparsedEntityDecl_TypeError:
        const char* overloads[] = {"QString, QString, QString, QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtXml.QXmlDTDHandler.unparsedEntityDecl", overloads);
        return 0;
}

static PyMethodDef Sbk_QXmlDTDHandler_methods[] = {
    {"errorString", (PyCFunction)Sbk_QXmlDTDHandlerFunc_errorString, METH_NOARGS},
    {"notationDecl", (PyCFunction)Sbk_QXmlDTDHandlerFunc_notationDecl, METH_VARARGS},
    {"unparsedEntityDecl", (PyCFunction)Sbk_QXmlDTDHandlerFunc_unparsedEntityDecl, METH_VARARGS},

    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QXmlDTDHandler_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtXml.QXmlDTDHandler",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QXmlDTDHandler_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QXmlDTDHandler_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QXmlDTDHandler(PyObject* module)
{
    SbkPySide_QtXmlTypes[SBK_QXMLDTDHANDLER_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QXmlDTDHandler_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QXmlDTDHandler_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QXmlDTDHandler_Type, &Shiboken::callCppDestructor<QXmlDTDHandler >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QXmlDTDHandler_Type) < 0)
        return;

    // Fill type discovery information

    Shiboken::ObjectType::setOriginalName(&Sbk_QXmlDTDHandler_Type, "QXmlDTDHandler*");
    PyModule_AddObject(module, "QXmlDTDHandler",
        ((PyObject*)&Sbk_QXmlDTDHandler_Type));


    Shiboken::TypeResolver::createObjectTypeResolver<QXmlDTDHandler >("QXmlDTDHandler*");
    Shiboken::TypeResolver::createObjectTypeResolver<QXmlDTDHandler >("QXmlDTDHandler$ConcreteWrapper*");
    Shiboken::TypeResolver::createObjectTypeResolver<QXmlDTDHandler >(typeid(QXmlDTDHandler).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QXmlDTDHandler >(typeid(QXmlDTDHandlerWrapper).name());
    PySide::initQtMetaType<QXmlDTDHandler* >();
}

