/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtxml_python.h"

#include "qxmlinputsource_wrapper.h"

// Extra includes
#include <qbytearray.h>
#include <qiodevice.h>


// Native ---------------------------------------------------------

QXmlInputSourceWrapper::QXmlInputSourceWrapper() : QXmlInputSource() {
    // ... middle
}

QXmlInputSourceWrapper::QXmlInputSourceWrapper(QIODevice * dev) : QXmlInputSource(dev) {
    // ... middle
}

QString QXmlInputSourceWrapper::data() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "data"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QXmlInputSource::data();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QString();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< QString >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QXmlInputSource.data", "QString", pyResult->ob_type->tp_name);
        return QString();
    }
    QString cppResult(Shiboken::Converter< QString >::toCpp(pyResult));
    return cppResult;
}

void QXmlInputSourceWrapper::fetchData()
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "fetchData"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QXmlInputSource::fetchData();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

QString QXmlInputSourceWrapper::fromRawData(const QByteArray & data, bool beginning)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "fromRawData"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QXmlInputSource::fromRawData(data, beginning);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QByteArray >::toPython(data),
        Shiboken::Converter< bool >::toPython(beginning)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QString();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< QString >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QXmlInputSource.fromRawData", "QString", pyResult->ob_type->tp_name);
        return QString();
    }
    QString cppResult(Shiboken::Converter< QString >::toCpp(pyResult));
    return cppResult;
}

QChar QXmlInputSourceWrapper::next()
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "next"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QXmlInputSource::next();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QChar(0);
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< QChar >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QXmlInputSource.next", "QChar", pyResult->ob_type->tp_name);
        return QChar(0);
    }
    QChar cppResult(Shiboken::Converter< QChar >::toCpp(pyResult));
    return cppResult;
}

void QXmlInputSourceWrapper::reset()
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "reset"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QXmlInputSource::reset();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QXmlInputSourceWrapper::setData(const QByteArray & dat)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "setData"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QXmlInputSource::setData(dat);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QByteArray >::toPython(dat)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QXmlInputSourceWrapper::setData(const QString & dat)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "setData"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QXmlInputSource::setData(dat);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< QString >::toPython(dat)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

QXmlInputSourceWrapper::~QXmlInputSourceWrapper()
{
    SbkObject* wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QXmlInputSource_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QXmlInputSource >()))
        return -1;

    QXmlInputSourceWrapper* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QXmlInputSource", 0, 1, &(pyargs[0])))
        return -1;

    // Overloaded function decisor
    // 0: QXmlInputSource()
    // 1: QXmlInputSource(QIODevice*)
    if (numArgs == 0) {
        overloadId = 0; // QXmlInputSource()
    } else if (numArgs == 1 && Shiboken::Converter< ::QIODevice * >::isConvertible(pyargs[0])) {
        overloadId = 1; // QXmlInputSource(QIODevice*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QXmlInputSource_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QXmlInputSource()
            {

                if(!PyErr_Occurred()) {
                    // QXmlInputSource()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QXmlInputSourceWrapper();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // QXmlInputSource(QIODevice*)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QIODevice * cppArg0 = Shiboken::Converter<QIODevice * >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QXmlInputSource(QIODevice*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QXmlInputSourceWrapper(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QXmlInputSource >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QXmlInputSource_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QXmlInputSource_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtCore.QIODevice", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtXml.QXmlInputSource", overloads);
        return -1;
}

static PyObject* Sbk_QXmlInputSourceFunc_data(PyObject* self)
{
    QXmlInputSource* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlInputSource* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // data()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QXmlInputSource::data():cppSelf->data());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QXmlInputSourceFunc_fetchData(PyObject* self)
{
    QXmlInputSource* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlInputSource* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // fetchData()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QXmlInputSource::fetchData():cppSelf->fetchData());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QXmlInputSourceFunc_fromRawData(PyObject* self, PyObject* args, PyObject* kwds)
{
    QXmlInputSource* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlInputSource* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtXml.QXmlInputSource.fromRawData(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtXml.QXmlInputSource.fromRawData(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:fromRawData", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: fromRawData(QByteArray,bool)
    if (Shiboken::Converter< ::QByteArray >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // fromRawData(QByteArray,bool)
        } else if (SbkNumber_Check(pyargs[1])) {
            overloadId = 0; // fromRawData(QByteArray,bool)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QXmlInputSourceFunc_fromRawData_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "beginning");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "beginning";
                    else if (SbkNumber_Check(value))
                        pyargs[1] = value;
else
                        goto Sbk_QXmlInputSourceFunc_fromRawData_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtXml.QXmlInputSource.fromRawData(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QByteArray cppArg0 = Shiboken::Converter<QByteArray >::toCpp(pyargs[0]);
            bool cppArg1 = pyargs[1] ? Shiboken::Converter<bool >::toCpp(pyargs[1]) : false;

            if(!PyErr_Occurred()) {
                // fromRawData(QByteArray,bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QXmlInputSource::fromRawData(cppArg0, cppArg1):cppSelf->fromRawData(cppArg0, cppArg1));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QXmlInputSourceFunc_fromRawData_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray, bool = false", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtXml.QXmlInputSource.fromRawData", overloads);
        return 0;
}

static PyObject* Sbk_QXmlInputSourceFunc_next(PyObject* self)
{
    QXmlInputSource* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlInputSource* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // next()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QChar cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QXmlInputSource::next():cppSelf->next());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QChar >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QXmlInputSourceFunc_reset(PyObject* self)
{
    QXmlInputSource* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlInputSource* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // reset()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QXmlInputSource::reset():cppSelf->reset());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QXmlInputSourceFunc_setData(PyObject* self, PyObject* arg)
{
    QXmlInputSource* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlInputSource* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setData(QByteArray)
    // 1: setData(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 1; // setData(QString)
    } else if (Shiboken::Converter< ::QByteArray >::isConvertible(arg)) {
        overloadId = 0; // setData(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QXmlInputSourceFunc_setData_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setData(QByteArray)
            {
                if (!Shiboken::Object::isValid(arg))
                    return 0;
                QByteArray cppArg0 = Shiboken::Converter<QByteArray >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // setData(QByteArray)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    (Shiboken::Object::isUserType(self) ? cppSelf->::QXmlInputSource::setData(cppArg0):cppSelf->setData(cppArg0));
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // setData(QString)
            {
                QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

                if(!PyErr_Occurred()) {
                    // setData(QString)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    (Shiboken::Object::isUserType(self) ? cppSelf->::QXmlInputSource::setData(cppArg0):cppSelf->setData(cppArg0));
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QXmlInputSourceFunc_setData_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray", "QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXml.QXmlInputSource.setData", overloads);
        return 0;
}

static PyMethodDef Sbk_QXmlInputSource_methods[] = {
    {"data", (PyCFunction)Sbk_QXmlInputSourceFunc_data, METH_NOARGS},
    {"fetchData", (PyCFunction)Sbk_QXmlInputSourceFunc_fetchData, METH_NOARGS},
    {"fromRawData", (PyCFunction)Sbk_QXmlInputSourceFunc_fromRawData, METH_VARARGS|METH_KEYWORDS},
    {"next", (PyCFunction)Sbk_QXmlInputSourceFunc_next, METH_NOARGS},
    {"reset", (PyCFunction)Sbk_QXmlInputSourceFunc_reset, METH_NOARGS},
    {"setData", (PyCFunction)Sbk_QXmlInputSourceFunc_setData, METH_O},

    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QXmlInputSource_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtXml.QXmlInputSource",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QXmlInputSource_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QXmlInputSource_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QXmlInputSource(PyObject* module)
{
    SbkPySide_QtXmlTypes[SBK_QXMLINPUTSOURCE_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QXmlInputSource_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QXmlInputSource_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QXmlInputSource_Type, &Shiboken::callCppDestructor<QXmlInputSource >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QXmlInputSource_Type) < 0)
        return;

    // Fill type discovery information

    Shiboken::ObjectType::setOriginalName(&Sbk_QXmlInputSource_Type, "QXmlInputSource*");
    PyModule_AddObject(module, "QXmlInputSource",
        ((PyObject*)&Sbk_QXmlInputSource_Type));


    Shiboken::TypeResolver::createObjectTypeResolver<QXmlInputSource >("QXmlInputSource*");
    Shiboken::TypeResolver::createObjectTypeResolver<QXmlInputSource >(typeid(QXmlInputSource).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QXmlInputSource >(typeid(QXmlInputSourceWrapper).name());
    PySide::initQtMetaType<QXmlInputSource* >();
}

