/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtxmlpatterns_python.h"

#include "qxmlformatter_wrapper.h"

// Extra includes
#include <qabstractxmlnodemodel.h>
#include <qabstractxmlreceiver.h>
#include <qiodevice.h>
#include <qtextcodec.h>
#include <qxmlname.h>
#include <qxmlquery.h>


// Native ---------------------------------------------------------

QXmlFormatterWrapper::QXmlFormatterWrapper(const QXmlQuery & query, QIODevice * outputDevice) : QXmlFormatter(query, outputDevice) {
    // ... middle
}

void QXmlFormatterWrapper::atomicValue(const QVariant & value)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "atomicValue"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QXmlFormatter::atomicValue(value);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< QVariant >::toPython(value)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QXmlFormatterWrapper::attribute(const QXmlName & name, const QStringRef & value)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "attribute"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QXmlFormatter::attribute(name, value);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QXmlName >::toPython(name),
        Shiboken::Converter< QStringRef >::toPython(value)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QXmlFormatterWrapper::characters(const QStringRef & value)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "characters"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QXmlFormatter::characters(value);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< QStringRef >::toPython(value)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QXmlFormatterWrapper::comment(const QString & value)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "comment"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QXmlFormatter::comment(value);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< QString >::toPython(value)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QXmlFormatterWrapper::endDocument()
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "endDocument"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QXmlFormatter::endDocument();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QXmlFormatterWrapper::endElement()
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "endElement"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QXmlFormatter::endElement();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QXmlFormatterWrapper::endOfSequence()
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "endOfSequence"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QXmlFormatter::endOfSequence();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QXmlFormatterWrapper::namespaceBinding(const QXmlName & nb)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "namespaceBinding"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QXmlSerializer::namespaceBinding(nb);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QXmlName >::toPython(nb)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QXmlFormatterWrapper::processingInstruction(const QXmlName & name, const QString & value)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "processingInstruction"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QXmlFormatter::processingInstruction(name, value);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QXmlName >::toPython(name),
        Shiboken::Converter< QString >::toPython(value)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QXmlFormatterWrapper::startDocument()
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "startDocument"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QXmlFormatter::startDocument();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QXmlFormatterWrapper::startElement(const QXmlName & name)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "startElement"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QXmlFormatter::startElement(name);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QXmlName >::toPython(name)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QXmlFormatterWrapper::startOfSequence()
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "startOfSequence"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QXmlFormatter::startOfSequence();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QXmlFormatterWrapper::whitespaceOnly(const QStringRef & value)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "whitespaceOnly"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractXmlReceiver::whitespaceOnly(value);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< QStringRef >::toPython(value)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

QXmlFormatterWrapper::~QXmlFormatterWrapper()
{
    SbkObject* wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QXmlFormatter_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QXmlFormatter >()))
        return -1;

    QXmlFormatterWrapper* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QXmlFormatter", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return -1;

    // Overloaded function decisor
    // 0: QXmlFormatter(QXmlQuery,QIODevice*)
    if (numArgs == 2 && Shiboken::Converter< ::QXmlQuery >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QIODevice * >::isConvertible(pyargs[1])) {
        overloadId = 0; // QXmlFormatter(QXmlQuery,QIODevice*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QXmlFormatter_Init_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(pyargs[0]))
                return -1;
            QXmlQuery cppArg0 = Shiboken::Converter<QXmlQuery >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return -1;
            QIODevice * cppArg1 = Shiboken::Converter<QIODevice * >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // QXmlFormatter(QXmlQuery,QIODevice*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new QXmlFormatterWrapper(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QXmlFormatter >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QXmlFormatter_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QXmlFormatter_Init_TypeError:
        const char* overloads[] = {"PySide.QtXmlPatterns.QXmlQuery, PySide.QtCore.QIODevice", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtXmlPatterns.QXmlFormatter", overloads);
        return -1;
}

static PyObject* Sbk_QXmlFormatterFunc_atomicValue(PyObject* self, PyObject* arg)
{
    QXmlFormatter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlFormatter* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: atomicValue(QVariant)
    if (Shiboken::Converter< QVariant >::isConvertible(arg)) {
        overloadId = 0; // atomicValue(QVariant)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QXmlFormatterFunc_atomicValue_TypeError;

    // Call function/method
    {
        {
            QVariant cppArg0 = Shiboken::Converter<QVariant >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // atomicValue(QVariant)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QXmlFormatter::atomicValue(cppArg0):cppSelf->atomicValue(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QXmlFormatterFunc_atomicValue_TypeError:
        const char* overloads[] = {"QVariant", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXmlPatterns.QXmlFormatter.atomicValue", overloads);
        return 0;
}

static PyObject* Sbk_QXmlFormatterFunc_attribute(PyObject* self, PyObject* args)
{
    QXmlFormatter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlFormatter* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "attribute", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: attribute(QXmlName,QStringRef)
    if (numArgs == 2 && Shiboken::Converter< ::QXmlName >::isConvertible(pyargs[0]) && Shiboken::Converter< QStringRef >::isConvertible(pyargs[1])) {
        overloadId = 0; // attribute(QXmlName,QStringRef)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QXmlFormatterFunc_attribute_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QXmlName cppArg0 = Shiboken::Converter<QXmlName >::toCpp(pyargs[0]);
            QStringRef cppArg1 = Shiboken::Converter<QStringRef >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // attribute(QXmlName,QStringRef)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QXmlFormatter::attribute(cppArg0, cppArg1):cppSelf->attribute(cppArg0, cppArg1));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QXmlFormatterFunc_attribute_TypeError:
        const char* overloads[] = {"PySide.QtXmlPatterns.QXmlName, QStringRef", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtXmlPatterns.QXmlFormatter.attribute", overloads);
        return 0;
}

static PyObject* Sbk_QXmlFormatterFunc_characters(PyObject* self, PyObject* arg)
{
    QXmlFormatter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlFormatter* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: characters(QStringRef)
    if (Shiboken::Converter< QStringRef >::isConvertible(arg)) {
        overloadId = 0; // characters(QStringRef)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QXmlFormatterFunc_characters_TypeError;

    // Call function/method
    {
        {
            QStringRef cppArg0 = Shiboken::Converter<QStringRef >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // characters(QStringRef)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QXmlFormatter::characters(cppArg0):cppSelf->characters(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QXmlFormatterFunc_characters_TypeError:
        const char* overloads[] = {"QStringRef", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXmlPatterns.QXmlFormatter.characters", overloads);
        return 0;
}

static PyObject* Sbk_QXmlFormatterFunc_comment(PyObject* self, PyObject* arg)
{
    QXmlFormatter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlFormatter* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: comment(QString)
    if (Shiboken::Converter< QString >::isConvertible(arg)) {
        overloadId = 0; // comment(QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QXmlFormatterFunc_comment_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // comment(QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QXmlFormatter::comment(cppArg0):cppSelf->comment(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QXmlFormatterFunc_comment_TypeError:
        const char* overloads[] = {"QString", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXmlPatterns.QXmlFormatter.comment", overloads);
        return 0;
}

static PyObject* Sbk_QXmlFormatterFunc_endDocument(PyObject* self)
{
    QXmlFormatter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlFormatter* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // endDocument()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QXmlFormatter::endDocument():cppSelf->endDocument());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QXmlFormatterFunc_endElement(PyObject* self)
{
    QXmlFormatter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlFormatter* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // endElement()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QXmlFormatter::endElement():cppSelf->endElement());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QXmlFormatterFunc_endOfSequence(PyObject* self)
{
    QXmlFormatter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlFormatter* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // endOfSequence()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QXmlFormatter::endOfSequence():cppSelf->endOfSequence());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QXmlFormatterFunc_indentationDepth(PyObject* self)
{
    QXmlFormatter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlFormatter* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // indentationDepth()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->indentationDepth();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QXmlFormatterFunc_processingInstruction(PyObject* self, PyObject* args)
{
    QXmlFormatter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlFormatter* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "processingInstruction", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: processingInstruction(QXmlName,QString)
    if (numArgs == 2 && Shiboken::Converter< ::QXmlName >::isConvertible(pyargs[0]) && Shiboken::Converter< QString >::isConvertible(pyargs[1])) {
        overloadId = 0; // processingInstruction(QXmlName,QString)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QXmlFormatterFunc_processingInstruction_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QXmlName cppArg0 = Shiboken::Converter<QXmlName >::toCpp(pyargs[0]);
            QString cppArg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // processingInstruction(QXmlName,QString)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QXmlFormatter::processingInstruction(cppArg0, cppArg1):cppSelf->processingInstruction(cppArg0, cppArg1));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QXmlFormatterFunc_processingInstruction_TypeError:
        const char* overloads[] = {"PySide.QtXmlPatterns.QXmlName, QString", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtXmlPatterns.QXmlFormatter.processingInstruction", overloads);
        return 0;
}

static PyObject* Sbk_QXmlFormatterFunc_setIndentationDepth(PyObject* self, PyObject* arg)
{
    QXmlFormatter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlFormatter* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setIndentationDepth(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setIndentationDepth(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QXmlFormatterFunc_setIndentationDepth_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setIndentationDepth(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setIndentationDepth(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QXmlFormatterFunc_setIndentationDepth_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXmlPatterns.QXmlFormatter.setIndentationDepth", overloads);
        return 0;
}

static PyObject* Sbk_QXmlFormatterFunc_startDocument(PyObject* self)
{
    QXmlFormatter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlFormatter* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // startDocument()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QXmlFormatter::startDocument():cppSelf->startDocument());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QXmlFormatterFunc_startElement(PyObject* self, PyObject* arg)
{
    QXmlFormatter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlFormatter* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: startElement(QXmlName)
    if (Shiboken::Converter< ::QXmlName >::isConvertible(arg)) {
        overloadId = 0; // startElement(QXmlName)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QXmlFormatterFunc_startElement_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QXmlName cppArg0 = Shiboken::Converter<QXmlName >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // startElement(QXmlName)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QXmlFormatter::startElement(cppArg0):cppSelf->startElement(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QXmlFormatterFunc_startElement_TypeError:
        const char* overloads[] = {"PySide.QtXmlPatterns.QXmlName", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtXmlPatterns.QXmlFormatter.startElement", overloads);
        return 0;
}

static PyObject* Sbk_QXmlFormatterFunc_startOfSequence(PyObject* self)
{
    QXmlFormatter* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlFormatter* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // startOfSequence()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QXmlFormatter::startOfSequence():cppSelf->startOfSequence());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyMethodDef Sbk_QXmlFormatter_methods[] = {
    {"atomicValue", (PyCFunction)Sbk_QXmlFormatterFunc_atomicValue, METH_O},
    {"attribute", (PyCFunction)Sbk_QXmlFormatterFunc_attribute, METH_VARARGS},
    {"characters", (PyCFunction)Sbk_QXmlFormatterFunc_characters, METH_O},
    {"comment", (PyCFunction)Sbk_QXmlFormatterFunc_comment, METH_O},
    {"endDocument", (PyCFunction)Sbk_QXmlFormatterFunc_endDocument, METH_NOARGS},
    {"endElement", (PyCFunction)Sbk_QXmlFormatterFunc_endElement, METH_NOARGS},
    {"endOfSequence", (PyCFunction)Sbk_QXmlFormatterFunc_endOfSequence, METH_NOARGS},
    {"indentationDepth", (PyCFunction)Sbk_QXmlFormatterFunc_indentationDepth, METH_NOARGS},
    {"processingInstruction", (PyCFunction)Sbk_QXmlFormatterFunc_processingInstruction, METH_VARARGS},
    {"setIndentationDepth", (PyCFunction)Sbk_QXmlFormatterFunc_setIndentationDepth, METH_O},
    {"startDocument", (PyCFunction)Sbk_QXmlFormatterFunc_startDocument, METH_NOARGS},
    {"startElement", (PyCFunction)Sbk_QXmlFormatterFunc_startElement, METH_O},
    {"startOfSequence", (PyCFunction)Sbk_QXmlFormatterFunc_startOfSequence, METH_NOARGS},

    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QXmlFormatter_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtXmlPatterns.QXmlFormatter",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QXmlFormatter_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QXmlFormatter_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern

static SbkObjectType* Sbk_QXmlFormatter_typeDiscovery(void* cptr, SbkObjectType* instanceType)
{
    if (instanceType == reinterpret_cast<SbkObjectType*>(Shiboken::SbkType<QAbstractXmlReceiver >()) && dynamic_cast<QXmlFormatter*>(reinterpret_cast<QAbstractXmlReceiver*>(cptr)))
        return &Sbk_QXmlFormatter_Type;
    return 0;
}


void init_QXmlFormatter(PyObject* module)
{
    SbkPySide_QtXmlPatternsTypes[SBK_QXMLFORMATTER_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QXmlFormatter_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QXmlFormatter_Type);
    Sbk_QXmlFormatter_Type.super.ht_type.tp_base = SbkPySide_QtXmlPatternsTypes[SBK_QXMLSERIALIZER_IDX];
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QXmlFormatter_Type, &Shiboken::callCppDestructor<QXmlFormatter >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QXmlFormatter_Type) < 0)
        return;

    // Fill type discovery information
    Shiboken::ObjectType::setTypeDiscoveryFunction(&Sbk_QXmlFormatter_Type, &Sbk_QXmlFormatter_typeDiscovery);
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkObjectType*>(SbkPySide_QtXmlPatternsTypes[SBK_QXMLSERIALIZER_IDX]), &Sbk_QXmlFormatter_Type);

    Shiboken::ObjectType::setOriginalName(&Sbk_QXmlFormatter_Type, "QXmlFormatter*");
    PyModule_AddObject(module, "QXmlFormatter",
        ((PyObject*)&Sbk_QXmlFormatter_Type));


    Shiboken::TypeResolver::createObjectTypeResolver<QXmlFormatter >("QXmlFormatter*");
    Shiboken::TypeResolver::createObjectTypeResolver<QXmlFormatter >(typeid(QXmlFormatter).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QXmlFormatter >(typeid(QXmlFormatterWrapper).name());
    PySide::initQtMetaType<QXmlFormatter* >();
}

