/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtxmlpatterns_python.h"

#include "qxmlnodemodelindex_wrapper.h"

// Extra includes
#include <qabstractxmlnodemodel.h>



// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QXmlNodeModelIndex_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QXmlNodeModelIndex >()))
        return -1;

    QXmlNodeModelIndex* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QXmlNodeModelIndex", 0, 1, &(pyargs[0])))
        return -1;

    // Overloaded function decisor
    // 0: QXmlNodeModelIndex()
    // 1: QXmlNodeModelIndex(QXmlNodeModelIndex)
    if (numArgs == 0) {
        overloadId = 0; // QXmlNodeModelIndex()
    } else if (numArgs == 1 && Shiboken::Converter< ::QXmlNodeModelIndex >::isConvertible(pyargs[0])) {
        overloadId = 1; // QXmlNodeModelIndex(QXmlNodeModelIndex)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QXmlNodeModelIndex_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QXmlNodeModelIndex()
            {

                if(!PyErr_Occurred()) {
                    // QXmlNodeModelIndex()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QXmlNodeModelIndex();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // QXmlNodeModelIndex(QXmlNodeModelIndex)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QXmlNodeModelIndex cppArg0 = Shiboken::Converter<QXmlNodeModelIndex >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // QXmlNodeModelIndex(QXmlNodeModelIndex)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QXmlNodeModelIndex(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QXmlNodeModelIndex >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QXmlNodeModelIndex_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QXmlNodeModelIndex_Init_TypeError:
        const char* overloads[] = {"", "PySide.QtXmlPatterns.QXmlNodeModelIndex", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtXmlPatterns.QXmlNodeModelIndex", overloads);
        return -1;
}

static PyObject* Sbk_QXmlNodeModelIndexFunc_additionalData(PyObject* self)
{
    QXmlNodeModelIndex* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlNodeModelIndex* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // additionalData()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qint64 cppResult = cppSelf->additionalData();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< long long >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QXmlNodeModelIndexFunc_data(PyObject* self)
{
    QXmlNodeModelIndex* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlNodeModelIndex* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // data()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qint64 cppResult = cppSelf->data();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< long long >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QXmlNodeModelIndexFunc_isNull(PyObject* self)
{
    QXmlNodeModelIndex* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlNodeModelIndex* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isNull()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->isNull();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QXmlNodeModelIndexFunc_model(PyObject* self)
{
    QXmlNodeModelIndex* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QXmlNodeModelIndex* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // model()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                const QAbstractXmlNodeModel * cppResult = cppSelf->model();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QAbstractXmlNodeModel * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject *Sbk_QXmlNodeModelIndex___copy__(PyObject *self)
{
        QXmlNodeModelIndex* cppSelf = 0;
        if (!Shiboken::Object::isValid(self))
            return 0;
        cppSelf = Shiboken::Converter<QXmlNodeModelIndex*>::toCpp(self);
        PyObject* pyResult = 0;
        QXmlNodeModelIndex* copy = new QXmlNodeModelIndex(*cppSelf);
        pyResult = Shiboken::Converter<QXmlNodeModelIndex*>::toPython(copy);
        Shiboken::Object::getOwnership(pyResult);

        if (PyErr_Occurred() || !pyResult) {
            Py_XDECREF(pyResult);
            return 0;
        }
        return pyResult;
}

static PyMethodDef Sbk_QXmlNodeModelIndex_methods[] = {
    {"additionalData", (PyCFunction)Sbk_QXmlNodeModelIndexFunc_additionalData, METH_NOARGS},
    {"data", (PyCFunction)Sbk_QXmlNodeModelIndexFunc_data, METH_NOARGS},
    {"isNull", (PyCFunction)Sbk_QXmlNodeModelIndexFunc_isNull, METH_NOARGS},
    {"model", (PyCFunction)Sbk_QXmlNodeModelIndexFunc_model, METH_NOARGS},

    {"__copy__", (PyCFunction)Sbk_QXmlNodeModelIndex___copy__, METH_NOARGS},
    {0} // Sentinel
};

// Rich comparison
static PyObject* Sbk_QXmlNodeModelIndex_richcompare(PyObject* self, PyObject* arg, int op)
{
    PyObject* pyResult = 0;
    QXmlNodeModelIndex& cppSelf = *Shiboken::Converter< QXmlNodeModelIndex* >::toCpp(self);

    switch (op) {
        case Py_NE:
            if (Shiboken::Converter< ::QXmlNodeModelIndex >::isConvertible(arg)) {
                // operator!=(const QXmlNodeModelIndex & other) const
                QXmlNodeModelIndex cppArg0 = Shiboken::Converter< ::QXmlNodeModelIndex >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf != cppArg0);
            } else goto Sbk_QXmlNodeModelIndex_RichComparison_TypeError;

            break;
        case Py_EQ:
            if (Shiboken::Converter< ::QXmlNodeModelIndex >::isConvertible(arg)) {
                // operator==(const QXmlNodeModelIndex & other) const
                QXmlNodeModelIndex cppArg0 = Shiboken::Converter< ::QXmlNodeModelIndex >::toCpp(arg);
                pyResult = Shiboken::Converter< bool >::toPython(cppSelf == cppArg0);
            } else goto Sbk_QXmlNodeModelIndex_RichComparison_TypeError;

            break;
        default:
            goto Sbk_QXmlNodeModelIndex_RichComparison_TypeError;
    }

    if (pyResult && !PyErr_Occurred())
        return pyResult;
    Sbk_QXmlNodeModelIndex_RichComparison_TypeError:
    PyErr_SetString(PyExc_NotImplementedError, "operator not implemented.");
    return 0;

}

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QXmlNodeModelIndex_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtXmlPatterns.QXmlNodeModelIndex",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      Sbk_QXmlNodeModelIndex_richcompare,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QXmlNodeModelIndex_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QXmlNodeModelIndex_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QXmlNodeModelIndex(PyObject* module)
{
    SbkPySide_QtXmlPatternsTypes[SBK_QXMLNODEMODELINDEX_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QXmlNodeModelIndex_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QXmlNodeModelIndex_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QXmlNodeModelIndex_Type, &Shiboken::callCppDestructor<QXmlNodeModelIndex >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QXmlNodeModelIndex_Type) < 0)
        return;

    Shiboken::ObjectType::setOriginalName(&Sbk_QXmlNodeModelIndex_Type, "QXmlNodeModelIndex");
    PyModule_AddObject(module, "QXmlNodeModelIndex",
        ((PyObject*)&Sbk_QXmlNodeModelIndex_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: NodeKind
    PyTypeObject* SbkPySide_QtXmlPatterns_QXmlNodeModelIndex_NodeKind = Shiboken::Enum::newType("NodeKind");
    SbkPySide_QtXmlPatternsTypes[SBK_QXMLNODEMODELINDEX_NODEKIND_IDX] = SbkPySide_QtXmlPatterns_QXmlNodeModelIndex_NodeKind;
    if (PyType_Ready(SbkPySide_QtXmlPatterns_QXmlNodeModelIndex_NodeKind) < 0)
        return;
    PyDict_SetItemString(Sbk_QXmlNodeModelIndex_Type.super.ht_type.tp_dict,
            "NodeKind",((PyObject*)SbkPySide_QtXmlPatterns_QXmlNodeModelIndex_NodeKind));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtXmlPatterns_QXmlNodeModelIndex_NodeKind,(long) QXmlNodeModelIndex::Attribute, "Attribute");
    PyDict_SetItemString(Sbk_QXmlNodeModelIndex_Type.super.ht_type.tp_dict,"Attribute", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtXmlPatterns_QXmlNodeModelIndex_NodeKind->tp_dict,"Attribute", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtXmlPatterns_QXmlNodeModelIndex_NodeKind,(long) QXmlNodeModelIndex::Comment, "Comment");
    PyDict_SetItemString(Sbk_QXmlNodeModelIndex_Type.super.ht_type.tp_dict,"Comment", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtXmlPatterns_QXmlNodeModelIndex_NodeKind->tp_dict,"Comment", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtXmlPatterns_QXmlNodeModelIndex_NodeKind,(long) QXmlNodeModelIndex::Document, "Document");
    PyDict_SetItemString(Sbk_QXmlNodeModelIndex_Type.super.ht_type.tp_dict,"Document", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtXmlPatterns_QXmlNodeModelIndex_NodeKind->tp_dict,"Document", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtXmlPatterns_QXmlNodeModelIndex_NodeKind,(long) QXmlNodeModelIndex::Element, "Element");
    PyDict_SetItemString(Sbk_QXmlNodeModelIndex_Type.super.ht_type.tp_dict,"Element", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtXmlPatterns_QXmlNodeModelIndex_NodeKind->tp_dict,"Element", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtXmlPatterns_QXmlNodeModelIndex_NodeKind,(long) QXmlNodeModelIndex::Namespace, "Namespace");
    PyDict_SetItemString(Sbk_QXmlNodeModelIndex_Type.super.ht_type.tp_dict,"Namespace", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtXmlPatterns_QXmlNodeModelIndex_NodeKind->tp_dict,"Namespace", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtXmlPatterns_QXmlNodeModelIndex_NodeKind,(long) QXmlNodeModelIndex::ProcessingInstruction, "ProcessingInstruction");
    PyDict_SetItemString(Sbk_QXmlNodeModelIndex_Type.super.ht_type.tp_dict,"ProcessingInstruction", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtXmlPatterns_QXmlNodeModelIndex_NodeKind->tp_dict,"ProcessingInstruction", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtXmlPatterns_QXmlNodeModelIndex_NodeKind,(long) QXmlNodeModelIndex::Text, "Text");
    PyDict_SetItemString(Sbk_QXmlNodeModelIndex_Type.super.ht_type.tp_dict,"Text", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtXmlPatterns_QXmlNodeModelIndex_NodeKind->tp_dict,"Text", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QXmlNodeModelIndex::NodeKind");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::NodeKind");
    // end of enum NodeKind

    // init enum: DocumentOrder
    PyTypeObject* SbkPySide_QtXmlPatterns_QXmlNodeModelIndex_DocumentOrder = Shiboken::Enum::newType("DocumentOrder");
    SbkPySide_QtXmlPatternsTypes[SBK_QXMLNODEMODELINDEX_DOCUMENTORDER_IDX] = SbkPySide_QtXmlPatterns_QXmlNodeModelIndex_DocumentOrder;
    if (PyType_Ready(SbkPySide_QtXmlPatterns_QXmlNodeModelIndex_DocumentOrder) < 0)
        return;
    PyDict_SetItemString(Sbk_QXmlNodeModelIndex_Type.super.ht_type.tp_dict,
            "DocumentOrder",((PyObject*)SbkPySide_QtXmlPatterns_QXmlNodeModelIndex_DocumentOrder));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtXmlPatterns_QXmlNodeModelIndex_DocumentOrder,(long) QXmlNodeModelIndex::Precedes, "Precedes");
    PyDict_SetItemString(Sbk_QXmlNodeModelIndex_Type.super.ht_type.tp_dict,"Precedes", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtXmlPatterns_QXmlNodeModelIndex_DocumentOrder->tp_dict,"Precedes", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtXmlPatterns_QXmlNodeModelIndex_DocumentOrder,(long) QXmlNodeModelIndex::Is, "Is");
    PyDict_SetItemString(Sbk_QXmlNodeModelIndex_Type.super.ht_type.tp_dict,"Is", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtXmlPatterns_QXmlNodeModelIndex_DocumentOrder->tp_dict,"Is", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtXmlPatterns_QXmlNodeModelIndex_DocumentOrder,(long) QXmlNodeModelIndex::Follows, "Follows");
    PyDict_SetItemString(Sbk_QXmlNodeModelIndex_Type.super.ht_type.tp_dict,"Follows", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtXmlPatterns_QXmlNodeModelIndex_DocumentOrder->tp_dict,"Follows", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QXmlNodeModelIndex::DocumentOrder");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::DocumentOrder");
    // end of enum DocumentOrder

    // init enum: Axis
    PyTypeObject* SbkPySide_QtXmlPatterns_QXmlNodeModelIndex_Axis = Shiboken::Enum::newType("Axis");
    SbkPySide_QtXmlPatternsTypes[SBK_QXMLNODEMODELINDEX_AXIS_IDX] = SbkPySide_QtXmlPatterns_QXmlNodeModelIndex_Axis;
    if (PyType_Ready(SbkPySide_QtXmlPatterns_QXmlNodeModelIndex_Axis) < 0)
        return;
    PyDict_SetItemString(Sbk_QXmlNodeModelIndex_Type.super.ht_type.tp_dict,
            "Axis",((PyObject*)SbkPySide_QtXmlPatterns_QXmlNodeModelIndex_Axis));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtXmlPatterns_QXmlNodeModelIndex_Axis,(long) QXmlNodeModelIndex::AxisChild, "AxisChild");
    PyDict_SetItemString(Sbk_QXmlNodeModelIndex_Type.super.ht_type.tp_dict,"AxisChild", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtXmlPatterns_QXmlNodeModelIndex_Axis->tp_dict,"AxisChild", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtXmlPatterns_QXmlNodeModelIndex_Axis,(long) QXmlNodeModelIndex::AxisDescendant, "AxisDescendant");
    PyDict_SetItemString(Sbk_QXmlNodeModelIndex_Type.super.ht_type.tp_dict,"AxisDescendant", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtXmlPatterns_QXmlNodeModelIndex_Axis->tp_dict,"AxisDescendant", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtXmlPatterns_QXmlNodeModelIndex_Axis,(long) QXmlNodeModelIndex::AxisAttribute, "AxisAttribute");
    PyDict_SetItemString(Sbk_QXmlNodeModelIndex_Type.super.ht_type.tp_dict,"AxisAttribute", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtXmlPatterns_QXmlNodeModelIndex_Axis->tp_dict,"AxisAttribute", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtXmlPatterns_QXmlNodeModelIndex_Axis,(long) QXmlNodeModelIndex::AxisSelf, "AxisSelf");
    PyDict_SetItemString(Sbk_QXmlNodeModelIndex_Type.super.ht_type.tp_dict,"AxisSelf", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtXmlPatterns_QXmlNodeModelIndex_Axis->tp_dict,"AxisSelf", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtXmlPatterns_QXmlNodeModelIndex_Axis,(long) QXmlNodeModelIndex::AxisDescendantOrSelf, "AxisDescendantOrSelf");
    PyDict_SetItemString(Sbk_QXmlNodeModelIndex_Type.super.ht_type.tp_dict,"AxisDescendantOrSelf", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtXmlPatterns_QXmlNodeModelIndex_Axis->tp_dict,"AxisDescendantOrSelf", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtXmlPatterns_QXmlNodeModelIndex_Axis,(long) QXmlNodeModelIndex::AxisFollowingSibling, "AxisFollowingSibling");
    PyDict_SetItemString(Sbk_QXmlNodeModelIndex_Type.super.ht_type.tp_dict,"AxisFollowingSibling", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtXmlPatterns_QXmlNodeModelIndex_Axis->tp_dict,"AxisFollowingSibling", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtXmlPatterns_QXmlNodeModelIndex_Axis,(long) QXmlNodeModelIndex::AxisNamespace, "AxisNamespace");
    PyDict_SetItemString(Sbk_QXmlNodeModelIndex_Type.super.ht_type.tp_dict,"AxisNamespace", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtXmlPatterns_QXmlNodeModelIndex_Axis->tp_dict,"AxisNamespace", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtXmlPatterns_QXmlNodeModelIndex_Axis,(long) QXmlNodeModelIndex::AxisFollowing, "AxisFollowing");
    PyDict_SetItemString(Sbk_QXmlNodeModelIndex_Type.super.ht_type.tp_dict,"AxisFollowing", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtXmlPatterns_QXmlNodeModelIndex_Axis->tp_dict,"AxisFollowing", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtXmlPatterns_QXmlNodeModelIndex_Axis,(long) QXmlNodeModelIndex::AxisParent, "AxisParent");
    PyDict_SetItemString(Sbk_QXmlNodeModelIndex_Type.super.ht_type.tp_dict,"AxisParent", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtXmlPatterns_QXmlNodeModelIndex_Axis->tp_dict,"AxisParent", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtXmlPatterns_QXmlNodeModelIndex_Axis,(long) QXmlNodeModelIndex::AxisAncestor, "AxisAncestor");
    PyDict_SetItemString(Sbk_QXmlNodeModelIndex_Type.super.ht_type.tp_dict,"AxisAncestor", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtXmlPatterns_QXmlNodeModelIndex_Axis->tp_dict,"AxisAncestor", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtXmlPatterns_QXmlNodeModelIndex_Axis,(long) QXmlNodeModelIndex::AxisPrecedingSibling, "AxisPrecedingSibling");
    PyDict_SetItemString(Sbk_QXmlNodeModelIndex_Type.super.ht_type.tp_dict,"AxisPrecedingSibling", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtXmlPatterns_QXmlNodeModelIndex_Axis->tp_dict,"AxisPrecedingSibling", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtXmlPatterns_QXmlNodeModelIndex_Axis,(long) QXmlNodeModelIndex::AxisPreceding, "AxisPreceding");
    PyDict_SetItemString(Sbk_QXmlNodeModelIndex_Type.super.ht_type.tp_dict,"AxisPreceding", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtXmlPatterns_QXmlNodeModelIndex_Axis->tp_dict,"AxisPreceding", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtXmlPatterns_QXmlNodeModelIndex_Axis,(long) QXmlNodeModelIndex::AxisAncestorOrSelf, "AxisAncestorOrSelf");
    PyDict_SetItemString(Sbk_QXmlNodeModelIndex_Type.super.ht_type.tp_dict,"AxisAncestorOrSelf", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtXmlPatterns_QXmlNodeModelIndex_Axis->tp_dict,"AxisAncestorOrSelf", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtXmlPatterns_QXmlNodeModelIndex_Axis,(long) QXmlNodeModelIndex::AxisChildOrTop, "AxisChildOrTop");
    PyDict_SetItemString(Sbk_QXmlNodeModelIndex_Type.super.ht_type.tp_dict,"AxisChildOrTop", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtXmlPatterns_QXmlNodeModelIndex_Axis->tp_dict,"AxisChildOrTop", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtXmlPatterns_QXmlNodeModelIndex_Axis,(long) QXmlNodeModelIndex::AxisAttributeOrTop, "AxisAttributeOrTop");
    PyDict_SetItemString(Sbk_QXmlNodeModelIndex_Type.super.ht_type.tp_dict,"AxisAttributeOrTop", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtXmlPatterns_QXmlNodeModelIndex_Axis->tp_dict,"AxisAttributeOrTop", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QXmlNodeModelIndex::Axis");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::Axis");
    // end of enum Axis


    Shiboken::TypeResolver::createValueTypeResolver<QXmlNodeModelIndex >("QXmlNodeModelIndex");
    Shiboken::TypeResolver::createObjectTypeResolver<QXmlNodeModelIndex >("QXmlNodeModelIndex*");
    Shiboken::TypeResolver::createValueTypeResolver<QXmlNodeModelIndex >(typeid(QXmlNodeModelIndex).name());
    PySide::initQtMetaType<QXmlNodeModelIndex >();
}

