/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include "pyside_phonon_python.h"

#include "phonon_mediacontroller_wrapper.h"

// Extra includes
#include <QList>
#include <mediaobject.h>
#include <objectdescription.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qthread.h>

using namespace Phonon;

// Native ---------------------------------------------------------

MediaControllerWrapper::MediaControllerWrapper(Phonon::MediaObject * parent) : Phonon::MediaController(parent) {
    // ... middle
}

void MediaControllerWrapper::childEvent(QChildEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "childEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::childEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QChildEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void MediaControllerWrapper::connectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "connectNotify"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void MediaControllerWrapper::customEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "customEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::customEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void MediaControllerWrapper::disconnectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

bool MediaControllerWrapper::event(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "event"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::event(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "MediaController.event", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
    return cppResult;
}

bool MediaControllerWrapper::eventFilter(QObject * arg__1, QEvent * arg__2)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "eventFilter"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::eventFilter(arg__1, arg__2);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QObject * >::toPython(arg__1),
        Shiboken::Converter< ::QEvent * >::toPython(arg__2)
    ));
    bool invalidadeArg2 = PyTuple_GET_ITEM(pyargs, 1)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "MediaController.eventFilter", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    if (invalidadeArg2)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 1));
    return cppResult;
}

void MediaControllerWrapper::timerEvent(QTimerEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "timerEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::timerEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QTimerEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

const QMetaObject* MediaControllerWrapper::metaObject() const
{
    SbkObject* pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    return reinterpret_cast<QMetaObject*>(Shiboken::Object::getTypeUserData(pySelf));
}

int MediaControllerWrapper::qt_metacall(QMetaObject::Call call, int id, void** args)
{
    int result = Phonon::MediaController::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

MediaControllerWrapper::~MediaControllerWrapper()
{
    SbkObject* wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_Phonon_MediaController_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<Phonon::MediaController >()))
        return -1;

    MediaControllerWrapper* cptr = 0;
    int overloadId = -1;
    const char** argNames = 0;
    const QMetaObject* metaObject;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "MediaController", 1, 1, &(pyargs[0])))
        return -1;

    // Overloaded function decisor
    // 0: MediaController(Phonon::MediaObject*)
    if (numArgs == 1 && Shiboken::Converter< ::Phonon::MediaObject * >::isConvertible(pyargs[0])) {
        overloadId = 0; // MediaController(Phonon::MediaObject*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_Phonon_MediaController_Init_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(pyargs[0]))
                return -1;
            Phonon::MediaObject * cppArg0 = Shiboken::Converter<Phonon::MediaObject * >::toCpp(pyargs[0]);

            if(!PyErr_Occurred()) {
                // MediaController(Phonon::MediaObject*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new MediaControllerWrapper(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                Shiboken::Object::setParent(pyargs[0], self);
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<Phonon::MediaController >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_Phonon_MediaController_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    metaObject = cptr->metaObject(); // <- init python qt properties
    if (kwds && !PySide::fillQtProperties(self, metaObject, kwds, argNames, 0))
        return -1;


    return 1;

    Sbk_Phonon_MediaController_Init_TypeError:
        const char* overloads[] = {"PySide.phonon.Phonon::MediaObject", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.phonon.MediaController", overloads);
        return -1;
}

static PyObject* Sbk_Phonon_MediaControllerFunc_autoplayTitles(PyObject* self)
{
    Phonon::MediaController* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< Phonon::MediaController* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // autoplayTitles()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->autoplayTitles();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_Phonon_MediaControllerFunc_availableAngles(PyObject* self)
{
    Phonon::MediaController* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< Phonon::MediaController* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // availableAngles()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->availableAngles();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_Phonon_MediaControllerFunc_availableAudioChannels(PyObject* self)
{
    Phonon::MediaController* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< Phonon::MediaController* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // availableAudioChannels()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QList<Phonon::AudioChannelDescription > cppResult = cppSelf->availableAudioChannels();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QList<Phonon::AudioChannelDescription > >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_Phonon_MediaControllerFunc_availableChapters(PyObject* self)
{
    Phonon::MediaController* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< Phonon::MediaController* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // availableChapters()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->availableChapters();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_Phonon_MediaControllerFunc_availableSubtitles(PyObject* self)
{
    Phonon::MediaController* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< Phonon::MediaController* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // availableSubtitles()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QList<Phonon::SubtitleDescription > cppResult = cppSelf->availableSubtitles();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QList<Phonon::SubtitleDescription > >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_Phonon_MediaControllerFunc_availableTitles(PyObject* self)
{
    Phonon::MediaController* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< Phonon::MediaController* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // availableTitles()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->availableTitles();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_Phonon_MediaControllerFunc_currentAngle(PyObject* self)
{
    Phonon::MediaController* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< Phonon::MediaController* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // currentAngle()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->currentAngle();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_Phonon_MediaControllerFunc_currentAudioChannel(PyObject* self)
{
    Phonon::MediaController* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< Phonon::MediaController* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // currentAudioChannel()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                Phonon::AudioChannelDescription cppResult = cppSelf->currentAudioChannel();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::Phonon::AudioChannelDescription >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_Phonon_MediaControllerFunc_currentChapter(PyObject* self)
{
    Phonon::MediaController* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< Phonon::MediaController* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // currentChapter()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->currentChapter();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_Phonon_MediaControllerFunc_currentSubtitle(PyObject* self)
{
    Phonon::MediaController* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< Phonon::MediaController* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // currentSubtitle()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                Phonon::SubtitleDescription cppResult = cppSelf->currentSubtitle();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::Phonon::SubtitleDescription >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_Phonon_MediaControllerFunc_currentTitle(PyObject* self)
{
    Phonon::MediaController* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< Phonon::MediaController* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // currentTitle()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->currentTitle();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_Phonon_MediaControllerFunc_nextTitle(PyObject* self)
{
    Phonon::MediaController* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< Phonon::MediaController* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // nextTitle()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->nextTitle();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_Phonon_MediaControllerFunc_previousTitle(PyObject* self)
{
    Phonon::MediaController* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< Phonon::MediaController* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // previousTitle()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->previousTitle();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_Phonon_MediaControllerFunc_setAutoplayTitles(PyObject* self, PyObject* arg)
{
    Phonon::MediaController* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< Phonon::MediaController* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setAutoplayTitles(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setAutoplayTitles(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_Phonon_MediaControllerFunc_setAutoplayTitles_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setAutoplayTitles(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setAutoplayTitles(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_Phonon_MediaControllerFunc_setAutoplayTitles_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.phonon.MediaController.setAutoplayTitles", overloads);
        return 0;
}

static PyObject* Sbk_Phonon_MediaControllerFunc_setCurrentAngle(PyObject* self, PyObject* arg)
{
    Phonon::MediaController* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< Phonon::MediaController* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setCurrentAngle(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setCurrentAngle(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_Phonon_MediaControllerFunc_setCurrentAngle_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setCurrentAngle(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setCurrentAngle(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_Phonon_MediaControllerFunc_setCurrentAngle_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.phonon.MediaController.setCurrentAngle", overloads);
        return 0;
}

static PyObject* Sbk_Phonon_MediaControllerFunc_setCurrentAudioChannel(PyObject* self, PyObject* arg)
{
    Phonon::MediaController* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< Phonon::MediaController* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setCurrentAudioChannel(Phonon::AudioChannelDescription)
    if (Shiboken::Converter< ::Phonon::AudioChannelDescription >::isConvertible(arg)) {
        overloadId = 0; // setCurrentAudioChannel(Phonon::AudioChannelDescription)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_Phonon_MediaControllerFunc_setCurrentAudioChannel_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            Phonon::AudioChannelDescription cppArg0 = Shiboken::Converter<Phonon::AudioChannelDescription >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setCurrentAudioChannel(Phonon::AudioChannelDescription)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setCurrentAudioChannel(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_Phonon_MediaControllerFunc_setCurrentAudioChannel_TypeError:
        const char* overloads[] = {"PySide.phonon.Phonon::AudioChannelDescription", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.phonon.MediaController.setCurrentAudioChannel", overloads);
        return 0;
}

static PyObject* Sbk_Phonon_MediaControllerFunc_setCurrentChapter(PyObject* self, PyObject* arg)
{
    Phonon::MediaController* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< Phonon::MediaController* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setCurrentChapter(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setCurrentChapter(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_Phonon_MediaControllerFunc_setCurrentChapter_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setCurrentChapter(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setCurrentChapter(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_Phonon_MediaControllerFunc_setCurrentChapter_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.phonon.MediaController.setCurrentChapter", overloads);
        return 0;
}

static PyObject* Sbk_Phonon_MediaControllerFunc_setCurrentSubtitle(PyObject* self, PyObject* arg)
{
    Phonon::MediaController* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< Phonon::MediaController* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setCurrentSubtitle(Phonon::SubtitleDescription)
    if (Shiboken::Converter< ::Phonon::SubtitleDescription >::isConvertible(arg)) {
        overloadId = 0; // setCurrentSubtitle(Phonon::SubtitleDescription)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_Phonon_MediaControllerFunc_setCurrentSubtitle_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            Phonon::SubtitleDescription cppArg0 = Shiboken::Converter<Phonon::SubtitleDescription >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setCurrentSubtitle(Phonon::SubtitleDescription)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setCurrentSubtitle(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_Phonon_MediaControllerFunc_setCurrentSubtitle_TypeError:
        const char* overloads[] = {"PySide.phonon.Phonon::SubtitleDescription", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.phonon.MediaController.setCurrentSubtitle", overloads);
        return 0;
}

static PyObject* Sbk_Phonon_MediaControllerFunc_setCurrentTitle(PyObject* self, PyObject* arg)
{
    Phonon::MediaController* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< Phonon::MediaController* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setCurrentTitle(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setCurrentTitle(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_Phonon_MediaControllerFunc_setCurrentTitle_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setCurrentTitle(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setCurrentTitle(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_Phonon_MediaControllerFunc_setCurrentTitle_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.phonon.MediaController.setCurrentTitle", overloads);
        return 0;
}

static PyObject* Sbk_Phonon_MediaControllerFunc_supportedFeatures(PyObject* self)
{
    Phonon::MediaController* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< Phonon::MediaController* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // supportedFeatures()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QFlags<Phonon::MediaController::Feature> cppResult = cppSelf->supportedFeatures();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QFlags<Phonon::MediaController::Feature> >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef Sbk_Phonon_MediaController_methods[] = {
    {"autoplayTitles", (PyCFunction)Sbk_Phonon_MediaControllerFunc_autoplayTitles, METH_NOARGS},
    {"availableAngles", (PyCFunction)Sbk_Phonon_MediaControllerFunc_availableAngles, METH_NOARGS},
    {"availableAudioChannels", (PyCFunction)Sbk_Phonon_MediaControllerFunc_availableAudioChannels, METH_NOARGS},
    {"availableChapters", (PyCFunction)Sbk_Phonon_MediaControllerFunc_availableChapters, METH_NOARGS},
    {"availableSubtitles", (PyCFunction)Sbk_Phonon_MediaControllerFunc_availableSubtitles, METH_NOARGS},
    {"availableTitles", (PyCFunction)Sbk_Phonon_MediaControllerFunc_availableTitles, METH_NOARGS},
    {"currentAngle", (PyCFunction)Sbk_Phonon_MediaControllerFunc_currentAngle, METH_NOARGS},
    {"currentAudioChannel", (PyCFunction)Sbk_Phonon_MediaControllerFunc_currentAudioChannel, METH_NOARGS},
    {"currentChapter", (PyCFunction)Sbk_Phonon_MediaControllerFunc_currentChapter, METH_NOARGS},
    {"currentSubtitle", (PyCFunction)Sbk_Phonon_MediaControllerFunc_currentSubtitle, METH_NOARGS},
    {"currentTitle", (PyCFunction)Sbk_Phonon_MediaControllerFunc_currentTitle, METH_NOARGS},
    {"nextTitle", (PyCFunction)Sbk_Phonon_MediaControllerFunc_nextTitle, METH_NOARGS},
    {"previousTitle", (PyCFunction)Sbk_Phonon_MediaControllerFunc_previousTitle, METH_NOARGS},
    {"setAutoplayTitles", (PyCFunction)Sbk_Phonon_MediaControllerFunc_setAutoplayTitles, METH_O},
    {"setCurrentAngle", (PyCFunction)Sbk_Phonon_MediaControllerFunc_setCurrentAngle, METH_O},
    {"setCurrentAudioChannel", (PyCFunction)Sbk_Phonon_MediaControllerFunc_setCurrentAudioChannel, METH_O},
    {"setCurrentChapter", (PyCFunction)Sbk_Phonon_MediaControllerFunc_setCurrentChapter, METH_O},
    {"setCurrentSubtitle", (PyCFunction)Sbk_Phonon_MediaControllerFunc_setCurrentSubtitle, METH_O},
    {"setCurrentTitle", (PyCFunction)Sbk_Phonon_MediaControllerFunc_setCurrentTitle, METH_O},
    {"supportedFeatures", (PyCFunction)Sbk_Phonon_MediaControllerFunc_supportedFeatures, METH_NOARGS},

    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_Phonon_MediaController_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.phonon.MediaController",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_Phonon_MediaController_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_Phonon_MediaController_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern

static SbkObjectType* Sbk_Phonon_MediaController_typeDiscovery(void* cptr, SbkObjectType* instanceType)
{
    if (instanceType == reinterpret_cast<SbkObjectType*>(Shiboken::SbkType<QObject >()) && dynamic_cast<Phonon::MediaController*>(reinterpret_cast<QObject*>(cptr)))
        return &Sbk_Phonon_MediaController_Type;
    return 0;
}

PyObject* SbkPySide_phonon_Phonon_MediaController_Feature___and__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< Phonon::MediaController::Features >::toPython(
        Shiboken::Converter<Phonon::MediaController::Features>::toCpp(self)
        & Shiboken::Converter< Phonon::MediaController::Features >::toCpp(arg)
    );
}

PyObject* SbkPySide_phonon_Phonon_MediaController_Feature___or__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< Phonon::MediaController::Features >::toPython(
        Shiboken::Converter<Phonon::MediaController::Features>::toCpp(self)
        | Shiboken::Converter< Phonon::MediaController::Features >::toCpp(arg)
    );
}

PyObject* SbkPySide_phonon_Phonon_MediaController_Feature___xor__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< Phonon::MediaController::Features >::toPython(
        Shiboken::Converter<Phonon::MediaController::Features>::toCpp(self)
        ^ Shiboken::Converter< Phonon::MediaController::Features >::toCpp(arg)
    );
}

PyObject* SbkPySide_phonon_Phonon_MediaController_Feature___invert__(PyObject* self, PyObject* arg)
{
    return Shiboken::Converter< Phonon::MediaController::Features >::toPython(
        ~Shiboken::Converter<Phonon::MediaController::Features >::toCpp(self)
    );
}


static PyNumberMethods SbkPySide_phonon_Phonon_MediaController_Feature_as_number = {
    /*nb_add*/                  0,
    /*nb_subtract*/             0,
    /*nb_multiply*/             0,
    /*nb_divide*/               0,
    /*nb_remainder*/            0,
    /*nb_divmod*/               0,
    /*nb_power*/                0,
    /*nb_negative*/             0,
    /*nb_positive*/             0,
    /*nb_absolute*/             0,
    /*nb_nonzero*/              0,
    /*nb_invert*/               (unaryfunc)SbkPySide_phonon_Phonon_MediaController_Feature___invert__,
    /*nb_lshift*/               0,
    /*nb_rshift*/               0,
    /*nb_and*/                  (binaryfunc)SbkPySide_phonon_Phonon_MediaController_Feature___and__,
    /*nb_xor*/                  (binaryfunc)SbkPySide_phonon_Phonon_MediaController_Feature___xor__,
    /*nb_or*/                   (binaryfunc)SbkPySide_phonon_Phonon_MediaController_Feature___or__,
    /*nb_coerce*/               0,
    /*nb_int*/                  0,
    /*nb_long*/                 0,
    /*nb_float*/                0,
    /*nb_oct*/                  0,
    /*nb_hex*/                  0,
    /*nb_inplace_add*/          0,
    /*nb_inplace_subtract*/     0,
    /*nb_inplace_multiply*/     0,
    /*nb_inplace_divide*/       0,
    /*nb_inplace_remainder*/    0,
    /*nb_inplace_power*/        0,
    /*nb_inplace_lshift*/       0,
    /*nb_inplace_rshift*/       0,
    /*nb_inplace_and*/          0,
    /*nb_inplace_xor*/          0,
    /*nb_inplace_or*/           0,
    /*nb_floor_divide*/         0,
    /*nb_true_divide*/          0,
    /*nb_inplace_floor_divide*/ 0,
    /*nb_inplace_true_divide*/  0,
    /*nb_index*/                0
};


// forward declaration of new function
static PyTypeObject SbkPySide_phonon_Phonon_MediaController_Features_Type = {
    PyObject_HEAD_INIT(&PyType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "Features",
    /*tp_basicsize*/        0,
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          0,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        &SbkPySide_phonon_Phonon_MediaController_Feature_as_number,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT | Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          0,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             &PyInt_Type,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             0,
    /*tp_alloc*/            0,
    /*tp_new*/              PyInt_Type.tp_new,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
};



void init_Phonon_MediaController(PyObject* module)
{
    SbkPySide_phononTypes[SBK_PHONON_MEDIACONTROLLER_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_Phonon_MediaController_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_Phonon_MediaController_Type);
    Shiboken::ObjectType::setSubTypeInitHook(&Sbk_Phonon_MediaController_Type, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(&Sbk_Phonon_MediaController_Type, &Phonon::MediaController::staticMetaObject);    Sbk_Phonon_MediaController_Type.super.ht_type.tp_base = SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX];
    Shiboken::ObjectType::setDestructorFunction(&Sbk_Phonon_MediaController_Type, &Shiboken::callCppDestructor<Phonon::MediaController >);
    if (PyType_Ready((PyTypeObject*)&Sbk_Phonon_MediaController_Type) < 0)
        return;

    // Fill type discovery information
    Shiboken::ObjectType::setTypeDiscoveryFunction(&Sbk_Phonon_MediaController_Type, &Sbk_Phonon_MediaController_typeDiscovery);
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkObjectType*>(SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX]), &Sbk_Phonon_MediaController_Type);

    Shiboken::ObjectType::setOriginalName(&Sbk_Phonon_MediaController_Type, "Phonon::MediaController*");
    PyDict_SetItemString(module,"MediaController", (PyObject*)&Sbk_Phonon_MediaController_Type);
    // Initialize enums
    PyObject* enumItem;

    // init enum: Feature
    PyTypeObject* SbkPySide_phonon_Phonon_MediaController_Feature = Shiboken::Enum::newType("Feature");
    SbkPySide_phonon_Phonon_MediaController_Feature->tp_as_number = &SbkPySide_phonon_Phonon_MediaController_Feature_as_number;
    SbkPySide_phononTypes[SBK_PHONON_MEDIACONTROLLER_FEATURE_IDX] = SbkPySide_phonon_Phonon_MediaController_Feature;
    if (PyType_Ready(SbkPySide_phonon_Phonon_MediaController_Feature) < 0)
        return;
    PyDict_SetItemString(Sbk_Phonon_MediaController_Type.super.ht_type.tp_dict,
            "Feature",((PyObject*)SbkPySide_phonon_Phonon_MediaController_Feature));

    // init flags class: QFlags<Phonon::MediaController::Feature>
    SbkPySide_phononTypes[SBK_QFLAGS_PHONON_MEDIACONTROLLER_FEATURE__IDX] = &SbkPySide_phonon_Phonon_MediaController_Features_Type;
    if (PyType_Ready((PyTypeObject*)&SbkPySide_phonon_Phonon_MediaController_Features_Type) < 0)
        return;
    PyDict_SetItemString(Sbk_Phonon_MediaController_Type.super.ht_type.tp_dict,
            "Features",((PyObject*)&SbkPySide_phonon_Phonon_MediaController_Features_Type));

    enumItem = Shiboken::Enum::newItem(SbkPySide_phonon_Phonon_MediaController_Feature,(long) Phonon::MediaController::Angles, "Angles");
    PyDict_SetItemString(Sbk_Phonon_MediaController_Type.super.ht_type.tp_dict,"Angles", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_phonon_Phonon_MediaController_Feature->tp_dict,"Angles", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_phonon_Phonon_MediaController_Feature,(long) Phonon::MediaController::Chapters, "Chapters");
    PyDict_SetItemString(Sbk_Phonon_MediaController_Type.super.ht_type.tp_dict,"Chapters", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_phonon_Phonon_MediaController_Feature->tp_dict,"Chapters", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_phonon_Phonon_MediaController_Feature,(long) Phonon::MediaController::Titles, "Titles");
    PyDict_SetItemString(Sbk_Phonon_MediaController_Type.super.ht_type.tp_dict,"Titles", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_phonon_Phonon_MediaController_Feature->tp_dict,"Titles", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("Phonon::MediaController::Feature");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::Feature");
    // end of enum Feature

    // Initialize signals
    PySideSignal* signal_item;

    signal_item = PySide::Signal::newObject("availableAudioChannelsChanged", "void", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_Phonon_MediaController_Type, "availableAudioChannelsChanged", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("angleChanged", "int", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_Phonon_MediaController_Type, "angleChanged", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("availableTitlesChanged", "int", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_Phonon_MediaController_Type, "availableTitlesChanged", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("chapterChanged", "int", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_Phonon_MediaController_Type, "chapterChanged", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("availableChaptersChanged", "int", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_Phonon_MediaController_Type, "availableChaptersChanged", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("availableAnglesChanged", "int", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_Phonon_MediaController_Type, "availableAnglesChanged", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("availableSubtitlesChanged", "void", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_Phonon_MediaController_Type, "availableSubtitlesChanged", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("titleChanged", "int", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_Phonon_MediaController_Type, "titleChanged", signal_item);
    Py_DECREF((PyObject*) signal_item);


    Shiboken::TypeResolver::createObjectTypeResolver<Phonon::MediaController >("Phonon::MediaController*");
    Shiboken::TypeResolver::createObjectTypeResolver<Phonon::MediaController >(typeid(Phonon::MediaController).name());
    Shiboken::TypeResolver::createObjectTypeResolver<Phonon::MediaController >(typeid(MediaControllerWrapper).name());
    PySide::initQtMetaType<Phonon::MediaController* >();
}

