/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_phonon_python.h"

#include "phonon_mediaobjectinterface_wrapper.h"

// Extra includes
#include <mediasource.h>

using namespace Phonon;

// Native ---------------------------------------------------------

MediaObjectInterfaceWrapper::MediaObjectInterfaceWrapper() : Phonon::MediaObjectInterface() {
    // ... middle
}

qint64 MediaObjectInterfaceWrapper::currentTime() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "currentTime"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'MediaObjectInterface.currentTime()' not implemented.");
        return qint64(0);
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return qint64(0);
    }
    // Check return type
    bool typeIsValid = PyLong_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "MediaObjectInterface.currentTime", "qint64", pyResult->ob_type->tp_name);
        return qint64(0);
    }
    qint64 cppResult(Shiboken::Converter< long long >::toCpp(pyResult));
    return cppResult;
}

QString MediaObjectInterfaceWrapper::errorString() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "errorString"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'MediaObjectInterface.errorString()' not implemented.");
        return QString();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QString();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< QString >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "MediaObjectInterface.errorString", "QString", pyResult->ob_type->tp_name);
        return QString();
    }
    QString cppResult(Shiboken::Converter< QString >::toCpp(pyResult));
    return cppResult;
}

Phonon::ErrorType MediaObjectInterfaceWrapper::errorType() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "errorType"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'MediaObjectInterface.errorType()' not implemented.");
        return Phonon::ErrorType();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return Phonon::ErrorType();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::Phonon::ErrorType >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "MediaObjectInterface.errorType", Shiboken::SbkType<Phonon::ErrorType >()->tp_name, pyResult->ob_type->tp_name);
        return Phonon::ErrorType();
    }
    Phonon::ErrorType cppResult(Shiboken::Converter< ::Phonon::ErrorType >::toCpp(pyResult));
    return cppResult;
}

bool MediaObjectInterfaceWrapper::hasVideo() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "hasVideo"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'MediaObjectInterface.hasVideo()' not implemented.");
        return bool(0);
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "MediaObjectInterface.hasVideo", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    return cppResult;
}

bool MediaObjectInterfaceWrapper::isSeekable() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "isSeekable"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'MediaObjectInterface.isSeekable()' not implemented.");
        return bool(0);
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "MediaObjectInterface.isSeekable", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    return cppResult;
}

void MediaObjectInterfaceWrapper::pause()
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "pause"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'MediaObjectInterface.pause()' not implemented.");
        return ;
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void MediaObjectInterfaceWrapper::play()
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "play"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'MediaObjectInterface.play()' not implemented.");
        return ;
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

qint32 MediaObjectInterfaceWrapper::prefinishMark() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "prefinishMark"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'MediaObjectInterface.prefinishMark()' not implemented.");
        return qint32(0);
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return qint32(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "MediaObjectInterface.prefinishMark", "qint32", pyResult->ob_type->tp_name);
        return qint32(0);
    }
    qint32 cppResult(Shiboken::Converter< int >::toCpp(pyResult));
    return cppResult;
}

qint64 MediaObjectInterfaceWrapper::remainingTime() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "remainingTime"));
    if (py_override.isNull()) {
        gil.release();
        return this->::Phonon::MediaObjectInterface::remainingTime();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return qint64(0);
    }
    // Check return type
    bool typeIsValid = PyLong_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "MediaObjectInterface.remainingTime", "qint64", pyResult->ob_type->tp_name);
        return qint64(0);
    }
    qint64 cppResult(Shiboken::Converter< long long >::toCpp(pyResult));
    return cppResult;
}

void MediaObjectInterfaceWrapper::seek(qint64 milliseconds)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "seek"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'MediaObjectInterface.seek()' not implemented.");
        return ;
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(L)",
        milliseconds
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void MediaObjectInterfaceWrapper::setNextSource(const Phonon::MediaSource & source)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "setNextSource"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'MediaObjectInterface.setNextSource()' not implemented.");
        return ;
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::Phonon::MediaSource >::toPython(source)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void MediaObjectInterfaceWrapper::setPrefinishMark(qint32 arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "setPrefinishMark"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'MediaObjectInterface.setPrefinishMark()' not implemented.");
        return ;
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(i)",
        arg__1
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void MediaObjectInterfaceWrapper::setSource(const Phonon::MediaSource & arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "setSource"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'MediaObjectInterface.setSource()' not implemented.");
        return ;
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::Phonon::MediaSource >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void MediaObjectInterfaceWrapper::setTickInterval(qint32 interval)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "setTickInterval"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'MediaObjectInterface.setTickInterval()' not implemented.");
        return ;
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(i)",
        interval
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void MediaObjectInterfaceWrapper::setTransitionTime(qint32 arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "setTransitionTime"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'MediaObjectInterface.setTransitionTime()' not implemented.");
        return ;
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(i)",
        arg__1
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

Phonon::MediaSource MediaObjectInterfaceWrapper::source() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "source"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'MediaObjectInterface.source()' not implemented.");
        return Phonon::MediaSource();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return Phonon::MediaSource();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::Phonon::MediaSource >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "MediaObjectInterface.source", Shiboken::SbkType<Phonon::MediaSource >()->tp_name, pyResult->ob_type->tp_name);
        return Phonon::MediaSource();
    }
    Phonon::MediaSource cppResult(Shiboken::Converter< ::Phonon::MediaSource >::toCpp(pyResult));
    return cppResult;
}

Phonon::State MediaObjectInterfaceWrapper::state() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "state"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'MediaObjectInterface.state()' not implemented.");
        return Phonon::State();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return Phonon::State();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::Phonon::State >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "MediaObjectInterface.state", Shiboken::SbkType<Phonon::State >()->tp_name, pyResult->ob_type->tp_name);
        return Phonon::State();
    }
    Phonon::State cppResult(Shiboken::Converter< ::Phonon::State >::toCpp(pyResult));
    return cppResult;
}

void MediaObjectInterfaceWrapper::stop()
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "stop"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'MediaObjectInterface.stop()' not implemented.");
        return ;
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

qint32 MediaObjectInterfaceWrapper::tickInterval() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "tickInterval"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'MediaObjectInterface.tickInterval()' not implemented.");
        return qint32(0);
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return qint32(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "MediaObjectInterface.tickInterval", "qint32", pyResult->ob_type->tp_name);
        return qint32(0);
    }
    qint32 cppResult(Shiboken::Converter< int >::toCpp(pyResult));
    return cppResult;
}

qint64 MediaObjectInterfaceWrapper::totalTime() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "totalTime"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'MediaObjectInterface.totalTime()' not implemented.");
        return qint64(0);
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return qint64(0);
    }
    // Check return type
    bool typeIsValid = PyLong_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "MediaObjectInterface.totalTime", "qint64", pyResult->ob_type->tp_name);
        return qint64(0);
    }
    qint64 cppResult(Shiboken::Converter< long long >::toCpp(pyResult));
    return cppResult;
}

qint32 MediaObjectInterfaceWrapper::transitionTime() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "transitionTime"));
    if (py_override.isNull()) {
        PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'MediaObjectInterface.transitionTime()' not implemented.");
        return qint32(0);
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return qint32(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "MediaObjectInterface.transitionTime", "qint32", pyResult->ob_type->tp_name);
        return qint32(0);
    }
    qint32 cppResult(Shiboken::Converter< int >::toCpp(pyResult));
    return cppResult;
}

MediaObjectInterfaceWrapper::~MediaObjectInterfaceWrapper()
{
    SbkObject* wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_Phonon_MediaObjectInterface_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<Phonon::MediaObjectInterface >()))
        return -1;

    MediaObjectInterfaceWrapper* cptr = 0;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);
    SbkObjectType* type = reinterpret_cast<SbkObjectType*>(self->ob_type);
    SbkObjectType* myType = reinterpret_cast<SbkObjectType*>(SbkPySide_phononTypes[SBK_PHONON_MEDIAOBJECTINTERFACE_IDX]);
    if (type == myType) {
        PyErr_SetString(PyExc_NotImplementedError,
            "'Phonon::MediaObjectInterface' represents a C++ abstract class and cannot be instantiated");
        return -1;
    }


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // MediaObjectInterface()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new MediaObjectInterfaceWrapper();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<Phonon::MediaObjectInterface >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject* Sbk_Phonon_MediaObjectInterfaceFunc_currentTime(PyObject* self)
{
    Phonon::MediaObjectInterface* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< Phonon::MediaObjectInterface* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // currentTime()const
                if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self))) {
                    PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'MediaObjectInterface.currentTime()' not implemented.");
                    return 0;
                }
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qint64 cppResult = cppSelf->currentTime();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< long long >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_Phonon_MediaObjectInterfaceFunc_errorString(PyObject* self)
{
    Phonon::MediaObjectInterface* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< Phonon::MediaObjectInterface* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // errorString()const
                if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self))) {
                    PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'MediaObjectInterface.errorString()' not implemented.");
                    return 0;
                }
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QString cppResult = cppSelf->errorString();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QString >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_Phonon_MediaObjectInterfaceFunc_errorType(PyObject* self)
{
    Phonon::MediaObjectInterface* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< Phonon::MediaObjectInterface* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // errorType()const
                if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self))) {
                    PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'MediaObjectInterface.errorType()' not implemented.");
                    return 0;
                }
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                Phonon::ErrorType cppResult = cppSelf->errorType();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::Phonon::ErrorType >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_Phonon_MediaObjectInterfaceFunc_hasVideo(PyObject* self)
{
    Phonon::MediaObjectInterface* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< Phonon::MediaObjectInterface* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // hasVideo()const
                if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self))) {
                    PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'MediaObjectInterface.hasVideo()' not implemented.");
                    return 0;
                }
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->hasVideo();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_Phonon_MediaObjectInterfaceFunc_isSeekable(PyObject* self)
{
    Phonon::MediaObjectInterface* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< Phonon::MediaObjectInterface* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isSeekable()const
                if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self))) {
                    PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'MediaObjectInterface.isSeekable()' not implemented.");
                    return 0;
                }
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->isSeekable();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_Phonon_MediaObjectInterfaceFunc_pause(PyObject* self)
{
    Phonon::MediaObjectInterface* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< Phonon::MediaObjectInterface* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // pause()
                if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self))) {
                    PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'MediaObjectInterface.pause()' not implemented.");
                    return 0;
                }
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->pause();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_Phonon_MediaObjectInterfaceFunc_play(PyObject* self)
{
    Phonon::MediaObjectInterface* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< Phonon::MediaObjectInterface* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // play()
                if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self))) {
                    PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'MediaObjectInterface.play()' not implemented.");
                    return 0;
                }
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->play();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_Phonon_MediaObjectInterfaceFunc_prefinishMark(PyObject* self)
{
    Phonon::MediaObjectInterface* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< Phonon::MediaObjectInterface* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // prefinishMark()const
                if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self))) {
                    PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'MediaObjectInterface.prefinishMark()' not implemented.");
                    return 0;
                }
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qint32 cppResult = cppSelf->prefinishMark();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_Phonon_MediaObjectInterfaceFunc_remainingTime(PyObject* self)
{
    Phonon::MediaObjectInterface* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< Phonon::MediaObjectInterface* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // remainingTime()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qint64 cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::Phonon::MediaObjectInterface::remainingTime():cppSelf->remainingTime());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< long long >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_Phonon_MediaObjectInterfaceFunc_seek(PyObject* self, PyObject* arg)
{
    Phonon::MediaObjectInterface* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< Phonon::MediaObjectInterface* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: seek(qint64)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // seek(qint64)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_Phonon_MediaObjectInterfaceFunc_seek_TypeError;

    // Call function/method
    {
        {
            qint64 cppArg0 = Shiboken::Converter<qint64 >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // seek(qint64)
                if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self))) {
                    PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'MediaObjectInterface.seek()' not implemented.");
                    return 0;
                }
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->seek(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_Phonon_MediaObjectInterfaceFunc_seek_TypeError:
        const char* overloads[] = {"long long", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.phonon.MediaObjectInterface.seek", overloads);
        return 0;
}

static PyObject* Sbk_Phonon_MediaObjectInterfaceFunc_setNextSource(PyObject* self, PyObject* arg)
{
    Phonon::MediaObjectInterface* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< Phonon::MediaObjectInterface* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setNextSource(Phonon::MediaSource)
    if (Shiboken::Converter< ::Phonon::MediaSource >::isConvertible(arg)) {
        overloadId = 0; // setNextSource(Phonon::MediaSource)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_Phonon_MediaObjectInterfaceFunc_setNextSource_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            Phonon::MediaSource cppArg0 = Shiboken::Converter<Phonon::MediaSource >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setNextSource(Phonon::MediaSource)
                if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self))) {
                    PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'MediaObjectInterface.setNextSource()' not implemented.");
                    return 0;
                }
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setNextSource(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_Phonon_MediaObjectInterfaceFunc_setNextSource_TypeError:
        const char* overloads[] = {"PySide.phonon.Phonon::MediaSource", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.phonon.MediaObjectInterface.setNextSource", overloads);
        return 0;
}

static PyObject* Sbk_Phonon_MediaObjectInterfaceFunc_setPrefinishMark(PyObject* self, PyObject* arg)
{
    Phonon::MediaObjectInterface* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< Phonon::MediaObjectInterface* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setPrefinishMark(qint32)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setPrefinishMark(qint32)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_Phonon_MediaObjectInterfaceFunc_setPrefinishMark_TypeError;

    // Call function/method
    {
        {
            qint32 cppArg0 = Shiboken::Converter<qint32 >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setPrefinishMark(qint32)
                if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self))) {
                    PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'MediaObjectInterface.setPrefinishMark()' not implemented.");
                    return 0;
                }
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setPrefinishMark(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_Phonon_MediaObjectInterfaceFunc_setPrefinishMark_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.phonon.MediaObjectInterface.setPrefinishMark", overloads);
        return 0;
}

static PyObject* Sbk_Phonon_MediaObjectInterfaceFunc_setSource(PyObject* self, PyObject* arg)
{
    Phonon::MediaObjectInterface* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< Phonon::MediaObjectInterface* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setSource(Phonon::MediaSource)
    if (Shiboken::Converter< ::Phonon::MediaSource >::isConvertible(arg)) {
        overloadId = 0; // setSource(Phonon::MediaSource)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_Phonon_MediaObjectInterfaceFunc_setSource_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            Phonon::MediaSource cppArg0 = Shiboken::Converter<Phonon::MediaSource >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setSource(Phonon::MediaSource)
                if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self))) {
                    PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'MediaObjectInterface.setSource()' not implemented.");
                    return 0;
                }
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setSource(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_Phonon_MediaObjectInterfaceFunc_setSource_TypeError:
        const char* overloads[] = {"PySide.phonon.Phonon::MediaSource", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.phonon.MediaObjectInterface.setSource", overloads);
        return 0;
}

static PyObject* Sbk_Phonon_MediaObjectInterfaceFunc_setTickInterval(PyObject* self, PyObject* arg)
{
    Phonon::MediaObjectInterface* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< Phonon::MediaObjectInterface* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setTickInterval(qint32)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setTickInterval(qint32)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_Phonon_MediaObjectInterfaceFunc_setTickInterval_TypeError;

    // Call function/method
    {
        {
            qint32 cppArg0 = Shiboken::Converter<qint32 >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setTickInterval(qint32)
                if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self))) {
                    PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'MediaObjectInterface.setTickInterval()' not implemented.");
                    return 0;
                }
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setTickInterval(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_Phonon_MediaObjectInterfaceFunc_setTickInterval_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.phonon.MediaObjectInterface.setTickInterval", overloads);
        return 0;
}

static PyObject* Sbk_Phonon_MediaObjectInterfaceFunc_setTransitionTime(PyObject* self, PyObject* arg)
{
    Phonon::MediaObjectInterface* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< Phonon::MediaObjectInterface* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setTransitionTime(qint32)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setTransitionTime(qint32)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_Phonon_MediaObjectInterfaceFunc_setTransitionTime_TypeError;

    // Call function/method
    {
        {
            qint32 cppArg0 = Shiboken::Converter<qint32 >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setTransitionTime(qint32)
                if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self))) {
                    PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'MediaObjectInterface.setTransitionTime()' not implemented.");
                    return 0;
                }
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setTransitionTime(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_Phonon_MediaObjectInterfaceFunc_setTransitionTime_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.phonon.MediaObjectInterface.setTransitionTime", overloads);
        return 0;
}

static PyObject* Sbk_Phonon_MediaObjectInterfaceFunc_source(PyObject* self)
{
    Phonon::MediaObjectInterface* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< Phonon::MediaObjectInterface* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // source()const
                if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self))) {
                    PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'MediaObjectInterface.source()' not implemented.");
                    return 0;
                }
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                Phonon::MediaSource cppResult = cppSelf->source();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::Phonon::MediaSource >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_Phonon_MediaObjectInterfaceFunc_state(PyObject* self)
{
    Phonon::MediaObjectInterface* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< Phonon::MediaObjectInterface* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // state()const
                if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self))) {
                    PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'MediaObjectInterface.state()' not implemented.");
                    return 0;
                }
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                Phonon::State cppResult = cppSelf->state();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::Phonon::State >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_Phonon_MediaObjectInterfaceFunc_stop(PyObject* self)
{
    Phonon::MediaObjectInterface* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< Phonon::MediaObjectInterface* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // stop()
                if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self))) {
                    PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'MediaObjectInterface.stop()' not implemented.");
                    return 0;
                }
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->stop();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_Phonon_MediaObjectInterfaceFunc_tickInterval(PyObject* self)
{
    Phonon::MediaObjectInterface* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< Phonon::MediaObjectInterface* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // tickInterval()const
                if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self))) {
                    PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'MediaObjectInterface.tickInterval()' not implemented.");
                    return 0;
                }
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qint32 cppResult = cppSelf->tickInterval();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_Phonon_MediaObjectInterfaceFunc_totalTime(PyObject* self)
{
    Phonon::MediaObjectInterface* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< Phonon::MediaObjectInterface* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // totalTime()const
                if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self))) {
                    PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'MediaObjectInterface.totalTime()' not implemented.");
                    return 0;
                }
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qint64 cppResult = cppSelf->totalTime();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< long long >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_Phonon_MediaObjectInterfaceFunc_transitionTime(PyObject* self)
{
    Phonon::MediaObjectInterface* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< Phonon::MediaObjectInterface* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // transitionTime()const
                if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject*>(self))) {
                    PyErr_SetString(PyExc_NotImplementedError, "pure virtual method 'MediaObjectInterface.transitionTime()' not implemented.");
                    return 0;
                }
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                qint32 cppResult = cppSelf->transitionTime();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyMethodDef Sbk_Phonon_MediaObjectInterface_methods[] = {
    {"currentTime", (PyCFunction)Sbk_Phonon_MediaObjectInterfaceFunc_currentTime, METH_NOARGS},
    {"errorString", (PyCFunction)Sbk_Phonon_MediaObjectInterfaceFunc_errorString, METH_NOARGS},
    {"errorType", (PyCFunction)Sbk_Phonon_MediaObjectInterfaceFunc_errorType, METH_NOARGS},
    {"hasVideo", (PyCFunction)Sbk_Phonon_MediaObjectInterfaceFunc_hasVideo, METH_NOARGS},
    {"isSeekable", (PyCFunction)Sbk_Phonon_MediaObjectInterfaceFunc_isSeekable, METH_NOARGS},
    {"pause", (PyCFunction)Sbk_Phonon_MediaObjectInterfaceFunc_pause, METH_NOARGS},
    {"play", (PyCFunction)Sbk_Phonon_MediaObjectInterfaceFunc_play, METH_NOARGS},
    {"prefinishMark", (PyCFunction)Sbk_Phonon_MediaObjectInterfaceFunc_prefinishMark, METH_NOARGS},
    {"remainingTime", (PyCFunction)Sbk_Phonon_MediaObjectInterfaceFunc_remainingTime, METH_NOARGS},
    {"seek", (PyCFunction)Sbk_Phonon_MediaObjectInterfaceFunc_seek, METH_O},
    {"setNextSource", (PyCFunction)Sbk_Phonon_MediaObjectInterfaceFunc_setNextSource, METH_O},
    {"setPrefinishMark", (PyCFunction)Sbk_Phonon_MediaObjectInterfaceFunc_setPrefinishMark, METH_O},
    {"setSource", (PyCFunction)Sbk_Phonon_MediaObjectInterfaceFunc_setSource, METH_O},
    {"setTickInterval", (PyCFunction)Sbk_Phonon_MediaObjectInterfaceFunc_setTickInterval, METH_O},
    {"setTransitionTime", (PyCFunction)Sbk_Phonon_MediaObjectInterfaceFunc_setTransitionTime, METH_O},
    {"source", (PyCFunction)Sbk_Phonon_MediaObjectInterfaceFunc_source, METH_NOARGS},
    {"state", (PyCFunction)Sbk_Phonon_MediaObjectInterfaceFunc_state, METH_NOARGS},
    {"stop", (PyCFunction)Sbk_Phonon_MediaObjectInterfaceFunc_stop, METH_NOARGS},
    {"tickInterval", (PyCFunction)Sbk_Phonon_MediaObjectInterfaceFunc_tickInterval, METH_NOARGS},
    {"totalTime", (PyCFunction)Sbk_Phonon_MediaObjectInterfaceFunc_totalTime, METH_NOARGS},
    {"transitionTime", (PyCFunction)Sbk_Phonon_MediaObjectInterfaceFunc_transitionTime, METH_NOARGS},

    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_Phonon_MediaObjectInterface_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.phonon.MediaObjectInterface",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_Phonon_MediaObjectInterface_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_Phonon_MediaObjectInterface_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_Phonon_MediaObjectInterface(PyObject* module)
{
    SbkPySide_phononTypes[SBK_PHONON_MEDIAOBJECTINTERFACE_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_Phonon_MediaObjectInterface_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_Phonon_MediaObjectInterface_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_Phonon_MediaObjectInterface_Type, &Shiboken::callCppDestructor<Phonon::MediaObjectInterface >);
    if (PyType_Ready((PyTypeObject*)&Sbk_Phonon_MediaObjectInterface_Type) < 0)
        return;

    // Fill type discovery information

    Shiboken::ObjectType::setOriginalName(&Sbk_Phonon_MediaObjectInterface_Type, "Phonon::MediaObjectInterface*");
    PyDict_SetItemString(module,"MediaObjectInterface", (PyObject*)&Sbk_Phonon_MediaObjectInterface_Type);

    Shiboken::TypeResolver::createObjectTypeResolver<Phonon::MediaObjectInterface >("Phonon::MediaObjectInterface*");
    Shiboken::TypeResolver::createObjectTypeResolver<Phonon::MediaObjectInterface >("Phonon::MediaObjectInterface$ConcreteWrapper*");
    Shiboken::TypeResolver::createObjectTypeResolver<Phonon::MediaObjectInterface >(typeid(Phonon::MediaObjectInterface).name());
    Shiboken::TypeResolver::createObjectTypeResolver<Phonon::MediaObjectInterface >(typeid(MediaObjectInterfaceWrapper).name());
    PySide::initQtMetaType<Phonon::MediaObjectInterface* >();
}

