/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <set>
#include "pyside_qtgui_python.h"

#include "qheaderview_wrapper.h"

// Extra includes
#include <QList>
#include <qabstractitemdelegate.h>
#include <qabstractitemmodel.h>
#include <qaction.h>
#include <qbitmap.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qcursor.h>
#include <qevent.h>
#include <qfont.h>
#include <qfontinfo.h>
#include <qfontmetrics.h>
#include <qgraphicseffect.h>
#include <qgraphicsproxywidget.h>
#include <qheaderview.h>
#include <qicon.h>
#include <qinputcontext.h>
#include <qitemselectionmodel.h>
#include <qkeysequence.h>
#include <qlayout.h>
#include <qlocale.h>
#include <qmargins.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpaintdevice.h>
#include <qpaintengine.h>
#include <qpainter.h>
#include <qpalette.h>
#include <qpoint.h>
#include <qrect.h>
#include <qregion.h>
#include <qscrollbar.h>
#include <qsize.h>
#include <qsizepolicy.h>
#include <qstyle.h>
#include <qstyleoption.h>
#include <qwidget.h>
#include <qx11info_x11.h>


// Native ---------------------------------------------------------

QHeaderViewWrapper::QHeaderViewWrapper(Qt::Orientation orientation, QWidget * parent) : QHeaderView(orientation, parent) {
    // ... middle
}

void QHeaderViewWrapper::actionEvent(QActionEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "actionEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::actionEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QActionEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QHeaderViewWrapper::changeEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "changeEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QFrame::changeEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QHeaderViewWrapper::childEvent(QChildEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "childEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::childEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QChildEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QHeaderViewWrapper::closeEditor(QWidget * editor, QAbstractItemDelegate::EndEditHint hint)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "closeEditor"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractItemView::closeEditor(editor, hint);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QWidget * >::toPython(editor),
        Shiboken::Converter< ::QAbstractItemDelegate::EndEditHint >::toPython(hint)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QHeaderViewWrapper::closeEvent(QCloseEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "closeEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::closeEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QCloseEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QHeaderViewWrapper::commitData(QWidget * editor)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "commitData"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractItemView::commitData(editor);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QWidget * >::toPython(editor)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QHeaderViewWrapper::connectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "connectNotify"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QHeaderViewWrapper::contextMenuEvent(QContextMenuEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "contextMenuEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractScrollArea::contextMenuEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QContextMenuEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QHeaderViewWrapper::currentChanged(const QModelIndex & current, const QModelIndex & old)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "currentChanged"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QHeaderView::currentChanged(current, old);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QModelIndex >::toPython(current),
        Shiboken::Converter< ::QModelIndex >::toPython(old)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QHeaderViewWrapper::customEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "customEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::customEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QHeaderViewWrapper::dataChanged(const QModelIndex & topLeft, const QModelIndex & bottomRight)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "dataChanged"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QHeaderView::dataChanged(topLeft, bottomRight);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QModelIndex >::toPython(topLeft),
        Shiboken::Converter< ::QModelIndex >::toPython(bottomRight)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

int QHeaderViewWrapper::devType() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "devType"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::devType();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QHeaderView.devType", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter< int >::toCpp(pyResult));
    return cppResult;
}

void QHeaderViewWrapper::disconnectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QHeaderViewWrapper::doItemsLayout()
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "doItemsLayout"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QHeaderView::doItemsLayout();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QHeaderViewWrapper::dragEnterEvent(QDragEnterEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "dragEnterEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractItemView::dragEnterEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QDragEnterEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QHeaderViewWrapper::dragLeaveEvent(QDragLeaveEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "dragLeaveEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractItemView::dragLeaveEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QDragLeaveEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QHeaderViewWrapper::dragMoveEvent(QDragMoveEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "dragMoveEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractItemView::dragMoveEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QDragMoveEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QHeaderViewWrapper::dropEvent(QDropEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "dropEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractItemView::dropEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QDropEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

bool QHeaderViewWrapper::edit(const QModelIndex & index, QAbstractItemView::EditTrigger trigger, QEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "edit"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractItemView::edit(index, trigger, event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NNN)",
        Shiboken::Converter< ::QModelIndex >::toPython(index),
        Shiboken::Converter< ::QAbstractItemView::EditTrigger >::toPython(trigger),
        Shiboken::Converter< ::QEvent * >::toPython(event)
    ));
    bool invalidadeArg3 = PyTuple_GET_ITEM(pyargs, 2)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QHeaderView.edit", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    if (invalidadeArg3)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 2));
    return cppResult;
}

void QHeaderViewWrapper::editorDestroyed(QObject * editor)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "editorDestroyed"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractItemView::editorDestroyed(editor);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QObject * >::toPython(editor)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QHeaderViewWrapper::enterEvent(QEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "enterEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::enterEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

bool QHeaderViewWrapper::event(QEvent * e)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "event"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QHeaderView::event(e);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(e)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QHeaderView.event", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    return cppResult;
}

bool QHeaderViewWrapper::eventFilter(QObject * arg__1, QEvent * arg__2)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "eventFilter"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::eventFilter(arg__1, arg__2);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QObject * >::toPython(arg__1),
        Shiboken::Converter< ::QEvent * >::toPython(arg__2)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QHeaderView.eventFilter", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    return cppResult;
}

void QHeaderViewWrapper::focusInEvent(QFocusEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "focusInEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractItemView::focusInEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QFocusEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

bool QHeaderViewWrapper::focusNextPrevChild(bool next)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "focusNextPrevChild"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractItemView::focusNextPrevChild(next);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< bool >::toPython(next)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QHeaderView.focusNextPrevChild", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    return cppResult;
}

void QHeaderViewWrapper::focusOutEvent(QFocusEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "focusOutEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractItemView::focusOutEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QFocusEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

int QHeaderViewWrapper::heightForWidth(int arg__1) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "heightForWidth"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::heightForWidth(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(i)",
        arg__1
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QHeaderView.heightForWidth", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter< int >::toCpp(pyResult));
    return cppResult;
}

void QHeaderViewWrapper::hideEvent(QHideEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "hideEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::hideEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QHideEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

int QHeaderViewWrapper::horizontalOffset() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "horizontalOffset"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QHeaderView::horizontalOffset();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QHeaderView.horizontalOffset", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter< int >::toCpp(pyResult));
    return cppResult;
}

void QHeaderViewWrapper::horizontalScrollbarAction(int action)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "horizontalScrollbarAction"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractItemView::horizontalScrollbarAction(action);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(i)",
        action
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QHeaderViewWrapper::horizontalScrollbarValueChanged(int value)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "horizontalScrollbarValueChanged"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractItemView::horizontalScrollbarValueChanged(value);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(i)",
        value
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

QModelIndex QHeaderViewWrapper::indexAt(const QPoint & p) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "indexAt"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QHeaderView::indexAt(p);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QPoint >::toPython(p)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QModelIndex();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QModelIndex >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QHeaderView.indexAt", Shiboken::SbkType<QModelIndex >()->tp_name, pyResult->ob_type->tp_name);
        return QModelIndex();
    }
    QModelIndex cppResult(Shiboken::Converter< ::QModelIndex >::toCpp(pyResult));
    return cppResult;
}

void QHeaderViewWrapper::inputMethodEvent(QInputMethodEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "inputMethodEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractItemView::inputMethodEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QInputMethodEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

QVariant QHeaderViewWrapper::inputMethodQuery(Qt::InputMethodQuery query) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "inputMethodQuery"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractItemView::inputMethodQuery(query);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::Qt::InputMethodQuery >::toPython(query)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QVariant(0);
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< QVariant >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QHeaderView.inputMethodQuery", "QVariant", pyResult->ob_type->tp_name);
        return QVariant(0);
    }
    QVariant cppResult(Shiboken::Converter< QVariant >::toCpp(pyResult));
    return cppResult;
}

bool QHeaderViewWrapper::isIndexHidden(const QModelIndex & index) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "isIndexHidden"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QHeaderView::isIndexHidden(index);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QModelIndex >::toPython(index)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QHeaderView.isIndexHidden", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    return cppResult;
}

void QHeaderViewWrapper::keyPressEvent(QKeyEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "keyPressEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractItemView::keyPressEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QKeyEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QHeaderViewWrapper::keyReleaseEvent(QKeyEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "keyReleaseEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::keyReleaseEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QKeyEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QHeaderViewWrapper::keyboardSearch(const QString & search)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "keyboardSearch"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractItemView::keyboardSearch(search);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< QString >::toPython(search)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QHeaderViewWrapper::languageChange()
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "languageChange"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::languageChange();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QHeaderViewWrapper::leaveEvent(QEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "leaveEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::leaveEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

int QHeaderViewWrapper::metric(QPaintDevice::PaintDeviceMetric arg__1) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "metric"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::metric(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QPaintDevice::PaintDeviceMetric >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QHeaderView.metric", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter< int >::toCpp(pyResult));
    return cppResult;
}

QSize QHeaderViewWrapper::minimumSizeHint() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "minimumSizeHint"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractScrollArea::minimumSizeHint();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QSize();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QSize >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QHeaderView.minimumSizeHint", Shiboken::SbkType<QSize >()->tp_name, pyResult->ob_type->tp_name);
        return QSize();
    }
    QSize cppResult(Shiboken::Converter< ::QSize >::toCpp(pyResult));
    return cppResult;
}

void QHeaderViewWrapper::mouseDoubleClickEvent(QMouseEvent * e)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "mouseDoubleClickEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QHeaderView::mouseDoubleClickEvent(e);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QMouseEvent * >::toPython(e)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QHeaderViewWrapper::mouseMoveEvent(QMouseEvent * e)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "mouseMoveEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QHeaderView::mouseMoveEvent(e);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QMouseEvent * >::toPython(e)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QHeaderViewWrapper::mousePressEvent(QMouseEvent * e)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "mousePressEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QHeaderView::mousePressEvent(e);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QMouseEvent * >::toPython(e)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QHeaderViewWrapper::mouseReleaseEvent(QMouseEvent * e)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "mouseReleaseEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QHeaderView::mouseReleaseEvent(e);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QMouseEvent * >::toPython(e)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QHeaderViewWrapper::moveEvent(QMoveEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "moveEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::moveEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QMoveEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

QPaintEngine * QHeaderViewWrapper::paintEngine() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "paintEngine"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::paintEngine();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return 0;
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QPaintEngine * >::isConvertible(pyResult);
    typeIsValid = typeIsValid || (pyResult == Py_None);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QHeaderView.paintEngine", Shiboken::SbkType<QPaintEngine >()->tp_name, pyResult->ob_type->tp_name);
        return 0;
    }
    QPaintEngine * cppResult(Shiboken::Converter< ::QPaintEngine * >::toCpp(pyResult));
    return cppResult;
}

void QHeaderViewWrapper::paintEvent(QPaintEvent * e)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "paintEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QHeaderView::paintEvent(e);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QPaintEvent * >::toPython(e)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QHeaderViewWrapper::paintSection(QPainter * painter, const QRect & rect, int logicalIndex) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "paintSection"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QHeaderView::paintSection(painter, rect, logicalIndex);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NNi)",
        Shiboken::Converter< ::QPainter * >::toPython(painter),
        Shiboken::Converter< ::QRect >::toPython(rect),
        logicalIndex
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QHeaderViewWrapper::reset()
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "reset"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QHeaderView::reset();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QHeaderViewWrapper::resizeEvent(QResizeEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "resizeEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractItemView::resizeEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QResizeEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QHeaderViewWrapper::rowsAboutToBeRemoved(const QModelIndex & parent, int start, int end)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "rowsAboutToBeRemoved"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractItemView::rowsAboutToBeRemoved(parent, start, end);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(Nii)",
        Shiboken::Converter< ::QModelIndex >::toPython(parent),
        start,
        end
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QHeaderViewWrapper::rowsInserted(const QModelIndex & parent, int start, int end)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "rowsInserted"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QHeaderView::rowsInserted(parent, start, end);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(Nii)",
        Shiboken::Converter< ::QModelIndex >::toPython(parent),
        start,
        end
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QHeaderViewWrapper::scrollContentsBy(int dx, int dy)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "scrollContentsBy"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QHeaderView::scrollContentsBy(dx, dy);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(ii)",
        dx,
        dy
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QHeaderViewWrapper::scrollTo(const QModelIndex & index, QAbstractItemView::ScrollHint hint)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "scrollTo"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QHeaderView::scrollTo(index, hint);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QModelIndex >::toPython(index),
        Shiboken::Converter< ::QAbstractItemView::ScrollHint >::toPython(hint)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

QSize QHeaderViewWrapper::sectionSizeFromContents(int logicalIndex) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "sectionSizeFromContents"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QHeaderView::sectionSizeFromContents(logicalIndex);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(i)",
        logicalIndex
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QSize();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QSize >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QHeaderView.sectionSizeFromContents", Shiboken::SbkType<QSize >()->tp_name, pyResult->ob_type->tp_name);
        return QSize();
    }
    QSize cppResult(Shiboken::Converter< ::QSize >::toCpp(pyResult));
    return cppResult;
}

void QHeaderViewWrapper::selectAll()
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "selectAll"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractItemView::selectAll();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

QList<QModelIndex > QHeaderViewWrapper::selectedIndexes() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "selectedIndexes"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractItemView::selectedIndexes();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QList<QModelIndex >();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QList<QModelIndex > >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QHeaderView.selectedIndexes", "list", pyResult->ob_type->tp_name);
        return QList<QModelIndex >();
    }
    QList<QModelIndex > cppResult(Shiboken::Converter< ::QList<QModelIndex > >::toCpp(pyResult));
    return cppResult;
}

void QHeaderViewWrapper::selectionChanged(const QItemSelection & selected, const QItemSelection & deselected)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "selectionChanged"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractItemView::selectionChanged(selected, deselected);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QItemSelection >::toPython(selected),
        Shiboken::Converter< ::QItemSelection >::toPython(deselected)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

QFlags<QItemSelectionModel::SelectionFlag> QHeaderViewWrapper::selectionCommand(const QModelIndex & index, const QEvent * event) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "selectionCommand"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractItemView::selectionCommand(index, event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QModelIndex >::toPython(index),
        Shiboken::Converter< ::QEvent * >::toPython(event)
    ));
    bool invalidadeArg2 = PyTuple_GET_ITEM(pyargs, 1)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QFlags<QItemSelectionModel::SelectionFlag>();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QFlags<QItemSelectionModel::SelectionFlag> >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QHeaderView.selectionCommand", Shiboken::SbkType<QFlags<QItemSelectionModel::SelectionFlag> >()->tp_name, pyResult->ob_type->tp_name);
        return QFlags<QItemSelectionModel::SelectionFlag>();
    }
    QFlags<QItemSelectionModel::SelectionFlag> cppResult(Shiboken::Converter< ::QFlags<QItemSelectionModel::SelectionFlag> >::toCpp(pyResult));
    if (invalidadeArg2)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 1));
    return cppResult;
}

void QHeaderViewWrapper::setModel(QAbstractItemModel * model)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "setModel"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QHeaderView::setModel(model);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QAbstractItemModel * >::toPython(model)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QHeaderViewWrapper::setRootIndex(const QModelIndex & index)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "setRootIndex"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractItemView::setRootIndex(index);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QModelIndex >::toPython(index)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QHeaderViewWrapper::setSelection(const QRect & rect, QFlags<QItemSelectionModel::SelectionFlag> flags)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "setSelection"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QHeaderView::setSelection(rect, flags);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QRect >::toPython(rect),
        Shiboken::Converter< ::QFlags<QItemSelectionModel::SelectionFlag> >::toPython(flags)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QHeaderViewWrapper::setSelectionModel(QItemSelectionModel * selectionModel)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "setSelectionModel"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractItemView::setSelectionModel(selectionModel);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QItemSelectionModel * >::toPython(selectionModel)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QHeaderViewWrapper::setVisible(bool visible)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "setVisible"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::setVisible(visible);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< bool >::toPython(visible)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QHeaderViewWrapper::showEvent(QShowEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "showEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::showEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QShowEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

QSize QHeaderViewWrapper::sizeHint() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "sizeHint"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QHeaderView::sizeHint();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QSize();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QSize >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QHeaderView.sizeHint", Shiboken::SbkType<QSize >()->tp_name, pyResult->ob_type->tp_name);
        return QSize();
    }
    QSize cppResult(Shiboken::Converter< ::QSize >::toCpp(pyResult));
    return cppResult;
}

int QHeaderViewWrapper::sizeHintForColumn(int column) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "sizeHintForColumn"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractItemView::sizeHintForColumn(column);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(i)",
        column
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QHeaderView.sizeHintForColumn", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter< int >::toCpp(pyResult));
    return cppResult;
}

int QHeaderViewWrapper::sizeHintForRow(int row) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "sizeHintForRow"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractItemView::sizeHintForRow(row);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(i)",
        row
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QHeaderView.sizeHintForRow", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter< int >::toCpp(pyResult));
    return cppResult;
}

void QHeaderViewWrapper::startDrag(QFlags<Qt::DropAction> supportedActions)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "startDrag"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractItemView::startDrag(supportedActions);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QFlags<Qt::DropAction> >::toPython(supportedActions)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QHeaderViewWrapper::tabletEvent(QTabletEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "tabletEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::tabletEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QTabletEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QHeaderViewWrapper::timerEvent(QTimerEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "timerEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractItemView::timerEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QTimerEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QHeaderViewWrapper::updateEditorData()
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "updateEditorData"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractItemView::updateEditorData();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QHeaderViewWrapper::updateEditorGeometries()
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "updateEditorGeometries"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractItemView::updateEditorGeometries();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QHeaderViewWrapper::updateGeometries()
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "updateGeometries"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QHeaderView::updateGeometries();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

int QHeaderViewWrapper::verticalOffset() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "verticalOffset"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QHeaderView::verticalOffset();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QHeaderView.verticalOffset", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter< int >::toCpp(pyResult));
    return cppResult;
}

void QHeaderViewWrapper::verticalScrollbarAction(int action)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "verticalScrollbarAction"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractItemView::verticalScrollbarAction(action);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(i)",
        action
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QHeaderViewWrapper::verticalScrollbarValueChanged(int value)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "verticalScrollbarValueChanged"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractItemView::verticalScrollbarValueChanged(value);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(i)",
        value
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

QStyleOptionViewItem QHeaderViewWrapper::viewOptions() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "viewOptions"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractItemView::viewOptions();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QStyleOptionViewItem();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QStyleOptionViewItem >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QHeaderView.viewOptions", Shiboken::SbkType<QStyleOptionViewItem >()->tp_name, pyResult->ob_type->tp_name);
        return QStyleOptionViewItem();
    }
    QStyleOptionViewItem cppResult(Shiboken::Converter< ::QStyleOptionViewItem >::toCpp(pyResult));
    return cppResult;
}

bool QHeaderViewWrapper::viewportEvent(QEvent * e)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "viewportEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QHeaderView::viewportEvent(e);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(e)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QHeaderView.viewportEvent", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
    return cppResult;
}

QRect QHeaderViewWrapper::visualRect(const QModelIndex & index) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "visualRect"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QHeaderView::visualRect(index);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QModelIndex >::toPython(index)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QRect();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QRect >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QHeaderView.visualRect", Shiboken::SbkType<QRect >()->tp_name, pyResult->ob_type->tp_name);
        return QRect();
    }
    QRect cppResult(Shiboken::Converter< ::QRect >::toCpp(pyResult));
    return cppResult;
}

QRegion QHeaderViewWrapper::visualRegionForSelection(const QItemSelection & selection) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "visualRegionForSelection"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QHeaderView::visualRegionForSelection(selection);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QItemSelection >::toPython(selection)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QRegion();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QRegion >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QHeaderView.visualRegionForSelection", Shiboken::SbkType<QRegion >()->tp_name, pyResult->ob_type->tp_name);
        return QRegion();
    }
    QRegion cppResult(Shiboken::Converter< ::QRegion >::toCpp(pyResult));
    return cppResult;
}

void QHeaderViewWrapper::wheelEvent(QWheelEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "wheelEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractScrollArea::wheelEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QWheelEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

const QMetaObject* QHeaderViewWrapper::metaObject() const
{
    SbkObject* pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    return reinterpret_cast<QMetaObject*>(Shiboken::Object::getTypeUserData(pySelf));
}

int QHeaderViewWrapper::qt_metacall(QMetaObject::Call call, int id, void** args)
{
    int result = QHeaderView::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

QHeaderViewWrapper::~QHeaderViewWrapper()
{
    SbkObject* wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QHeaderView_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QHeaderView >()))
        return -1;

    QHeaderViewWrapper* cptr = 0;
    int overloadId = -1;
    const char* argNames[] = {"parent"};
    const QMetaObject* metaObject;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QHeaderView(): not enough arguments");
        return -1;
    }

    if (!PyArg_ParseTuple(args, "|OO:QHeaderView", &(pyargs[0]), &(pyargs[1])))
        return -1;

    // Overloaded function decisor
    // 0: QHeaderView(Qt::Orientation,QWidget*)
    if (Shiboken::Converter< ::Qt::Orientation >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // QHeaderView(Qt::Orientation,QWidget*)
        } else if (Shiboken::Converter< ::QWidget * >::isConvertible(pyargs[1])) {
            overloadId = 0; // QHeaderView(Qt::Orientation,QWidget*)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QHeaderView_Init_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "parent");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "parent";
                    else if (Shiboken::Converter< ::QWidget * >::isConvertible(value))
                        pyargs[1] = value;
else
                        goto Sbk_QHeaderView_Init_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QHeaderView(): got multiple values for keyword argument '%s'", errorArgName);
                    return -1;
                }
            }
            Qt::Orientation cppArg0 = Shiboken::Converter<Qt::Orientation >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return -1;
            QWidget * cppArg1 = pyargs[1] ? Shiboken::Converter<QWidget * >::toCpp(pyargs[1]) : 0;

            if(!PyErr_Occurred()) {
                // QHeaderView(Qt::Orientation,QWidget*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new QHeaderViewWrapper(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                Shiboken::Object::setParent(pyargs[1], self);
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QHeaderView >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QHeaderView_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    metaObject = cptr->metaObject(); // <- init python qt properties
    if (kwds && !PySide::fillQtProperties(self, metaObject, kwds, argNames, 1))
        return -1;


    return 1;

    Sbk_QHeaderView_Init_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.Orientation, PySide.QtGui.QWidget = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QHeaderView", overloads);
        return -1;
}

static PyObject* Sbk_QHeaderViewFunc_cascadingSectionResizes(PyObject* self)
{
    QHeaderView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHeaderView* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // cascadingSectionResizes()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->cascadingSectionResizes();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QHeaderViewFunc_count(PyObject* self)
{
    QHeaderView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHeaderView* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // count()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->count();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QHeaderViewFunc_currentChanged(PyObject* self, PyObject* args)
{
    QHeaderView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHeaderView* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "currentChanged", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: currentChanged(QModelIndex,QModelIndex)
    if (numArgs == 2 && Shiboken::Converter< ::QModelIndex >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QModelIndex >::isConvertible(pyargs[1])) {
        overloadId = 0; // currentChanged(QModelIndex,QModelIndex)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QHeaderViewFunc_currentChanged_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QModelIndex cppArg0 = Shiboken::Converter<QModelIndex >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QModelIndex cppArg1 = Shiboken::Converter<QModelIndex >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // currentChanged(QModelIndex,QModelIndex)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QHeaderView::currentChanged(cppArg0, cppArg1):cppSelf->currentChanged(cppArg0, cppArg1));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QHeaderViewFunc_currentChanged_TypeError:
        const char* overloads[] = {"PySide.QtCore.QModelIndex, PySide.QtCore.QModelIndex", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QHeaderView.currentChanged", overloads);
        return 0;
}

static PyObject* Sbk_QHeaderViewFunc_dataChanged(PyObject* self, PyObject* args)
{
    QHeaderView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHeaderView* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "dataChanged", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: dataChanged(QModelIndex,QModelIndex)
    if (numArgs == 2 && Shiboken::Converter< ::QModelIndex >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QModelIndex >::isConvertible(pyargs[1])) {
        overloadId = 0; // dataChanged(QModelIndex,QModelIndex)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QHeaderViewFunc_dataChanged_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QModelIndex cppArg0 = Shiboken::Converter<QModelIndex >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QModelIndex cppArg1 = Shiboken::Converter<QModelIndex >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // dataChanged(QModelIndex,QModelIndex)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QHeaderView::dataChanged(cppArg0, cppArg1):cppSelf->dataChanged(cppArg0, cppArg1));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QHeaderViewFunc_dataChanged_TypeError:
        const char* overloads[] = {"PySide.QtCore.QModelIndex, PySide.QtCore.QModelIndex", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QHeaderView.dataChanged", overloads);
        return 0;
}

static PyObject* Sbk_QHeaderViewFunc_defaultAlignment(PyObject* self)
{
    QHeaderView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHeaderView* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // defaultAlignment()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QFlags<Qt::AlignmentFlag> cppResult = cppSelf->defaultAlignment();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QFlags<Qt::AlignmentFlag> >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QHeaderViewFunc_defaultSectionSize(PyObject* self)
{
    QHeaderView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHeaderView* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // defaultSectionSize()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->defaultSectionSize();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QHeaderViewFunc_doItemsLayout(PyObject* self)
{
    QHeaderView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHeaderView* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // doItemsLayout()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QHeaderView::doItemsLayout():cppSelf->doItemsLayout());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QHeaderViewFunc_event(PyObject* self, PyObject* arg)
{
    QHeaderView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHeaderView* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: event(QEvent*)
    if (Shiboken::Converter< ::QEvent * >::isConvertible(arg)) {
        overloadId = 0; // event(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QHeaderViewFunc_event_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QEvent * cppArg0 = Shiboken::Converter<QEvent * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // event(QEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QHeaderView::event(cppArg0):cppSelf->event(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QHeaderViewFunc_event_TypeError:
        const char* overloads[] = {"PySide.QtCore.QEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QHeaderView.event", overloads);
        return 0;
}

static PyObject* Sbk_QHeaderViewFunc_headerDataChanged(PyObject* self, PyObject* args)
{
    QHeaderView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHeaderView* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "headerDataChanged", 3, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: headerDataChanged(Qt::Orientation,int,int)
    if (numArgs == 3 && Shiboken::Converter< ::Qt::Orientation >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
        overloadId = 0; // headerDataChanged(Qt::Orientation,int,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QHeaderViewFunc_headerDataChanged_TypeError;

    // Call function/method
    {
        {
            Qt::Orientation cppArg0 = Shiboken::Converter<Qt::Orientation >::toCpp(pyargs[0]);
            int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
            int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

            if(!PyErr_Occurred()) {
                // headerDataChanged(Qt::Orientation,int,int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->headerDataChanged(cppArg0, cppArg1, cppArg2);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QHeaderViewFunc_headerDataChanged_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.Orientation, int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QHeaderView.headerDataChanged", overloads);
        return 0;
}

static PyObject* Sbk_QHeaderViewFunc_hiddenSectionCount(PyObject* self)
{
    QHeaderView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHeaderView* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // hiddenSectionCount()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->hiddenSectionCount();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QHeaderViewFunc_hideSection(PyObject* self, PyObject* arg)
{
    QHeaderView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHeaderView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: hideSection(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // hideSection(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QHeaderViewFunc_hideSection_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // hideSection(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->hideSection(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QHeaderViewFunc_hideSection_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QHeaderView.hideSection", overloads);
        return 0;
}

static PyObject* Sbk_QHeaderViewFunc_highlightSections(PyObject* self)
{
    QHeaderView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHeaderView* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // highlightSections()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->highlightSections();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QHeaderViewFunc_horizontalOffset(PyObject* self)
{
    QHeaderView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHeaderView* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // horizontalOffset()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QHeaderView::horizontalOffset():cppSelf->horizontalOffset());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QHeaderViewFunc_indexAt(PyObject* self, PyObject* arg)
{
    QHeaderView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHeaderView* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: indexAt(QPoint)const
    if (Shiboken::Converter< ::QPoint >::isConvertible(arg)) {
        overloadId = 0; // indexAt(QPoint)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QHeaderViewFunc_indexAt_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QPoint cppArg0 = Shiboken::Converter<QPoint >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // indexAt(QPoint)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QModelIndex cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QHeaderView::indexAt(cppArg0):cppSelf->indexAt(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QModelIndex >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QHeaderViewFunc_indexAt_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QHeaderView.indexAt", overloads);
        return 0;
}

static PyObject* Sbk_QHeaderViewFunc_initStyleOption(PyObject* self, PyObject* arg)
{
    QHeaderView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHeaderView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: initStyleOption(QStyleOptionHeader*)const
    if (Shiboken::Converter< ::QStyleOptionHeader * >::isConvertible(arg)) {
        overloadId = 0; // initStyleOption(QStyleOptionHeader*)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QHeaderViewFunc_initStyleOption_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QStyleOptionHeader * cppArg0 = Shiboken::Converter<QStyleOptionHeader * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // initStyleOption(QStyleOptionHeader*)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->initStyleOption(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QHeaderViewFunc_initStyleOption_TypeError:
        const char* overloads[] = {"PySide.QtGui.QStyleOptionHeader", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QHeaderView.initStyleOption", overloads);
        return 0;
}

static PyObject* Sbk_QHeaderViewFunc_initialize(PyObject* self)
{
    QHeaderView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHeaderView* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // initialize()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->initialize();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QHeaderViewFunc_initializeSections(PyObject* self, PyObject* args)
{
    QHeaderView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHeaderView* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs == 1)
        goto Sbk_QHeaderViewFunc_initializeSections_TypeError;

    if (!PyArg_UnpackTuple(args, "initializeSections", 0, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: initializeSections()
    // 1: initializeSections(int,int)
    if (numArgs == 0) {
        overloadId = 0; // initializeSections()
    } else if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 1; // initializeSections(int,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QHeaderViewFunc_initializeSections_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // initializeSections()
            {

                if(!PyErr_Occurred()) {
                    // initializeSections()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->initializeSections();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // initializeSections(int,int)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // initializeSections(int,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->initializeSections(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QHeaderViewFunc_initializeSections_TypeError:
        const char* overloads[] = {"", "int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QHeaderView.initializeSections", overloads);
        return 0;
}

static PyObject* Sbk_QHeaderViewFunc_isClickable(PyObject* self)
{
    QHeaderView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHeaderView* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isClickable()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->isClickable();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QHeaderViewFunc_isIndexHidden(PyObject* self, PyObject* arg)
{
    QHeaderView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHeaderView* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: isIndexHidden(QModelIndex)const
    if (Shiboken::Converter< ::QModelIndex >::isConvertible(arg)) {
        overloadId = 0; // isIndexHidden(QModelIndex)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QHeaderViewFunc_isIndexHidden_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QModelIndex cppArg0 = Shiboken::Converter<QModelIndex >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // isIndexHidden(QModelIndex)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QHeaderView::isIndexHidden(cppArg0):cppSelf->isIndexHidden(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QHeaderViewFunc_isIndexHidden_TypeError:
        const char* overloads[] = {"PySide.QtCore.QModelIndex", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QHeaderView.isIndexHidden", overloads);
        return 0;
}

static PyObject* Sbk_QHeaderViewFunc_isMovable(PyObject* self)
{
    QHeaderView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHeaderView* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isMovable()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->isMovable();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QHeaderViewFunc_isSectionHidden(PyObject* self, PyObject* arg)
{
    QHeaderView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHeaderView* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: isSectionHidden(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // isSectionHidden(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QHeaderViewFunc_isSectionHidden_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // isSectionHidden(int)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->isSectionHidden(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QHeaderViewFunc_isSectionHidden_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QHeaderView.isSectionHidden", overloads);
        return 0;
}

static PyObject* Sbk_QHeaderViewFunc_isSortIndicatorShown(PyObject* self)
{
    QHeaderView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHeaderView* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isSortIndicatorShown()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->isSortIndicatorShown();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QHeaderViewFunc_length(PyObject* self)
{
    QHeaderView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHeaderView* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // length()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->length();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QHeaderViewFunc_logicalIndex(PyObject* self, PyObject* arg)
{
    QHeaderView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHeaderView* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: logicalIndex(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // logicalIndex(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QHeaderViewFunc_logicalIndex_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // logicalIndex(int)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->logicalIndex(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QHeaderViewFunc_logicalIndex_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QHeaderView.logicalIndex", overloads);
        return 0;
}

static PyObject* Sbk_QHeaderViewFunc_logicalIndexAt(PyObject* self, PyObject* args)
{
    QHeaderView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHeaderView* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "logicalIndexAt", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: logicalIndexAt(QPoint)const
    // 1: logicalIndexAt(int)const
    // 2: logicalIndexAt(int,int)const
    if (SbkNumber_Check(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 1; // logicalIndexAt(int)const
        } else if (numArgs == 2 && SbkNumber_Check(pyargs[1])) {
            overloadId = 2; // logicalIndexAt(int,int)const
        }
    } else if (numArgs == 1 && Shiboken::Converter< ::QPoint >::isConvertible(pyargs[0])) {
        overloadId = 0; // logicalIndexAt(QPoint)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QHeaderViewFunc_logicalIndexAt_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // logicalIndexAt(QPoint)const
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QPoint cppArg0 = Shiboken::Converter<QPoint >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // logicalIndexAt(QPoint)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    int cppResult = cppSelf->logicalIndexAt(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< int >::toPython(cppResult);
                }
                break;
            }
            case 1: // logicalIndexAt(int)const
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // logicalIndexAt(int)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    int cppResult = cppSelf->logicalIndexAt(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< int >::toPython(cppResult);
                }
                break;
            }
            case 2: // logicalIndexAt(int,int)const
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // logicalIndexAt(int,int)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    int cppResult = cppSelf->logicalIndexAt(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< int >::toPython(cppResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QHeaderViewFunc_logicalIndexAt_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint", "int", "int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QHeaderView.logicalIndexAt", overloads);
        return 0;
}

static PyObject* Sbk_QHeaderViewFunc_minimumSectionSize(PyObject* self)
{
    QHeaderView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHeaderView* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // minimumSectionSize()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->minimumSectionSize();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QHeaderViewFunc_mouseDoubleClickEvent(PyObject* self, PyObject* arg)
{
    QHeaderView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHeaderView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: mouseDoubleClickEvent(QMouseEvent*)
    if (Shiboken::Converter< ::QMouseEvent * >::isConvertible(arg)) {
        overloadId = 0; // mouseDoubleClickEvent(QMouseEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QHeaderViewFunc_mouseDoubleClickEvent_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QMouseEvent * cppArg0 = Shiboken::Converter<QMouseEvent * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // mouseDoubleClickEvent(QMouseEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QHeaderView::mouseDoubleClickEvent(cppArg0):cppSelf->mouseDoubleClickEvent(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QHeaderViewFunc_mouseDoubleClickEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QMouseEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QHeaderView.mouseDoubleClickEvent", overloads);
        return 0;
}

static PyObject* Sbk_QHeaderViewFunc_mouseMoveEvent(PyObject* self, PyObject* arg)
{
    QHeaderView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHeaderView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: mouseMoveEvent(QMouseEvent*)
    if (Shiboken::Converter< ::QMouseEvent * >::isConvertible(arg)) {
        overloadId = 0; // mouseMoveEvent(QMouseEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QHeaderViewFunc_mouseMoveEvent_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QMouseEvent * cppArg0 = Shiboken::Converter<QMouseEvent * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // mouseMoveEvent(QMouseEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QHeaderView::mouseMoveEvent(cppArg0):cppSelf->mouseMoveEvent(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QHeaderViewFunc_mouseMoveEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QMouseEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QHeaderView.mouseMoveEvent", overloads);
        return 0;
}

static PyObject* Sbk_QHeaderViewFunc_mousePressEvent(PyObject* self, PyObject* arg)
{
    QHeaderView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHeaderView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: mousePressEvent(QMouseEvent*)
    if (Shiboken::Converter< ::QMouseEvent * >::isConvertible(arg)) {
        overloadId = 0; // mousePressEvent(QMouseEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QHeaderViewFunc_mousePressEvent_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QMouseEvent * cppArg0 = Shiboken::Converter<QMouseEvent * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // mousePressEvent(QMouseEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QHeaderView::mousePressEvent(cppArg0):cppSelf->mousePressEvent(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QHeaderViewFunc_mousePressEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QMouseEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QHeaderView.mousePressEvent", overloads);
        return 0;
}

static PyObject* Sbk_QHeaderViewFunc_mouseReleaseEvent(PyObject* self, PyObject* arg)
{
    QHeaderView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHeaderView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: mouseReleaseEvent(QMouseEvent*)
    if (Shiboken::Converter< ::QMouseEvent * >::isConvertible(arg)) {
        overloadId = 0; // mouseReleaseEvent(QMouseEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QHeaderViewFunc_mouseReleaseEvent_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QMouseEvent * cppArg0 = Shiboken::Converter<QMouseEvent * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // mouseReleaseEvent(QMouseEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QHeaderView::mouseReleaseEvent(cppArg0):cppSelf->mouseReleaseEvent(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QHeaderViewFunc_mouseReleaseEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QMouseEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QHeaderView.mouseReleaseEvent", overloads);
        return 0;
}

static PyObject* Sbk_QHeaderViewFunc_moveSection(PyObject* self, PyObject* args)
{
    QHeaderView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHeaderView* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "moveSection", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: moveSection(int,int)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // moveSection(int,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QHeaderViewFunc_moveSection_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // moveSection(int,int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->moveSection(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QHeaderViewFunc_moveSection_TypeError:
        const char* overloads[] = {"int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QHeaderView.moveSection", overloads);
        return 0;
}

static PyObject* Sbk_QHeaderViewFunc_offset(PyObject* self)
{
    QHeaderView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHeaderView* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // offset()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->offset();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QHeaderViewFunc_orientation(PyObject* self)
{
    QHeaderView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHeaderView* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // orientation()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                Qt::Orientation cppResult = cppSelf->orientation();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::Qt::Orientation >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QHeaderViewFunc_paintEvent(PyObject* self, PyObject* arg)
{
    QHeaderView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHeaderView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: paintEvent(QPaintEvent*)
    if (Shiboken::Converter< ::QPaintEvent * >::isConvertible(arg)) {
        overloadId = 0; // paintEvent(QPaintEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QHeaderViewFunc_paintEvent_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QPaintEvent * cppArg0 = Shiboken::Converter<QPaintEvent * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // paintEvent(QPaintEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QHeaderView::paintEvent(cppArg0):cppSelf->paintEvent(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QHeaderViewFunc_paintEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPaintEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QHeaderView.paintEvent", overloads);
        return 0;
}

static PyObject* Sbk_QHeaderViewFunc_paintSection(PyObject* self, PyObject* args)
{
    QHeaderView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHeaderView* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "paintSection", 3, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: paintSection(QPainter*,QRect,int)const
    if (numArgs == 3 && Shiboken::Converter< ::QPainter * >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QRect >::isConvertible(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
        overloadId = 0; // paintSection(QPainter*,QRect,int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QHeaderViewFunc_paintSection_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QPainter * cppArg0 = Shiboken::Converter<QPainter * >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QRect cppArg1 = Shiboken::Converter<QRect >::toCpp(pyargs[1]);
            int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

            if(!PyErr_Occurred()) {
                // paintSection(QPainter*,QRect,int)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QHeaderView::paintSection(cppArg0, cppArg1, cppArg2):cppSelf->paintSection(cppArg0, cppArg1, cppArg2));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QHeaderViewFunc_paintSection_TypeError:
        const char* overloads[] = {"PySide.QtGui.QPainter, PySide.QtCore.QRect, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QHeaderView.paintSection", overloads);
        return 0;
}

static PyObject* Sbk_QHeaderViewFunc_reset(PyObject* self)
{
    QHeaderView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHeaderView* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // reset()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QHeaderView::reset():cppSelf->reset());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QHeaderViewFunc_resizeMode(PyObject* self, PyObject* arg)
{
    QHeaderView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHeaderView* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: resizeMode(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // resizeMode(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QHeaderViewFunc_resizeMode_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // resizeMode(int)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QHeaderView::ResizeMode cppResult = cppSelf->resizeMode(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QHeaderView::ResizeMode >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QHeaderViewFunc_resizeMode_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QHeaderView.resizeMode", overloads);
        return 0;
}

static PyObject* Sbk_QHeaderViewFunc_resizeSection(PyObject* self, PyObject* args)
{
    QHeaderView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHeaderView* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "resizeSection", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: resizeSection(int,int)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // resizeSection(int,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QHeaderViewFunc_resizeSection_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // resizeSection(int,int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->resizeSection(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QHeaderViewFunc_resizeSection_TypeError:
        const char* overloads[] = {"int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QHeaderView.resizeSection", overloads);
        return 0;
}

static PyObject* Sbk_QHeaderViewFunc_resizeSections(PyObject* self, PyObject* args)
{
    QHeaderView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHeaderView* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "resizeSections", 0, 1, &(pyargs[0])))
        return 0;


    // Overloaded function decisor
    // 0: resizeSections()
    // 1: resizeSections(QHeaderView::ResizeMode)
    if (numArgs == 0) {
        overloadId = 0; // resizeSections()
    } else if (numArgs == 1 && Shiboken::Converter< ::QHeaderView::ResizeMode >::isConvertible(pyargs[0])) {
        overloadId = 1; // resizeSections(QHeaderView::ResizeMode)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QHeaderViewFunc_resizeSections_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // resizeSections()
            {

                if(!PyErr_Occurred()) {
                    // resizeSections()
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->resizeSections();
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // resizeSections(QHeaderView::ResizeMode)
            {
                QHeaderView::ResizeMode cppArg0 = Shiboken::Converter<QHeaderView::ResizeMode >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // resizeSections(QHeaderView::ResizeMode)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->resizeSections(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QHeaderViewFunc_resizeSections_TypeError:
        const char* overloads[] = {"", "PySide.QtGui.QHeaderView.ResizeMode", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QHeaderView.resizeSections", overloads);
        return 0;
}

static PyObject* Sbk_QHeaderViewFunc_restoreState(PyObject* self, PyObject* arg)
{
    QHeaderView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHeaderView* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: restoreState(QByteArray)
    if (Shiboken::Converter< ::QByteArray >::isConvertible(arg)) {
        overloadId = 0; // restoreState(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QHeaderViewFunc_restoreState_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QByteArray cppArg0 = Shiboken::Converter<QByteArray >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // restoreState(QByteArray)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->restoreState(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QHeaderViewFunc_restoreState_TypeError:
        const char* overloads[] = {"PySide.QtCore.QByteArray", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QHeaderView.restoreState", overloads);
        return 0;
}

static PyObject* Sbk_QHeaderViewFunc_rowsInserted(PyObject* self, PyObject* args)
{
    QHeaderView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHeaderView* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "rowsInserted", 3, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: rowsInserted(QModelIndex,int,int)
    if (numArgs == 3 && Shiboken::Converter< ::QModelIndex >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
        overloadId = 0; // rowsInserted(QModelIndex,int,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QHeaderViewFunc_rowsInserted_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QModelIndex cppArg0 = Shiboken::Converter<QModelIndex >::toCpp(pyargs[0]);
            int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
            int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

            if(!PyErr_Occurred()) {
                // rowsInserted(QModelIndex,int,int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QHeaderView::rowsInserted(cppArg0, cppArg1, cppArg2):cppSelf->rowsInserted(cppArg0, cppArg1, cppArg2));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QHeaderViewFunc_rowsInserted_TypeError:
        const char* overloads[] = {"PySide.QtCore.QModelIndex, int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QHeaderView.rowsInserted", overloads);
        return 0;
}

static PyObject* Sbk_QHeaderViewFunc_saveState(PyObject* self)
{
    QHeaderView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHeaderView* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // saveState()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QByteArray cppResult = cppSelf->saveState();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QByteArray >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QHeaderViewFunc_scrollContentsBy(PyObject* self, PyObject* args)
{
    QHeaderView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHeaderView* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "scrollContentsBy", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: scrollContentsBy(int,int)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // scrollContentsBy(int,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QHeaderViewFunc_scrollContentsBy_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // scrollContentsBy(int,int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QHeaderView::scrollContentsBy(cppArg0, cppArg1):cppSelf->scrollContentsBy(cppArg0, cppArg1));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QHeaderViewFunc_scrollContentsBy_TypeError:
        const char* overloads[] = {"int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QHeaderView.scrollContentsBy", overloads);
        return 0;
}

static PyObject* Sbk_QHeaderViewFunc_scrollTo(PyObject* self, PyObject* args)
{
    QHeaderView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHeaderView* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "scrollTo", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: scrollTo(QModelIndex,QAbstractItemView::ScrollHint)
    if (numArgs == 2 && Shiboken::Converter< ::QModelIndex >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QAbstractItemView::ScrollHint >::isConvertible(pyargs[1])) {
        overloadId = 0; // scrollTo(QModelIndex,QAbstractItemView::ScrollHint)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QHeaderViewFunc_scrollTo_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QModelIndex cppArg0 = Shiboken::Converter<QModelIndex >::toCpp(pyargs[0]);
            QAbstractItemView::ScrollHint cppArg1 = Shiboken::Converter<QAbstractItemView::ScrollHint >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // scrollTo(QModelIndex,QAbstractItemView::ScrollHint)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QHeaderView::scrollTo(cppArg0, cppArg1):cppSelf->scrollTo(cppArg0, cppArg1));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QHeaderViewFunc_scrollTo_TypeError:
        const char* overloads[] = {"PySide.QtCore.QModelIndex, PySide.QtGui.QAbstractItemView.ScrollHint", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QHeaderView.scrollTo", overloads);
        return 0;
}

static PyObject* Sbk_QHeaderViewFunc_sectionPosition(PyObject* self, PyObject* arg)
{
    QHeaderView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHeaderView* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: sectionPosition(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // sectionPosition(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QHeaderViewFunc_sectionPosition_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // sectionPosition(int)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->sectionPosition(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QHeaderViewFunc_sectionPosition_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QHeaderView.sectionPosition", overloads);
        return 0;
}

static PyObject* Sbk_QHeaderViewFunc_sectionSize(PyObject* self, PyObject* arg)
{
    QHeaderView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHeaderView* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: sectionSize(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // sectionSize(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QHeaderViewFunc_sectionSize_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // sectionSize(int)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->sectionSize(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QHeaderViewFunc_sectionSize_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QHeaderView.sectionSize", overloads);
        return 0;
}

static PyObject* Sbk_QHeaderViewFunc_sectionSizeFromContents(PyObject* self, PyObject* arg)
{
    QHeaderView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHeaderView* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: sectionSizeFromContents(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // sectionSizeFromContents(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QHeaderViewFunc_sectionSizeFromContents_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // sectionSizeFromContents(int)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QSize cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QHeaderView::sectionSizeFromContents(cppArg0):cppSelf->sectionSizeFromContents(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QSize >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QHeaderViewFunc_sectionSizeFromContents_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QHeaderView.sectionSizeFromContents", overloads);
        return 0;
}

static PyObject* Sbk_QHeaderViewFunc_sectionSizeHint(PyObject* self, PyObject* arg)
{
    QHeaderView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHeaderView* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: sectionSizeHint(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // sectionSizeHint(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QHeaderViewFunc_sectionSizeHint_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // sectionSizeHint(int)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->sectionSizeHint(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QHeaderViewFunc_sectionSizeHint_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QHeaderView.sectionSizeHint", overloads);
        return 0;
}

static PyObject* Sbk_QHeaderViewFunc_sectionViewportPosition(PyObject* self, PyObject* arg)
{
    QHeaderView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHeaderView* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: sectionViewportPosition(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // sectionViewportPosition(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QHeaderViewFunc_sectionViewportPosition_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // sectionViewportPosition(int)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->sectionViewportPosition(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QHeaderViewFunc_sectionViewportPosition_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QHeaderView.sectionViewportPosition", overloads);
        return 0;
}

static PyObject* Sbk_QHeaderViewFunc_sectionsAboutToBeRemoved(PyObject* self, PyObject* args)
{
    QHeaderView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHeaderView* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "sectionsAboutToBeRemoved", 3, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: sectionsAboutToBeRemoved(QModelIndex,int,int)
    if (numArgs == 3 && Shiboken::Converter< ::QModelIndex >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
        overloadId = 0; // sectionsAboutToBeRemoved(QModelIndex,int,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QHeaderViewFunc_sectionsAboutToBeRemoved_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QModelIndex cppArg0 = Shiboken::Converter<QModelIndex >::toCpp(pyargs[0]);
            int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
            int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

            if(!PyErr_Occurred()) {
                // sectionsAboutToBeRemoved(QModelIndex,int,int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->sectionsAboutToBeRemoved(cppArg0, cppArg1, cppArg2);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QHeaderViewFunc_sectionsAboutToBeRemoved_TypeError:
        const char* overloads[] = {"PySide.QtCore.QModelIndex, int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QHeaderView.sectionsAboutToBeRemoved", overloads);
        return 0;
}

static PyObject* Sbk_QHeaderViewFunc_sectionsHidden(PyObject* self)
{
    QHeaderView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHeaderView* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // sectionsHidden()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->sectionsHidden();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QHeaderViewFunc_sectionsInserted(PyObject* self, PyObject* args)
{
    QHeaderView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHeaderView* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "sectionsInserted", 3, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: sectionsInserted(QModelIndex,int,int)
    if (numArgs == 3 && Shiboken::Converter< ::QModelIndex >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
        overloadId = 0; // sectionsInserted(QModelIndex,int,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QHeaderViewFunc_sectionsInserted_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QModelIndex cppArg0 = Shiboken::Converter<QModelIndex >::toCpp(pyargs[0]);
            int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
            int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

            if(!PyErr_Occurred()) {
                // sectionsInserted(QModelIndex,int,int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->sectionsInserted(cppArg0, cppArg1, cppArg2);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QHeaderViewFunc_sectionsInserted_TypeError:
        const char* overloads[] = {"PySide.QtCore.QModelIndex, int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QHeaderView.sectionsInserted", overloads);
        return 0;
}

static PyObject* Sbk_QHeaderViewFunc_sectionsMoved(PyObject* self)
{
    QHeaderView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHeaderView* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // sectionsMoved()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->sectionsMoved();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QHeaderViewFunc_setCascadingSectionResizes(PyObject* self, PyObject* arg)
{
    QHeaderView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHeaderView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setCascadingSectionResizes(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setCascadingSectionResizes(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QHeaderViewFunc_setCascadingSectionResizes_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setCascadingSectionResizes(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setCascadingSectionResizes(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QHeaderViewFunc_setCascadingSectionResizes_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QHeaderView.setCascadingSectionResizes", overloads);
        return 0;
}

static PyObject* Sbk_QHeaderViewFunc_setClickable(PyObject* self, PyObject* arg)
{
    QHeaderView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHeaderView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setClickable(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setClickable(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QHeaderViewFunc_setClickable_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setClickable(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setClickable(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QHeaderViewFunc_setClickable_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QHeaderView.setClickable", overloads);
        return 0;
}

static PyObject* Sbk_QHeaderViewFunc_setDefaultAlignment(PyObject* self, PyObject* arg)
{
    QHeaderView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHeaderView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDefaultAlignment(QFlags<Qt::AlignmentFlag>)
    if (Shiboken::Converter< ::QFlags<Qt::AlignmentFlag> >::isConvertible(arg)) {
        overloadId = 0; // setDefaultAlignment(QFlags<Qt::AlignmentFlag>)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QHeaderViewFunc_setDefaultAlignment_TypeError;

    // Call function/method
    {
        {
            QFlags<Qt::AlignmentFlag> cppArg0 = Shiboken::Converter<QFlags<Qt::AlignmentFlag> >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setDefaultAlignment(QFlags<Qt::AlignmentFlag>)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setDefaultAlignment(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QHeaderViewFunc_setDefaultAlignment_TypeError:
        const char* overloads[] = {"PySide.QtCore.Qt.Alignment", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QHeaderView.setDefaultAlignment", overloads);
        return 0;
}

static PyObject* Sbk_QHeaderViewFunc_setDefaultSectionSize(PyObject* self, PyObject* arg)
{
    QHeaderView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHeaderView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setDefaultSectionSize(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setDefaultSectionSize(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QHeaderViewFunc_setDefaultSectionSize_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setDefaultSectionSize(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setDefaultSectionSize(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QHeaderViewFunc_setDefaultSectionSize_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QHeaderView.setDefaultSectionSize", overloads);
        return 0;
}

static PyObject* Sbk_QHeaderViewFunc_setHighlightSections(PyObject* self, PyObject* arg)
{
    QHeaderView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHeaderView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setHighlightSections(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setHighlightSections(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QHeaderViewFunc_setHighlightSections_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setHighlightSections(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setHighlightSections(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QHeaderViewFunc_setHighlightSections_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QHeaderView.setHighlightSections", overloads);
        return 0;
}

static PyObject* Sbk_QHeaderViewFunc_setMinimumSectionSize(PyObject* self, PyObject* arg)
{
    QHeaderView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHeaderView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setMinimumSectionSize(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setMinimumSectionSize(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QHeaderViewFunc_setMinimumSectionSize_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setMinimumSectionSize(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setMinimumSectionSize(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QHeaderViewFunc_setMinimumSectionSize_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QHeaderView.setMinimumSectionSize", overloads);
        return 0;
}

static PyObject* Sbk_QHeaderViewFunc_setModel(PyObject* self, PyObject* arg)
{
    QHeaderView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHeaderView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setModel(QAbstractItemModel*)
    if (Shiboken::Converter< ::QAbstractItemModel * >::isConvertible(arg)) {
        overloadId = 0; // setModel(QAbstractItemModel*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QHeaderViewFunc_setModel_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QAbstractItemModel * cppArg0 = Shiboken::Converter<QAbstractItemModel * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setModel(QAbstractItemModel*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QHeaderView::setModel(cppArg0):cppSelf->setModel(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                Shiboken::Object::keepReference(reinterpret_cast<SbkObject*>(self), "setModel(QAbstractItemModel*)1", arg);
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QHeaderViewFunc_setModel_TypeError:
        const char* overloads[] = {"PySide.QtCore.QAbstractItemModel", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QHeaderView.setModel", overloads);
        return 0;
}

static PyObject* Sbk_QHeaderViewFunc_setMovable(PyObject* self, PyObject* arg)
{
    QHeaderView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHeaderView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setMovable(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setMovable(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QHeaderViewFunc_setMovable_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setMovable(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setMovable(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QHeaderViewFunc_setMovable_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QHeaderView.setMovable", overloads);
        return 0;
}

static PyObject* Sbk_QHeaderViewFunc_setOffset(PyObject* self, PyObject* arg)
{
    QHeaderView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHeaderView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setOffset(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setOffset(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QHeaderViewFunc_setOffset_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setOffset(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setOffset(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QHeaderViewFunc_setOffset_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QHeaderView.setOffset", overloads);
        return 0;
}

static PyObject* Sbk_QHeaderViewFunc_setOffsetToLastSection(PyObject* self)
{
    QHeaderView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHeaderView* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // setOffsetToLastSection()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setOffsetToLastSection();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QHeaderViewFunc_setOffsetToSectionPosition(PyObject* self, PyObject* arg)
{
    QHeaderView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHeaderView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setOffsetToSectionPosition(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setOffsetToSectionPosition(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QHeaderViewFunc_setOffsetToSectionPosition_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setOffsetToSectionPosition(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setOffsetToSectionPosition(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QHeaderViewFunc_setOffsetToSectionPosition_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QHeaderView.setOffsetToSectionPosition", overloads);
        return 0;
}

static PyObject* Sbk_QHeaderViewFunc_setResizeMode(PyObject* self, PyObject* args)
{
    QHeaderView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHeaderView* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setResizeMode", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setResizeMode(QHeaderView::ResizeMode)
    // 1: setResizeMode(int,QHeaderView::ResizeMode)
    if (numArgs == 1 && Shiboken::Converter< ::QHeaderView::ResizeMode >::isConvertible(pyargs[0])) {
        overloadId = 0; // setResizeMode(QHeaderView::ResizeMode)
    } else if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && Shiboken::Converter< ::QHeaderView::ResizeMode >::isConvertible(pyargs[1])) {
        overloadId = 1; // setResizeMode(int,QHeaderView::ResizeMode)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QHeaderViewFunc_setResizeMode_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setResizeMode(QHeaderView::ResizeMode)
            {
                QHeaderView::ResizeMode cppArg0 = Shiboken::Converter<QHeaderView::ResizeMode >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // setResizeMode(QHeaderView::ResizeMode)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setResizeMode(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // setResizeMode(int,QHeaderView::ResizeMode)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                QHeaderView::ResizeMode cppArg1 = Shiboken::Converter<QHeaderView::ResizeMode >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // setResizeMode(int,QHeaderView::ResizeMode)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setResizeMode(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QHeaderViewFunc_setResizeMode_TypeError:
        const char* overloads[] = {"PySide.QtGui.QHeaderView.ResizeMode", "int, PySide.QtGui.QHeaderView.ResizeMode", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QHeaderView.setResizeMode", overloads);
        return 0;
}

static PyObject* Sbk_QHeaderViewFunc_setSectionHidden(PyObject* self, PyObject* args)
{
    QHeaderView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHeaderView* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setSectionHidden", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setSectionHidden(int,bool)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // setSectionHidden(int,bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QHeaderViewFunc_setSectionHidden_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            bool cppArg1 = Shiboken::Converter<bool >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // setSectionHidden(int,bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setSectionHidden(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QHeaderViewFunc_setSectionHidden_TypeError:
        const char* overloads[] = {"int, bool", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QHeaderView.setSectionHidden", overloads);
        return 0;
}

static PyObject* Sbk_QHeaderViewFunc_setSelection(PyObject* self, PyObject* args)
{
    QHeaderView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHeaderView* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setSelection", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setSelection(QRect,QFlags<QItemSelectionModel::SelectionFlag>)
    if (numArgs == 2 && Shiboken::Converter< ::QRect >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QFlags<QItemSelectionModel::SelectionFlag> >::isConvertible(pyargs[1])) {
        overloadId = 0; // setSelection(QRect,QFlags<QItemSelectionModel::SelectionFlag>)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QHeaderViewFunc_setSelection_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QRect cppArg0 = Shiboken::Converter<QRect >::toCpp(pyargs[0]);
            QFlags<QItemSelectionModel::SelectionFlag> cppArg1 = Shiboken::Converter<QFlags<QItemSelectionModel::SelectionFlag> >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // setSelection(QRect,QFlags<QItemSelectionModel::SelectionFlag>)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QHeaderView::setSelection(cppArg0, cppArg1):cppSelf->setSelection(cppArg0, cppArg1));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QHeaderViewFunc_setSelection_TypeError:
        const char* overloads[] = {"PySide.QtCore.QRect, PySide.QtGui.QItemSelectionModel.SelectionFlags", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QHeaderView.setSelection", overloads);
        return 0;
}

static PyObject* Sbk_QHeaderViewFunc_setSortIndicator(PyObject* self, PyObject* args)
{
    QHeaderView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHeaderView* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setSortIndicator", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setSortIndicator(int,Qt::SortOrder)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && Shiboken::Converter< ::Qt::SortOrder >::isConvertible(pyargs[1])) {
        overloadId = 0; // setSortIndicator(int,Qt::SortOrder)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QHeaderViewFunc_setSortIndicator_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            Qt::SortOrder cppArg1 = Shiboken::Converter<Qt::SortOrder >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // setSortIndicator(int,Qt::SortOrder)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setSortIndicator(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QHeaderViewFunc_setSortIndicator_TypeError:
        const char* overloads[] = {"int, PySide.QtCore.Qt.SortOrder", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QHeaderView.setSortIndicator", overloads);
        return 0;
}

static PyObject* Sbk_QHeaderViewFunc_setSortIndicatorShown(PyObject* self, PyObject* arg)
{
    QHeaderView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHeaderView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setSortIndicatorShown(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setSortIndicatorShown(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QHeaderViewFunc_setSortIndicatorShown_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setSortIndicatorShown(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setSortIndicatorShown(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QHeaderViewFunc_setSortIndicatorShown_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QHeaderView.setSortIndicatorShown", overloads);
        return 0;
}

static PyObject* Sbk_QHeaderViewFunc_setStretchLastSection(PyObject* self, PyObject* arg)
{
    QHeaderView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHeaderView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setStretchLastSection(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setStretchLastSection(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QHeaderViewFunc_setStretchLastSection_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setStretchLastSection(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setStretchLastSection(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QHeaderViewFunc_setStretchLastSection_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QHeaderView.setStretchLastSection", overloads);
        return 0;
}

static PyObject* Sbk_QHeaderViewFunc_showSection(PyObject* self, PyObject* arg)
{
    QHeaderView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHeaderView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: showSection(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // showSection(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QHeaderViewFunc_showSection_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // showSection(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->showSection(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QHeaderViewFunc_showSection_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QHeaderView.showSection", overloads);
        return 0;
}

static PyObject* Sbk_QHeaderViewFunc_sizeHint(PyObject* self)
{
    QHeaderView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHeaderView* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // sizeHint()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QSize cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QHeaderView::sizeHint():cppSelf->sizeHint());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QSize >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QHeaderViewFunc_sortIndicatorOrder(PyObject* self)
{
    QHeaderView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHeaderView* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // sortIndicatorOrder()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                Qt::SortOrder cppResult = cppSelf->sortIndicatorOrder();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::Qt::SortOrder >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QHeaderViewFunc_sortIndicatorSection(PyObject* self)
{
    QHeaderView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHeaderView* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // sortIndicatorSection()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->sortIndicatorSection();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QHeaderViewFunc_stretchLastSection(PyObject* self)
{
    QHeaderView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHeaderView* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // stretchLastSection()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->stretchLastSection();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QHeaderViewFunc_stretchSectionCount(PyObject* self)
{
    QHeaderView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHeaderView* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // stretchSectionCount()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->stretchSectionCount();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QHeaderViewFunc_swapSections(PyObject* self, PyObject* args)
{
    QHeaderView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHeaderView* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "swapSections", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: swapSections(int,int)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // swapSections(int,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QHeaderViewFunc_swapSections_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // swapSections(int,int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->swapSections(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QHeaderViewFunc_swapSections_TypeError:
        const char* overloads[] = {"int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QHeaderView.swapSections", overloads);
        return 0;
}

static PyObject* Sbk_QHeaderViewFunc_updateGeometries(PyObject* self)
{
    QHeaderView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHeaderView* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // updateGeometries()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QHeaderView::updateGeometries():cppSelf->updateGeometries());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QHeaderViewFunc_updateSection(PyObject* self, PyObject* arg)
{
    QHeaderView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHeaderView* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: updateSection(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // updateSection(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QHeaderViewFunc_updateSection_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // updateSection(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->updateSection(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QHeaderViewFunc_updateSection_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QHeaderView.updateSection", overloads);
        return 0;
}

static PyObject* Sbk_QHeaderViewFunc_verticalOffset(PyObject* self)
{
    QHeaderView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHeaderView* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // verticalOffset()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QHeaderView::verticalOffset():cppSelf->verticalOffset());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QHeaderViewFunc_viewportEvent(PyObject* self, PyObject* arg)
{
    QHeaderView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHeaderView* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: viewportEvent(QEvent*)
    if (Shiboken::Converter< ::QEvent * >::isConvertible(arg)) {
        overloadId = 0; // viewportEvent(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QHeaderViewFunc_viewportEvent_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QEvent * cppArg0 = Shiboken::Converter<QEvent * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // viewportEvent(QEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QHeaderView::viewportEvent(cppArg0):cppSelf->viewportEvent(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QHeaderViewFunc_viewportEvent_TypeError:
        const char* overloads[] = {"PySide.QtCore.QEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QHeaderView.viewportEvent", overloads);
        return 0;
}

static PyObject* Sbk_QHeaderViewFunc_visualIndex(PyObject* self, PyObject* arg)
{
    QHeaderView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHeaderView* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: visualIndex(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // visualIndex(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QHeaderViewFunc_visualIndex_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // visualIndex(int)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->visualIndex(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QHeaderViewFunc_visualIndex_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QHeaderView.visualIndex", overloads);
        return 0;
}

static PyObject* Sbk_QHeaderViewFunc_visualIndexAt(PyObject* self, PyObject* arg)
{
    QHeaderView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHeaderView* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: visualIndexAt(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // visualIndexAt(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QHeaderViewFunc_visualIndexAt_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // visualIndexAt(int)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->visualIndexAt(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QHeaderViewFunc_visualIndexAt_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QHeaderView.visualIndexAt", overloads);
        return 0;
}

static PyObject* Sbk_QHeaderViewFunc_visualRect(PyObject* self, PyObject* arg)
{
    QHeaderView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHeaderView* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: visualRect(QModelIndex)const
    if (Shiboken::Converter< ::QModelIndex >::isConvertible(arg)) {
        overloadId = 0; // visualRect(QModelIndex)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QHeaderViewFunc_visualRect_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QModelIndex cppArg0 = Shiboken::Converter<QModelIndex >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // visualRect(QModelIndex)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QRect cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QHeaderView::visualRect(cppArg0):cppSelf->visualRect(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QRect >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QHeaderViewFunc_visualRect_TypeError:
        const char* overloads[] = {"PySide.QtCore.QModelIndex", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QHeaderView.visualRect", overloads);
        return 0;
}

static PyObject* Sbk_QHeaderViewFunc_visualRegionForSelection(PyObject* self, PyObject* arg)
{
    QHeaderView* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QHeaderView* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: visualRegionForSelection(QItemSelection)const
    if (Shiboken::Converter< ::QItemSelection >::isConvertible(arg)) {
        overloadId = 0; // visualRegionForSelection(QItemSelection)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QHeaderViewFunc_visualRegionForSelection_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QItemSelection cppArg0 = Shiboken::Converter<QItemSelection >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // visualRegionForSelection(QItemSelection)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QRegion cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QHeaderView::visualRegionForSelection(cppArg0):cppSelf->visualRegionForSelection(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QRegion >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QHeaderViewFunc_visualRegionForSelection_TypeError:
        const char* overloads[] = {"PySide.QtGui.QItemSelection", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QHeaderView.visualRegionForSelection", overloads);
        return 0;
}

static PyMethodDef Sbk_QHeaderView_methods[] = {
    {"cascadingSectionResizes", (PyCFunction)Sbk_QHeaderViewFunc_cascadingSectionResizes, METH_NOARGS},
    {"count", (PyCFunction)Sbk_QHeaderViewFunc_count, METH_NOARGS},
    {"currentChanged", (PyCFunction)Sbk_QHeaderViewFunc_currentChanged, METH_VARARGS},
    {"dataChanged", (PyCFunction)Sbk_QHeaderViewFunc_dataChanged, METH_VARARGS},
    {"defaultAlignment", (PyCFunction)Sbk_QHeaderViewFunc_defaultAlignment, METH_NOARGS},
    {"defaultSectionSize", (PyCFunction)Sbk_QHeaderViewFunc_defaultSectionSize, METH_NOARGS},
    {"doItemsLayout", (PyCFunction)Sbk_QHeaderViewFunc_doItemsLayout, METH_NOARGS},
    {"event", (PyCFunction)Sbk_QHeaderViewFunc_event, METH_O},
    {"headerDataChanged", (PyCFunction)Sbk_QHeaderViewFunc_headerDataChanged, METH_VARARGS},
    {"hiddenSectionCount", (PyCFunction)Sbk_QHeaderViewFunc_hiddenSectionCount, METH_NOARGS},
    {"hideSection", (PyCFunction)Sbk_QHeaderViewFunc_hideSection, METH_O},
    {"highlightSections", (PyCFunction)Sbk_QHeaderViewFunc_highlightSections, METH_NOARGS},
    {"horizontalOffset", (PyCFunction)Sbk_QHeaderViewFunc_horizontalOffset, METH_NOARGS},
    {"indexAt", (PyCFunction)Sbk_QHeaderViewFunc_indexAt, METH_O},
    {"initStyleOption", (PyCFunction)Sbk_QHeaderViewFunc_initStyleOption, METH_O},
    {"initialize", (PyCFunction)Sbk_QHeaderViewFunc_initialize, METH_NOARGS},
    {"initializeSections", (PyCFunction)Sbk_QHeaderViewFunc_initializeSections, METH_VARARGS},
    {"isClickable", (PyCFunction)Sbk_QHeaderViewFunc_isClickable, METH_NOARGS},
    {"isIndexHidden", (PyCFunction)Sbk_QHeaderViewFunc_isIndexHidden, METH_O},
    {"isMovable", (PyCFunction)Sbk_QHeaderViewFunc_isMovable, METH_NOARGS},
    {"isSectionHidden", (PyCFunction)Sbk_QHeaderViewFunc_isSectionHidden, METH_O},
    {"isSortIndicatorShown", (PyCFunction)Sbk_QHeaderViewFunc_isSortIndicatorShown, METH_NOARGS},
    {"length", (PyCFunction)Sbk_QHeaderViewFunc_length, METH_NOARGS},
    {"logicalIndex", (PyCFunction)Sbk_QHeaderViewFunc_logicalIndex, METH_O},
    {"logicalIndexAt", (PyCFunction)Sbk_QHeaderViewFunc_logicalIndexAt, METH_VARARGS},
    {"minimumSectionSize", (PyCFunction)Sbk_QHeaderViewFunc_minimumSectionSize, METH_NOARGS},
    {"mouseDoubleClickEvent", (PyCFunction)Sbk_QHeaderViewFunc_mouseDoubleClickEvent, METH_O},
    {"mouseMoveEvent", (PyCFunction)Sbk_QHeaderViewFunc_mouseMoveEvent, METH_O},
    {"mousePressEvent", (PyCFunction)Sbk_QHeaderViewFunc_mousePressEvent, METH_O},
    {"mouseReleaseEvent", (PyCFunction)Sbk_QHeaderViewFunc_mouseReleaseEvent, METH_O},
    {"moveSection", (PyCFunction)Sbk_QHeaderViewFunc_moveSection, METH_VARARGS},
    {"offset", (PyCFunction)Sbk_QHeaderViewFunc_offset, METH_NOARGS},
    {"orientation", (PyCFunction)Sbk_QHeaderViewFunc_orientation, METH_NOARGS},
    {"paintEvent", (PyCFunction)Sbk_QHeaderViewFunc_paintEvent, METH_O},
    {"paintSection", (PyCFunction)Sbk_QHeaderViewFunc_paintSection, METH_VARARGS},
    {"reset", (PyCFunction)Sbk_QHeaderViewFunc_reset, METH_NOARGS},
    {"resizeMode", (PyCFunction)Sbk_QHeaderViewFunc_resizeMode, METH_O},
    {"resizeSection", (PyCFunction)Sbk_QHeaderViewFunc_resizeSection, METH_VARARGS},
    {"resizeSections", (PyCFunction)Sbk_QHeaderViewFunc_resizeSections, METH_VARARGS},
    {"restoreState", (PyCFunction)Sbk_QHeaderViewFunc_restoreState, METH_O},
    {"rowsInserted", (PyCFunction)Sbk_QHeaderViewFunc_rowsInserted, METH_VARARGS},
    {"saveState", (PyCFunction)Sbk_QHeaderViewFunc_saveState, METH_NOARGS},
    {"scrollContentsBy", (PyCFunction)Sbk_QHeaderViewFunc_scrollContentsBy, METH_VARARGS},
    {"scrollTo", (PyCFunction)Sbk_QHeaderViewFunc_scrollTo, METH_VARARGS},
    {"sectionPosition", (PyCFunction)Sbk_QHeaderViewFunc_sectionPosition, METH_O},
    {"sectionSize", (PyCFunction)Sbk_QHeaderViewFunc_sectionSize, METH_O},
    {"sectionSizeFromContents", (PyCFunction)Sbk_QHeaderViewFunc_sectionSizeFromContents, METH_O},
    {"sectionSizeHint", (PyCFunction)Sbk_QHeaderViewFunc_sectionSizeHint, METH_O},
    {"sectionViewportPosition", (PyCFunction)Sbk_QHeaderViewFunc_sectionViewportPosition, METH_O},
    {"sectionsAboutToBeRemoved", (PyCFunction)Sbk_QHeaderViewFunc_sectionsAboutToBeRemoved, METH_VARARGS},
    {"sectionsHidden", (PyCFunction)Sbk_QHeaderViewFunc_sectionsHidden, METH_NOARGS},
    {"sectionsInserted", (PyCFunction)Sbk_QHeaderViewFunc_sectionsInserted, METH_VARARGS},
    {"sectionsMoved", (PyCFunction)Sbk_QHeaderViewFunc_sectionsMoved, METH_NOARGS},
    {"setCascadingSectionResizes", (PyCFunction)Sbk_QHeaderViewFunc_setCascadingSectionResizes, METH_O},
    {"setClickable", (PyCFunction)Sbk_QHeaderViewFunc_setClickable, METH_O},
    {"setDefaultAlignment", (PyCFunction)Sbk_QHeaderViewFunc_setDefaultAlignment, METH_O},
    {"setDefaultSectionSize", (PyCFunction)Sbk_QHeaderViewFunc_setDefaultSectionSize, METH_O},
    {"setHighlightSections", (PyCFunction)Sbk_QHeaderViewFunc_setHighlightSections, METH_O},
    {"setMinimumSectionSize", (PyCFunction)Sbk_QHeaderViewFunc_setMinimumSectionSize, METH_O},
    {"setModel", (PyCFunction)Sbk_QHeaderViewFunc_setModel, METH_O},
    {"setMovable", (PyCFunction)Sbk_QHeaderViewFunc_setMovable, METH_O},
    {"setOffset", (PyCFunction)Sbk_QHeaderViewFunc_setOffset, METH_O},
    {"setOffsetToLastSection", (PyCFunction)Sbk_QHeaderViewFunc_setOffsetToLastSection, METH_NOARGS},
    {"setOffsetToSectionPosition", (PyCFunction)Sbk_QHeaderViewFunc_setOffsetToSectionPosition, METH_O},
    {"setResizeMode", (PyCFunction)Sbk_QHeaderViewFunc_setResizeMode, METH_VARARGS},
    {"setSectionHidden", (PyCFunction)Sbk_QHeaderViewFunc_setSectionHidden, METH_VARARGS},
    {"setSelection", (PyCFunction)Sbk_QHeaderViewFunc_setSelection, METH_VARARGS},
    {"setSortIndicator", (PyCFunction)Sbk_QHeaderViewFunc_setSortIndicator, METH_VARARGS},
    {"setSortIndicatorShown", (PyCFunction)Sbk_QHeaderViewFunc_setSortIndicatorShown, METH_O},
    {"setStretchLastSection", (PyCFunction)Sbk_QHeaderViewFunc_setStretchLastSection, METH_O},
    {"showSection", (PyCFunction)Sbk_QHeaderViewFunc_showSection, METH_O},
    {"sizeHint", (PyCFunction)Sbk_QHeaderViewFunc_sizeHint, METH_NOARGS},
    {"sortIndicatorOrder", (PyCFunction)Sbk_QHeaderViewFunc_sortIndicatorOrder, METH_NOARGS},
    {"sortIndicatorSection", (PyCFunction)Sbk_QHeaderViewFunc_sortIndicatorSection, METH_NOARGS},
    {"stretchLastSection", (PyCFunction)Sbk_QHeaderViewFunc_stretchLastSection, METH_NOARGS},
    {"stretchSectionCount", (PyCFunction)Sbk_QHeaderViewFunc_stretchSectionCount, METH_NOARGS},
    {"swapSections", (PyCFunction)Sbk_QHeaderViewFunc_swapSections, METH_VARARGS},
    {"updateGeometries", (PyCFunction)Sbk_QHeaderViewFunc_updateGeometries, METH_NOARGS},
    {"updateSection", (PyCFunction)Sbk_QHeaderViewFunc_updateSection, METH_O},
    {"verticalOffset", (PyCFunction)Sbk_QHeaderViewFunc_verticalOffset, METH_NOARGS},
    {"viewportEvent", (PyCFunction)Sbk_QHeaderViewFunc_viewportEvent, METH_O},
    {"visualIndex", (PyCFunction)Sbk_QHeaderViewFunc_visualIndex, METH_O},
    {"visualIndexAt", (PyCFunction)Sbk_QHeaderViewFunc_visualIndexAt, METH_O},
    {"visualRect", (PyCFunction)Sbk_QHeaderViewFunc_visualRect, METH_O},
    {"visualRegionForSelection", (PyCFunction)Sbk_QHeaderViewFunc_visualRegionForSelection, METH_O},

    {0} // Sentinel
};

} // extern "C"

static void* Sbk_QHeaderViewSpecialCastFunction(void* obj, SbkObjectType* desiredType)
{
    QHeaderView* me = reinterpret_cast<QHeaderView*>(obj);
    if (desiredType == reinterpret_cast<SbkObjectType*>(SbkPySide_QtGuiTypes[SBK_QABSTRACTITEMVIEW_IDX]))
        return static_cast<QAbstractItemView*>(me);
    else if (desiredType == reinterpret_cast<SbkObjectType*>(SbkPySide_QtGuiTypes[SBK_QABSTRACTSCROLLAREA_IDX]))
        return static_cast<QAbstractScrollArea*>(me);
    else if (desiredType == reinterpret_cast<SbkObjectType*>(SbkPySide_QtGuiTypes[SBK_QFRAME_IDX]))
        return static_cast<QFrame*>(me);
    else if (desiredType == reinterpret_cast<SbkObjectType*>(SbkPySide_QtGuiTypes[SBK_QWIDGET_IDX]))
        return static_cast<QWidget*>(me);
    else if (desiredType == reinterpret_cast<SbkObjectType*>(SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX]))
        return static_cast<QObject*>(me);
    else if (desiredType == reinterpret_cast<SbkObjectType*>(SbkPySide_QtGuiTypes[SBK_QPAINTDEVICE_IDX]))
        return static_cast<QPaintDevice*>(me);
    return me;
}


// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QHeaderView_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QHeaderView",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QHeaderView_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QHeaderView_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern

static SbkObjectType* Sbk_QHeaderView_typeDiscovery(void* cptr, SbkObjectType* instanceType)
{
    if (instanceType == reinterpret_cast<SbkObjectType*>(Shiboken::SbkType<QObject >()) && dynamic_cast<QHeaderView*>(reinterpret_cast<QObject*>(cptr)))
        return &Sbk_QHeaderView_Type;
    if (instanceType == reinterpret_cast<SbkObjectType*>(Shiboken::SbkType<QPaintDevice >()) && dynamic_cast<QHeaderView*>(reinterpret_cast<QPaintDevice*>(cptr)))
        return &Sbk_QHeaderView_Type;
    return 0;
}


void init_QHeaderView(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QHEADERVIEW_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QHeaderView_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QHeaderView_Type);
    Shiboken::ObjectType::setSubTypeInitHook(&Sbk_QHeaderView_Type, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(&Sbk_QHeaderView_Type, &QHeaderView::staticMetaObject);    Sbk_QHeaderView_Type.super.ht_type.tp_base = SbkPySide_QtGuiTypes[SBK_QABSTRACTITEMVIEW_IDX];
    MultipleInheritanceInitFunction func;
    func = Shiboken::ObjectType::getMultipleIheritanceFunction(reinterpret_cast<SbkObjectType*>(SbkPySide_QtGuiTypes[SBK_QWIDGET_IDX]));
    Shiboken::ObjectType::setMultipleIheritanceFunction(&Sbk_QHeaderView_Type, func);
    Shiboken::ObjectType::setCastFunction(&Sbk_QHeaderView_Type, &Sbk_QHeaderViewSpecialCastFunction);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QHeaderView_Type, &Shiboken::callCppDestructor<QHeaderView >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QHeaderView_Type) < 0)
        return;

    // Fill type discovery information
    Shiboken::ObjectType::setTypeDiscoveryFunction(&Sbk_QHeaderView_Type, &Sbk_QHeaderView_typeDiscovery);
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkObjectType*>(SbkPySide_QtGuiTypes[SBK_QABSTRACTITEMVIEW_IDX]), &Sbk_QHeaderView_Type);

    Shiboken::ObjectType::setOriginalName(&Sbk_QHeaderView_Type, "QHeaderView*");
    PyModule_AddObject(module, "QHeaderView",
        ((PyObject*)&Sbk_QHeaderView_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: ResizeMode
    PyTypeObject* SbkPySide_QtGui_QHeaderView_ResizeMode = Shiboken::Enum::newType("ResizeMode");
    SbkPySide_QtGuiTypes[SBK_QHEADERVIEW_RESIZEMODE_IDX] = SbkPySide_QtGui_QHeaderView_ResizeMode;
    if (PyType_Ready(SbkPySide_QtGui_QHeaderView_ResizeMode) < 0)
        return;
    PyDict_SetItemString(Sbk_QHeaderView_Type.super.ht_type.tp_dict,
            "ResizeMode",((PyObject*)SbkPySide_QtGui_QHeaderView_ResizeMode));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QHeaderView_ResizeMode,(long) QHeaderView::Interactive, "Interactive");
    PyDict_SetItemString(Sbk_QHeaderView_Type.super.ht_type.tp_dict,"Interactive", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QHeaderView_ResizeMode->tp_dict,"Interactive", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QHeaderView_ResizeMode,(long) QHeaderView::Stretch, "Stretch");
    PyDict_SetItemString(Sbk_QHeaderView_Type.super.ht_type.tp_dict,"Stretch", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QHeaderView_ResizeMode->tp_dict,"Stretch", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QHeaderView_ResizeMode,(long) QHeaderView::Fixed, "Fixed");
    PyDict_SetItemString(Sbk_QHeaderView_Type.super.ht_type.tp_dict,"Fixed", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QHeaderView_ResizeMode->tp_dict,"Fixed", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QHeaderView_ResizeMode,(long) QHeaderView::ResizeToContents, "ResizeToContents");
    PyDict_SetItemString(Sbk_QHeaderView_Type.super.ht_type.tp_dict,"ResizeToContents", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QHeaderView_ResizeMode->tp_dict,"ResizeToContents", enumItem);
    Py_DECREF(enumItem);
    enumItem = Shiboken::Enum::newItem(SbkPySide_QtGui_QHeaderView_ResizeMode,(long) QHeaderView::Custom, "Custom");
    PyDict_SetItemString(Sbk_QHeaderView_Type.super.ht_type.tp_dict,"Custom", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtGui_QHeaderView_ResizeMode->tp_dict,"Custom", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QHeaderView::ResizeMode");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::ResizeMode");
    // end of enum ResizeMode

    // Initialize signals
    PySideSignal* signal_item;

    signal_item = PySide::Signal::newObject("sectionMoved", "int,int,int", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QHeaderView_Type, "sectionMoved", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("sectionAutoResize", "int,QHeaderView::ResizeMode", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QHeaderView_Type, "sectionAutoResize", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("sectionCountChanged", "int,int", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QHeaderView_Type, "sectionCountChanged", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("sectionResized", "int,int,int", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QHeaderView_Type, "sectionResized", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("sectionClicked", "int", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QHeaderView_Type, "sectionClicked", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("sectionHandleDoubleClicked", "int", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QHeaderView_Type, "sectionHandleDoubleClicked", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("sortIndicatorChanged", "int,SortOrder", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QHeaderView_Type, "sortIndicatorChanged", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("sectionEntered", "int", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QHeaderView_Type, "sectionEntered", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("sectionDoubleClicked", "int", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QHeaderView_Type, "sectionDoubleClicked", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("geometriesChanged", "void", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QHeaderView_Type, "geometriesChanged", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("sectionPressed", "int", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QHeaderView_Type, "sectionPressed", signal_item);
    Py_DECREF((PyObject*) signal_item);


    Shiboken::TypeResolver::createObjectTypeResolver<QHeaderView >("QHeaderView*");
    Shiboken::TypeResolver::createObjectTypeResolver<QHeaderView >(typeid(QHeaderView).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QHeaderView >(typeid(QHeaderViewWrapper).name());
    PySide::initQtMetaType<QHeaderView* >();
}

