/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <set>
#include "pyside_qtgui_python.h"

#include "qtablewidget_wrapper.h"

// Extra includes
#include <QList>
#include <QStringList>
#include <qabstractitemdelegate.h>
#include <qabstractitemmodel.h>
#include <qaction.h>
#include <qbitmap.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qcursor.h>
#include <qevent.h>
#include <qfont.h>
#include <qfontinfo.h>
#include <qfontmetrics.h>
#include <qgraphicseffect.h>
#include <qgraphicsproxywidget.h>
#include <qheaderview.h>
#include <qicon.h>
#include <qinputcontext.h>
#include <qitemselectionmodel.h>
#include <qkeysequence.h>
#include <qlayout.h>
#include <qlocale.h>
#include <qmargins.h>
#include <qmimedata.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpaintdevice.h>
#include <qpaintengine.h>
#include <qpainter.h>
#include <qpalette.h>
#include <qpoint.h>
#include <qrect.h>
#include <qregion.h>
#include <qscrollbar.h>
#include <qsize.h>
#include <qsizepolicy.h>
#include <qstyle.h>
#include <qstyleoption.h>
#include <qtablewidget.h>
#include <qwidget.h>
#include <qx11info_x11.h>


// Native ---------------------------------------------------------

QTableWidgetWrapper::QTableWidgetWrapper(QWidget * parent) : QTableWidget(parent) {
    // ... middle
}

QTableWidgetWrapper::QTableWidgetWrapper(int rows, int columns, QWidget * parent) : QTableWidget(rows, columns, parent) {
    // ... middle
}

void QTableWidgetWrapper::actionEvent(QActionEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "actionEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::actionEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QActionEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QTableWidgetWrapper::changeEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "changeEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QFrame::changeEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QTableWidgetWrapper::childEvent(QChildEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "childEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::childEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QChildEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QTableWidgetWrapper::closeEditor(QWidget * editor, QAbstractItemDelegate::EndEditHint hint)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "closeEditor"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractItemView::closeEditor(editor, hint);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QWidget * >::toPython(editor),
        Shiboken::Converter< ::QAbstractItemDelegate::EndEditHint >::toPython(hint)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QTableWidgetWrapper::closeEvent(QCloseEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "closeEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::closeEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QCloseEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QTableWidgetWrapper::commitData(QWidget * editor)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "commitData"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractItemView::commitData(editor);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QWidget * >::toPython(editor)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QTableWidgetWrapper::connectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "connectNotify"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QTableWidgetWrapper::contextMenuEvent(QContextMenuEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "contextMenuEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractScrollArea::contextMenuEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QContextMenuEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QTableWidgetWrapper::currentChanged(const QModelIndex & current, const QModelIndex & previous)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "currentChanged"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QTableView::currentChanged(current, previous);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QModelIndex >::toPython(current),
        Shiboken::Converter< ::QModelIndex >::toPython(previous)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QTableWidgetWrapper::customEvent(QEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "customEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::customEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QTableWidgetWrapper::dataChanged(const QModelIndex & topLeft, const QModelIndex & bottomRight)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "dataChanged"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractItemView::dataChanged(topLeft, bottomRight);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QModelIndex >::toPython(topLeft),
        Shiboken::Converter< ::QModelIndex >::toPython(bottomRight)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

int QTableWidgetWrapper::devType() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "devType"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::devType();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QTableWidget.devType", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter< int >::toCpp(pyResult));
    return cppResult;
}

void QTableWidgetWrapper::disconnectNotify(const char * signal)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "disconnectNotify"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< const char * >::toPython(signal)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QTableWidgetWrapper::doItemsLayout()
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "doItemsLayout"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractItemView::doItemsLayout();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QTableWidgetWrapper::dragEnterEvent(QDragEnterEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "dragEnterEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractItemView::dragEnterEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QDragEnterEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QTableWidgetWrapper::dragLeaveEvent(QDragLeaveEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "dragLeaveEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractItemView::dragLeaveEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QDragLeaveEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QTableWidgetWrapper::dragMoveEvent(QDragMoveEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "dragMoveEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractItemView::dragMoveEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QDragMoveEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QTableWidgetWrapper::dropEvent(QDropEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "dropEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QTableWidget::dropEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QDropEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

bool QTableWidgetWrapper::dropMimeData(int row, int column, const QMimeData * data, Qt::DropAction action)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "dropMimeData"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QTableWidget::dropMimeData(row, column, data, action);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(iiNN)",
        row,
        column,
        Shiboken::Converter< ::QMimeData * >::toPython(data),
        Shiboken::Converter< ::Qt::DropAction >::toPython(action)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QTableWidget.dropMimeData", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    return cppResult;
}

bool QTableWidgetWrapper::edit(const QModelIndex & index, QAbstractItemView::EditTrigger trigger, QEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "edit"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractItemView::edit(index, trigger, event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NNN)",
        Shiboken::Converter< ::QModelIndex >::toPython(index),
        Shiboken::Converter< ::QAbstractItemView::EditTrigger >::toPython(trigger),
        Shiboken::Converter< ::QEvent * >::toPython(event)
    ));
    bool invalidadeArg3 = PyTuple_GET_ITEM(pyargs, 2)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QTableWidget.edit", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    if (invalidadeArg3)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 2));
    return cppResult;
}

void QTableWidgetWrapper::editorDestroyed(QObject * editor)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "editorDestroyed"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractItemView::editorDestroyed(editor);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QObject * >::toPython(editor)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QTableWidgetWrapper::enterEvent(QEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "enterEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::enterEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

bool QTableWidgetWrapper::event(QEvent * e)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "event"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QTableWidget::event(e);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(e)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QTableWidget.event", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    return cppResult;
}

bool QTableWidgetWrapper::eventFilter(QObject * arg__1, QEvent * arg__2)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "eventFilter"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QObject::eventFilter(arg__1, arg__2);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QObject * >::toPython(arg__1),
        Shiboken::Converter< ::QEvent * >::toPython(arg__2)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QTableWidget.eventFilter", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    return cppResult;
}

void QTableWidgetWrapper::focusInEvent(QFocusEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "focusInEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractItemView::focusInEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QFocusEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

bool QTableWidgetWrapper::focusNextPrevChild(bool next)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "focusNextPrevChild"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractItemView::focusNextPrevChild(next);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< bool >::toPython(next)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QTableWidget.focusNextPrevChild", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    return cppResult;
}

void QTableWidgetWrapper::focusOutEvent(QFocusEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "focusOutEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractItemView::focusOutEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QFocusEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

int QTableWidgetWrapper::heightForWidth(int arg__1) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "heightForWidth"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::heightForWidth(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(i)",
        arg__1
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QTableWidget.heightForWidth", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter< int >::toCpp(pyResult));
    return cppResult;
}

void QTableWidgetWrapper::hideEvent(QHideEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "hideEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::hideEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QHideEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

int QTableWidgetWrapper::horizontalOffset() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "horizontalOffset"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QTableView::horizontalOffset();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QTableWidget.horizontalOffset", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter< int >::toCpp(pyResult));
    return cppResult;
}

void QTableWidgetWrapper::horizontalScrollbarAction(int action)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "horizontalScrollbarAction"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QTableView::horizontalScrollbarAction(action);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(i)",
        action
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QTableWidgetWrapper::horizontalScrollbarValueChanged(int value)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "horizontalScrollbarValueChanged"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractItemView::horizontalScrollbarValueChanged(value);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(i)",
        value
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

QModelIndex QTableWidgetWrapper::indexAt(const QPoint & p) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "indexAt"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QTableView::indexAt(p);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QPoint >::toPython(p)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QModelIndex();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QModelIndex >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QTableWidget.indexAt", Shiboken::SbkType<QModelIndex >()->tp_name, pyResult->ob_type->tp_name);
        return QModelIndex();
    }
    QModelIndex cppResult(Shiboken::Converter< ::QModelIndex >::toCpp(pyResult));
    return cppResult;
}

void QTableWidgetWrapper::inputMethodEvent(QInputMethodEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "inputMethodEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractItemView::inputMethodEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QInputMethodEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

QVariant QTableWidgetWrapper::inputMethodQuery(Qt::InputMethodQuery query) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "inputMethodQuery"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractItemView::inputMethodQuery(query);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::Qt::InputMethodQuery >::toPython(query)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QVariant(0);
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< QVariant >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QTableWidget.inputMethodQuery", "QVariant", pyResult->ob_type->tp_name);
        return QVariant(0);
    }
    QVariant cppResult(Shiboken::Converter< QVariant >::toCpp(pyResult));
    return cppResult;
}

bool QTableWidgetWrapper::isIndexHidden(const QModelIndex & index) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "isIndexHidden"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QTableView::isIndexHidden(index);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QModelIndex >::toPython(index)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QTableWidget.isIndexHidden", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    return cppResult;
}

void QTableWidgetWrapper::keyPressEvent(QKeyEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "keyPressEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractItemView::keyPressEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QKeyEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QTableWidgetWrapper::keyReleaseEvent(QKeyEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "keyReleaseEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::keyReleaseEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QKeyEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QTableWidgetWrapper::keyboardSearch(const QString & search)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "keyboardSearch"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractItemView::keyboardSearch(search);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< QString >::toPython(search)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QTableWidgetWrapper::languageChange()
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "languageChange"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::languageChange();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QTableWidgetWrapper::leaveEvent(QEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "leaveEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::leaveEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

int QTableWidgetWrapper::metric(QPaintDevice::PaintDeviceMetric arg__1) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "metric"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::metric(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QPaintDevice::PaintDeviceMetric >::toPython(arg__1)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QTableWidget.metric", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter< int >::toCpp(pyResult));
    return cppResult;
}

QMimeData * QTableWidgetWrapper::mimeData(const QList<QTableWidgetItem * > items) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "mimeData"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QTableWidget::mimeData(items);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QList<QTableWidgetItem * > >::toPython(items)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return 0;
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QMimeData * >::isConvertible(pyResult);
    typeIsValid = typeIsValid || (pyResult == Py_None);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QTableWidget.mimeData", Shiboken::SbkType<QMimeData >()->tp_name, pyResult->ob_type->tp_name);
        return 0;
    }
    QMimeData * cppResult(Shiboken::Converter< ::QMimeData * >::toCpp(pyResult));
    return cppResult;
}

QStringList QTableWidgetWrapper::mimeTypes() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "mimeTypes"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QTableWidget::mimeTypes();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QStringList();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QStringList >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QTableWidget.mimeTypes", "list", pyResult->ob_type->tp_name);
        return QStringList();
    }
    QStringList cppResult(Shiboken::Converter< ::QStringList >::toCpp(pyResult));
    return cppResult;
}

QSize QTableWidgetWrapper::minimumSizeHint() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "minimumSizeHint"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractScrollArea::minimumSizeHint();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QSize();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QSize >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QTableWidget.minimumSizeHint", Shiboken::SbkType<QSize >()->tp_name, pyResult->ob_type->tp_name);
        return QSize();
    }
    QSize cppResult(Shiboken::Converter< ::QSize >::toCpp(pyResult));
    return cppResult;
}

void QTableWidgetWrapper::mouseDoubleClickEvent(QMouseEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "mouseDoubleClickEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractItemView::mouseDoubleClickEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QMouseEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QTableWidgetWrapper::mouseMoveEvent(QMouseEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "mouseMoveEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractItemView::mouseMoveEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QMouseEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QTableWidgetWrapper::mousePressEvent(QMouseEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "mousePressEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractItemView::mousePressEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QMouseEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QTableWidgetWrapper::mouseReleaseEvent(QMouseEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "mouseReleaseEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractItemView::mouseReleaseEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QMouseEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QTableWidgetWrapper::moveEvent(QMoveEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "moveEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::moveEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QMoveEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

QPaintEngine * QTableWidgetWrapper::paintEngine() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "paintEngine"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::paintEngine();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return 0;
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QPaintEngine * >::isConvertible(pyResult);
    typeIsValid = typeIsValid || (pyResult == Py_None);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QTableWidget.paintEngine", Shiboken::SbkType<QPaintEngine >()->tp_name, pyResult->ob_type->tp_name);
        return 0;
    }
    QPaintEngine * cppResult(Shiboken::Converter< ::QPaintEngine * >::toCpp(pyResult));
    return cppResult;
}

void QTableWidgetWrapper::paintEvent(QPaintEvent * e)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "paintEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QTableView::paintEvent(e);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QPaintEvent * >::toPython(e)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QTableWidgetWrapper::reset()
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "reset"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractItemView::reset();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QTableWidgetWrapper::resizeEvent(QResizeEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "resizeEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractItemView::resizeEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QResizeEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QTableWidgetWrapper::rowsAboutToBeRemoved(const QModelIndex & parent, int start, int end)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "rowsAboutToBeRemoved"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractItemView::rowsAboutToBeRemoved(parent, start, end);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(Nii)",
        Shiboken::Converter< ::QModelIndex >::toPython(parent),
        start,
        end
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QTableWidgetWrapper::rowsInserted(const QModelIndex & parent, int start, int end)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "rowsInserted"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractItemView::rowsInserted(parent, start, end);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(Nii)",
        Shiboken::Converter< ::QModelIndex >::toPython(parent),
        start,
        end
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QTableWidgetWrapper::scrollContentsBy(int dx, int dy)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "scrollContentsBy"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QTableView::scrollContentsBy(dx, dy);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(ii)",
        dx,
        dy
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QTableWidgetWrapper::scrollTo(const QModelIndex & index, QAbstractItemView::ScrollHint hint)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "scrollTo"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QTableView::scrollTo(index, hint);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QModelIndex >::toPython(index),
        Shiboken::Converter< ::QAbstractItemView::ScrollHint >::toPython(hint)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QTableWidgetWrapper::selectAll()
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "selectAll"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractItemView::selectAll();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

QList<QModelIndex > QTableWidgetWrapper::selectedIndexes() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "selectedIndexes"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QTableView::selectedIndexes();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QList<QModelIndex >();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QList<QModelIndex > >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QTableWidget.selectedIndexes", "list", pyResult->ob_type->tp_name);
        return QList<QModelIndex >();
    }
    QList<QModelIndex > cppResult(Shiboken::Converter< ::QList<QModelIndex > >::toCpp(pyResult));
    return cppResult;
}

void QTableWidgetWrapper::selectionChanged(const QItemSelection & selected, const QItemSelection & deselected)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "selectionChanged"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QTableView::selectionChanged(selected, deselected);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QItemSelection >::toPython(selected),
        Shiboken::Converter< ::QItemSelection >::toPython(deselected)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

QFlags<QItemSelectionModel::SelectionFlag> QTableWidgetWrapper::selectionCommand(const QModelIndex & index, const QEvent * event) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "selectionCommand"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractItemView::selectionCommand(index, event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QModelIndex >::toPython(index),
        Shiboken::Converter< ::QEvent * >::toPython(event)
    ));
    bool invalidadeArg2 = PyTuple_GET_ITEM(pyargs, 1)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QFlags<QItemSelectionModel::SelectionFlag>();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QFlags<QItemSelectionModel::SelectionFlag> >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QTableWidget.selectionCommand", Shiboken::SbkType<QFlags<QItemSelectionModel::SelectionFlag> >()->tp_name, pyResult->ob_type->tp_name);
        return QFlags<QItemSelectionModel::SelectionFlag>();
    }
    QFlags<QItemSelectionModel::SelectionFlag> cppResult(Shiboken::Converter< ::QFlags<QItemSelectionModel::SelectionFlag> >::toCpp(pyResult));
    if (invalidadeArg2)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 1));
    return cppResult;
}

void QTableWidgetWrapper::setRootIndex(const QModelIndex & index)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "setRootIndex"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QTableView::setRootIndex(index);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QModelIndex >::toPython(index)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QTableWidgetWrapper::setSelection(const QRect & rect, QFlags<QItemSelectionModel::SelectionFlag> command)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "setSelection"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QTableView::setSelection(rect, command);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QRect >::toPython(rect),
        Shiboken::Converter< ::QFlags<QItemSelectionModel::SelectionFlag> >::toPython(command)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QTableWidgetWrapper::setSelectionModel(QItemSelectionModel * selectionModel)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "setSelectionModel"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QTableView::setSelectionModel(selectionModel);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QItemSelectionModel * >::toPython(selectionModel)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QTableWidgetWrapper::setVisible(bool visible)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "setVisible"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::setVisible(visible);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< bool >::toPython(visible)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QTableWidgetWrapper::showEvent(QShowEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "showEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::showEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QShowEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

QSize QTableWidgetWrapper::sizeHint() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "sizeHint"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractScrollArea::sizeHint();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QSize();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QSize >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QTableWidget.sizeHint", Shiboken::SbkType<QSize >()->tp_name, pyResult->ob_type->tp_name);
        return QSize();
    }
    QSize cppResult(Shiboken::Converter< ::QSize >::toCpp(pyResult));
    return cppResult;
}

int QTableWidgetWrapper::sizeHintForColumn(int column) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "sizeHintForColumn"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QTableView::sizeHintForColumn(column);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(i)",
        column
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QTableWidget.sizeHintForColumn", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter< int >::toCpp(pyResult));
    return cppResult;
}

int QTableWidgetWrapper::sizeHintForRow(int row) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "sizeHintForRow"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QTableView::sizeHintForRow(row);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(i)",
        row
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QTableWidget.sizeHintForRow", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter< int >::toCpp(pyResult));
    return cppResult;
}

void QTableWidgetWrapper::startDrag(QFlags<Qt::DropAction> supportedActions)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "startDrag"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractItemView::startDrag(supportedActions);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QFlags<Qt::DropAction> >::toPython(supportedActions)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

QFlags<Qt::DropAction> QTableWidgetWrapper::supportedDropActions() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "supportedDropActions"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QTableWidget::supportedDropActions();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QFlags<Qt::DropAction>();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QFlags<Qt::DropAction> >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QTableWidget.supportedDropActions", Shiboken::SbkType<QFlags<Qt::DropAction> >()->tp_name, pyResult->ob_type->tp_name);
        return QFlags<Qt::DropAction>();
    }
    QFlags<Qt::DropAction> cppResult(Shiboken::Converter< ::QFlags<Qt::DropAction> >::toCpp(pyResult));
    return cppResult;
}

void QTableWidgetWrapper::tabletEvent(QTabletEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "tabletEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QWidget::tabletEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QTabletEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

void QTableWidgetWrapper::timerEvent(QTimerEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "timerEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QTableView::timerEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QTimerEvent * >::toPython(event)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QTableWidgetWrapper::updateEditorData()
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "updateEditorData"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractItemView::updateEditorData();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QTableWidgetWrapper::updateEditorGeometries()
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "updateEditorGeometries"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractItemView::updateEditorGeometries();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QTableWidgetWrapper::updateGeometries()
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "updateGeometries"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QTableView::updateGeometries();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

int QTableWidgetWrapper::verticalOffset() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "verticalOffset"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QTableView::verticalOffset();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return int(0);
    }
    // Check return type
    bool typeIsValid = PyInt_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QTableWidget.verticalOffset", "int", pyResult->ob_type->tp_name);
        return int(0);
    }
    int cppResult(Shiboken::Converter< int >::toCpp(pyResult));
    return cppResult;
}

void QTableWidgetWrapper::verticalScrollbarAction(int action)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "verticalScrollbarAction"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QTableView::verticalScrollbarAction(action);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(i)",
        action
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QTableWidgetWrapper::verticalScrollbarValueChanged(int value)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "verticalScrollbarValueChanged"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractItemView::verticalScrollbarValueChanged(value);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(i)",
        value
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

QStyleOptionViewItem QTableWidgetWrapper::viewOptions() const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "viewOptions"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QTableView::viewOptions();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QStyleOptionViewItem();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QStyleOptionViewItem >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QTableWidget.viewOptions", Shiboken::SbkType<QStyleOptionViewItem >()->tp_name, pyResult->ob_type->tp_name);
        return QStyleOptionViewItem();
    }
    QStyleOptionViewItem cppResult(Shiboken::Converter< ::QStyleOptionViewItem >::toCpp(pyResult));
    return cppResult;
}

bool QTableWidgetWrapper::viewportEvent(QEvent * event)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "viewportEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractItemView::viewportEvent(event);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QEvent * >::toPython(event)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QTableWidget.viewportEvent", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
    return cppResult;
}

QRect QTableWidgetWrapper::visualRect(const QModelIndex & index) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "visualRect"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QTableView::visualRect(index);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QModelIndex >::toPython(index)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QRect();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QRect >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QTableWidget.visualRect", Shiboken::SbkType<QRect >()->tp_name, pyResult->ob_type->tp_name);
        return QRect();
    }
    QRect cppResult(Shiboken::Converter< ::QRect >::toCpp(pyResult));
    return cppResult;
}

QRegion QTableWidgetWrapper::visualRegionForSelection(const QItemSelection & selection) const
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "visualRegionForSelection"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QTableView::visualRegionForSelection(selection);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QItemSelection >::toPython(selection)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QRegion();
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< ::QRegion >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QTableWidget.visualRegionForSelection", Shiboken::SbkType<QRegion >()->tp_name, pyResult->ob_type->tp_name);
        return QRegion();
    }
    QRegion cppResult(Shiboken::Converter< ::QRegion >::toCpp(pyResult));
    return cppResult;
}

void QTableWidgetWrapper::wheelEvent(QWheelEvent * arg__1)
{
    Shiboken::GilState gil;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "wheelEvent"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QAbstractScrollArea::wheelEvent(arg__1);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QWheelEvent * >::toPython(arg__1)
    ));
    bool invalidadeArg1 = PyTuple_GET_ITEM(pyargs, 0)->ob_refcnt == 1;

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
    if (invalidadeArg1)
        Shiboken::Object::invalidate(PyTuple_GET_ITEM(pyargs, 0));
}

const QMetaObject* QTableWidgetWrapper::metaObject() const
{
    SbkObject* pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    return reinterpret_cast<QMetaObject*>(Shiboken::Object::getTypeUserData(pySelf));
}

int QTableWidgetWrapper::qt_metacall(QMetaObject::Call call, int id, void** args)
{
    int result = QTableWidget::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

QTableWidgetWrapper::~QTableWidgetWrapper()
{
    SbkObject* wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QTableWidget_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QTableWidget >()))
        return -1;

    QTableWidgetWrapper* cptr = 0;
    int overloadId = -1;
    const char* argNames[] = {"parent"};
    const QMetaObject* metaObject;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_ParseTuple(args, "|OOO:QTableWidget", &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return -1;

    // Overloaded function decisor
    // 0: QTableWidget(QWidget*)
    // 1: QTableWidget(int,int,QWidget*)
    if (numArgs == 0) {
        overloadId = 0; // QTableWidget(QWidget*)
    } else if (numArgs >= 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 1; // QTableWidget(int,int,QWidget*)
        } else if (Shiboken::Converter< ::QWidget * >::isConvertible(pyargs[2])) {
            overloadId = 1; // QTableWidget(int,int,QWidget*)
        }
    } else if (Shiboken::Converter< ::QWidget * >::isConvertible(pyargs[0])) {
        overloadId = 0; // QTableWidget(QWidget*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTableWidget_Init_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // QTableWidget(QWidget*)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "parent");
                    if (value) {
                        if (pyargs[0])
                            errorArgName = "parent";
                        else if (Shiboken::Converter< ::QWidget * >::isConvertible(value))
                            pyargs[0] = value;
else
                            goto Sbk_QTableWidget_Init_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QTableWidget(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return -1;
                QWidget * cppArg0 = pyargs[0] ? Shiboken::Converter<QWidget * >::toCpp(pyargs[0]) : 0;

                if(!PyErr_Occurred()) {
                    // QTableWidget(QWidget*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QTableWidgetWrapper(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    Shiboken::Object::setParent(pyargs[0], self);
                }
                break;
            }
            case 1: // QTableWidget(int,int,QWidget*)
            {
                if (kwds) {
                    const char* errorArgName = 0;
                    PyObject* value = PyDict_GetItemString(kwds, "parent");
                    if (value) {
                        if (pyargs[2])
                            errorArgName = "parent";
                        else if (Shiboken::Converter< ::QWidget * >::isConvertible(value))
                            pyargs[2] = value;
else
                            goto Sbk_QTableWidget_Init_TypeError;
                    }
                    if (errorArgName) {
                        PyErr_Format(PyExc_TypeError, "PySide.QtGui.QTableWidget(): got multiple values for keyword argument '%s'", errorArgName);
                        return -1;
                    }
                }
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                if (!Shiboken::Object::isValid(pyargs[2]))
                    return -1;
                QWidget * cppArg2 = pyargs[2] ? Shiboken::Converter<QWidget * >::toCpp(pyargs[2]) : 0;

                if(!PyErr_Occurred()) {
                    // QTableWidget(int,int,QWidget*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cptr = new QTableWidgetWrapper(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    Shiboken::Object::setParent(pyargs[2], self);
                }
                break;
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QTableWidget >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QTableWidget_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    metaObject = cptr->metaObject(); // <- init python qt properties
    if (kwds && !PySide::fillQtProperties(self, metaObject, kwds, argNames, 1))
        return -1;


    return 1;

    Sbk_QTableWidget_Init_TypeError:
        const char* overloads[] = {"PySide.QtGui.QWidget = None", "int, int, PySide.QtGui.QWidget = None", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTableWidget", overloads);
        return -1;
}

static PyObject* Sbk_QTableWidgetFunc_cellWidget(PyObject* self, PyObject* args)
{
    QTableWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTableWidget* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "cellWidget", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: cellWidget(int,int)const
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // cellWidget(int,int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTableWidgetFunc_cellWidget_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // cellWidget(int,int)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QWidget * cppResult = cppSelf->cellWidget(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QWidget * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTableWidgetFunc_cellWidget_TypeError:
        const char* overloads[] = {"int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTableWidget.cellWidget", overloads);
        return 0;
}

static PyObject* Sbk_QTableWidgetFunc_clear(PyObject* self)
{
    QTableWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTableWidget* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // clear()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->clear();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QTableWidgetFunc_clearContents(PyObject* self)
{
    QTableWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTableWidget* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // clearContents()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->clearContents();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QTableWidgetFunc_closePersistentEditor(PyObject* self, PyObject* arg)
{
    QTableWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTableWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: closePersistentEditor(QTableWidgetItem*)
    if (Shiboken::Converter< ::QTableWidgetItem * >::isConvertible(arg)) {
        overloadId = 0; // closePersistentEditor(QTableWidgetItem*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTableWidgetFunc_closePersistentEditor_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QTableWidgetItem * cppArg0 = Shiboken::Converter<QTableWidgetItem * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // closePersistentEditor(QTableWidgetItem*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->closePersistentEditor(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTableWidgetFunc_closePersistentEditor_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTableWidgetItem", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTableWidget.closePersistentEditor", overloads);
        return 0;
}

static PyObject* Sbk_QTableWidgetFunc_column(PyObject* self, PyObject* arg)
{
    QTableWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTableWidget* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: column(const QTableWidgetItem*)const
    if (Shiboken::Converter< ::QTableWidgetItem * >::isConvertible(arg)) {
        overloadId = 0; // column(const QTableWidgetItem*)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTableWidgetFunc_column_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QTableWidgetItem * cppArg0 = Shiboken::Converter<QTableWidgetItem * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // column(const QTableWidgetItem*)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->column(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTableWidgetFunc_column_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTableWidgetItem", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTableWidget.column", overloads);
        return 0;
}

static PyObject* Sbk_QTableWidgetFunc_columnCount(PyObject* self)
{
    QTableWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTableWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // columnCount()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->columnCount();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTableWidgetFunc_currentColumn(PyObject* self)
{
    QTableWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTableWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // currentColumn()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->currentColumn();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTableWidgetFunc_currentItem(PyObject* self)
{
    QTableWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTableWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // currentItem()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QTableWidgetItem * cppResult = cppSelf->currentItem();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QTableWidgetItem * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTableWidgetFunc_currentRow(PyObject* self)
{
    QTableWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTableWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // currentRow()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->currentRow();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTableWidgetFunc_dropEvent(PyObject* self, PyObject* arg)
{
    QTableWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTableWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: dropEvent(QDropEvent*)
    if (Shiboken::Converter< ::QDropEvent * >::isConvertible(arg)) {
        overloadId = 0; // dropEvent(QDropEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTableWidgetFunc_dropEvent_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QDropEvent * cppArg0 = Shiboken::Converter<QDropEvent * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // dropEvent(QDropEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QTableWidget::dropEvent(cppArg0):cppSelf->dropEvent(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTableWidgetFunc_dropEvent_TypeError:
        const char* overloads[] = {"PySide.QtGui.QDropEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTableWidget.dropEvent", overloads);
        return 0;
}

static PyObject* Sbk_QTableWidgetFunc_dropMimeData(PyObject* self, PyObject* args)
{
    QTableWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTableWidget* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "dropMimeData", 4, 4, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: dropMimeData(int,int,const QMimeData*,Qt::DropAction)
    if (numArgs == 4 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && Shiboken::Converter< ::QMimeData * >::isConvertible(pyargs[2]) && Shiboken::Converter< ::Qt::DropAction >::isConvertible(pyargs[3])) {
        overloadId = 0; // dropMimeData(int,int,const QMimeData*,Qt::DropAction)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTableWidgetFunc_dropMimeData_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
            if (!Shiboken::Object::isValid(pyargs[2]))
                return 0;
            QMimeData * cppArg2 = Shiboken::Converter<QMimeData * >::toCpp(pyargs[2]);
            Qt::DropAction cppArg3 = Shiboken::Converter<Qt::DropAction >::toCpp(pyargs[3]);

            if(!PyErr_Occurred()) {
                // dropMimeData(int,int,const QMimeData*,Qt::DropAction)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QTableWidget::dropMimeData(cppArg0, cppArg1, cppArg2, cppArg3):cppSelf->dropMimeData(cppArg0, cppArg1, cppArg2, cppArg3));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTableWidgetFunc_dropMimeData_TypeError:
        const char* overloads[] = {"int, int, PySide.QtCore.QMimeData, PySide.QtCore.Qt.DropAction", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTableWidget.dropMimeData", overloads);
        return 0;
}

static PyObject* Sbk_QTableWidgetFunc_editItem(PyObject* self, PyObject* arg)
{
    QTableWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTableWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: editItem(QTableWidgetItem*)
    if (Shiboken::Converter< ::QTableWidgetItem * >::isConvertible(arg)) {
        overloadId = 0; // editItem(QTableWidgetItem*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTableWidgetFunc_editItem_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QTableWidgetItem * cppArg0 = Shiboken::Converter<QTableWidgetItem * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // editItem(QTableWidgetItem*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->editItem(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTableWidgetFunc_editItem_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTableWidgetItem", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTableWidget.editItem", overloads);
        return 0;
}

static PyObject* Sbk_QTableWidgetFunc_event(PyObject* self, PyObject* arg)
{
    QTableWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTableWidget* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: event(QEvent*)
    if (Shiboken::Converter< ::QEvent * >::isConvertible(arg)) {
        overloadId = 0; // event(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTableWidgetFunc_event_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QEvent * cppArg0 = Shiboken::Converter<QEvent * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // event(QEvent*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QTableWidget::event(cppArg0):cppSelf->event(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTableWidgetFunc_event_TypeError:
        const char* overloads[] = {"PySide.QtCore.QEvent", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTableWidget.event", overloads);
        return 0;
}

static PyObject* Sbk_QTableWidgetFunc_findItems(PyObject* self, PyObject* args)
{
    QTableWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTableWidget* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "findItems", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: findItems(QString,QFlags<Qt::MatchFlag>)const
    if (numArgs == 2 && Shiboken::Converter< QString >::isConvertible(pyargs[0]) && Shiboken::Converter< ::QFlags<Qt::MatchFlag> >::isConvertible(pyargs[1])) {
        overloadId = 0; // findItems(QString,QFlags<Qt::MatchFlag>)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTableWidgetFunc_findItems_TypeError;

    // Call function/method
    {
        {
            QString cppArg0 = Shiboken::Converter<QString >::toCpp(pyargs[0]);
            QFlags<Qt::MatchFlag> cppArg1 = Shiboken::Converter<QFlags<Qt::MatchFlag> >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // findItems(QString,QFlags<Qt::MatchFlag>)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QList<QTableWidgetItem * > cppResult = cppSelf->findItems(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QList<QTableWidgetItem * > >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTableWidgetFunc_findItems_TypeError:
        const char* overloads[] = {"QString, PySide.QtCore.Qt.MatchFlags", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTableWidget.findItems", overloads);
        return 0;
}

static PyObject* Sbk_QTableWidgetFunc_horizontalHeaderItem(PyObject* self, PyObject* arg)
{
    QTableWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTableWidget* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: horizontalHeaderItem(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // horizontalHeaderItem(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTableWidgetFunc_horizontalHeaderItem_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // horizontalHeaderItem(int)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QTableWidgetItem * cppResult = cppSelf->horizontalHeaderItem(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QTableWidgetItem * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTableWidgetFunc_horizontalHeaderItem_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTableWidget.horizontalHeaderItem", overloads);
        return 0;
}

static PyObject* Sbk_QTableWidgetFunc_indexFromItem(PyObject* self, PyObject* arg)
{
    QTableWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTableWidget* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: indexFromItem(QTableWidgetItem*)const
    if (Shiboken::Converter< ::QTableWidgetItem * >::isConvertible(arg)) {
        overloadId = 0; // indexFromItem(QTableWidgetItem*)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTableWidgetFunc_indexFromItem_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QTableWidgetItem * cppArg0 = Shiboken::Converter<QTableWidgetItem * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // indexFromItem(QTableWidgetItem*)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QModelIndex cppResult = cppSelf->indexFromItem(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QModelIndex >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTableWidgetFunc_indexFromItem_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTableWidgetItem", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTableWidget.indexFromItem", overloads);
        return 0;
}

static PyObject* Sbk_QTableWidgetFunc_insertColumn(PyObject* self, PyObject* arg)
{
    QTableWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTableWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: insertColumn(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // insertColumn(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTableWidgetFunc_insertColumn_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // insertColumn(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->insertColumn(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTableWidgetFunc_insertColumn_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTableWidget.insertColumn", overloads);
        return 0;
}

static PyObject* Sbk_QTableWidgetFunc_insertRow(PyObject* self, PyObject* arg)
{
    QTableWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTableWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: insertRow(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // insertRow(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTableWidgetFunc_insertRow_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // insertRow(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->insertRow(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTableWidgetFunc_insertRow_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTableWidget.insertRow", overloads);
        return 0;
}

static PyObject* Sbk_QTableWidgetFunc_isSortingEnabled(PyObject* self)
{
    QTableWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTableWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // isSortingEnabled()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = cppSelf->isSortingEnabled();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTableWidgetFunc_item(PyObject* self, PyObject* args)
{
    QTableWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTableWidget* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "item", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: item(int,int)const
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // item(int,int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTableWidgetFunc_item_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // item(int,int)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QTableWidgetItem * cppResult = cppSelf->item(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QTableWidgetItem * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTableWidgetFunc_item_TypeError:
        const char* overloads[] = {"int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTableWidget.item", overloads);
        return 0;
}

static PyObject* Sbk_QTableWidgetFunc_itemAt(PyObject* self, PyObject* args)
{
    QTableWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTableWidget* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "itemAt", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: itemAt(QPoint)const
    // 1: itemAt(int,int)const
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 1; // itemAt(int,int)const
    } else if (numArgs == 1 && Shiboken::Converter< ::QPoint >::isConvertible(pyargs[0])) {
        overloadId = 0; // itemAt(QPoint)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTableWidgetFunc_itemAt_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // itemAt(QPoint)const
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QPoint cppArg0 = Shiboken::Converter<QPoint >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // itemAt(QPoint)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QTableWidgetItem * cppResult = cppSelf->itemAt(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QTableWidgetItem * >::toPython(cppResult);
                    Shiboken::Object::setParent(self, pyResult);
                }
                break;
            }
            case 1: // itemAt(int,int)const
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // itemAt(int,int)const
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    QTableWidgetItem * cppResult = cppSelf->itemAt(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    pyResult = Shiboken::Converter< ::QTableWidgetItem * >::toPython(cppResult);
                    Shiboken::Object::setParent(self, pyResult);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTableWidgetFunc_itemAt_TypeError:
        const char* overloads[] = {"PySide.QtCore.QPoint", "int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTableWidget.itemAt", overloads);
        return 0;
}

static PyObject* Sbk_QTableWidgetFunc_itemFromIndex(PyObject* self, PyObject* arg)
{
    QTableWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTableWidget* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: itemFromIndex(QModelIndex)const
    if (Shiboken::Converter< ::QModelIndex >::isConvertible(arg)) {
        overloadId = 0; // itemFromIndex(QModelIndex)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTableWidgetFunc_itemFromIndex_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QModelIndex cppArg0 = Shiboken::Converter<QModelIndex >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // itemFromIndex(QModelIndex)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QTableWidgetItem * cppResult = cppSelf->itemFromIndex(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QTableWidgetItem * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTableWidgetFunc_itemFromIndex_TypeError:
        const char* overloads[] = {"PySide.QtCore.QModelIndex", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTableWidget.itemFromIndex", overloads);
        return 0;
}

static PyObject* Sbk_QTableWidgetFunc_itemPrototype(PyObject* self)
{
    QTableWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTableWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // itemPrototype()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                const QTableWidgetItem * cppResult = cppSelf->itemPrototype();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QTableWidgetItem * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTableWidgetFunc_items(PyObject* self, PyObject* arg)
{
    QTableWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTableWidget* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: items(const QMimeData*)const
    if (Shiboken::Converter< ::QMimeData * >::isConvertible(arg)) {
        overloadId = 0; // items(const QMimeData*)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTableWidgetFunc_items_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QMimeData * cppArg0 = Shiboken::Converter<QMimeData * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // items(const QMimeData*)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QList<QTableWidgetItem * > cppResult = cppSelf->items(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QList<QTableWidgetItem * > >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTableWidgetFunc_items_TypeError:
        const char* overloads[] = {"PySide.QtCore.QMimeData", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTableWidget.items", overloads);
        return 0;
}

static PyObject* Sbk_QTableWidgetFunc_mimeData(PyObject* self, PyObject* arg)
{
    QTableWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTableWidget* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: mimeData(QList<QTableWidgetItem*>)const
    if (Shiboken::Converter< ::QList<QTableWidgetItem * > >::isConvertible(arg)) {
        overloadId = 0; // mimeData(QList<QTableWidgetItem*>)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTableWidgetFunc_mimeData_TypeError;

    // Call function/method
    {
        {
            QList<QTableWidgetItem * > cppArg0 = Shiboken::Converter<QList<QTableWidgetItem * > >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // mimeData(QList<QTableWidgetItem*>)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QMimeData * cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QTableWidget::mimeData(cppArg0):cppSelf->mimeData(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QMimeData * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTableWidgetFunc_mimeData_TypeError:
        const char* overloads[] = {"list", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTableWidget.mimeData", overloads);
        return 0;
}

static PyObject* Sbk_QTableWidgetFunc_mimeTypes(PyObject* self)
{
    QTableWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTableWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // mimeTypes()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QStringList cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QTableWidget::mimeTypes():cppSelf->mimeTypes());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QStringList >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTableWidgetFunc_openPersistentEditor(PyObject* self, PyObject* arg)
{
    QTableWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTableWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: openPersistentEditor(QTableWidgetItem*)
    if (Shiboken::Converter< ::QTableWidgetItem * >::isConvertible(arg)) {
        overloadId = 0; // openPersistentEditor(QTableWidgetItem*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTableWidgetFunc_openPersistentEditor_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QTableWidgetItem * cppArg0 = Shiboken::Converter<QTableWidgetItem * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // openPersistentEditor(QTableWidgetItem*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->openPersistentEditor(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTableWidgetFunc_openPersistentEditor_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTableWidgetItem", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTableWidget.openPersistentEditor", overloads);
        return 0;
}

static PyObject* Sbk_QTableWidgetFunc_removeCellWidget(PyObject* self, PyObject* args)
{
    QTableWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTableWidget* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "removeCellWidget", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: removeCellWidget(int,int)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // removeCellWidget(int,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTableWidgetFunc_removeCellWidget_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // removeCellWidget(int,int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->removeCellWidget(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTableWidgetFunc_removeCellWidget_TypeError:
        const char* overloads[] = {"int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTableWidget.removeCellWidget", overloads);
        return 0;
}

static PyObject* Sbk_QTableWidgetFunc_removeColumn(PyObject* self, PyObject* arg)
{
    QTableWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTableWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: removeColumn(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // removeColumn(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTableWidgetFunc_removeColumn_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // removeColumn(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->removeColumn(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTableWidgetFunc_removeColumn_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTableWidget.removeColumn", overloads);
        return 0;
}

static PyObject* Sbk_QTableWidgetFunc_removeRow(PyObject* self, PyObject* arg)
{
    QTableWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTableWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: removeRow(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // removeRow(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTableWidgetFunc_removeRow_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // removeRow(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->removeRow(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTableWidgetFunc_removeRow_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTableWidget.removeRow", overloads);
        return 0;
}

static PyObject* Sbk_QTableWidgetFunc_row(PyObject* self, PyObject* arg)
{
    QTableWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTableWidget* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: row(const QTableWidgetItem*)const
    if (Shiboken::Converter< ::QTableWidgetItem * >::isConvertible(arg)) {
        overloadId = 0; // row(const QTableWidgetItem*)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTableWidgetFunc_row_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QTableWidgetItem * cppArg0 = Shiboken::Converter<QTableWidgetItem * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // row(const QTableWidgetItem*)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->row(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTableWidgetFunc_row_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTableWidgetItem", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTableWidget.row", overloads);
        return 0;
}

static PyObject* Sbk_QTableWidgetFunc_rowCount(PyObject* self)
{
    QTableWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTableWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // rowCount()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->rowCount();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTableWidgetFunc_scrollToItem(PyObject* self, PyObject* args, PyObject* kwds)
{
    QTableWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTableWidget* >::toCpp(self);

    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QTableWidget.scrollToItem(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QTableWidget.scrollToItem(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:scrollToItem", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: scrollToItem(const QTableWidgetItem*,QAbstractItemView::ScrollHint)
    if (Shiboken::Converter< ::QTableWidgetItem * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // scrollToItem(const QTableWidgetItem*,QAbstractItemView::ScrollHint)
        } else if (Shiboken::Converter< ::QAbstractItemView::ScrollHint >::isConvertible(pyargs[1])) {
            overloadId = 0; // scrollToItem(const QTableWidgetItem*,QAbstractItemView::ScrollHint)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTableWidgetFunc_scrollToItem_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "hint");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "hint";
                    else if (Shiboken::Converter< ::QAbstractItemView::ScrollHint >::isConvertible(value))
                        pyargs[1] = value;
else
                        goto Sbk_QTableWidgetFunc_scrollToItem_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QTableWidget.scrollToItem(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QTableWidgetItem * cppArg0 = Shiboken::Converter<QTableWidgetItem * >::toCpp(pyargs[0]);
            QAbstractItemView::ScrollHint cppArg1 = pyargs[1] ? Shiboken::Converter<QAbstractItemView::ScrollHint >::toCpp(pyargs[1]) : QAbstractItemView::EnsureVisible;

            if(!PyErr_Occurred()) {
                // scrollToItem(const QTableWidgetItem*,QAbstractItemView::ScrollHint)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->scrollToItem(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTableWidgetFunc_scrollToItem_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTableWidgetItem, PySide.QtGui.QAbstractItemView.ScrollHint = EnsureVisible", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTableWidget.scrollToItem", overloads);
        return 0;
}

static PyObject* Sbk_QTableWidgetFunc_selectedItems(PyObject* self)
{
    QTableWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTableWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // selectedItems()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QList<QTableWidgetItem * > cppResult = cppSelf->selectedItems();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QList<QTableWidgetItem * > >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTableWidgetFunc_selectedRanges(PyObject* self)
{
    QTableWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTableWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // selectedRanges()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QList<QTableWidgetSelectionRange > cppResult = cppSelf->selectedRanges();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QList<QTableWidgetSelectionRange > >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTableWidgetFunc_setCellWidget(PyObject* self, PyObject* args)
{
    QTableWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTableWidget* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setCellWidget", 3, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: setCellWidget(int,int,QWidget*)
    if (numArgs == 3 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && Shiboken::Converter< ::QWidget * >::isConvertible(pyargs[2])) {
        overloadId = 0; // setCellWidget(int,int,QWidget*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTableWidgetFunc_setCellWidget_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
            if (!Shiboken::Object::isValid(pyargs[2]))
                return 0;
            QWidget * cppArg2 = Shiboken::Converter<QWidget * >::toCpp(pyargs[2]);

            if(!PyErr_Occurred()) {
                // setCellWidget(int,int,QWidget*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setCellWidget(cppArg0, cppArg1, cppArg2);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                Shiboken::Object::setParent(self, pyargs[2]);
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTableWidgetFunc_setCellWidget_TypeError:
        const char* overloads[] = {"int, int, PySide.QtGui.QWidget", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTableWidget.setCellWidget", overloads);
        return 0;
}

static PyObject* Sbk_QTableWidgetFunc_setColumnCount(PyObject* self, PyObject* arg)
{
    QTableWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTableWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setColumnCount(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setColumnCount(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTableWidgetFunc_setColumnCount_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setColumnCount(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setColumnCount(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTableWidgetFunc_setColumnCount_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTableWidget.setColumnCount", overloads);
        return 0;
}

static PyObject* Sbk_QTableWidgetFunc_setCurrentCell(PyObject* self, PyObject* args)
{
    QTableWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTableWidget* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setCurrentCell", 2, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: setCurrentCell(int,int)
    // 1: setCurrentCell(int,int,QFlags<QItemSelectionModel::SelectionFlag>)
    if (numArgs >= 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        if (numArgs == 2) {
            overloadId = 0; // setCurrentCell(int,int)
        } else if (numArgs == 3 && Shiboken::Converter< ::QFlags<QItemSelectionModel::SelectionFlag> >::isConvertible(pyargs[2])) {
            overloadId = 1; // setCurrentCell(int,int,QFlags<QItemSelectionModel::SelectionFlag>)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTableWidgetFunc_setCurrentCell_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setCurrentCell(int,int)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // setCurrentCell(int,int)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setCurrentCell(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
            case 1: // setCurrentCell(int,int,QFlags<QItemSelectionModel::SelectionFlag>)
            {
                int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
                int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
                QFlags<QItemSelectionModel::SelectionFlag> cppArg2 = Shiboken::Converter<QFlags<QItemSelectionModel::SelectionFlag> >::toCpp(pyargs[2]);

                if(!PyErr_Occurred()) {
                    // setCurrentCell(int,int,QFlags<QItemSelectionModel::SelectionFlag>)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setCurrentCell(cppArg0, cppArg1, cppArg2);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTableWidgetFunc_setCurrentCell_TypeError:
        const char* overloads[] = {"int, int", "int, int, PySide.QtGui.QItemSelectionModel.SelectionFlags", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTableWidget.setCurrentCell", overloads);
        return 0;
}

static PyObject* Sbk_QTableWidgetFunc_setCurrentItem(PyObject* self, PyObject* args)
{
    QTableWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTableWidget* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setCurrentItem", 1, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setCurrentItem(QTableWidgetItem*)
    // 1: setCurrentItem(QTableWidgetItem*,QFlags<QItemSelectionModel::SelectionFlag>)
    if (Shiboken::Converter< ::QTableWidgetItem * >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // setCurrentItem(QTableWidgetItem*)
        } else if (numArgs == 2 && Shiboken::Converter< ::QFlags<QItemSelectionModel::SelectionFlag> >::isConvertible(pyargs[1])) {
            overloadId = 1; // setCurrentItem(QTableWidgetItem*,QFlags<QItemSelectionModel::SelectionFlag>)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTableWidgetFunc_setCurrentItem_TypeError;

    // Call function/method
    {
        switch (overloadId) {
            case 0: // setCurrentItem(QTableWidgetItem*)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QTableWidgetItem * cppArg0 = Shiboken::Converter<QTableWidgetItem * >::toCpp(pyargs[0]);

                if(!PyErr_Occurred()) {
                    // setCurrentItem(QTableWidgetItem*)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setCurrentItem(cppArg0);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    Shiboken::Object::setParent(self, pyargs[0]);
                }
                break;
            }
            case 1: // setCurrentItem(QTableWidgetItem*,QFlags<QItemSelectionModel::SelectionFlag>)
            {
                if (!Shiboken::Object::isValid(pyargs[0]))
                    return 0;
                QTableWidgetItem * cppArg0 = Shiboken::Converter<QTableWidgetItem * >::toCpp(pyargs[0]);
                QFlags<QItemSelectionModel::SelectionFlag> cppArg1 = Shiboken::Converter<QFlags<QItemSelectionModel::SelectionFlag> >::toCpp(pyargs[1]);

                if(!PyErr_Occurred()) {
                    // setCurrentItem(QTableWidgetItem*,QFlags<QItemSelectionModel::SelectionFlag>)
                    PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                    cppSelf->setCurrentItem(cppArg0, cppArg1);
                    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                    Shiboken::Object::setParent(self, pyargs[0]);
                }
                break;
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTableWidgetFunc_setCurrentItem_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTableWidgetItem", "PySide.QtGui.QTableWidgetItem, PySide.QtGui.QItemSelectionModel.SelectionFlags", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTableWidget.setCurrentItem", overloads);
        return 0;
}

static PyObject* Sbk_QTableWidgetFunc_setHorizontalHeaderItem(PyObject* self, PyObject* args)
{
    QTableWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTableWidget* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setHorizontalHeaderItem", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setHorizontalHeaderItem(int,QTableWidgetItem*)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && Shiboken::Converter< ::QTableWidgetItem * >::isConvertible(pyargs[1])) {
        overloadId = 0; // setHorizontalHeaderItem(int,QTableWidgetItem*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTableWidgetFunc_setHorizontalHeaderItem_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QTableWidgetItem * cppArg1 = Shiboken::Converter<QTableWidgetItem * >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // setHorizontalHeaderItem(int,QTableWidgetItem*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setHorizontalHeaderItem(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                Shiboken::Object::setParent(self, pyargs[1]);
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTableWidgetFunc_setHorizontalHeaderItem_TypeError:
        const char* overloads[] = {"int, PySide.QtGui.QTableWidgetItem", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTableWidget.setHorizontalHeaderItem", overloads);
        return 0;
}

static PyObject* Sbk_QTableWidgetFunc_setHorizontalHeaderLabels(PyObject* self, PyObject* arg)
{
    QTableWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTableWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setHorizontalHeaderLabels(QStringList)
    if (Shiboken::Converter< ::QStringList >::isConvertible(arg)) {
        overloadId = 0; // setHorizontalHeaderLabels(QStringList)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTableWidgetFunc_setHorizontalHeaderLabels_TypeError;

    // Call function/method
    {
        {
            QStringList cppArg0 = Shiboken::Converter<QStringList >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setHorizontalHeaderLabels(QStringList)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setHorizontalHeaderLabels(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTableWidgetFunc_setHorizontalHeaderLabels_TypeError:
        const char* overloads[] = {"list", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTableWidget.setHorizontalHeaderLabels", overloads);
        return 0;
}

static PyObject* Sbk_QTableWidgetFunc_setItem(PyObject* self, PyObject* args)
{
    QTableWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTableWidget* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setItem", 3, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: setItem(int,int,QTableWidgetItem*)
    if (numArgs == 3 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && Shiboken::Converter< ::QTableWidgetItem * >::isConvertible(pyargs[2])) {
        overloadId = 0; // setItem(int,int,QTableWidgetItem*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTableWidgetFunc_setItem_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
            if (!Shiboken::Object::isValid(pyargs[2]))
                return 0;
            QTableWidgetItem * cppArg2 = Shiboken::Converter<QTableWidgetItem * >::toCpp(pyargs[2]);

            if(!PyErr_Occurred()) {
                // setItem(int,int,QTableWidgetItem*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setItem(cppArg0, cppArg1, cppArg2);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                Shiboken::Object::setParent(self, pyargs[2]);
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTableWidgetFunc_setItem_TypeError:
        const char* overloads[] = {"int, int, PySide.QtGui.QTableWidgetItem", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTableWidget.setItem", overloads);
        return 0;
}

static PyObject* Sbk_QTableWidgetFunc_setItemPrototype(PyObject* self, PyObject* arg)
{
    QTableWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTableWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setItemPrototype(const QTableWidgetItem*)
    if (Shiboken::Converter< ::QTableWidgetItem * >::isConvertible(arg)) {
        overloadId = 0; // setItemPrototype(const QTableWidgetItem*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTableWidgetFunc_setItemPrototype_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QTableWidgetItem * cppArg0 = Shiboken::Converter<QTableWidgetItem * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setItemPrototype(const QTableWidgetItem*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setItemPrototype(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                Shiboken::Object::setParent(self, arg);
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTableWidgetFunc_setItemPrototype_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTableWidgetItem", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTableWidget.setItemPrototype", overloads);
        return 0;
}

static PyObject* Sbk_QTableWidgetFunc_setModel(PyObject* self, PyObject* arg)
{
    QTableWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTableWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setModel(QAbstractItemModel*)
    if (Shiboken::Converter< ::QAbstractItemModel * >::isConvertible(arg)) {
        overloadId = 0; // setModel(QAbstractItemModel*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTableWidgetFunc_setModel_TypeError;

    // Call function/method
    {
        {
            PyErr_Format(PyExc_TypeError, "%s is a private method.", "setModel(QAbstractItemModel * model)");
            return 0;
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTableWidgetFunc_setModel_TypeError:
        const char* overloads[] = {"PySide.QtCore.QAbstractItemModel", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTableWidget.setModel", overloads);
        return 0;
}

static PyObject* Sbk_QTableWidgetFunc_setRangeSelected(PyObject* self, PyObject* args)
{
    QTableWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTableWidget* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setRangeSelected", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setRangeSelected(QTableWidgetSelectionRange,bool)
    if (numArgs == 2 && Shiboken::Converter< ::QTableWidgetSelectionRange >::isConvertible(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // setRangeSelected(QTableWidgetSelectionRange,bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTableWidgetFunc_setRangeSelected_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(pyargs[0]))
                return 0;
            QTableWidgetSelectionRange cppArg0 = Shiboken::Converter<QTableWidgetSelectionRange >::toCpp(pyargs[0]);
            bool cppArg1 = Shiboken::Converter<bool >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // setRangeSelected(QTableWidgetSelectionRange,bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setRangeSelected(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTableWidgetFunc_setRangeSelected_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTableWidgetSelectionRange, bool", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTableWidget.setRangeSelected", overloads);
        return 0;
}

static PyObject* Sbk_QTableWidgetFunc_setRowCount(PyObject* self, PyObject* arg)
{
    QTableWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTableWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setRowCount(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setRowCount(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTableWidgetFunc_setRowCount_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setRowCount(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setRowCount(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTableWidgetFunc_setRowCount_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTableWidget.setRowCount", overloads);
        return 0;
}

static PyObject* Sbk_QTableWidgetFunc_setSortingEnabled(PyObject* self, PyObject* arg)
{
    QTableWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTableWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setSortingEnabled(bool)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // setSortingEnabled(bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTableWidgetFunc_setSortingEnabled_TypeError;

    // Call function/method
    {
        {
            bool cppArg0 = Shiboken::Converter<bool >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setSortingEnabled(bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setSortingEnabled(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTableWidgetFunc_setSortingEnabled_TypeError:
        const char* overloads[] = {"bool", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTableWidget.setSortingEnabled", overloads);
        return 0;
}

static PyObject* Sbk_QTableWidgetFunc_setVerticalHeaderItem(PyObject* self, PyObject* args)
{
    QTableWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTableWidget* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "setVerticalHeaderItem", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: setVerticalHeaderItem(int,QTableWidgetItem*)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && Shiboken::Converter< ::QTableWidgetItem * >::isConvertible(pyargs[1])) {
        overloadId = 0; // setVerticalHeaderItem(int,QTableWidgetItem*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTableWidgetFunc_setVerticalHeaderItem_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QTableWidgetItem * cppArg1 = Shiboken::Converter<QTableWidgetItem * >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // setVerticalHeaderItem(int,QTableWidgetItem*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setVerticalHeaderItem(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                Shiboken::Object::setParent(self, pyargs[1]);
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTableWidgetFunc_setVerticalHeaderItem_TypeError:
        const char* overloads[] = {"int, PySide.QtGui.QTableWidgetItem", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTableWidget.setVerticalHeaderItem", overloads);
        return 0;
}

static PyObject* Sbk_QTableWidgetFunc_setVerticalHeaderLabels(PyObject* self, PyObject* arg)
{
    QTableWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTableWidget* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: setVerticalHeaderLabels(QStringList)
    if (Shiboken::Converter< ::QStringList >::isConvertible(arg)) {
        overloadId = 0; // setVerticalHeaderLabels(QStringList)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTableWidgetFunc_setVerticalHeaderLabels_TypeError;

    // Call function/method
    {
        {
            QStringList cppArg0 = Shiboken::Converter<QStringList >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // setVerticalHeaderLabels(QStringList)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->setVerticalHeaderLabels(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTableWidgetFunc_setVerticalHeaderLabels_TypeError:
        const char* overloads[] = {"list", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTableWidget.setVerticalHeaderLabels", overloads);
        return 0;
}

static PyObject* Sbk_QTableWidgetFunc_sortItems(PyObject* self, PyObject* args, PyObject* kwds)
{
    QTableWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTableWidget* >::toCpp(self);

    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QTableWidget.sortItems(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtGui.QTableWidget.sortItems(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:sortItems", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: sortItems(int,Qt::SortOrder)
    if (SbkNumber_Check(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // sortItems(int,Qt::SortOrder)
        } else if (Shiboken::Converter< ::Qt::SortOrder >::isConvertible(pyargs[1])) {
            overloadId = 0; // sortItems(int,Qt::SortOrder)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTableWidgetFunc_sortItems_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "order");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "order";
                    else if (Shiboken::Converter< ::Qt::SortOrder >::isConvertible(value))
                        pyargs[1] = value;
else
                        goto Sbk_QTableWidgetFunc_sortItems_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtGui.QTableWidget.sortItems(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            Qt::SortOrder cppArg1 = pyargs[1] ? Shiboken::Converter<Qt::SortOrder >::toCpp(pyargs[1]) : Qt::AscendingOrder;

            if(!PyErr_Occurred()) {
                // sortItems(int,Qt::SortOrder)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->sortItems(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QTableWidgetFunc_sortItems_TypeError:
        const char* overloads[] = {"int, PySide.QtCore.Qt.SortOrder = Qt.AscendingOrder", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTableWidget.sortItems", overloads);
        return 0;
}

static PyObject* Sbk_QTableWidgetFunc_supportedDropActions(PyObject* self)
{
    QTableWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTableWidget* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // supportedDropActions()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QFlags<Qt::DropAction> cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QTableWidget::supportedDropActions():cppSelf->supportedDropActions());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QFlags<Qt::DropAction> >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QTableWidgetFunc_takeHorizontalHeaderItem(PyObject* self, PyObject* arg)
{
    QTableWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTableWidget* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: takeHorizontalHeaderItem(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // takeHorizontalHeaderItem(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTableWidgetFunc_takeHorizontalHeaderItem_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // takeHorizontalHeaderItem(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QTableWidgetItem * cppResult = cppSelf->takeHorizontalHeaderItem(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QTableWidgetItem * >::toPython(cppResult);
                Shiboken::Object::setParent(Py_None, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTableWidgetFunc_takeHorizontalHeaderItem_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTableWidget.takeHorizontalHeaderItem", overloads);
        return 0;
}

static PyObject* Sbk_QTableWidgetFunc_takeItem(PyObject* self, PyObject* args)
{
    QTableWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTableWidget* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "takeItem", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: takeItem(int,int)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1])) {
        overloadId = 0; // takeItem(int,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTableWidgetFunc_takeItem_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(pyargs[0]);
            int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // takeItem(int,int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QTableWidgetItem * cppResult = cppSelf->takeItem(cppArg0, cppArg1);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QTableWidgetItem * >::toPython(cppResult);
                Shiboken::Object::setParent(Py_None, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTableWidgetFunc_takeItem_TypeError:
        const char* overloads[] = {"int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtGui.QTableWidget.takeItem", overloads);
        return 0;
}

static PyObject* Sbk_QTableWidgetFunc_takeVerticalHeaderItem(PyObject* self, PyObject* arg)
{
    QTableWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTableWidget* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: takeVerticalHeaderItem(int)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // takeVerticalHeaderItem(int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTableWidgetFunc_takeVerticalHeaderItem_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // takeVerticalHeaderItem(int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QTableWidgetItem * cppResult = cppSelf->takeVerticalHeaderItem(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QTableWidgetItem * >::toPython(cppResult);
                Shiboken::Object::setParent(Py_None, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTableWidgetFunc_takeVerticalHeaderItem_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTableWidget.takeVerticalHeaderItem", overloads);
        return 0;
}

static PyObject* Sbk_QTableWidgetFunc_verticalHeaderItem(PyObject* self, PyObject* arg)
{
    QTableWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTableWidget* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: verticalHeaderItem(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // verticalHeaderItem(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTableWidgetFunc_verticalHeaderItem_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // verticalHeaderItem(int)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QTableWidgetItem * cppResult = cppSelf->verticalHeaderItem(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QTableWidgetItem * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTableWidgetFunc_verticalHeaderItem_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTableWidget.verticalHeaderItem", overloads);
        return 0;
}

static PyObject* Sbk_QTableWidgetFunc_visualColumn(PyObject* self, PyObject* arg)
{
    QTableWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTableWidget* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: visualColumn(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // visualColumn(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTableWidgetFunc_visualColumn_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // visualColumn(int)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->visualColumn(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTableWidgetFunc_visualColumn_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTableWidget.visualColumn", overloads);
        return 0;
}

static PyObject* Sbk_QTableWidgetFunc_visualItemRect(PyObject* self, PyObject* arg)
{
    QTableWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTableWidget* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: visualItemRect(const QTableWidgetItem*)const
    if (Shiboken::Converter< ::QTableWidgetItem * >::isConvertible(arg)) {
        overloadId = 0; // visualItemRect(const QTableWidgetItem*)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTableWidgetFunc_visualItemRect_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(arg))
                return 0;
            QTableWidgetItem * cppArg0 = Shiboken::Converter<QTableWidgetItem * >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // visualItemRect(const QTableWidgetItem*)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QRect cppResult = cppSelf->visualItemRect(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QRect >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTableWidgetFunc_visualItemRect_TypeError:
        const char* overloads[] = {"PySide.QtGui.QTableWidgetItem", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTableWidget.visualItemRect", overloads);
        return 0;
}

static PyObject* Sbk_QTableWidgetFunc_visualRow(PyObject* self, PyObject* arg)
{
    QTableWidget* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QTableWidget* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: visualRow(int)const
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // visualRow(int)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QTableWidgetFunc_visualRow_TypeError;

    // Call function/method
    {
        {
            int cppArg0 = Shiboken::Converter<int >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // visualRow(int)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                int cppResult = cppSelf->visualRow(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< int >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QTableWidgetFunc_visualRow_TypeError:
        const char* overloads[] = {"int", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtGui.QTableWidget.visualRow", overloads);
        return 0;
}

static PyMethodDef Sbk_QTableWidget_methods[] = {
    {"cellWidget", (PyCFunction)Sbk_QTableWidgetFunc_cellWidget, METH_VARARGS},
    {"clear", (PyCFunction)Sbk_QTableWidgetFunc_clear, METH_NOARGS},
    {"clearContents", (PyCFunction)Sbk_QTableWidgetFunc_clearContents, METH_NOARGS},
    {"closePersistentEditor", (PyCFunction)Sbk_QTableWidgetFunc_closePersistentEditor, METH_O},
    {"column", (PyCFunction)Sbk_QTableWidgetFunc_column, METH_O},
    {"columnCount", (PyCFunction)Sbk_QTableWidgetFunc_columnCount, METH_NOARGS},
    {"currentColumn", (PyCFunction)Sbk_QTableWidgetFunc_currentColumn, METH_NOARGS},
    {"currentItem", (PyCFunction)Sbk_QTableWidgetFunc_currentItem, METH_NOARGS},
    {"currentRow", (PyCFunction)Sbk_QTableWidgetFunc_currentRow, METH_NOARGS},
    {"dropEvent", (PyCFunction)Sbk_QTableWidgetFunc_dropEvent, METH_O},
    {"dropMimeData", (PyCFunction)Sbk_QTableWidgetFunc_dropMimeData, METH_VARARGS},
    {"editItem", (PyCFunction)Sbk_QTableWidgetFunc_editItem, METH_O},
    {"event", (PyCFunction)Sbk_QTableWidgetFunc_event, METH_O},
    {"findItems", (PyCFunction)Sbk_QTableWidgetFunc_findItems, METH_VARARGS},
    {"horizontalHeaderItem", (PyCFunction)Sbk_QTableWidgetFunc_horizontalHeaderItem, METH_O},
    {"indexFromItem", (PyCFunction)Sbk_QTableWidgetFunc_indexFromItem, METH_O},
    {"insertColumn", (PyCFunction)Sbk_QTableWidgetFunc_insertColumn, METH_O},
    {"insertRow", (PyCFunction)Sbk_QTableWidgetFunc_insertRow, METH_O},
    {"isSortingEnabled", (PyCFunction)Sbk_QTableWidgetFunc_isSortingEnabled, METH_NOARGS},
    {"item", (PyCFunction)Sbk_QTableWidgetFunc_item, METH_VARARGS},
    {"itemAt", (PyCFunction)Sbk_QTableWidgetFunc_itemAt, METH_VARARGS},
    {"itemFromIndex", (PyCFunction)Sbk_QTableWidgetFunc_itemFromIndex, METH_O},
    {"itemPrototype", (PyCFunction)Sbk_QTableWidgetFunc_itemPrototype, METH_NOARGS},
    {"items", (PyCFunction)Sbk_QTableWidgetFunc_items, METH_O},
    {"mimeData", (PyCFunction)Sbk_QTableWidgetFunc_mimeData, METH_O},
    {"mimeTypes", (PyCFunction)Sbk_QTableWidgetFunc_mimeTypes, METH_NOARGS},
    {"openPersistentEditor", (PyCFunction)Sbk_QTableWidgetFunc_openPersistentEditor, METH_O},
    {"removeCellWidget", (PyCFunction)Sbk_QTableWidgetFunc_removeCellWidget, METH_VARARGS},
    {"removeColumn", (PyCFunction)Sbk_QTableWidgetFunc_removeColumn, METH_O},
    {"removeRow", (PyCFunction)Sbk_QTableWidgetFunc_removeRow, METH_O},
    {"row", (PyCFunction)Sbk_QTableWidgetFunc_row, METH_O},
    {"rowCount", (PyCFunction)Sbk_QTableWidgetFunc_rowCount, METH_NOARGS},
    {"scrollToItem", (PyCFunction)Sbk_QTableWidgetFunc_scrollToItem, METH_VARARGS|METH_KEYWORDS},
    {"selectedItems", (PyCFunction)Sbk_QTableWidgetFunc_selectedItems, METH_NOARGS},
    {"selectedRanges", (PyCFunction)Sbk_QTableWidgetFunc_selectedRanges, METH_NOARGS},
    {"setCellWidget", (PyCFunction)Sbk_QTableWidgetFunc_setCellWidget, METH_VARARGS},
    {"setColumnCount", (PyCFunction)Sbk_QTableWidgetFunc_setColumnCount, METH_O},
    {"setCurrentCell", (PyCFunction)Sbk_QTableWidgetFunc_setCurrentCell, METH_VARARGS},
    {"setCurrentItem", (PyCFunction)Sbk_QTableWidgetFunc_setCurrentItem, METH_VARARGS},
    {"setHorizontalHeaderItem", (PyCFunction)Sbk_QTableWidgetFunc_setHorizontalHeaderItem, METH_VARARGS},
    {"setHorizontalHeaderLabels", (PyCFunction)Sbk_QTableWidgetFunc_setHorizontalHeaderLabels, METH_O},
    {"setItem", (PyCFunction)Sbk_QTableWidgetFunc_setItem, METH_VARARGS},
    {"setItemPrototype", (PyCFunction)Sbk_QTableWidgetFunc_setItemPrototype, METH_O},
    {"setModel", (PyCFunction)Sbk_QTableWidgetFunc_setModel, METH_O},
    {"setRangeSelected", (PyCFunction)Sbk_QTableWidgetFunc_setRangeSelected, METH_VARARGS},
    {"setRowCount", (PyCFunction)Sbk_QTableWidgetFunc_setRowCount, METH_O},
    {"setSortingEnabled", (PyCFunction)Sbk_QTableWidgetFunc_setSortingEnabled, METH_O},
    {"setVerticalHeaderItem", (PyCFunction)Sbk_QTableWidgetFunc_setVerticalHeaderItem, METH_VARARGS},
    {"setVerticalHeaderLabels", (PyCFunction)Sbk_QTableWidgetFunc_setVerticalHeaderLabels, METH_O},
    {"sortItems", (PyCFunction)Sbk_QTableWidgetFunc_sortItems, METH_VARARGS|METH_KEYWORDS},
    {"supportedDropActions", (PyCFunction)Sbk_QTableWidgetFunc_supportedDropActions, METH_NOARGS},
    {"takeHorizontalHeaderItem", (PyCFunction)Sbk_QTableWidgetFunc_takeHorizontalHeaderItem, METH_O},
    {"takeItem", (PyCFunction)Sbk_QTableWidgetFunc_takeItem, METH_VARARGS},
    {"takeVerticalHeaderItem", (PyCFunction)Sbk_QTableWidgetFunc_takeVerticalHeaderItem, METH_O},
    {"verticalHeaderItem", (PyCFunction)Sbk_QTableWidgetFunc_verticalHeaderItem, METH_O},
    {"visualColumn", (PyCFunction)Sbk_QTableWidgetFunc_visualColumn, METH_O},
    {"visualItemRect", (PyCFunction)Sbk_QTableWidgetFunc_visualItemRect, METH_O},
    {"visualRow", (PyCFunction)Sbk_QTableWidgetFunc_visualRow, METH_O},

    {0} // Sentinel
};

} // extern "C"

static void* Sbk_QTableWidgetSpecialCastFunction(void* obj, SbkObjectType* desiredType)
{
    QTableWidget* me = reinterpret_cast<QTableWidget*>(obj);
    if (desiredType == reinterpret_cast<SbkObjectType*>(SbkPySide_QtGuiTypes[SBK_QTABLEVIEW_IDX]))
        return static_cast<QTableView*>(me);
    else if (desiredType == reinterpret_cast<SbkObjectType*>(SbkPySide_QtGuiTypes[SBK_QABSTRACTITEMVIEW_IDX]))
        return static_cast<QAbstractItemView*>(me);
    else if (desiredType == reinterpret_cast<SbkObjectType*>(SbkPySide_QtGuiTypes[SBK_QABSTRACTSCROLLAREA_IDX]))
        return static_cast<QAbstractScrollArea*>(me);
    else if (desiredType == reinterpret_cast<SbkObjectType*>(SbkPySide_QtGuiTypes[SBK_QFRAME_IDX]))
        return static_cast<QFrame*>(me);
    else if (desiredType == reinterpret_cast<SbkObjectType*>(SbkPySide_QtGuiTypes[SBK_QWIDGET_IDX]))
        return static_cast<QWidget*>(me);
    else if (desiredType == reinterpret_cast<SbkObjectType*>(SbkPySide_QtCoreTypes[SBK_QOBJECT_IDX]))
        return static_cast<QObject*>(me);
    else if (desiredType == reinterpret_cast<SbkObjectType*>(SbkPySide_QtGuiTypes[SBK_QPAINTDEVICE_IDX]))
        return static_cast<QPaintDevice*>(me);
    return me;
}


// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QTableWidget_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtGui.QTableWidget",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QTableWidget_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             0,
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QTableWidget_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern

static SbkObjectType* Sbk_QTableWidget_typeDiscovery(void* cptr, SbkObjectType* instanceType)
{
    if (instanceType == reinterpret_cast<SbkObjectType*>(Shiboken::SbkType<QObject >()) && dynamic_cast<QTableWidget*>(reinterpret_cast<QObject*>(cptr)))
        return &Sbk_QTableWidget_Type;
    if (instanceType == reinterpret_cast<SbkObjectType*>(Shiboken::SbkType<QPaintDevice >()) && dynamic_cast<QTableWidget*>(reinterpret_cast<QPaintDevice*>(cptr)))
        return &Sbk_QTableWidget_Type;
    return 0;
}


void init_QTableWidget(PyObject* module)
{
    SbkPySide_QtGuiTypes[SBK_QTABLEWIDGET_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QTableWidget_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QTableWidget_Type);
    Shiboken::ObjectType::setSubTypeInitHook(&Sbk_QTableWidget_Type, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(&Sbk_QTableWidget_Type, &QTableWidget::staticMetaObject);    Sbk_QTableWidget_Type.super.ht_type.tp_base = SbkPySide_QtGuiTypes[SBK_QTABLEVIEW_IDX];
    MultipleInheritanceInitFunction func;
    func = Shiboken::ObjectType::getMultipleIheritanceFunction(reinterpret_cast<SbkObjectType*>(SbkPySide_QtGuiTypes[SBK_QWIDGET_IDX]));
    Shiboken::ObjectType::setMultipleIheritanceFunction(&Sbk_QTableWidget_Type, func);
    Shiboken::ObjectType::setCastFunction(&Sbk_QTableWidget_Type, &Sbk_QTableWidgetSpecialCastFunction);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QTableWidget_Type, &Shiboken::callCppDestructor<QTableWidget >);
    if (PyType_Ready((PyTypeObject*)&Sbk_QTableWidget_Type) < 0)
        return;

    // Fill type discovery information
    Shiboken::ObjectType::setTypeDiscoveryFunction(&Sbk_QTableWidget_Type, &Sbk_QTableWidget_typeDiscovery);
    Shiboken::BindingManager& bm = Shiboken::BindingManager::instance();
    bm.addClassInheritance(reinterpret_cast<SbkObjectType*>(SbkPySide_QtGuiTypes[SBK_QTABLEVIEW_IDX]), &Sbk_QTableWidget_Type);

    Shiboken::ObjectType::setOriginalName(&Sbk_QTableWidget_Type, "QTableWidget*");
    PyModule_AddObject(module, "QTableWidget",
        ((PyObject*)&Sbk_QTableWidget_Type));

    // Initialize signals
    PySideSignal* signal_item;

    signal_item = PySide::Signal::newObject("currentItemChanged", "QTableWidgetItem*,QTableWidgetItem*", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QTableWidget_Type, "currentItemChanged", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("itemChanged", "QTableWidgetItem*", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QTableWidget_Type, "itemChanged", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("itemDoubleClicked", "QTableWidgetItem*", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QTableWidget_Type, "itemDoubleClicked", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("itemClicked", "QTableWidgetItem*", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QTableWidget_Type, "itemClicked", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("cellDoubleClicked", "int,int", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QTableWidget_Type, "cellDoubleClicked", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("itemActivated", "QTableWidgetItem*", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QTableWidget_Type, "itemActivated", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("cellActivated", "int,int", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QTableWidget_Type, "cellActivated", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("cellChanged", "int,int", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QTableWidget_Type, "cellChanged", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("cellClicked", "int,int", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QTableWidget_Type, "cellClicked", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("itemPressed", "QTableWidgetItem*", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QTableWidget_Type, "itemPressed", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("cellPressed", "int,int", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QTableWidget_Type, "cellPressed", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("itemSelectionChanged", "void", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QTableWidget_Type, "itemSelectionChanged", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("currentCellChanged", "int,int,int,int", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QTableWidget_Type, "currentCellChanged", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("itemEntered", "QTableWidgetItem*", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QTableWidget_Type, "itemEntered", signal_item);
    Py_DECREF((PyObject*) signal_item);
    signal_item = PySide::Signal::newObject("cellEntered", "int,int", NULL);
    PySide::Signal::addSignalToWrapper(&Sbk_QTableWidget_Type, "cellEntered", signal_item);
    Py_DECREF((PyObject*) signal_item);


    Shiboken::TypeResolver::createObjectTypeResolver<QTableWidget >("QTableWidget*");
    Shiboken::TypeResolver::createObjectTypeResolver<QTableWidget >(typeid(QTableWidget).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QTableWidget >(typeid(QTableWidgetWrapper).name());
    PySide::initQtMetaType<QTableWidget* >();
}

